(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    553020,      14244]*)
(*NotebookOutlinePosition[    553729,      14269]*)
(*  CellTagsIndexPosition[    553685,      14265]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CurvesGraphics", "Title"],

Cell[TextData[{
  "for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " up to version 5.2"
}], "Subtitle"],

Cell[TextData[{
  "By ",
  ButtonBox["Gianluca Gorni",
    ButtonData:>{
      URL[ "http://www.dimi.uniud.it/~gorni"], None},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["Department of Mathematics and Computer Science",
    ButtonData:>{
      URL[ "http://www.dimi.uniud.it"], None},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["University of Udine",
    ButtonData:>{
      URL[ "http://web.uniud.it"], None},
    ButtonStyle->"Hyperlink"],
  ", Italy. Latest revision: 2008-09-07."
}], "Text"],

Cell[TextData[{
  "The package defined in this notebook adds the following capabilities to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics:"
}], "Text"],

Cell[TextData[{
  StyleBox["easily",
    FontSlant->"Italic"],
  " placing ",
  StyleBox["arrows along curves",
    FontWeight->"Bold"],
  " in 2D or 3D space along the curves produced by  ",
  ButtonBox["Plot",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["ParametricPlot",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["ParametricPlot3D",
    ButtonStyle->"RefGuideLink"],
  ", and ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"],
  ", and along the solutions to differential equations given by ",
  ButtonBox["NDSolve",
    ButtonStyle->"RefGuideLink"],
  ";"
}], "Text",
  CellDingbat->"\[FilledCircle]",
  CellMargins->{{100, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "drawing ",
  StyleBox["parametric or contour curves, or text, on a surface in 3D space, \
or the intersection curve of two surfaces,",
    FontWeight->"Bold"],
  " all curves with optional arrows along them."
}], "Text",
  CellDingbat->"\[FilledCircle]",
  CellMargins->{{100, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Number, positions, size, shape, style, color of the arrows and of \
the curves are customizable through options. The default values of the \
options have been chosen to give pleasing results in most typical cases that \
I could think of, with hardly any tweaking.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Warning:",
    FontWeight->"Bold"],
  " The following two features of this package"
}], "Text"],

Cell["3D arrows and 3D text", "Text",
  TextAlignment->Center],

Cell[TextData[{
  "will not work unless you have installed ",
  ButtonBox["David Park",
    ButtonData:>{
      URL[ "http://home.earthlink.net/~djmp/"], None},
    ButtonStyle->"Hyperlink"],
  "'s ",
  StyleBox["DrawGraphics", "Input"],
  " package, which costs 50 US Dollars; see the page ",
  ButtonBox["http://home.earthlink.net/~djmp/Mathematica.html",
    ButtonData:>{
      URL[ "http://home.earthlink.net/~djmp/Mathematica.html"], None},
    ButtonStyle->"Hyperlink"],
  ", scrolling down to the section on ",
  StyleBox["the DrawGraphics Paradigm",
    FontSlant->"Italic"],
  ". ",
  StyleBox["DrawGraphics", "Input"],
  " is a ",
  StyleBox["must",
    FontSlant->"Italic"],
  " for anyone making serious pictures with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CurvesGraphics", "Input"],
  " uses internally ,and is integrated with, ",
  StyleBox["DrawGraphics", "Input"],
  ". However, once you have ",
  StyleBox["DrawGraphics", "Input"],
  " properly installed, you can proceed to try ",
  StyleBox["CurvesGraphics", "Input"],
  " and don't need to learn ",
  StyleBox["DrawGraphics", "Input"],
  " usage first, for most purposes."
}], "Text"],

Cell[TextData[{
  "If you don't have ",
  StyleBox["DrawGraphics", "Input"],
  " on your machine, this ",
  StyleBox["CurvesGraphics", "Input"],
  " package should run anyway, simply ignoring 3D arrows and 3D text with a \
warning message."
}], "Text"],

Cell[TextData[{
  StyleBox["Instructions",
    FontWeight->"Bold"],
  ": The package is embedded in this notebook file. You load the package by \
clicking on the following button (whose effect is the same as the menu \
command \"Evaluate Initialization\"), and then you can evaluate the tutorial \
examples, and make your own variations. Read on for instruction on how to \
make a more permanent installation."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Button[
      StyleForm["\<Click here to load package!\>", 
        FontColor \[Rule] RGBColor[1, 0, 0], FontSize \[Rule] 16, 
        FontWeight -> "\<Bold\>"], 
      ButtonFunction \[RuleDelayed] 
        FrontEndExecute[FrontEndToken["\<EvaluateInitialization\>"]], 
      ButtonEvaluator \[Rule] None, Active \[Rule] True]\)], "Input",
  CellOpen->False],

Cell[BoxData[
    FormBox[
      ButtonBox[
        TagBox[
          StyleBox["\<\"Click here to load package!\"\>",
            FontSize->16,
            FontWeight->"Bold",
            FontColor->RGBColor[1, 0, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0], FontSize -> 16, 
            FontWeight -> "Bold"]&)],
        ButtonFunction:>FrontEndExecute[ 
            FrontEndToken[ "EvaluateInitialization"]],
        ButtonEvaluator->None,
        Active->True], TraditionalForm]], "Output",
  Editable->False,
  TextAlignment->Center]
}, Open  ]],

Cell[CellGroupData[{

Cell["Installation instructions and disclaimers", "Subsubtitle"],

Cell[TextData[{
  "This notebook is not meant for absolute beginners of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". It assumes some familiarity with notebooks and with the syntax of such \
basic standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands as ",
  ButtonBox["Plot",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["ParametricPlot",
    ButtonStyle->"RefGuideLink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Instructions for permanent installation of the package.",
    FontWeight->"Bold"],
  " If you like this package and wish to be able to load it the same way as \
with standard packages, do as follows: with the help of the ",
  ButtonBox["Option Inspector",
    ButtonStyle->"RefGuideLink"],
  " reset the notebook option  ",
  ButtonBox["AutoGeneratedPackage",
    ButtonStyle->"RefGuideLink"],
  " to ",
  StyleBox["Automatic", "Input"],
  ". Alternatively, evaluate the following cell:"
}], "Text"],

Cell[BoxData[
    \(SetOptions[InputNotebook[], 
      AutoGeneratedPackage \[Rule] Automatic]\)], "Input"],

Cell[TextData[{
  "Then save the notebook. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will generate a new package file called ",
  StyleBox["CurvesGraphics.m", "Input"],
  " inside the same directory as this notebook file. Then you should place \
this new ",
  StyleBox["CurvesGraphics.m", "Input"],
  " file somewhere ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will find it, for example in the directory that you will get from \
evaluating the following command:"
}], "Text"],

Cell[BoxData[
    \(ToFileName[{$UserAddOnsDirectory, "\<Applications\>"}]\)], "Input"],

Cell[TextData[{
  "See also the section ",
  ButtonBox["Installing New Add-ons",
    ButtonStyle->"AddOnsLink"],
  " in the on-line help. If the installation is done correctly you will be \
able to load the package when you need it with the command"
}], "Text"],

Cell[BoxData[
    \(Needs["\<CurvesGraphics`\>"]\)], "Input"],

Cell["\<\
If you call any function of the package without loading it first, \
you will get obscure error messages, and your code won't work. If you plan to \
use the package somewhat more than sporadically, you may consider pre-loading \
the functions automatically every time you start up the kernel. This \
pre-loading takes almost no memory and no time, and it shoud be trouble-free, \
except in the unfortunate case you load another package that happened to \
define functions with the very same names. Settin up the pre-loading is easy: \
evaluate the following command:\
\>", "Text"],

Cell[BoxData[
    \(ToFileName[{$UserAddOnsDirectory, "\<Kernel\>"}, "\<init.m\>"]\)], \
"Input"],

Cell[TextData[{
  "It will give you the location of the kernel ",
  StyleBox["init.m", "Input"],
  " file, (The file may lying in a hidden directory: make it visible then; if \
you don't know how, ask for help). Then open the file and  append to it this \
following text:"
}], "Text"],

Cell[BoxData[
    \(DeclarePackage["\<CurvesGraphics`\>", {"\<Arrow3DColor\>", \
"\<Arrow3DEdgeForm\>", "\<ArrowDensity\>", "\<ArrowPositions\>", \
"\<ArrowsAcrossSubdivisions\>", "\<ArrowShaftLength\>", "\<ClosedCurve\>", \
"\<CurveOnSurface\>", "\<DrawCurveOnSurface3D\>", "\<DrawSolution\>", \
"\<EvaluateOnCoefficients\>", "\<FilledClosedCurve\>", "\<GridPoints\>", \
"\<HamiltonianPlot\>", "\<HowManyArrows\>", "\<InitialPoints\>", \
"\<LevelDraw3D\>", "\<LevelPlot3D\>", "\<LinearClip\>", \
"\<LinearClipDraw3D\>", "\<LinearClipPlot3D\>", "\<LinearPhasePlot\>", \
"\<LinearPhasePlot2D\>", "\<ListPlotStyle\>", "\<NDSolvePlot\>", \
"\<NotableLineStyle\>", "\<NumberOfTrajectories\>", "\<Oriented\>", \
"\<OrientedParametricPlot\>", "\<OrientedParametricPlot3D\>", "\<OrientedPlot\
\>", "\<OrientedPlot3D\>", "\<ParametricTrigInterpolation\>", "\<Period\>", "\
\<PhaseDraw\>", "\<PhasePlot\>", "\<PlotCurveOnSurface3D\>", \
"\<PlotSolution\>", "\<PolynomialLevelSetTrigInterpolation\>", \
"\<PrepareForSlices\>", "\<ProjectAt\>", "\<ReverseOrientation\>", \
"\<ShowCurves\>", "\<ShowField\>", "\<ShowFormula\>", "\<ShowListPlot\>", \
"\<ShowProjectedLevelSets\>", "\<ShowSurface\>", "\<ShowTimesListQ\>", \
"\<SliceSurface\>", "\<SliceSurfaceDraw3D\>", "\<SliceSurfacePlot3D\>", \
"\<SurfaceIntersectionDraw3D\>", "\<SurfaceIntersectionPlot3D\>", \
"\<SurfaceSelfIntersectionDraw3D\>", "\<SurfaceSelfIntersectionPlot3D\>", \
"\<SurfaceStyle\>", "\<TrigInterpolation\>", "\<TrigInterpolationDraw\>", \
"\<TrigInterpolationParametricDraw\>", \
"\<TrigInterpolationParametricDraw3D\>", \
"\<TrigInterpolationParametricPlot\>", \
"\<TrigInterpolationParametricPlot3D\>", "\<TrigInterpolationPlot\>", \
"\<WriteReport\>"}]\)], "Input"],

Cell[TextData[{
  "Save the ",
  StyleBox["init.m", "Input"],
  " file using the menu item ",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(Save\ As\ \(Special : \ Text\)\),
          ButtonStyle->"OtherInformationLink"], TraditionalForm]]],
  ", (NOT the simple \"",
  ButtonBox["Save",
    ButtonStyle->"OtherInformationLink"],
  "\", be careful!), and you are all set. From now on, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will automatically load the package whenever it meets one of its \
functions in your code."
}], "Text"],

Cell[TextData[{
  StyleBox["Disclaimers",
    FontWeight->"Bold"],
  ". I wrote the package for myself and for anybody interested. I make no \
guarantee of any kind. For example, I tried to make the program correct and \
easy to use,  but I gave only marginal concern to speed. I doubt whether the \
program may be practical in a large-scale graphics project, and I never tried \
anyway. Also, bad-input handling and error messages would deserve more work.\n\
This package adds new options to the following built-in commands: ",
  ButtonBox["Plot",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["ParametricPlot",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["ParametricPlot3D",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"],
  ". Their new functionality is triggered by setting ",
  StyleBox["Oriented\[Rule]True", "Input"],
  ". Similarly, the existing  ",
  ButtonBox["NDSolve",
    ButtonStyle->"RefGuideLink"],
  "  will plot the solution when given the new option ",
  StyleBox["PlotSolution\[Rule]True", "Input"],
  ". This design choice makes the package easier to use, in my opinion, but \
it may break pre-existing code. However, as far as I understand the behaviour \
of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ",  I think that you are unlikely to have trouble if your old code only \
relies on built-in commands and options."
}], "Text"],

Cell[TextData[{
  StyleBox["Wish list",
    FontWeight->"Bold"],
  ". You will find that my 3D routines are rather slow, specially ",
  StyleBox["SurfaceIntersectionPlot", "Input"],
  ". I suppose this is an area where parallel processing could help a lot. \
Unfortunately, for the time being I don't have the equipment and the \
expertise.\nI have a routine to slice a surface with a plane. I won't be \
completely satisfied until I have a function that cuts a surface with another \
surface. Next time I have some free time...\nRight now I can position an \
arrow along a curve at 1/2 its length, or 2/3 of its length, or in general at \
some fraction of its length. I don't give a way to position it in absolute \
terms, say, at 1/3 of a unit length from the first end point."
}], "Text"],

Cell[TextData[{
  StyleBox["Obsolete versions:",
    FontWeight->"Bold"],
  " the forbears of ",
  StyleBox["CurvesGraphics", "Input"],
  " are still available for download: ",
  ButtonBox["ODEplot",
    ButtonData:>{
      URL[ "http://www.dimi.uniud.it/gorni/Mma/ODEplot.nb"], None},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["LevelPlot3D",
    ButtonData:>{
      URL[ "http://www.dimi.uniud.it/gorni/Mma/LevelPlot3D.nb"], None},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["CurveOnSurface",
    ButtonData:>{
      URL[ "http://www.dimi.uniud.it/gorni/Mma/CurveOnSurface.nb"], None},
    ButtonStyle->"Hyperlink"],
  ". They don't need ",
  StyleBox["DrawGraphics", "Input"],
  ". They have no 3D-arrow capability, and the user interface is different. I \
tried to make ",
  StyleBox["DrawGraphics", "Input"],
  " backward compatible with the older syntax, but I make no guarantee."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Versions History", "Subsubtitle"],

Cell[TextData[{
  "2008-09-07: Added a version check and a warning for users of Mathematica \
version 6 or later.\n2008-08-09: Corrected a bug in plotting the solution of \
a differential equation with a single unknown function.\n2008-02-07: \
Corrected a typo in the documentation.\n2007-03-16: Corrected the handling of \
arrows on zero-length lines.\n2007-03-12: Support for ",
  ButtonBox["Arrow",
    ButtonStyle->"AddOnsLink"],
  " has been added to ",
  StyleBox["PlotCurveOnSurface3D", "Input"],
  ". As a consequence, the output of ",
  StyleBox["PhasePlot", "Input"],
  " can be draped onto a surface together with its arrows.\n2006-12-14: the \
code for ",
  StyleBox["PlotSolution", "Input"],
  " in ",
  StyleBox["NDSolve", "Input"],
  " and for ",
  StyleBox["PhasePlot", "Input"],
  " now plots the solutions on the time domain returned by the ",
  ButtonBox["InterpolatingFunction",
    ButtonStyle->"RefGuideLink"],
  " solution, and not on the original time domain required by the user.\n\
2006-12-13: added a new example in the documentation.\n2006-12-03: corrected \
a glitch in the documentation.\n2006-06-26: corrected a glitch in the \
documentation.\n2005-01-09: rules added to ",
  StyleBox["LinearClipPlot3D", "Input"],
  " so that it now accepts combinations of inequalities, such as ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x \[LessEqual] 1\)]],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`x < y < x + z \[And] z \[LessEqual] 1\)]],
  ", as input. Extended the documentation on ",
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " for contour plots. LinearPhasePlot renamed as ",
  StyleBox["LinearPhasePlot2D", "Input"],
  ", for more consistency, and retouched to allow for column vector field as \
input.\n2005-04-18: retouched the installation instructions.\n2005-06-02: \
retouched the ",
  StyleBox["TrigInterpolation", "Input"],
  " functions so that you can now give ",
  ButtonBox["Method",
    ButtonStyle->"RefGuideLink"],
  " as an option to choose how ",
  ButtonBox["LinearSolve",
    ButtonStyle->"RefGuideLink"],
  " will handle the under-determined linear systems that turn out in the \
calculations. For floating-point starting data the default method gives \
unpleasing results under ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.1. Also, activated the dormant ShowTimesListQ option. Updated the \
documentation accordingly.\n2005-06-10: fixed small bug in ",
  StyleBox["TrigInterpolationParametricPlot", "Input"],
  ".\n2005-07-10: added instructions for package pre-loading. Also, from now \
on, ",
  StyleBox["TrigInterpolationParametricDraw", "Input"],
  " and its other ",
  StyleBox["Draw", "Input"],
  " siblings won't ignore the options ",
  StyleBox["ShowFormula\[Rule]True", "Input"],
  " and ",
  StyleBox["ShowTimesList\[Rule]True", "Input"],
  ".\n2005-07-21: retouched one-dimensional ",
  StyleBox["TrigInterpolation", "Input"],
  " functions, so that they accept the syntax of both ",
  ButtonBox["Interpolation",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["InterpolatingPolynomial",
    ButtonStyle->"RefGuideLink"],
  ".\n",
  StyleBox["2005-09-25: A major new feature:",
    FontColor->RGBColor[1, 0, 0]],
  " the whole new function ",
  StyleBox["SurfaceIntersectionPlot3D", "Input"],
  " added, with the companions ",
  StyleBox["SurfaceSelfIntersectionPlot3D", "Input"],
  " and the ",
  ButtonBox["Draw",
    ButtonStyle->"AddOnsLink"],
  " equivalents. The two new options ",
  StyleBox["ShowSurface", "Input"],
  " and ",
  StyleBox["ShowCurves", "Input"],
  " are added to all relevant functions.\n2005-10-24: Corrected a couple of \
trivial errors in ",
  StyleBox["SurfaceIntersectionPlot3D", "Input"],
  "  and ",
  StyleBox["LevelPlot3D", "Input"],
  " that I had introduced with the latest revisions, and a pair of errors in \
the documentation.\n",
  StyleBox["2005-12-11: New feature: ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " will now draw arbitrary ",
  ButtonBox["Line",
    ButtonStyle->"RefGuideLink"],
  "s, ",
  ButtonBox["Point",
    ButtonStyle->"RefGuideLink"],
  "s and specially ",
  ButtonBox["Text",
    ButtonStyle->"RefGuideLink"],
  " onto your parametric surface. Also, all unnecessary dependencies from \
DrawGraphics have been removed. Assorted fixes."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package code"
}], "Subtitle"],

Cell[TextData[{
  "This is the program. It is meant to be read only by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programmers."
}], "Text"],

Cell[CellGroupData[{

Cell["Preliminaries and usage documentation", "Subsubtitle"],

Cell[BoxData[
    \(\(If[$VersionNumber \[GreaterEqual] 6, 
        Print["\<Sorry, this version of CurvesGraphics does not work for \
Mathematica version 6 or later. Check for an update on the web \
site\>"]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Off[General::"\<spell\>"]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Off[General::"\<spell1\>"]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(BeginPackage["\<CurvesGraphics`\>", "\<Utilities`FilterOptions`\>", "\
\<Graphics`Arrow`\>", "\<Graphics`Colors`\>", "\<Graphics`FilledPlot`\>", \
"\<Graphics`PlotField`\>", "\<Algebra`InequalitySolve`\>", 
        If[Length@
              FileNames["\<*DrawingMaster.m\>", {$AddOnsDirectory, \
$UserAddOnsDirectory, $UserBaseDirectory}, Infinity] > 
            0, "\<DrawGraphics`DrawingMaster`\>", 
          Sequence @@ {}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Unprotect["\<`*\>"];\)\), "\[IndentingNewLine]", 
    \(\(ClearAll["\<`*\>"];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CurvesGraphics::"\<Version problem\>" = "\<The CurvesGraphics package \
is written for Mathematica version up to 5.2. It does not work on later \
versions. Check the web site for updates\>";\)\)], "Input",
  InitializationCell->True,
  CellChangeTimes -> {{3.4297817801862392`*^9, 3.429781824573715*^9}}],

Cell[BoxData[
    \(\(If[$VersionNumber \[GreaterEqual] 6, 
        Message[CurvesGraphics::"\<Version problem\>"]];\)\)], "Input",
  InitializationCell->True,
  CellChangeTimes -> {{3.429781833239223*^9, 3.4297818595362988`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Oriented", "Input"],
  ", and its ancillary options"
}], "Subsection"],

Cell[BoxData[
    \(\(Oriented::usage = "\<Oriented is an option for Plot, ParametricPlot, \
Plot3D, ParametricPlot3D, ContourPlot, PlotCurveOnSurface, \
TrigInterpolationPlot, TrigInterpolationParametricPlot, NDSolve, PhasePlot, \
LinearPhasePlot2D, LevelPlot3D, SliceSurfacePlot, and their Draw \
counterparts. With Oriented->True the curves will come out with arrows along \
them; 3D arrows need the package DrawGraphics.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Oriented::"\<DrawGraphics not installed\>" = "\<The DrawGraphics \
package cannot be found in $AddOnsDirectory, $UserAddOnsDirectory, \
$UserBaseDirectory. 3D arrows and 3D texts will be ignored.\>";\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(HowManyArrows::usage = "\<HowManyArrows is an option for Plot, \
ParametricPlot, ParametricPlot3D, and other functions that accept the \
Oriented option, that directs how many arrows to add along the curve. The \
default is HowManyArrows->Automatic, which is based on the ratio of the \
length of the curve(s) to the longest side of the smallest Rectangle (or \
Cuboid) that contains the curve(s) (see also ArrowDensity). When more than \
one curve is drawn at the same time, HowManyArrows accepts a list of values, \
that will be applied cyclically to the curves.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ArrowPositions::usage = "\<ArrowPositions->{p1,p2,...} is an option \
for Plot, ParametricPlot, ParametricPlot3D, and other functions that accept \
the Oriented option (ContourPlot not included), that directs where to draw \
the arrows heads along the curve. The values p1,p2,... are supposed to be \
numbers between 0 and 1 (otherwise they are normalized automatically), and \
refer to the curve parameterized by arc length. The default is \
ArrowPositions->Automatic, under which the lengths of the arcs between the \
first or last arrow and the end point is d, while the arcs between successive \
arrow heads are 2d. This arrangement is best for closed cuves, as all \
successive arrows are separated by arcs of the same length.\>";\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(ReverseOrientation::usage = "\<ReverseOrientation is an option for \
Plot, ParametricPlot, ParametricPlot3D, and other functions that accept the \
Oriented option. When set to True, the orientation of the arrows gets \
reversed. The default is ReverseOrientation->False.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ArrowDensity::usage = "\<ArrowDensity is an option for Plot, \
ParametricPlot, ParametricPlot3D, and other functions that accept the \
Oriented option, influencing how many arrows to draw along the lines. The \
number of arrows increases with the value of ArrowDensity. The default value \
is ArrowDensity->1.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ArrowShaftLength::usage = "\<ArrowShaftLength is an option for Plot, \
ParametricPlot, ParametricPlot3D, and other functions that accept the \
Oriented option. It sets how long the arrow shafts should be, in the original \
coordinates of the graph (not scaled). Do not confuse this with the arrow \
head length. You may need to tweak ArrowShaftLength if your lines have hight \
curvature, or the AspectRatio is far from Automatic.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ArrowsAcrossSubdivisions::usage = "\<ArrowsAcrossSubdivisions is an \
option for Plot, ParametricPlot, ParametricPlot3D, and other functions that \
accept the Oriented option. The default is ArrowsAcrossSubdivisions->True. \
When set to False, each arrow shaft placed along the curve will be contained \
in a single one of the straight line segments the Line is made of. This may \
help improve the look of a picture. Try also ArrowShaftLength.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Arrow3DColor::usage = "\<Arrow3DColor is an option for \
ParametricPlot3D, LevelPlot3D and other functions that draw 3D arrows. The \
default is Arrow3DColor->Automatic,which means the same color as the curve \
along which the arrow is placed, typically black. Arrow3DColor->{} will make \
3D arrows with no intrinsic color, just like any other surface.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Arrow3DEdgeForm::usage = "\<Arrow3DEdgeForm is an option for \
ParametricPlot3D, LevelPlot3D and other functions that draw 3D arrows. It \
instructs how to draw the edges of the triangles the 3D arrows are made of. \
The default is Arrow3DEdgeForm\[Rule]EdgeForm[], that is, edges are not \
drawn.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "The \"engines\" that power the ",
  StyleBox["Oriented", "Input"],
  " options in the various situations:"
}], "Subsection"],

Cell[BoxData[
    \(\(OrientedPlot::usage = "\<OrientedPlot[f[x],{x,xMin,xMax},opts] makes \
a Plot and then adds arrows along the curve. Specific options are \
HowManyArrows, ArrowPositions, ReverseOrientation. It also accepts options \
from Plot and Graphics`Arrow`. By default HeadScaling->Automatic and \
HeadLength->1/20.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrientedParametricPlot::usage = \
"\<OrientedParametricPlot[{x[t],y[t]},{t,tMin,tMax},opts] makes a \
ParametricPlot and then adds arrows along the curve. Specific options are \
HowManyArrows, ArrowPositions, ReverseOrientation. It also accepts options \
from ParametricPlot and Graphics`Arrow`. By default HeadScaling->Automatic \
and HeadLength->1/20.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrientedParametricPlot3D::usage = \
"\<OrientedParametricPlot3D[{x[t],y[t],z[t]},{t,tMin,tMax},opts] makes a \
ParametricPlot3D and then adds arrows along the curve. Specific options \
include HowManyArrows, ArrowPositions, ReverseOrientation. It also accepts \
options from ParametricPlot3D. DrawGraphics`DrawingArrows`. \
HeadScaling3D->Absolute by default and HeadLength3D->1/20.
OrientedParametricPlot3D[{x[t,u],y[t,u],z[t,u]},{t,tMin,tMax},{u,uMin,uMax},\
opts] makes a ParametricPlot3D of the surface, and then adds arrows along its \
boundary, in a counterclockwise (in the t-u space) direction.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrientedPlot3D::usage = \
"\<OrientedParametricPlot3D[f[x,y],{x,xMin,xMax},{y,yMin,yMax},opts] makes a \
Plot3D of the surface, and then adds arrows along its boundary, in a \
counterclockwise (in the t-u space) direction.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(HamiltonianPlot::usage = \
"\<HamiltonianPlot[f[x,y],{x,xMin,xMax},{y,yMin,yMax},opts] is the function \
that takes over ContourPlot when this has the option Oriented->True\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigInterpolation", "Subsection"],

Cell[BoxData[
    \(\(TrigInterpolation::usage = "\<TrigInterpolation[data,var] attempts to \
find a trigonometric function that interpolates exactly between the data. The \
data format is the same as for InterpolatingPolynomial. Options are \
EvaluateOnCoefficients and Period\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(EvaluateOnCoefficients::usage = "\<EvaluateOnCoefficients is an \
option for TrigInterpolation, TrigInterpolationPlot and similar. It specifies \
what transformation to make on the coefficients of the trigonometric \
expression. A typical value may be \
EvaluateOnCoefficients->Simplify.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Period::usage = "\<Period is an option for TrigInterpolation, \
TrigInterpolationPlot and similar. It specifies the (joint) period of the \
trigonometric functions that will make up the interpolation. The default is \
Period->Automatic\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ParametricTrigInterpolation::usage = \
"\<ParametricTrigInterpolation[data,t] attempts to find a trigonometric \
function that interpolates exactly between the data. The data structure is a \
list, of which each element is either a pair (or triplet) of numbers or a \
list of pairs (or triplets)\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationPlot::usage = \
"\<TrigInterpolationPlot[data,xMin,xMax,opts] attempts to find a \
trigonometric function that interpolates exactly between the data and then \
plots its graph between xMin and xMax. The data have the same syntax as for \
InterpolatingPolynomial. It takes the options from Plot and from \
TrigInterpolation, plus ShowFormula, ShowListPlot, ListPlotStyle.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationDraw::usage = \
"\<TrigInterpolationDraw[data,xMin,xMax,opts] is the DrawGraphics companion \
to TrigInterpolationPlot\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationParametricPlot::usage = \
"\<TrigInterpolationParametricPlot[data] is attempts to find a trigonometric \
function that interpolates exactly between the data and then plot its \
parametric graph. The data structure is a list, of which each element is \
either a pair (or triplet) of numbers or a list of pairs (or triplets). In \
case of pairs the plot will be 2-dimensional, otherwise it will be \
3-dimensional. With the option ClosedCurve->True the plot will be a closed \
curve (a loop). It takes also the options from Plot and from \
TrigInterpolation, plus ShowFormula, ShowListPlot, ListPlotStyle.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationParametricDraw::usage = \
"\<TrigInterpolationParametricDraw[data] is the DrawGraphics companion to \
TrigInterpolationParametricPlot\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationParametricPlot3D::usage = \
"\<TrigInterpolationParametricPlot3D[3Ddata,opts] is just \
TrigInterpolationParametricPlot but for 3D curves only. It is provided only \
for naming symmetry.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationParametricDraw3D::usage = \
"\<TrigInterpolationParametricDraw[data] is the DrawGraphics companion to \
TrigInterpolationParametricPlot3D\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PolynomialLevelSetTrigInterpolation::usage = \
"\<PolynomialLevelSetTrigInterpolation[2Ddata,t,x,y,opts] attempts to find a \
two-variable polynomial whose 0-level set interpolates the given data. The \
output will be a couple: the first element is the output of \
ParametricTrigInterpolation[2Ddata,t,opts], while the second element will be \
a polynomial in x and y.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ShowListPlot::usage = "\<ShowListPlot is an option for \
TrigInterpolationPlot and TrigInterpolationParametricPlot. When \
ShowListPlot->True, the data points will be displayed along the \
curve.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ListPlotStyle::usage = "\<ListPlotStyle is an option for \
TrigInterpolationPlot and TrigInterpolationParametricPlot. It specifies the \
style of the data points that are drawn when ShowListPlot is set to \
True\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ClosedCurve::usage = "\<ClosedCurve is an option for \
TrigInterpolationParametricPlot. The default is \
TrigInterpolationParametricPlot->False. When \
TrigInterpolationParametricPlot->True the curve will be closed (a \
loop).\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FilledClosedCurve::usage = "\<FilledClosedCurve is an option for \
TrigInterpolationParametricPlot, in the 2D case. The default is \
FilledClosedCurve->False. When FilledClosedCurve->True the curve will be \
closed (a loop) and it will be shown filled. The color is specified with the \
option Fills from Graphics`FilledPlot`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ShowFormula::usage = "\<ShowFormula is an option for \
TrigInterpolationPlot and TrigInterpolationParametricPlot. The default is \
ShowFormula->False. If ShowFormula->True, the output will be a couple with \
first the graphics output and then the output of TrigInterpolation or \
ParametricTrigInterpolation.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ShowTimesListQ::usage = "\<ShowTimesListQ is an option for \
OpenCurveInterpolation, ClosedCurveInterpolation and \
TrigInterpolationParametricPlot. The default is ShowTimesListQ->False. If \
ShowTimesListQ->True, the output will comprise a list of the times at which \
the parametric curve passes through the given points.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LevelPlot3D", "Input"],
  " and its companions:"
}], "Subsection"],

Cell[BoxData[
    \(\(LevelPlot3D::usage = \
\[IndentingNewLine]"\<LevelPlot3D[f,{x,x0,x1},{y,y0,y1}] draws a 3D plot of \
the function f with the level sets emphasized. You can control the number (or \
precise position) of level sets to be drawn with the option Contours. \
Example: LevelPlot3D[x^2+y^2,{x,-1,1},{y,-1,1},PlotPoints->11,Contours->5}].\>\
";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LevelDraw3D::usage = \
\[IndentingNewLine]"\<LevelDraw3D[f,{x,x0,x1},{y,y0,y1}] extract the Graphics \
primitives from LevelPlot3D, suppressing the display.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SliceSurfacePlot3D::usage = "\<SliceSurfacePlot3D[3DSurface, \
LinearForm,variables] draws on the surface the level sets of the LinearForm. \
You can control how many level sets (or their precise values) with the option \
Contours. Example: \
SliceSurfacePlot3D[Plot3D[Sin[x*y],{x,0,Pi},{y,0,Pi}],x+y,x,y,z].\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SliceSurface::usage = "\<SliceSurface[3DSurface, \
LinearForm,variables] is an obsolete name for SliceSurfacePlot3D, retained \
for backward compatibility.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SliceSurface = SliceSurfacePlot3D;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SliceSurfaceDraw3D::usage = "\<SliceSurfaceDraw3D[3DSurface, \
LinearForm,variables] is the DrawGraphics companion to \
SliceSurfacePlot3D.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipPlot3D::usage = "\<LinearClipPlot3D[3DSurface, \
LinearInequality,variables] shows the part of the surface that lies in the \
half-plane defined by the linear inequality. Example: \
LinearClipPlot3D[Plot3D[Sin[x*y],{x,0,Pi},{y,0,Pi}],x+y>=8z,x,y,z].\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClip::usage = "\<LinearClip[3DSurface, \
LinearInequality,variables] is an obsolete name for LinearClipPlot3D, \
retained for backward compatibility.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClip = LinearClipPlot3D;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipDraw3D::usage = "\<LinearClipDraw3D[3DSurface, \
LinearInequality,variables] is the DrawGraphics companion to \
LinearPlot3D].\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PrepareForSlices::usage = "\<PrepareForSlices is an option for \
LinearClipPlot3D, specifying whether to keep both the two parts of the \
surface when cutting with a plane. It can take the values True or \
False.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SurfaceStyle::usage = "\<SurfaceStyle is an option for \
SliceSurfacePlot3D and LevelPlot3D, containing the Graphis3D directives to \
affect the appearance of the surface.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ShowProjectedLevelSets::usage = "\<ShowProjectedLevelSets is an \
option for LevelPlot3D and SliceSurfacePlot3D. When set to True, the level \
sets will be shown both on the 3D surface and as orthogonally projected onto \
a horizontal plane (or onto a level plane of the linear form in the \
SliceSurfacePlot3D case). The z-level of the plane is controlled with \
ProjectAt. The default is ShowProjectedLevelSets->False\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ProjectAt::usage = "\<ProjectAt is an option for LevelPlot3D and \
SliceSurfacePlot3D. Together with ShowProjectedLevelSets->True, \
ProjectAt->realNumber tells at what z-level (or linear form level) to draw \
the projected level sets. The default is ProjectAt->0\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PlotCurveOnSurface", "Input"],
  " and its ",
  StyleBox["Draw", "Input"],
  " companion:"
}], "Subsection"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D::usage = \
\[IndentingNewLine]"\<PlotCurveOnSurface3D[surface,curve1,curve2,...,options] \
draws the curves on the surface adding plot points to the curve as to avoid \
disappearance of the curves behind the surface. The surface can be specified \
as in either Plot3D or ParametricPlot3D. The curves are expressed in the \
parameter space of the surface. Example: \
PlotCurveOnSurface3D[{x^2+y^2,{x,-1,1},{y,-1,1}},{{Cos[t],Sin[t]},{t,0,2Pi},\
PlotPoints->41}].\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CurveOnSurface::usage = \
\[IndentingNewLine]"\<CurveOnSurface[surface,curve1,curve2,...,options] is an \
obsolete name for PlotCurveOnSurface3D. It is retained for backward \
compatibility.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D::"\<DrawGraphics not installed\>" = "\<The \
DrawGraphics package cannot be found in $AddOnsDirectory, \
$UserAddOnsDirectory, $UserBaseDirectory. 3D text will be ignored.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CurveOnSurface = PlotCurveOnSurface3D;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DrawCurveOnSurface3D::usage = \
\[IndentingNewLine]"\<DrawCurveOnSurface3D[surface,curve1,curve2,...,options] \
is the DrawGraphics companion to PlotCurveOnSurface3D.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SurfaceIntersectionPlot3D", "Subsection"],

Cell[BoxData[
    \(\(SurfaceIntersectionPlot3D::usage = \
\[IndentingNewLine]"\<SurfaceIntersectionPlot3D[surface1,surface2,options] \
draws the intersection curve of the two surfaces, optionally with arrows. It \
works also with three or more surfaces, drawing the pairwise \
intersections.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SurfaceSelfIntersectionPlot3D::usage = \
\[IndentingNewLine]"\<SurfaceSelfIntersectionPlot3D[surface,options] draws \
the self-intersection curve of a surface, optionally with arrows.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SurfaceIntersectionDraw3D::usage = \
\[IndentingNewLine]"\<SurfaceIntersectionDraw3D[surface1,surface2,options] \
extracts the graphics primitives from \
SurfaceIntersectionPlot3D[surface1,surface2,options].\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SurfaceSelfIntersectionDraw3D::usage = \
\[IndentingNewLine]"\<SurfaceSelfIntersectionDraw3D[surface1,surface2,options]\
 extracts the graphics primitives from \
SurfaceSelfIntersectionPlot3D[surface,options].\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ShowSurface::usage = \[IndentingNewLine]"\<ShowSurface is an options \
for SurfaceIntersectionPlot3D, SurfaceSelfIntersectionPlot3D, \
PlotCurveOnSurface3D, LevelPlot3D, SliceSurfacePlot3D, to control whether the \
surface is to be drawn or not.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ShowCurves::usage = \[IndentingNewLine]"\<ShowCurves is an options \
for SurfaceIntersectionPlot3D, SurfaceSelfIntersectionPlot3D, \
PlotCurveOnSurface3D, LevelPlot3D, SliceSurfacePlot3D, to control whether the \
curves are to be drawn or not.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PlotSolution for NDSolve", "Subsection"],

Cell[BoxData[
    \(\(NDSolvePlot::usage = "\<NDSolvePlot[differential equations,options] \
is the engine of NDSolve when given the option PlotSolution->True. It solves \
the equations with NDSolve and then draws a plot of the solution. For a \
planar system the plot has arrows on it. The output is a couple \
{Graphics,NDSolve output}. It takes all options of NDSolve and \
OrientedParametricPlot.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PlotSolution::usage = "\<PlotSolution is a new option for NDSolve. If \
it is set to True and the unknown functions are at most 3, then the output of \
NDSolve becomes a list of the form {solution, graph of the \
solution}\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DrawSolution::usage = "\<DrawSolution is a new option for NDSolve, \
the DrawGraphics companion to PlotSolution. If it is set to True and the \
unknown functions are at most 3, then the output of NDSolve becomes a list of \
the form {solution, graphics primitives of the graph of the \
solution}\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "LinearPhasePlot2D",
  " and ",
  StyleBox["PhasePlot", "Input"]
}], "Subsection"],

Cell[BoxData[
    \(\(LinearPhasePlot2D::usage = \
\[IndentingNewLine]"\<LinearPhasePlot2D[matrix,options] plots a phase \
portrait of the system of two differential equations \
{x'[t],y'[t]}==mat.{x[t],y[t]}. The matrix must be numeric and exact. The \
curves are drawn from the exact symbolic solutions of the system. Options are \
NotableLineStyle, NumberOfTrajectories, WriteReport, ShowField, Oriented, \
ArrowDensity. LinearPhasePlot2D also accepts all options for Graphics`Arrow` \
and Graphics. Example: LinearPhasePlot2D[{{1,2}},{-2,1}}].\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearPhasePlot::usage = \[IndentingNewLine]"\<LinearPhasePlot is the \
older name of LinearPhasePlot2D, retained for backward \
compatibility.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NotableLineStyle::usage = "\<NotableLineStyle is an option for \
LinearPhasePlot2D specifying how to highlight the straight lines that are of \
special significance for the system (either eigenspaces or principal \
directions). The default value is \
NotableLineStyle->RGBColor[1,0,0].\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NumberOfTrajectories::usage = "\<NumberOfTrajectories is an option \
for LinearPhasePlot2D that helps control how many trajectories to (attempt \
to) draw, approximately. The default value is NotableLineStyle->5.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(WriteReport::usage = "\<WriteReport is an option for \
LinearPhasePlot2D specifying whether to write the classification of the given \
system. The default value is WriteReport->True.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ShowField::usage = "\<ShowField is an option for PhasePlot, \
LinearPhasePlot2D and ContourPlot specifying whether to draw the direction \
field of the system (by means of the package Graphics`PlotField`) together \
with the trajectories. The default value is ShowField->False.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PhasePlot::usage = \
"\<PhasePlot[{f[x,y],g[x,y]},{x,xMin,xMax},{y,yMin,yMax},{tMin,tMax},options] \
makes a phase portrait of the system \
{x'[t]==f[x[t],y[t]],y'[t]==g[x[t],y[t]]}. Specific options are PlotPoints \
(that controls how many points there are in the initial values grid), \
InitialPoints, Oriented. It also accepts NDSolve, Graphics`Arrow` and \
Graphics options.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PhaseDraw::usage = \
"\<PhaseDraw[{f[x,y],g[x,y]},{x,xMin,xMax},{y,yMin,yMax},{tMin,tMax},options] \
is the DrawGraphics companion to PhasePlot.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(InitialPoints::usage = "\<InitialPoints is an option for PhasePlot: \
it takes as value a list of points in 2D or 3D that are to be the starting \
points for the trajectories.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GridPoints::usage = "\<GridPoints is an option for PhasePlot: it \
takes as value an integer or a list of two or three integers, stating the \
dimensions of the grid of starting points for the trajectories.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["tail", "Subsection"],

Cell[BoxData[
    \(\(Begin["\<`Private`\>"];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(OrientedCurve = Oriented;\)\), "\[IndentingNewLine]", 
    \(\(OrientedContour = Oriented;\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DrawGraphicsInstalledQ = 
        Length@FileNames["\<*DrawingMaster.m\>", {$AddOnsDirectory, \
$UserAddOnsDirectory, $UserBaseDirectory}, Infinity] > 0;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(If[DrawGraphicsInstalledQ, 
      Needs["\<DrawGraphics`DrawingMaster`\>"]]\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Arrow stuff", "Subsubtitle"],

Cell["Finding the length of a path:", "Text"],

Cell[BoxData[
    \(\(lineLength[pts_List] := 
        Apply[Plus, 
          Sqrt[Apply[Plus, Rest[pts - RotateRight[pts]]^2, 1]]];\)\)], "Input",\

  InitializationCell->True],

Cell["\<\
Finding the lengths of the subpaths obtained by taking the first \
1,2,3,... points of the given path:\
\>", "Text"],

Cell[BoxData[
    \(\(successiveLengths[pts_List] := 
        Map[lineLength, Rest[FoldList[Append, {}, pts]]];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "Parameterizing a path by arc length, taking some care not to get ",
  ButtonBox["Interpolation",
    ButtonStyle->"RefGuideLink"],
  " error messages because of duplicate parameter values:"
}], "Text"],

Cell[BoxData[
    \(\(byArcLength[pts_List] := 
        Module[{withoutDuplicates = 
              pts //. \(({a___, b_List, c_, d___} /; 
                      b \[Equal] c)\) \[RuleDelayed] {a, b, d}, 
            divisionPointsNo}, \[IndentingNewLine]divisionPointsNo = 
            Length[successiveLengths[
                  withoutDuplicates] //. {a___, b_List, b_, 
                    c___} \[RuleDelayed] {a, b, 
                    c}]; \[IndentingNewLine]Function[{t}, 
            Evaluate[
              Through[\(Map[
                    Interpolation[
                        Transpose[{successiveLengths[
                                withoutDuplicates], #}] //. \(({a___List, {b_?
                                    NumericQ, c_}, {b_, d_}, 
                                e___})\) \[RuleDelayed] {a, {b, c}, e}, 
                        InterpolationOrder \[Rule] 
                          If[divisionPointsNo > 1, 1, 0]] &, 
                    Transpose[withoutDuplicates]]\)[t]]]]];\)\)], "Input",
  InitializationCell->True],

Cell["Color functions:", "Text"],

Cell[BoxData[
    \(\(colorSpecPattern = _CMYColor | _CMYKColor | _GrayLevel | _Hue | \
_RGBColor;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Inserting arrow heads along a path in given positions (represented \
by fractions of the total arc length of the path):\
\>", "Text"],

Cell[BoxData[
    \(\(Options[insertArrows] = {ArrowShaftLength \[Rule] 1/1000, 
          Arrow3DColor \[Rule] Automatic, Arrow3DEdgeForm \[Rule] EdgeForm[], 
          ReverseOrientation \[Rule] False, 
          ArrowsAcrossSubdivisions \[Rule] True, 
          PlotStyle \[Rule] Automatic};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(insertArrows[pts_List, {}, opts___?OptionQ] := 
        Sequence @@ {};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(insertArrows[pts_List /; lineLength[pts] > $MachineEpsilon, 
          positions_List, 
          opts___?OptionQ] := \[IndentingNewLine]Module[{dim = 
              Length@\(First@pts\), el = lineLength[N@pts], revQ, acrossQ, 
            arw3Dedgfrm, arwDelta, pltSty, arw3Dclr, ptsFinal, par, 
            normalizedPlotPts, subdivisionInterval, arw, delta, arrowBase, 
            arrowTip}, \[IndentingNewLine]{revQ, acrossQ} = 
            Map[TrueQ, \({ReverseOrientation, 
                    ArrowsAcrossSubdivisions} /. {opts}\) /. 
                Options[insertArrows]]; \[IndentingNewLine]{arw3Dedgfrm, 
              arwDelta, pltSty, 
              arw3Dclr} = \({Arrow3DEdgeForm, ArrowShaftLength, PlotStyle, 
                  Arrow3DColor} /. {opts}\) /. 
              Options[insertArrows]; \[IndentingNewLine]pltSty = 
            Cases[pltSty, colorSpecPattern, {0, 1}]; \[IndentingNewLine]If[
            arw3Dclr === Automatic, \[IndentingNewLine]If[pltSty === {}, 
              arw3Dclr = GrayLevel[0], 
              arw3Dclr = Last[pltSty]]]; \[IndentingNewLine]If[
            Not[TrueQ[arwDelta > 0]], 
            arwDelta = 
              ArrowShaftLength /. 
                Options[insertArrows]]; \[IndentingNewLine]ptsFinal = 
            If[TrueQ[revQ], Reverse[pts], pts]; \[IndentingNewLine]par = 
            byArcLength[N@ptsFinal]; \[IndentingNewLine]normalizedPlotPts = 
            Flatten@Cases[
                  par /. InterpolatingFunction \[Rule] 
                      intFunc, \(intFunc[_, _, {s_}, ___]\)[___] \
\[RuleDelayed] s, {0, Infinity}, 1]/
              el; \[IndentingNewLine]subdivisionInterval[t_] := 
            First@Cases[
                Partition[normalizedPlotPts, 2, 1], {a_, b_} /; 
                  a \[LessEqual] t \[LessEqual] b, 
                1]; \[IndentingNewLine]arw = 
            Which[dim \[Equal] 2, 
              Arrow, \[IndentingNewLine]And[dim \[Equal] 3, 
                DrawGraphicsInstalledQ], 
              DrawGraphics`DrawingArrows`Arrow3D, \[IndentingNewLine]True, {} \
&]; \[IndentingNewLine]halfDelta = 
            Which[dim \[Equal] 2, 
              arwDelta/2, \[IndentingNewLine]And[dim \[Equal] 3, 
                DrawGraphicsInstalledQ], \
\[IndentingNewLine]\(DrawGraphics`DrawingArrows`HeadLength3D*
                    DrawGraphics`DrawingArrows`HeadScaling3D/2 /. {opts}\) /. 
                Options[
                  DrawGraphics`DrawingArrows`Arrow3D], \
\[IndentingNewLine]True, arwDelta/2]; \[IndentingNewLine]arrowBase[
              t_ /; acrossQ] := 
            Max[el*t - halfDelta, 0]; \[IndentingNewLine]arrowBase[
              t_ /; Not@acrossQ] := 
            el*Max[First@subdivisionInterval[t], 
                t - halfDelta/el]; \[IndentingNewLine]arrowTip[
              t_ /; acrossQ] := 
            Min[el*t + halfDelta, el]; \[IndentingNewLine]arrowTip[
              t_ /; Not@acrossQ] := 
            el*Min[t + halfDelta/el, 
                Last@subdivisionInterval[t]]; \[IndentingNewLine]{If[
              dim \[Equal] 3, 
              Sequence @@ {If[arw3Dclr === None, Sequence @@ {}, 
                    SurfaceColor[Sequence @@ Flatten[{arw3Dclr}]]], 
                  arw3Dedgfrm}, Sequence @@ {}], 
            Map[\((arw[par[arrowBase[#]], par[arrowTip[#]], 
                    FilterOptions[arw, HeadScaling \[Rule] Automatic, 
                      opts]])\) &, positions]}];\)\)], "Input",
  InitializationCell->True],

Cell["Ignoring arrows when the path is too short:", "Text"],

Cell[BoxData[
    \(\(insertArrows[
          pts_List /; lineLength[pts] \[LessEqual] \ $MachineEpsilon, 
          positions_List, opts___?OptionQ] := Sequence @@ {};\)\)], "Input",
  InitializationCell->True],

Cell["Co\[ODoubleDot]rdinating the various ways to assign the arrow \
positions:", "Text"],

Cell[BoxData[{
    \(\(normalizedArrowPositions[
          pos_ /; And[pos =!= Automatic, 
              MatchQ[pos, \(({u__ /; Element[{u}, Reals]})\) | \((v_ /; 
                      Element[v, Reals])\)]], _] := 
        Flatten[{\((pos - Min[pos, 0])\)/\((Max[pos, 1] - 
                  Min[pos, 0])\)}];\)\), "\[IndentingNewLine]", 
    \(\(normalizedArrowPositions[Automatic, howMany_Integer] := 
        Range[1, 2  howMany - 1, 
            2]/\((2  Max[howMany, 1])\);\)\), "\[IndentingNewLine]", 
    \(\(normalizedArrowPositions[Automatic, 
          howMany_] := {};\)\), "\[IndentingNewLine]", 
    \(normalizedArrowPositions[
        pos_ /; And[pos =!= Automatic, 
            Not@MatchQ[
                pos, \(({u__ /; Element[{u}, Reals]})\) | \((v_ /; 
                      Element[v, Reals])\)]], _] := {}\)}], "Input",
  InitializationCell->True],

Cell[TextData[{
  "Choosing ",
  StyleBox["HeadScaling3D", "Input"],
  " as the length of the longest side of the smallest ",
  ButtonBox["Rectangle",
    ButtonStyle->"RefGuideLink"],
  " or ",
  ButtonBox["Cuboid",
    ButtonStyle->"RefGuideLink"],
  " that encloses all the ",
  StyleBox["Line", "Input"],
  "s in a ",
  StyleBox["Graphics", "Input"],
  " or ",
  StyleBox["Graphics3D", "Input"],
  " object:"
}], "Text"],

Cell[BoxData[
    \(\(maxLineExcursion[gr_] := 
        Max[0, Max @@ 
            Cases[gr, 
              Line[pts_] \[RuleDelayed] 
                Max@Map[Max[#] - Min[#] &, Transpose[pts]], {0, 
                Infinity}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Options[
          automaticHeadScaling3D] = {DrawGraphics`DrawingArrows`HeadScaling3D \
\[Rule] Automatic};\)\), "\[IndentingNewLine]", 
    \(\(automaticHeadScaling3D[gr_, 
          opts___?OptionQ] := \[IndentingNewLine]Module[{maxExcursion, 
            scalingFromOpts}, \[IndentingNewLine]maxExcursion = 
            maxLineExcursion[
              gr]; \[IndentingNewLine]scalingFromOpts = \
\(DrawGraphics`DrawingArrows`HeadScaling3D /. {opts}\) /. 
              Options[automaticHeadScaling3D]; \
\[IndentingNewLine]DrawGraphics`DrawingArrows`HeadScaling3D \[Rule] 
            If[TrueQ[scalingFromOpts \[GreaterEqual] 0], scalingFromOpts, 
              maxExcursion]];\)\)}], "Input",
  InitializationCell->True],

Cell["\<\
A utility to estimate automatically how many arrows to draw along \
curves, based on the ratio of their length with a reference dimension:\
\>", \
"Text"],

Cell[BoxData[
    \(\(sortOutHowManyArrows[graf_, declaredHowMany_, referenceDimension_, 
          arrowDensityParameter_] := 
        Module[{automaticHowMany, 
            howMany}, \[IndentingNewLine]automaticHowMany := 
            Cases[graf, 
              Line[pts_List] \[RuleDelayed] 
                Ceiling[
                  If[TrueQ[arrowDensityParameter \[GreaterEqual] 0], 
                      arrowDensityParameter, 1]*
                    If[referenceDimension \[LessEqual] $MachineEpsilon, 0, 
                      lineLength[pts]/referenceDimension]], {1, 
                Infinity}]; \[IndentingNewLine]Which[
            declaredHowMany === Automatic, 
            howMany = 
              automaticHowMany, \[IndentingNewLine]Length[
                declaredHowMany] \[Equal] 0, 
            howMany = {declaredHowMany}, \[IndentingNewLine]True, 
            howMany = declaredHowMany]; \[IndentingNewLine]If[
            Not@FreeQ[howMany, Automatic], 
            howMany = 
              MapIndexed[#1 /. 
                    Automatic \[Rule] cyclicPart[automaticHowMany, #2] &, 
                howMany]]; \[IndentingNewLine]howMany];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(sortOutHowManyArrowsAndAnnotateLines[graf_, declaredHowMany_, 
          referenceDimension_, arrowDensityParameter_] := 
        Module[{automaticHowMany, howMany}, \[IndentingNewLine]lineList = 
            Cases[graf, _Line, {0, 
                Infinity}]; \[IndentingNewLine]lineListWithAutomaticHowMany := 
            lineList /. 
              Line[pts_List] \[RuleDelayed] 
                Line[pts, 
                  HowManyArrows \[Rule] 
                    Ceiling[
                      If[TrueQ[arrowDensityParameter \[GreaterEqual] 0], 
                          arrowDensityParameter, 1]*
                        If[referenceDimension \[LessEqual] $MachineEpsilon, 
                          0, lineLength[pts]/
                            referenceDimension]]]; \[IndentingNewLine]Which[
            declaredHowMany === Automatic, 
            howMany = {Automatic}, \[IndentingNewLine]Length[
                declaredHowMany] \[Equal] 0, 
            howMany = {declaredHowMany}, \[IndentingNewLine]True, 
            howMany = 
              declaredHowMany]; \[IndentingNewLine]MapIndexed[#1 /. 
                Line[pts_, automtc_] \[RuleDelayed] 
                  Line[pts, 
                    If[cyclicPart[howMany, #2] === Automatic, 
                      Sequence @@ {automtc}, 
                      HowManyArrows \[Rule] cyclicPart[howMany, #2]]] &, 
            lineListWithAutomaticHowMany]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["OrientedPlot", "Subsubtitle"],

Cell[BoxData[{
    \(\(cyclicPart[obj_ /; Length[obj] \[Equal] 0, _] = 
        obj;\)\), "\[IndentingNewLine]", 
    \(\(cyclicPart[obj_, i_Integer] := 
        obj[\([Mod[i, Length[obj], 1]]\)];\)\), "\[IndentingNewLine]", 
    \(\(cyclicPart[obj_, {i_Integer}] := cyclicPart[obj, i];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(SetAttributes[OrientedPlot, HoldAll]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[OrientedPlot] = 
        Join[{Oriented \[Rule] True, HowManyArrows\  \[Rule] \ Automatic, 
            ArrowPositions \[Rule] Automatic, 
            ReverseOrientation \[Rule] False, 
            Graphics`Arrow`HeadScaling \[Rule] Automatic, 
            Graphics`Arrow`HeadLength \[Rule] 1/20, 
            ArrowShaftLength \[Rule] Automatic, 
            ArrowsAcrossSubdivisions \[Rule] True, ArrowDensity \[Rule] 1}, 
          Options[Plot], 
          DeleteCases[
            Options[Arrow], \((Graphics`Arrow`HeadScaling | 
                  Graphics`Arrow`HeadLength)\) \[Rule] _]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrientedPlot[f_, it_List, opts___?OptionQ] := 
        Module[{howMany, pos, revQ, c, 
            referenceDimension}, \[IndentingNewLine]{howMany, 
              arrowDensityParameter, pos, revQ, 
              arwShftLngth} = \({HowManyArrows, ArrowDensity, ArrowPositions, 
                  ReverseOrientation, ArrowShaftLength} /. {opts}\) /. 
              Options[OrientedPlot]; \[IndentingNewLine]If[NumericQ[pos], 
            pos = {{pos}}]; \[IndentingNewLine]If[pos === Automatic, 
            pos = {Automatic}]; \[IndentingNewLine]If[
            MatchQ[pos, {x__} /; Element[{x}, Reals]], 
            pos = {pos}]; \[IndentingNewLine]If[Length[revQ] === 0, 
            revQ = {revQ}]; \[IndentingNewLine]c = 
            Block[{$DisplayFunction = Identity}, 
              Plot[f, it, Evaluate[FilterOptions[Plot, opts]]] // 
                First]; \[IndentingNewLine]referenceDimension = 
            maxLineExcursion[c]; \[IndentingNewLine]howMany = 
            sortOutHowManyArrows[c, howMany, referenceDimension, 
              arrowDensityParameter]; \[IndentingNewLine]arwShftLngth = 
            If[TrueQ[arwShftLngth \[GreaterEqual] 0], 
              arwShftLngth, \(referenceDimension*
                    Graphics`Arrow`HeadLength /. {opts}\) /. 
                Options[OrientedPlot]]; \[IndentingNewLine]Show[
            Graphics[{c, \[IndentingNewLine]MapIndexed[#1 /. 
                      Line[pts_List] \[RuleDelayed] \
\[IndentingNewLine]insertArrows[
                          pts, \[IndentingNewLine]normalizedArrowPositions[
                            cyclicPart[pos, #2], cyclicPart[howMany, #2]], 
                          ReverseOrientation \[Rule] 
                            TrueQ[cyclicPart[revQ, #2]], 
                          ArrowShaftLength \[Rule] arwShftLngth, 
                          opts] &, \[IndentingNewLine]c]}], \
\[IndentingNewLine]FilterOptions[Graphics, opts, 
              Options[Plot]]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["OrientedParametricPlot", "Subsubtitle"],

Cell[BoxData[
    \(SetAttributes[OrientedParametricPlot, HoldAll]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[OrientedParametricPlot] = 
        Join[{Oriented \[Rule] True, HowManyArrows \[Rule] Automatic, 
            ArrowPositions \[Rule] Automatic, 
            ReverseOrientation \[Rule] False, 
            Graphics`Arrow`HeadScaling \[Rule] Automatic, 
            Graphics`Arrow`HeadLength \[Rule] 1/20, 
            ArrowShaftLength \[Rule] Automatic, 
            ArrowsAcrossSubdivisions \[Rule] True, ArrowDensity \[Rule] 1}, 
          Options[ParametricPlot], 
          DeleteCases[
            Options[Arrow], \((Graphics`Arrow`HeadScaling | 
                  Graphics`Arrow`HeadLength)\) \[Rule] _]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrientedParametricPlot[f_, it_List, opts___?OptionQ] := 
        Module[{howMany, pos, revQ, c, referenceDimension, 
            arwShftLngth}, \[IndentingNewLine]{howMany, 
              arrowDensityParameter, pos, 
              revQ} = \({HowManyArrows, ArrowDensity, ArrowPositions, 
                  ReverseOrientation} /. {opts}\) /. 
              Options[OrientedParametricPlot]; \[IndentingNewLine]If[
            NumericQ[pos], pos = {{pos}}]; \[IndentingNewLine]If[
            pos === Automatic, pos = {Automatic}]; \[IndentingNewLine]If[
            MatchQ[pos, {x__} /; Element[{x}, Reals]], 
            pos = {pos}]; \[IndentingNewLine]If[Length[revQ] === 0, 
            revQ = {revQ}]; \[IndentingNewLine]\[IndentingNewLine]c = 
            Block[{$DisplayFunction = Identity}, \(ParametricPlot[f, it, 
                  Evaluate[
                    FilterOptions[ParametricPlot, 
                      opts]]]\)[\([1]\)]]; \[IndentingNewLine]\
\[IndentingNewLine]referenceDimension = 
            maxLineExcursion[c]; \[IndentingNewLine]howMany = 
            sortOutHowManyArrows[c, howMany, referenceDimension, 
              arrowDensityParameter]; \[IndentingNewLine]arwShftLngth = 
            If[TrueQ[arwShftLngth \[GreaterEqual] 0], 
              arwShftLngth, \(referenceDimension*
                    Graphics`Arrow`HeadLength /. {opts}\) /. 
                Options[OrientedPlot]]; \[IndentingNewLine]Show[
            Graphics[{c, \[IndentingNewLine]MapIndexed[#1 /. 
                      Line[pts_List] \[RuleDelayed] \
\[IndentingNewLine]insertArrows[
                          pts, \[IndentingNewLine]normalizedArrowPositions[
                            cyclicPart[pos, #2], cyclicPart[howMany, #2]], 
                          ReverseOrientation \[Rule] 
                            TrueQ[cyclicPart[revQ, #2]], 
                          ArrowShaftLength \[Rule] arwShftLngth, 
                          opts] &, \[IndentingNewLine]c]}], \
\[IndentingNewLine]FilterOptions[Graphics, opts, Options[ParametricPlot], 
              DisplayFunction \[Rule] $DisplayFunction]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["OrientedParametricPlot3D (curve)", "Subsubtitle"],

Cell[BoxData[
    \(SetAttributes[OrientedParametricPlot3D, HoldAll]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[OrientedParametricPlot3D] = 
        Join[{Oriented \[Rule] True, HowManyArrows \[Rule] Automatic, 
            ArrowPositions \[Rule] Automatic, 
            ReverseOrientation \[Rule] False, 
            DrawGraphics`DrawingArrows`HeadScaling3D \[Rule] Automatic, 
            DrawGraphics`DrawingArrows`HeadLength3D \[Rule] 1/10, 
            Arrow3DColor \[Rule] Automatic, ContourStyle \[Rule] Automatic, 
            PlotStyle \[Rule] Automatic, 
            ArrowsAcrossSubdivisions \[Rule] True, 
            ArrowDensity \[Rule] 1}, \[IndentingNewLine]Options[
            insertArrows], \[IndentingNewLine]DeleteCases[
            Options[DrawGraphics`DrawingArrows`Arrow3D], 
            DrawGraphics`DrawingArrows`HeadScaling3D \[Rule] _], \
\[IndentingNewLine]Options[ParametricPlot3D]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(joinChain[obj_] := 
      obj //. \[IndentingNewLine]{{primitive___, Line[{a__, b_}], 
              Line[{b_, c__}], d___} \[RuleDelayed] {primitive, 
              Line[{a, b, c}], 
              d}, {primitives0___, {primitives1___, 
                Line[{a__, b_}]}, {primitives2___, Line[{b_, c__}]}, 
              d___} \[RuleDelayed] {primitives0, {primitives1, 
                Line[{a, b, c}]}, d}}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(makeStandardStyle[sty_] := 
        Which[\[IndentingNewLine]sty === 
            None, {{None}}, \[IndentingNewLine]sty === 
            Automatic, {Automatic}, \[IndentingNewLine]sty === {}, {{}}, \
\[IndentingNewLine]sty === {{}}, {Automatic}, \[IndentingNewLine]Head[sty] =!= 
            List, {{sty}}, \[IndentingNewLine]MatchQ[
            sty, {___, 
              prim_ /; Not[
                  Head[prim] === 
                    List], ___}], {sty}, \[IndentingNewLine]True, 
          sty];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrientedParametricPlot3D[f_, it_List, opts___?OptionQ] := 
        Module[{howMany, pos, revQ, arw3Dcolor, pltStyle, pltStyle2, c, 
            cStyled, joinedLine, 
            hdscl3D}, \[IndentingNewLine]{ortdQ, howMany, 
              arrowDensityParameter, pos, revQ, arw3Dcolor, 
              pltStyle} = \({OrientedCurve, HowManyArrows, ArrowDensity, 
                  ArrowPositions, ReverseOrientation, Arrow3DColor, 
                  PlotStyle} /. {opts}\) /. 
              Options[OrientedParametricPlot3D]; \[IndentingNewLine]If[
            Not@DrawGraphicsInstalledQ, 
            Message[Oriented::"\<DrawGraphics not installed\>"]]; \
\[IndentingNewLine]If[Not@TrueQ[ortdQ], howMany = 0]; \[IndentingNewLine]If[
            NumericQ[pos], pos = {{pos}}]; \[IndentingNewLine]If[
            pos === Automatic, pos = {Automatic}]; \[IndentingNewLine]If[
            MatchQ[pos, {x__} /; Element[{x}, Reals]], 
            pos = {pos}]; \[IndentingNewLine]If[Length[revQ] === 0, 
            revQ = {revQ}]; \[IndentingNewLine]arw3Dcolor = 
            makeStandardStyle[arw3Dcolor]; \[IndentingNewLine]pltStyle = 
            makeStandardStyle[pltStyle]; \[IndentingNewLine]pltStyle2 = 
            makeStandardStyle[pltStyle] /. 
              Automatic \[Rule] {}; \[IndentingNewLine]\[IndentingNewLine]c = 
            Block[{$DisplayFunction = Identity}, \(ParametricPlot3D[f, it, 
                  Evaluate[
                    FilterOptions[ParametricPlot3D, 
                      opts]]]\)[\([1]\)]]; \[IndentingNewLine]\
\[IndentingNewLine]cStyled = 
            If[MatchQ[c, {__Line}], 
              Join[pltStyle2[\([1]\)], c], \[IndentingNewLine]Replace[
                Transpose[{Table[cyclicPart[pltStyle2, i], {i, Length[c]}], 
                    c}], {{x___}, y_} \[RuleDelayed] {x, 
                    y}, {1}]]; \[IndentingNewLine]joinedLine = 
            c // joinChain; \[IndentingNewLine]referenceDimension = 
            maxLineExcursion[joinedLine]; \[IndentingNewLine]howMany = 
            sortOutHowManyArrows[joinedLine, howMany, referenceDimension, 
              arrowDensityParameter]; \[IndentingNewLine]hdscl3D = 
            automaticHeadScaling3D[joinedLine, opts, 
              Sequence @@ 
                Options[OrientedParametricPlot3D]]; \[IndentingNewLine]Show[
            Graphics3D[{cStyled, 
                MapIndexed[#1 /. 
                      Line[pts_List] \[RuleDelayed] \
\[IndentingNewLine]insertArrows[
                          pts, \[IndentingNewLine]normalizedArrowPositions[
                            cyclicPart[pos, #2], cyclicPart[howMany, #2]], 
                          ReverseOrientation \[Rule] 
                            TrueQ[cyclicPart[
                                revQ, #2]], \[IndentingNewLine]Arrow3DColor \
\[Rule] cyclicPart[arw3Dcolor, #2], \[IndentingNewLine]PlotStyle \[Rule] 
                            cyclicPart[
                              pltStyle, #2], \[IndentingNewLine]hdscl3D, 
                          opts, FilterOptions[
                            DrawGraphics`DrawingArrows`Arrow3D, 
                            Options[
                              OrientedParametricPlot3D]]] &, \
\[IndentingNewLine]joinedLine]}], \[IndentingNewLine]FilterOptions[
              Graphics3D, opts, Options[ParametricPlot3D], 
              DisplayFunction \[Rule] $DisplayFunction]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PlotCurveOnSurface3D", "Subsubtitle"],

Cell[CellGroupData[{

Cell["insertion of points along a line", "Section"],

Cell[TextData[{
  "The function to",
  StyleBox["SplitQ[1,pt1,pt2]", "Input"],
  " decides whether the line between the two points ",
  StyleBox["pt1", "Input"],
  " and ",
  StyleBox["pt2", "Input"],
  " crosses over a vertical line with integer abscissa, and gives a list of \
the integer abscissas that are crossed. ",
  StyleBox["SplitQ[2,pt1,pt2]", "Input"],
  " does the same with crossing with horizontal lines."
}], "Text"],

Cell[BoxData[
    \(\(toSplitQ[n_Integer /; n < 3, pt0_List /; NumericQ[pt0[\([1]\)]], 
            pt1_List] /; 
          MatrixQ[{pt0, 
              pt1}] := \[IndentingNewLine]Module[{coord = \(Transpose[{pt0, 
                    pt1}]\)[\([n]\)], med1, 
            med2}, \[IndentingNewLine]{med1, 
              med2} = \({Floor[Min[Simplify@#]] + 1, 
                  Ceiling[Max[Simplify@#]] - 1} &\)[
              coord]; \[IndentingNewLine]{med1 \[LessEqual] 
              med2, \(If[OrderedQ[coord], Identity, Reverse]\)[
              Range[med1, med2]]}];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function ",
  StyleBox["makeSplit[1][{pt1,pt2}]", "Input"],
  " inserts new points along the line segment between ",
  StyleBox["pt1", "Input"],
  " and ",
  StyleBox["pt2", "Input"],
  " at all crossings with vertical lines of integer abscissa. So does",
  StyleBox[" makeSplit[2][{pt1,pt2}]", "Input"],
  " with horizontal lines."
}], "Text"],

Cell[BoxData[
    \(\(\(makeSplit[
            n_Integer /; n < 3]\)[{pt0_List /; NumericQ[pt0[\([1]\)]], 
            pt1_List}] := \[IndentingNewLine]Module[{}, \
\[IndentingNewLine]{answer, divisions} = 
            toSplitQ[n, pt0, pt1]; \[IndentingNewLine]If[
            answer, \[IndentingNewLine]Join[{pt0}, 
              t*pt1 + \((1 - t)\)*pt0 /. 
                Map[\(Solve[\((t*pt1 + \((1 - t)\)*
                                  pt0)\)[\([n]\)] \[Equal] #, 
                        t]\)[\([1]\)] &, divisions], {pt1}], {pt0, 
              pt1}]];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function ",
  StyleBox["toSplitQ[3,pt0,pt1]", "Input"],
  " decides whether the line segment between the two points ",
  StyleBox["pt0", "Input"],
  " and ",
  StyleBox["pt1 ", "Input"],
  "crosses",
  " the diagonal of the integer cell the two points are in, and gives the \
coordinates of the crossing point."
}], "Text"],

Cell[BoxData[
    \(toSplitQ[3, pt0_List, pt1_List] := 
      Module[{v, c}, \[IndentingNewLine]v = 
          Floor[Map[Min, 
              Simplify@Transpose[{pt0, pt1}]]]; \[IndentingNewLine]c = {pt0 - 
              v, pt1 - v}; \[IndentingNewLine]{Simplify[
              Subtract @@ c[\([1]\)]*Subtract @@ c[\([2]\)]] < 0, 
          c}]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function make",
  StyleBox["Split[3][{pt0,pt1}]", "Input"],
  " adds to the line between the points ",
  StyleBox["pt0", "Input"],
  " and ",
  StyleBox["pt1", "Input"],
  " the crossing (if any) between the line and the diagonal of the integer \
cell the two points are in."
}], "Text"],

Cell[BoxData[
    \(\(\(makeSplit[3]\)[{pt0_List /; NumericQ[pt0[\([1]\)]], pt1_List}] := 
        Module[{answer, c0, c1}, \[IndentingNewLine]{answer, {c0, c1}} = 
            toSplitQ[3, pt0, pt1]; \[IndentingNewLine]If[answer, 
            Join[{pt0}, 
              t*pt1 + \((1 - t)\) pt0 /. 
                Solve[Equal @@ \((t*c1 + \((1 - t)\) c0)\), t], {pt1}], {pt0, 
              pt1}]];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function ",
  StyleBox["divideLine[ptsList]", "Input"],
  " takes the list of points ",
  StyleBox["ptsList", "Input"],
  " and inserts points at all crossings with vertical or horizontal or \
diagonal lines."
}], "Text"],

Cell[BoxData[{
    \(\(divideLine[{{x_?NumericQ, y_}}] := {{x, 
            y}};\)\), "\[IndentingNewLine]", 
    \(\(divideLine[ptsList_List] := 
        Fold[Flatten[Map[makeSplit[#2], Partition[#1, 2, 1]], 1] &, 
            ptsList, {1, 2, 3}] //. {a___, b_List, b_, 
              c___} \[RuleDelayed] {a, b, c};\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["making the 3D curves", "Section"],

Cell[TextData[{
  "The function ",
  StyleBox["weight[pt]", "Input"],
  " expresses the 2D point ",
  StyleBox["pt", "Input"],
  " as a convex combination of the four vertices of the integer cell the \
point is in, and gives the coefficients."
}], "Text"],

Cell[BoxData[
    \(\(weight[pt_List /; NumericQ[pt[\([1]\)]]] := 
        Module[{vert, loc, belowDiagQ}, \[IndentingNewLine]vert = 
            Floor[pt]; \[IndentingNewLine]loc = 
            pt - vert; \[IndentingNewLine]belowDiagQ = \((Simplify[
                  Subtract @@ loc] \[GreaterEqual] 
                0)\); \[IndentingNewLine]Map[Flatten, 
            Cases[\({{vert, w00}, {vert + {1, 0}, w10}, {vert + {1, 1}, 
                      w11}, {vert + {0, 1}, w01}} /. \(Solve[
                      Thread[loc \[Equal] 
                            w00 {0, 0} + 
                              If[belowDiagQ, w10 {1, 0}, w01 {0, 1}] + 
                              w11 {1, 1}]~
                        Join~{w00 + If[belowDiagQ, w10, w01] + w11 \[Equal] 
                            1}, {w00, If[belowDiagQ, w10, w01], 
                        w11}]\)[\([1]\)]\) /. {w10 \[Rule] 0, 
                  w01 \[Rule] 0}, {_, w_ /; w =!= 0}]]];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function ",
  StyleBox["polygonVerticesCoordinates", "Input"],
  " makes a matrix of the coordinates of the vertices of the surface."
}], "Text"],

Cell[BoxData[
    \(SetAttributes[polygonVerticesCoordinates, HoldAll]; \)], "Input"],

Cell[BoxData[
    \(\(polygonVerticesCoordinates[
          f_ /; Not[Head[f] === List], {u_, uMin_, uMax_}, {v_, vMin_, 
            vMax_}, optsS___?
            OptionQ] := \[IndentingNewLine]Block[{$DisplayFunction = 
              Identity}, 
          Transpose[{\(Plot3D[u, {u, uMin, uMax}, {v, vMin, vMax}, 
                  optsS]\)[\([1]\)], \(Plot3D[
                  v, {u, uMin, uMax}, {v, vMin, vMax}, 
                  optsS]\)[\([1]\)], \(Plot3D[
                  f, {u, uMin, uMax}, {v, vMin, vMax}, 
                  optsS]\)[\([1]\)]}, {3, 1, 2}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(polygonVerticesCoordinates[{fx_, fy_, fz_, ___}, {u_, uMin_, 
            uMax_}, {v_, vMin_, vMax_}, 
          optsS___?
            OptionQ] := \[IndentingNewLine]Block[{$DisplayFunction = 
              Identity}, 
          Transpose[{\(Plot3D[fx, {u, uMin, uMax}, {v, vMin, vMax}, 
                  optsS]\)[\([1]\)], \(Plot3D[
                  fy, {u, uMin, uMax}, {v, vMin, vMax}, 
                  optsS]\)[\([1]\)], \(Plot3D[
                  fz, {u, uMin, uMax}, {v, vMin, vMax}, 
                  optsS]\)[\([1]\)]}, {3, 1, 2}]];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function ",
  StyleBox["normalizeCoordinates[pt,xMin,", "Input"],
  "stepX",
  StyleBox[",yMin,", "Input"],
  "stepY",
  StyleBox["]", "Input"],
  " takes the grid with vertex at ",
  StyleBox["{xMin,yMin}", "Input"],
  " and takes it to the integer grid starting at the origin."
}], "Text"],

Cell[BoxData[
    \(\(normalizeCoordinates[pt_List /; NumericQ[pt[\([1]\)]], xMin_, stepX_, 
          yMin_, stepY_] := 
        Rationalize[\((pt - {xMin, yMin})\)/{stepX, 
              stepY},  .00001];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function ",
  StyleBox["originalCoordinates[nrmPt,xMin,", "Input"],
  "stepX",
  StyleBox[",yMin,", "Input"],
  "stepY",
  StyleBox["]", "Input"],
  " takes back a point in the integer grid to the original grid."
}], "Text"],

Cell[BoxData[
    \(\(originalCoordinates[nrmPt_List /; NumericQ[nrmPt[\([1]\)]], xMin_, 
          stepX_, yMin_, stepY_] := 
        nrmPt*{stepX, stepY} + {xMin, yMin};\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function ",
  StyleBox["basicCurvePoints[{gu,gv},{t,tMin,tMax}] ", "Input"],
  "effectively calculates the values of ",
  StyleBox["{gu,gv}", "Input"],
  " for ",
  StyleBox["t", "Input"],
  " from ",
  StyleBox["tMin", "Input"],
  " to ",
  StyleBox["tMax", "Input"],
  " at uniform increments of ",
  StyleBox["t", "Input"],
  ". It uses ",
  StyleBox["ParametricPlot3D", "Input"],
  ", and not ",
  StyleBox["Table", "Input"],
  " or such, because we want the evaluation of our function to behave like \
the built-in ",
  StyleBox["Plot3D", "Input"],
  " and ",
  StyleBox["ParametricPlot3D", "Input"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(SetAttributes[basicCurvePoints, HoldAll];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(basicCurvePoints[{gu_, gv_}, {t_, tMin_, tMax_}, optsC___?OptionQ] := 
        Transpose[
            Drop[Transpose[\(ParametricPlot3D[{gu, gv, 0}, {t, tMin, tMax}, 
                      Evaluate[FilterOptions[ParametricPlot3D, optsC]], 
                      PlotPoints \[Rule] 15, 
                      DisplayFunction \[Rule] Identity]\)[\([1]\)] /. 
                  Line[{a__}] \[RuleDelayed] 
                    Sequence @@ {a}], \(-1\)]] //. {x___, y_List, y_, 
              z___} \[RuleDelayed] {x, y, z};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Final", "Section"],

Cell["\<\
Combining the surface and the curve(s), possibly with arrows:\
\>", \
"Text"],

Cell[BoxData[
    \(\(SetAttributes[PlotCurveOnSurface3D, HoldAll];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "Handling the ",
  StyleBox["Oriented", "Input"],
  " option in the surface itself when it occurs twice or is set to ",
  StyleBox["False", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{f_ /; Not[MatchQ[f, {__List}]], {u_Symbol, 
              uMin_, uMax_}, {v_Symbol, vMin_, vMax_}, optsS1___?OptionQ, 
            Oriented \[Rule] a_, optsS2___?OptionQ, Oriented \[Rule] _, 
            optsS3___?
              OptionQ}, \[IndentingNewLine]curves : \((\(({_, {_Symbol, _, \
_}, {_Symbol, _, _}, ___?OptionQ} | {{_, _}, {_Symbol, _, _}, ___?
                        OptionQ})\) ... )\), optsGen___?OptionQ] := 
        PlotCurveOnSurface3D[{f, {u, uMin, uMax}, {v, vMin, vMax}, optsS1, 
            Oriented \[Rule] a, optsS2, optsS3}, curves, 
          optsGen];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{f_ /; Not[MatchQ[f, {__List}]], {u_Symbol, 
              uMin_, uMax_}, {v_Symbol, vMin_, vMax_}, optsS1___?OptionQ, 
            Oriented \[Rule] \((a_ /; Not[TrueQ[a]])\), optsS2___?OptionQ, 
            Oriented \[Rule] _, optsS3___?OptionQ}, 
          curves : \((\(({_, {_Symbol, _, _}, {_Symbol, _, _}, ___?
                        OptionQ} | {{_, _}, {_Symbol, _, _}, ___?
                        OptionQ})\) ... )\), optsGen___?OptionQ] := 
        PlotCurveOnSurface3D[{f, {u, uMin, uMax}, {v, vMin, vMax}, optsS1, 
            optsS2, optsS3}, curves, optsGen];\)\)], "Input",
  InitializationCell->True],

Cell["The case when the surface itself is not oriented:", "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{f_ /; Not[MatchQ[f, {__List}]], {u_Symbol, 
              uMin_, uMax_}, {v_Symbol, vMin_, vMax_}, 
            optsS___?OptionQ /; Not[True === \((Oriented /. {optsS})\)]}, 
          curves : \((\(({_, {_Symbol, _, _}, {_Symbol, _, _}, ___?
                        OptionQ} | {{_, _}, {_Symbol, _, _}, ___?
                        OptionQ} | _Graphics)\) ... )\), 
          optsGen___?
            OptionQ] := \[IndentingNewLine]Module[{parametric2DCurves, 
            contour2DCurves, ctrdr, raw2DContours, basic2DContoursAndStyles, 
            howManyContourArrows, basic2DContours, contoursStyles, 
            basic2DParametricCurves, basic2Dcurves, basicGraphicsLines, 
            arrowShfts, rulesForText3D, xMin, xMax, yMin, yMax, dr, pdr, 
            testSurface, n1, n2, stepX, stepY, gridInfo, 
            normalizedbasic2Dcurves, normalizedbasicGraphicsLines, myArrow, 
            normalizedbasicGraphicsLinesCoordinates, curveXMin, curveXMax, 
            curveYMin, curveYMax, subdividedCur, subdividedGraphicsLines, 
            weightsList, weightListForGraphicsLines, fCoordinates, 
            verticesData, weightedCoord, weightedCoordForGraphicsLines, 
            cur3D, graphicsLines3D, parametricCur3D, contourCur3D, 
            parametric2DCurveOptions, statedHowManyParametricArrows, 
            referenceDimension, arrowDensityParameter, 
            howManyParametricArrows, parametricCurveOpts, contourCurveOpts, 
            curveOpts, parametricStyles, sty, adaptedCurvesWithOpts, 
            srfVertices, plg, srface, srfSty, sr, hdscl3D, howMany, 
            pos}, \[IndentingNewLine]If[
            And[Not[FreeQ[{curves}, \((Oriented \[Rule] True)\) | Arrow | 
                    Text]], Not@DrawGraphicsInstalledQ], 
            Message[Oriented::"\<DrawGraphics not installed\>"]]; \
\[IndentingNewLine]parametric2DCurves = 
            Cases[{curves}, {{_, _}, {_Symbol, _, _}, ___?
                  OptionQ}]; \[IndentingNewLine]contour2DCurves = 
            Cases[{curves}, {_, {_Symbol, _, _}, {_Symbol, _, _}, ___?
                  OptionQ}]; \[IndentingNewLine]ctrdr = 
            Block[{$DisplayFunction = Identity}, \(Graphics[
                    ContourPlot[##]]\)[\([1]\)]] &; \
\[IndentingNewLine]raw2DContours = 
            Apply[ctrdr, contour2DCurves, 
              1]; \[IndentingNewLine]basic2DContoursAndStyles = 
            Cases[raw2DContours, {___, {_Line, ___}} | {__, _Line, ___}, {1, 
                Infinity}]; \[IndentingNewLine]howManyContourArrows = 
            Map[Count[#, _Arrow, {1, Infinity}] &, 
              basic2DContoursAndStyles]; \[IndentingNewLine]basic2DContours = 
            Cases[basic2DContoursAndStyles, 
              Line[pts_] \[RuleDelayed] pts, {1, 
                Infinity}]; \[IndentingNewLine]contoursStyles = \
\(basic2DContoursAndStyles /. {_Line, ___} \[RuleDelayed] Sequence @@ {}\) /. 
              Line[_] \[RuleDelayed] 
                Sequence @@ {}; \[IndentingNewLine]basic2DParametricCurves = 
            Apply[basicCurvePoints, parametric2DCurves, 
              1]; \[IndentingNewLine]basic2Dcurves = 
            Join[basic2DContours, 
              basic2DParametricCurves]; \[IndentingNewLine]{xMin, xMax, yMin, 
              yMax} = Rationalize[Evaluate[{uMin, uMax, vMin, vMax}], 
              1/10^6]; \[IndentingNewLine]basicGraphicsLines = 
            DeleteCases[
                Cases[{curves}, Graphics[gr_, ___] \[RuleDelayed] {gr}], 
                Rectangle | Polygon | Circle | Disk | Raster | 
                  If[Not@DrawGraphicsInstalledQ, Arrow, Sequence @@ {}], 
                Infinity] /. {\((col : colorSpecPattern)\) \[RuleDelayed] 
                  Sequence @@ {col, SurfaceColor[col], 
                      EdgeForm[]}}; \[IndentingNewLine]arrowShfts = 
            Cases[basicGraphicsLines, 
              Arrow[bs_, tip_, ___] \[RuleDelayed] Line[{bs, tip}], 
              Infinity]; \[IndentingNewLine]rulesForText3D = 
            If[DrawGraphicsInstalledQ, {Text[str_String, {x0_, y0_}, 
                    opts___Rule] \[RuleDelayed] \((DrawGraphics`Text3D`Text3D[
                        str, {x0, y0, 0}, {1, 1}, {0, 0, 0}, 
                        opts] /. {x_?NumericQ, y_, z_} \[RuleDelayed] {x, 
                          y})\), 
                Text[str_String, {x0_, y0_}, {scaleX_, scaleY_}, 
                    opts___Rule] \[RuleDelayed] \((DrawGraphics`Text3D`Text3D[
                        str, {x0, y0, 0}, {scaleX, scaleY}, {0, 0, 0}, 
                        opts] /. {x_?NumericQ, y_, z_} \[RuleDelayed] {x, 
                          y})\), \[IndentingNewLine]Text[
                    str_String, {x0_, y0_}, {scaleX_, scaleY_}, {dirX_, 
                      dirY_}, 
                    opts___Rule] \[RuleDelayed] \((DrawGraphics`Text3D`Text3D[
                        str, {x0, y0, 0}, {scaleX, scaleY}, {0, 0, 
                          ArcTan[dirX, dirY]}, 
                        opts] /. {x_?NumericQ, y_, z_} \[RuleDelayed] {x, 
                          y})\)}, \[IndentingNewLine]_Text \[RuleDelayed] 
                Sequence @@ {}]; \[IndentingNewLine]basicGraphicsLines = 
            basicGraphicsLines /. rulesForText3D; \[IndentingNewLine]dr = 
            Block[{$DisplayFunction = 
                    Identity}, \(Plot3D[##]\)[\([1]\)]] &; \
\[IndentingNewLine]pdr = 
            Block[{$DisplayFunction = 
                    Identity}, \(ParametricPlot3D[##]\)[\([1]\)]] &; \
\[IndentingNewLine]testSurface = 
            If[MatchQ[
                f, {_, _, _, ___}], \(ParametricPlot3D[{x, y, 0}, {x, 0, 
                    1}, {y, 2, 3}, DisplayFunction \[Rule] Identity, 
                  Evaluate@
                    FilterOptions[ParametricPlot3D, optsS, 
                      optsGen]]\)[\([1]\)], \
\[IndentingNewLine]First@\(Graphics3D@
                    Plot3D[0, {x, 0, 1}, {y, 2, 3}, 
                      DisplayFunction \[Rule] Identity, 
                      Evaluate@FilterOptions[Plot3D, optsS, optsGen]]\) /. 
                Polygon[pts_] \[RuleDelayed] 
                  Polygon[RotateLeft[pts]]]; \[IndentingNewLine]n1 = 
            1 + Count[testSurface, 
                Polygon[{{_, 2. , _}, __}], {1, 
                  Infinity}]; \[IndentingNewLine]n2 = 
            1 + Count[testSurface, 
                Polygon[{{0. , __}, __}], {1, 
                  Infinity}]; \[IndentingNewLine]{stepX, 
              stepY} = \(({xMax, yMax} - {xMin, yMin})\)/\(({n1, n2} - 
                  1)\); \[IndentingNewLine]gridInfo = {xMin, stepX, yMin, 
              stepY}; \[IndentingNewLine]normalizedbasic2Dcurves = 
            Map[normalizeCoordinates[#, Sequence @@ gridInfo] &, 
              basic2Dcurves, {2}]; \
\[IndentingNewLine]normalizedbasicGraphicsLines = 
            basicGraphicsLines /. {Line[pts_] \[RuleDelayed] 
                  Line@Map[normalizeCoordinates[#, Sequence @@ gridInfo] &, 
                      pts], \[IndentingNewLine]Point[pt_] \[RuleDelayed] 
                  Point[normalizeCoordinates[pt, 
                      Sequence @@ gridInfo]], \[IndentingNewLine]Arrow[bs_, 
                    tip_, o___] \[RuleDelayed] \[IndentingNewLine]{Line@
                      Map[normalizeCoordinates[#, 
                            Sequence @@ gridInfo] &, {bs, tip}], 
                    myArrow[
                      Map[normalizeCoordinates[#, 
                            Sequence @@ gridInfo] &, {bs, 
                          tip}]]}}; \
\[IndentingNewLine]\[IndentingNewLine]normalizedbasicGraphicsLinesCoordinates \
= Cases[normalizedbasicGraphicsLines, 
              Line[pts_] \[RuleDelayed] Sequence @@ pts, 
              Infinity]; \
\[IndentingNewLine]normalizedbasicGraphicsPointsCoordinates = 
            Cases[normalizedbasicGraphicsLines, Point[pt_] \[RuleDelayed] pt, 
              Infinity]; \[IndentingNewLine]{{curveXMin, 
                curveXMax}, {curveYMin, curveYMax}} = 
            Map[{Min[Floor[#]], Max[Ceiling[#]]} &, 
              Transpose[
                Join[Flatten[normalizedbasic2Dcurves, 1], 
                  normalizedbasicGraphicsLinesCoordinates, 
                  normalizedbasicGraphicsPointsCoordinates, {{xMin, 
                      yMin}, {xMax, 
                      yMax}}]]]; \[IndentingNewLine]subdividedCur = 
            Map[divideLine, 
              normalizedbasic2Dcurves]; \
\[IndentingNewLine]subdividedGraphicsLines = 
            normalizedbasicGraphicsLines /. {Line[pts_] \[RuleDelayed] 
                  Line@\(divideLine@\(Simplify@
                        pts\)\), \[IndentingNewLine]myArrow[
                    pts_] \[RuleDelayed] 
                  myArrow[
                    divideLine@\(Simplify@
                        pts\)]}; \
\[IndentingNewLine]\[IndentingNewLine]weightsList = 
            Map[weight, 
              subdividedCur, {2}]; \
\[IndentingNewLine]weightListForGraphicsLines = 
            subdividedGraphicsLines /. {Line[pts_] \[RuleDelayed] 
                  Line@Map[weight, pts], 
                Point[pt_] \[RuleDelayed] 
                  Point@\(weight@pt\), \[IndentingNewLine]myArrow[
                    pts_] \[RuleDelayed] 
                  myArrow[
                    Map[weight, 
                      pts]]}; \
\[IndentingNewLine]\[IndentingNewLine]fCoordinates = 
            Which[Head[Evaluate[f]] =!= 
                List, {u, v, f} /. Thread[{u, v} \[Rule] #] &, 
              MatchQ[f, {_, _, _, ___}], 
              Take[f /. Thread[{u, v} \[Rule] #], 
                  3] &, \[IndentingNewLine]MatchQ[
                f, {_, _}], {u, v, First[f]} /. 
                  Thread[{u, 
                        v} \[Rule] #] &]; \[IndentingNewLine]verticesData = 
            Map[fCoordinates, \[IndentingNewLine]N@
                  Table[{x, y}, {y, yMin + curveYMin*stepY, 
                      yMin + curveYMax*stepY, stepY}, {x, 
                      xMin + curveXMin*stepX, xMin + curveXMax*stepX, 
                      stepX}], {2}] // \((Rationalize[#, 
                    1/10^6] &)\); \[IndentingNewLine]weightedCoord = 
            Apply[#3*
                  verticesData[\([#2 - curveYMin + 1, #1 - curveXMin + 
                        1]\)] &, 
              weightsList, {3}]; \
\[IndentingNewLine]weightedCoordForGraphicsLines = 
            weightListForGraphicsLines /. {Line[weightedPts_] \[RuleDelayed] 
                  Line@
                    Apply[#3*
                          verticesData[\([#2 - curveYMin + 1, #1 - 
                                curveXMin + 1]\)] &, 
                      weightedPts, {2}], \[IndentingNewLine]Point[
                    weightedPt_] \[RuleDelayed] 
                  Point[Apply[#3*
                          verticesData[\([#2 - curveYMin + 1, #1 - 
                                curveXMin + 1]\)] &, 
                      weightedPt, {1}]], \[IndentingNewLine]myArrow[
                    weightedPts_] \[RuleDelayed] 
                  myArrow@
                    Apply[#3*
                          verticesData[\([#2 - curveYMin + 1, #1 - 
                                curveXMin + 1]\)] &, 
                      weightedPts, {2}]}; \[IndentingNewLine]cur3D = 
            Map[Line[Apply[Plus, #, 1]] &, 
              weightedCoord]; \[IndentingNewLine]graphicsLines3D = 
            weightedCoordForGraphicsLines /. {Line[
                    weightedPts_] \[RuleDelayed] 
                  Line@Apply[Plus, weightedPts, 1], 
                Point[weightedPt_] \[RuleDelayed] 
                  Point@Apply[Plus, weightedPt], \[IndentingNewLine]myArrow[
                    weightedPts_] \[RuleDelayed] \[IndentingNewLine]myArrow[
                    Apply[Plus, weightedPts, 
                      1]]}; \[IndentingNewLine]parametricCur3D = 
            Take[cur3D, \(-Length[
                  basic2DParametricCurves]\)]; \
\[IndentingNewLine]contourCur3D = 
            Take[cur3D, 
              Length[basic2DContoursAndStyles]]; \
\[IndentingNewLine]parametric2DCurveOptions = 
            Map[Drop[#, 2] &, 
              parametric2DCurves]; \
\[IndentingNewLine]statedHowManyParametricArrows = \(HowManyArrows /. 
                parametric2DCurveOptions\) /. 
              Options[OrientedParametricPlot3D]; \
\[IndentingNewLine]referenceDimension = 
            maxLineExcursion[
              cur3D]; \[IndentingNewLine]arrowDensityParameter = \
\(ArrowDensity /. {optsGen}\) /. 
              Options[OrientedParametricPlot3D]; \
\[IndentingNewLine]howManyParametricArrows = 
            sortOutHowManyArrows[parametricCur3D, 
              statedHowManyParametricArrows, referenceDimension, 
              arrowDensityParameter]; \[IndentingNewLine]parametricCurveOpts \
= Apply[Prepend, 
              Transpose[{parametric2DCurveOptions, 
                  Thread[HowManyArrows \[Rule] howManyParametricArrows]}], 
              1]; \[IndentingNewLine]contourCurveOpts = 
            Map[List, 
                Thread[HowManyArrows \[Rule] 
                    howManyContourArrows]] /. {HowManyArrows \[Rule] 
                    n_?Positive} \[RuleDelayed] {HowManyArrows \[Rule] n, 
                  Oriented \[Rule] True}; \[IndentingNewLine]{contoursStyles, 
              contourCurveOpts} = 
            If[contoursStyles === {}, {{}, {}}, 
              Transpose[
                Transpose[{contoursStyles, 
                      contourCurveOpts}] /. {{a___, col : colorSpecPattern, 
                        c___}, {d___}} \[RuleDelayed] {{a, col, c}, {d, 
                        Arrow3DColor \[Rule] 
                          col}}]]; \[IndentingNewLine]curveOpts = 
            Join[contourCurveOpts, 
              parametricCurveOpts]; \[IndentingNewLine]parametricStyles = 
            If[parametric2DCurves === {}, {}, 
              Map[Flatten[#, 2] &, \({PlotStyle} /. 
                    parametricCurveOpts\) /. {Automatic \[Rule] {}, 
                    PlotStyle \[Rule] {}}]]; \[IndentingNewLine]sty = 
            Join[contoursStyles, 
              parametricStyles]; \[IndentingNewLine]cur3D = 
            Map[Flatten[#, 1] &, 
              Transpose[{sty, 
                  cur3D}]]; \[IndentingNewLine]adaptedCurvesWithOpts = 
            If[TrueQ[\(ShowCurves /. {optsGen}\) /. ShowCurves \[Rule] True], 
              Transpose[{cur3D, 
                  curveOpts}], {}]; \[IndentingNewLine]srfVertices = 
            Map[fCoordinates, 
                N@Table[{x, y}, {y, yMin, yMax, stepY}, {x, xMin, xMax, 
                      stepX}], {2}] // \((Rationalize[#, 
                    1/10^6] &)\); \[IndentingNewLine]plg[i_, j_] := 
            Polygon[Apply[srfVertices[\([##]\)] &, 
                Map[{i, j} + # &, {{0, 0}, {0, 1}, {1, 1}, {1, 0}}], 
                1]]; \[IndentingNewLine]srface = 
            Flatten@Table[
                plg[i, j], {i, n2 - 1}, {j, 
                  n1 - 1}]; \[IndentingNewLine]Which[
            Not@TrueQ[\(ShowSurface /. {optsS, optsGen}\) /. 
                  ShowSurface \[Rule] True], 
            srface = {}, \[IndentingNewLine]MatchQ[f, {_, _, _, _}], 
            srfSty = 
              Map[Drop[#, \(-1\)] &, 
                pdr[f, {u, uMin, uMax}, {v, vMin, vMax}, 
                  PlotPoints \[Rule] {n1, n2}]]; \[IndentingNewLine]srface = 
              Map[Flatten[#, 1] &, 
                Transpose[{srfSty, srface}]], \[IndentingNewLine]Or[
              Head[f] =!= List, 
              Length[f] \[Equal] 
                2], \[IndentingNewLine]sr = \(Graphics3D[
                    Plot3D[f, {u, uMin, uMax}, {v, vMin, vMax}, 
                      PlotPoints \[Rule] {n1, n2}, 
                      DisplayFunction \[Rule] Identity, 
                      Evaluate[
                        FilterOptions[Plot3D, 
                          optsS]]]]\)[\([1]\)] /. _Polygon \[RuleDelayed] 
                  Sequence @@ {}; \[IndentingNewLine]srfSty = 
              Which[MatchQ[sr, {__, {__}}], 
                Map[Join[Drop[sr, \(-1\)], {#}] &, 
                  Last[sr]], \[IndentingNewLine]MatchQ[sr, {__, {}}], 
                Table[Drop[
                    sr, \(-1\)], {\((n1 - 1)\) \((n2 - 
                          1)\)}], \[IndentingNewLine]MatchQ[sr, {__}], 
                Map[List, sr], \[IndentingNewLine]MatchQ[sr, {}], 
                Table[{}, {\((n1 - 1)\) \((n2 - 
                          1)\)}]\[IndentingNewLine]]; \
\[IndentingNewLine]srface = 
              Map[Flatten[#, 1] &, 
                Transpose[{srfSty, srface}]]]; \[IndentingNewLine]hdscl3D = 
            automaticHeadScaling3D[{arrowShfts, cur3D} // N, optsGen, 
              Sequence @@ 
                Options[
                  OrientedParametricPlot3D]]; \[IndentingNewLine]\
\[IndentingNewLine]Show[
            Graphics3D[{{EdgeForm[], srface}, 
                adaptedCurvesWithOpts /. {{sty___, 
                        Line[pts_List]}, {opt___}} \[RuleDelayed] \
\(({howMany, pos} = \({HowManyArrows, ArrowPositions} /. {opt, optsGen}\) /. 
                          Options[
                            OrientedParametricPlot3D]; \[IndentingNewLine]If[
                        Not@TrueQ[OrientedCurve /. {opt}], 
                        pos = {}]; \[IndentingNewLine]{If[
                          MemberQ[{None, {None}}, PlotStyle /. {opt}], 
                          Sequence @@ {}, Sequence @@ {sty, Line[pts]}], 
                        insertArrows[pts, 
                          normalizedArrowPositions[pos, howMany], opt, 
                          optsGen, hdscl3D, 
                          Sequence @@ 
                            Options[
                              OrientedParametricPlot3D]]})\), \
\[IndentingNewLine]If[graphicsLines3D \[Equal] {}, Sequence @@ {}, 
                  graphicsLines3D /. 
                    myArrow[
                        pts_] \[RuleDelayed] \
\[IndentingNewLine]DrawGraphics`DrawingArrows`Arrow3D[
                        Sequence @@ Take[pts, \(-2\)], 
                        hdscl3D]]}], \[IndentingNewLine]FilterOptions[
              Graphics3D, optsGen, 
              If[MatchQ[f, {_, _}], Lighting \[Rule] False, {}], 
              Options[OrientedParametricPlot3D]]]];\)\)], "Input",
  InitializationCell->True],

Cell["The case when the surface is itself oriented:", "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{f_ /; Not[MatchQ[f, {__List}]], {u_Symbol, 
              uMin_, uMax_}, {v_Symbol, vMin_, vMax_}, optsS1___?OptionQ, 
            Oriented \[Rule] True, optsS2___?OptionQ}, 
          curves : \((\(({_, {_Symbol, _, _}, {_Symbol, _, _}, ___?
                        OptionQ} | {{_, _}, {_Symbol, _, _}, ___?
                        OptionQ} | _Graphics)\) ... )\), 
          optsGen___?OptionQ] := \[IndentingNewLine]Module[{howMany, pos, 
            revQ, hdlngh3D, cntrstyle, arwColor, 
            bdrOpts}, \[IndentingNewLine]{howMany, pos, revQ, hdlngh3D, 
              cntrstyle, 
              arwColor} = \(\({HowManyArrows, ArrowPositions, 
                    ReverseOrientation, 
                    DrawGraphics`DrawingArrows`HeadLength3D, ContourStyle, 
                    Arrow3DColor} /. {optsS1, optsS2, optsGen}\) /. 
                Options[OrientedParametricPlot]\) /. 
              Options[OrientedParametricPlot3D]; \[IndentingNewLine]If[
            Head[howMany] =!= List, 
            howMany = {howMany}]; \[IndentingNewLine]If[
            MatchQ[pos, {__?NumericQ} | Automatic], 
            pos = {pos}]; \[IndentingNewLine]If[Length[revQ] === 0, 
            revQ = {revQ}]; \[IndentingNewLine]cntrstyle = 
            makeStandardStyle[cntrstyle]; \[IndentingNewLine]arwColor = 
            makeStandardStyle[arwColor]; \[IndentingNewLine]bdrOpts[
              i_] := {HowManyArrows \[Rule] cyclicPart[howMany, i], 
              ArrowPositions \[Rule] 
                cyclicPart[pos, 
                  i], \[IndentingNewLine]ReverseOrientation \[Rule] 
                cyclicPart[revQ, i], \[IndentingNewLine]PlotStyle \[Rule] 
                cyclicPart[cntrstyle, 
                  i], \[IndentingNewLine]Arrow3DColor \[Rule] 
                cyclicPart[arwColor, i], 
              DrawGraphics`DrawingArrows`HeadLength3D \[Rule] 
                hdlngh3D}; \[IndentingNewLine]PlotCurveOnSurface3D[{f, {u, 
                uMin, uMax}, {v, vMin, vMax}, optsS1, 
              optsS2}, \[IndentingNewLine]Evaluate[{{u, vMin}, {u, uMin, 
                  uMax}, Oriented \[Rule] True, PlotPoints \[Rule] 2, 
                Sequence @@ bdrOpts[1]}], \[IndentingNewLine]Evaluate[{{uMax, 
                  v}, {v, vMin, vMax}, Oriented \[Rule] True, 
                PlotPoints \[Rule] 2, 
                Sequence @@ 
                  bdrOpts[2]}], \[IndentingNewLine]Evaluate[{{uMax - u, 
                  vMax}, {u, 0, uMax - uMin}, Oriented \[Rule] True, 
                PlotPoints \[Rule] 2, 
                Sequence @@ bdrOpts[3]}], \[IndentingNewLine]Evaluate[{{uMin, 
                  vMax - v}, {v, 0, vMax - vMin}, Oriented \[Rule] True, 
                PlotPoints \[Rule] 2, 
                Sequence @@ bdrOpts[4]}], \[IndentingNewLine]curves, 
            optsGen]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SetAttributes[DrawCurveOnSurface3D, HoldAll];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DrawCurveOnSurface3D[
          surf : {f_ /; Not[MatchQ[f, {__List}]], {u_Symbol, uMin_, 
                uMax_}, {v_Symbol, vMin_, vMax_}, optsS___?OptionQ}, 
          curves : \((\(({_, {_Symbol, _, _}, {_Symbol, _, _}, ___?
                        OptionQ} | {{_, _}, {_Symbol, _, _}, ___?
                        OptionQ} | _Graphics)\) ... )\), optsGen___?OptionQ] := 
        Block[{$DisplayFunction = 
              Identity}, \[IndentingNewLine]\(PlotCurveOnSurface3D[surf, 
              curves, optsGen]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SurfaceIntersectionPlot3D", "Subsubtitle"],

Cell["Utilities to handle the cuboids that enclose surfaces:", "Text"],

Cell[BoxData[
    \(enclosingCuboid[{extr__Interval}] := {extr}; 
    enclosingCuboid[obj_ /; Not@FreeQ[obj, Polygon]] := 
      Module[{polygonVertices}, \[IndentingNewLine]polygonVertices = 
          Flatten[Cases[obj, 
              Polygon[pts_] \[RuleDelayed] pts, {0, Infinity}], 
            1]; \[IndentingNewLine]Map[Interval@{Min[#], Max[#]} &, 
          Transpose@polygonVertices]];\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(cuboidIntersection[obj1_, obj2_] := 
        Inner[IntervalIntersection, enclosingCuboid@obj1, 
          enclosingCuboid@obj2, List];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(overlappingCuboidsQ[obj1_, obj2_] := 
        FreeQ[cuboidIntersection[obj1, obj2], Interval[]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Utilities to find the normal vector to a triangle and whether two \
triangles are parallel:\
\>", "Text"],

Cell[BoxData[
    \(\(normalVectorToTriangle[{pt1_, pt2_, pt3_}] := 
        Cross[pt2 - pt1, pt3 - pt1];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(parallelTrianglesQ[Polygon[tr1_], Polygon[tr2_]] := 
        Cross[normalVectorToTriangle[tr1], 
            normalVectorToTriangle[tr2]] === {0, 0, 0};\)\)], "Input",
  InitializationCell->True],

Cell["\<\
A routine to find the intersection of two triangles in 3D \
space:\
\>", "Text"],

Cell[BoxData[
    \(\(twoTrianglesIntersection[tr1_, tr2_] /; 
          Or[Not@overlappingCuboidsQ[tr1, tr2], 
            parallelTrianglesQ[tr1, tr2]] := {};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(twoTrianglesIntersection[Polygon[{tr11_, tr12_, tr13_}], 
          Polygon[{tr21_, tr22_, tr23_}]] := 
        Module[{a, b, c, d, sys, sol, firstExtremum, secondExtremum, 
            orientatn}, \[IndentingNewLine]sys = 
            Flatten@{tr11 + a \((tr12 - tr11)\) + 
                    b \((tr13 - tr11)\) \[Equal] 
                  tr21 + c \((tr22 - tr21)\) + 
                    d \((tr23 - tr21)\), \[IndentingNewLine]Thread[{a, b, c, 
                      d, 1 - a - b, 1 - c - d} \[GreaterEqual] 
                    0]}; \[IndentingNewLine]sol = 
            Algebra`InequalitySolve`InequalitySolve[
              sys, {a, b, c, d}]; \[IndentingNewLine]If[sol === False, 
            Return[{}]]; \[IndentingNewLine]If[FreeQ[sol, Inequality], 
            Return[{}]]; \[IndentingNewLine]{firstExtremum, secondExtremum} = 
            tr11 + a \((tr12 - tr11)\) + 
                b \((tr13 - tr11)\) /. {\(Solve[
                    sol /. Inequality[amin_, LessEqual, var_, LessEqual, 
                          amax_] \[RuleDelayed] 
                        var \[Equal] amin]\)[\([1]\)], \(Solve[
                    sol /. Inequality[amin_, LessEqual, var_, LessEqual, 
                          amax_] \[RuleDelayed] 
                        var \[Equal] 
                          amax]\)[\([1]\)]}; \[IndentingNewLine]orientatn = 
            If[Det[{secondExtremum - firstExtremum, 
                    normalVectorToTriangle[{tr11, tr12, tr13}], 
                    normalVectorToTriangle[{tr21, tr22, tr23}]}] > 0, 
              Identity, Reverse]; \[IndentingNewLine]Line[
            orientatn@{firstExtremum, 
                secondExtremum}]];\)\), "\[IndentingNewLine]", 
    \(\(twoTrianglesIntersection[{Polygon[pts1_], Polygon[pts2_]}] := 
        twoTrianglesIntersection[pts1, pts2];\)\)}], "Input",
  InitializationCell->True],

Cell["\<\
When two triangles have one edge in common they are usually to be \
excluded from the self-intersection of a surface:\
\>", "Text"],

Cell[BoxData[
    \(\(oneEdgeInCommonQ[Polygon[{tr11_, tr12_, tr13_}], 
          Polygon[{tr21_, tr22_, tr23_}]] := 
        Length@Intersection[{tr11, tr12, tr13}, {tr21, tr22, 
                tr23}] \[GreaterEqual] 2;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(twoTrianglesNonEdgeIntersection[tr1_, tr2_] := 
        If[TrueQ@oneEdgeInCommonQ[tr1, tr2], {}, 
          twoTrianglesIntersection[tr1, tr2]];\)\)], "Input",
  InitializationCell->True],

Cell["Three utilities to simplify the handling of options:", "Text"],

Cell[BoxData[{
    \(\(SetAttributes[normalizeTrueFalseOption, 
        HoldFirst];\)\), "\[IndentingNewLine]", 
    \(\(normalizeTrueFalseOption[optName_, dflt_:  True] := 
        Which[MemberQ[{True, False}, optName], 
          optName = {optName}, \[IndentingNewLine]Head[optName] =!= List, 
          optName = {dflt}, \[IndentingNewLine]Not@
            TrueQ[Complement[optName, {True, False}] === {}], 
          optName = {dflt}];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SetAttributes[normalizeSingleNumericOption, 
        HoldFirst];\)\), "\[IndentingNewLine]", 
    \(\(normalizeSingleNumericOption[optName_, dflt_] := 
        Which[NumericQ@optName, 
          optName = {optName}, \[IndentingNewLine]Not[
            MatchQ[optName, {__?NumericQ}]], optName = {dflt}];\)\)}], "Input",\

  InitializationCell->True],

Cell[BoxData[{
    \(\(SetAttributes[normalizeListOfNumericOption, 
        HoldFirst];\)\), "\[IndentingNewLine]", 
    \(\(normalizeListOfNumericOption[optName_, dflt_:  Automatic] := 
        Which[optName === dflt, 
          optName = {dflt}, \[IndentingNewLine]MatchQ[
            optName, {___?NumericQ}], 
          optName = {optName}, \[IndentingNewLine]NumericQ[optName], 
          pos = {{optName}}, \[IndentingNewLine]Not@
            MatchQ[optName, {___?\((MatchQ[#, {___?NumericQ} | dflt] &)\)}], 
          pos = {dflt}];\)\)}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["SurfaceIntersectionPlot3D", "Input"],
  " draws the pairwise intersection of two or more surfaces:"
}], "Text"],

Cell[BoxData[
    \(\(Options[SurfaceIntersectionPlot3D] = {ShowSurface \[Rule] True, 
          ShowCurves \[Rule] True, PlotStyle \[Rule] Automatic, 
          SurfaceStyle \[Rule] {EdgeForm[]}, OrientedCurve \[Rule] False, 
          HowManyArrows \[Rule] Automatic, ArrowDensity \[Rule] 1, 
          ArrowPositions \[Rule] Automatic, ReverseOrientation \[Rule] False, 
          Arrow3DColor \[Rule] Automatic, 
          DrawGraphics`DrawingArrows`HeadScaling3D \[Rule] Automatic, 
          DrawGraphics`DrawingArrows`HeadLength3D \[Rule] 1/10};\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(SurfaceIntersectionPlot3D[gr1_, gr2_, gr3___?\((Not@OptionQ[#] &)\), 
          opts___?OptionQ] := 
        Module[{howManySurfaces, grOps, ratGr, showSurf, showCrv, curveSty, 
            mshsty, withArrowQ, arrowDensityParameter, statedHowMany, pos, 
            revQ, arw3Dcolor, hdLngth3D, srf, triangleExtraction, tr, 
            rulesForConnectingSegments, trashTwoWaysLines, includeEdgeIntrs, 
            triangleIntersectionRoutine, intersectionCurve, 
            referenceDimension, hdscl3D, curvesWithOpts, 
            curvesWithArrows}, \[IndentingNewLine]howManySurfaces = 
            Length[{gr1, gr2, gr3}]; \[IndentingNewLine]grOps = 
            If[MatchQ[gr1, Graphics3D[obj_, op__]], 
              Rest[gr1], {}]; \[IndentingNewLine]ratGr = 
            Rationalize[{gr1, gr2, gr3} /. 
                  obj_SurfaceGraphics \[RuleDelayed] Graphics3D[obj], 
                1/10^6] /. 
              Graphics3D[obj_, 
                  op___] \[Rule] {obj}; \[IndentingNewLine]{showSurf, 
              showCrv, curveSty, mshsty, withArrowQ, arrowDensityParameter, 
              statedHowMany, pos, revQ, arw3Dcolor, 
              hdLngth3D} = \({ShowSurface, ShowCurves, PlotStyle, 
                  SurfaceStyle, Oriented, ArrowDensity, HowManyArrows, 
                  ArrowPositions, ReverseOrientation, Arrow3DColor, 
                  DrawGraphics`DrawingArrows`HeadLength3D} /. {opts}\) /. 
              Options[SurfaceIntersectionPlot3D]; \[IndentingNewLine]If[
            And[withArrowQ, Not@DrawGraphicsInstalledQ], 
            Message[Oriented::"\<DrawGraphics not installed\>"]]; \
\[IndentingNewLine]mshsty = 
            Which[MatchQ[mshsty, {__List}], 
              mshsty, \[IndentingNewLine]Union@\(Flatten@{mshsty}\) === \
{Automatic}, {{}}, \[IndentingNewLine]True, {Flatten@{mshsty}}]; \
\[IndentingNewLine]normalizeTrueFalseOption[
            showSurf]; \[IndentingNewLine]srf = 
            Table[If[cyclicPart[showSurf, i], 
                Join[cyclicPart[mshsty, i], 
                  If[Head[ratGr[\([i]\)]] =!= List, List, Identity]@
                    ratGr[\([i]\)]], {}], {i, 
                howManySurfaces}]; \[IndentingNewLine]triangleExtraction[
              obj_] := \[IndentingNewLine]Flatten@
              Cases[obj, 
                Polygon[{pt1_, pts__}] \[RuleDelayed] 
                  Map[Polygon[{pt1, Sequence @@ #}] &, 
                    Partition[{pts}, 2, 1]], {0, 
                  Infinity}]; \[IndentingNewLine]tr = 
            Map[triangleExtraction, 
              ratGr]; \[IndentingNewLine]rulesForConnectingSegments = \
{\(({a___, Line[{b_List, c1_, c___}], d___, Line[{e___, e1_, b_}], f___} /; 
                    c1 =!= e1)\) \[RuleDelayed] \[IndentingNewLine]{Line[{e, 
                      e1, b, c1, c}], a, d, 
                  f}, \(({a___, Line[{c___, c1_, b_List}], d___, 
                      Line[{b_, e1_, e___}], f___} /; 
                    c1 =!= e1)\) \[RuleDelayed] {Line[{c, c1, b, e1, e}], a, 
                  d, f}}; \[IndentingNewLine]trashTwoWaysLines = \(({a___, 
                    Line[pts1_], b___, Line[pts2_], c___} /; 
                  pts1 === Reverse@pts2)\) \[RuleDelayed] {a, Line[pts1], b, 
                c}; \[IndentingNewLine]includeEdgeIntrs = \
\(IncludeTrianglePairsWithOneEdgeInCommon /. {opts}\) /. 
              IncludeTrianglePairsWithOneEdgeInCommon \[Rule] 
                False; \[IndentingNewLine]triangleIntersectionRoutine = 
            If[includeEdgeIntrs, twoTrianglesIntersection, 
              twoTrianglesNonEdgeIntersection]; \
\[IndentingNewLine]intersectionCurve := \(intersectionCurve = 
              Table[\(Flatten[
                        Outer[triangleIntersectionRoutine, tr[\([i]\)], 
                          tr[\([j]\)]]] //. rulesForConnectingSegments\) //. 
                    If[includeEdgeIntrs, {}, 
                      trashTwoWaysLines], \[IndentingNewLine]{i, 
                    howManySurfaces - 1}, {j, i + 1, 
                    howManySurfaces}] // \((Flatten[#, 
                      1] &)\)\); \[IndentingNewLine]intersectionCurve = 
            Table[If[cyclicPart[showCrv, i], 
                intersectionCurve[\([i]\)], {}], {i, 
                Length@intersectionCurve}]; \
\[IndentingNewLine]referenceDimension := 
            maxLineExcursion[
              intersectionCurve]; \
\[IndentingNewLine]normalizeListOfNumericOption[pos, 
            Automatic]; \[IndentingNewLine]normalizeSingleNumericOption[
            arrowDensityParameter, 
            ArrowDensity /. 
              Options[SurfaceIntersectionPlot3D]]; \
\[IndentingNewLine]normalizeSingleNumericOption[hdLngth3D, 
            DrawGraphics`DrawingArrows`HeadLength3D /. 
              Options[SurfaceIntersectionPlot3D]]; \
\[IndentingNewLine]normalizeSingleNumericOption[statedHowMany, 
            HowManyArrows /. 
              Options[SurfaceIntersectionPlot3D]]; \
\[IndentingNewLine]normalizeTrueFalseOption[
            revQ]; \[IndentingNewLine]normalizeTrueFalseOption[
            withArrowQ]; \[IndentingNewLine]arw3Dcolor = 
            makeStandardStyle[arw3Dcolor]; \[IndentingNewLine]pltStyle = 
            makeStandardStyle[curveSty]; \[IndentingNewLine]pltStyle2 = 
            makeStandardStyle[pltStyle] /. 
              Automatic \[Rule] {}; \[IndentingNewLine]hdscl3D := 
            automaticHeadScaling3D[intersectionCurve // N, opts, 
              Sequence @@ 
                Options[
                  OrientedParametricPlot3D]]; \
\[IndentingNewLine]curvesWithOpts := 
            MapIndexed[
              Join[cyclicPart[pltStyle2, #2], 
                    sortOutHowManyArrowsAndAnnotateLines[#1, 
                      cyclicPart[statedHowMany, #2], referenceDimension, 
                      cyclicPart[arrowDensityParameter, #2]]] /. 
                  Line[pts_, hwmny__] \[RuleDelayed] 
                    Line[pts, hwmny, 
                      Arrow3DColor \[Rule] cyclicPart[arw3Dcolor, #2], 
                      ReverseOrientation \[Rule] cyclicPart[revQ, #2], 
                      hdscl3D, ArrowPositions \[Rule] cyclicPart[pos, #2], 
                      Oriented \[Rule] cyclicPart[withArrowQ, #2], 
                      PlotStyle \[Rule] cyclicPart[pltStyle2, #2], 
                      DrawGraphics`DrawingArrows`HeadLength3D \[Rule] 
                        cyclicPart[hdLngth3D, #2]] &, 
              intersectionCurve]; \[IndentingNewLine]curvesWithArrows = 
            curvesWithOpts /. 
              Line[pts_, arwOpts___] \[RuleDelayed] 
                If[Not@TrueQ[Oriented /. {arwOpts}], 
                  Line[pts], \[IndentingNewLine]{Line[pts], 
                    insertArrows[pts, 
                      normalizedArrowPositions[ArrowPositions /. {arwOpts}, 
                        HowManyArrows /. {arwOpts}], hdscl3D, arwOpts, opts, 
                      Sequence @@ 
                        Options[
                          SurfaceIntersectionPlot3D]]}]; \
\[IndentingNewLine]Show[
            Graphics3D@{srf, 
                curvesWithArrows}, \[IndentingNewLine]FilterOptions[
              Graphics3D, opts, grOps]]];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["SurfaceSelfIntersectionPlot3D", "Input"],
  " draws the self-intersection of a surface. It uses ",
  StyleBox["SurfaceIntersectionPlot3D", "Input"],
  " with the option to exclude the common edge of two polygons from the \
self-intersection. This is achieved with the private option ",
  StyleBox["IncludeTrianglePairsWithOneEdgeInCommon", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(Options[
          SurfaceSelfIntersectionPlot3D] = {ShowSurface \[Rule] {True, 
              False}, ShowCurves \[Rule] True, PlotStyle \[Rule] Automatic, 
          SurfaceStyle \[Rule] {EdgeForm[]}, OrientedCurve \[Rule] False, 
          HowManyArrows \[Rule] Automatic, ArrowDensity \[Rule] 1, 
          ArrowPositions \[Rule] Automatic, ReverseOrientation \[Rule] False, 
          Arrow3DColor \[Rule] Automatic, 
          DrawGraphics`DrawingArrows`HeadScaling3D \[Rule] Automatic, 
          DrawGraphics`DrawingArrows`HeadLength3D \[Rule] 1/10};\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(SurfaceSelfIntersectionPlot3D[gr_, opts___?OptionQ] := 
        SurfaceIntersectionPlot3D[gr, gr, 
          IncludeTrianglePairsWithOneEdgeInCommon \[Rule] False, opts, 
          ShowSurface \[Rule] {True, False}];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The ",
  StyleBox["Draw", "Input"],
  " versions of ",
  StyleBox["SurfaceIntersectionPlot3D", "Input"],
  " and ",
  StyleBox["SurfaceSelfIntersectionPlot3D", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(SurfaceIntersectionDraw3D[gr1_, gr2_, 
          opts___?OptionQ] := \[IndentingNewLine]Block[{$DisplayFunction = 
              Identity}, \[IndentingNewLine]SurfaceIntersectionPlot3D[gr1, 
              gr2, opts] // First];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SurfaceSelfIntersectionDraw3D[gr1_, 
          opts___?OptionQ] := \[IndentingNewLine]Block[{$DisplayFunction = 
              Identity}, \[IndentingNewLine]SurfaceSelfIntersectionPlot3D[
              gr1, opts] // First];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["OrientedParametricPlot3D (surface)", "Subsubtitle"],

Cell[BoxData[
    \(\(OrientedParametricPlot3D[f_, it1_List, it2_List, opts___?OptionQ] := 
        PlotCurveOnSurface3D[{f, it1, it2, Oriented \[Rule] True, opts}, 
          Evaluate@FilterOptions[Graphics3D, opts]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["OrientedPlot3D", "Subsubtitle"],

Cell[BoxData[
    \(SetAttributes[OrientedPlot3D, HoldAll]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrientedPlot3D[f_, it1_List, it2_List, opts___?OptionQ] := 
        PlotCurveOnSurface3D[{f, it1, it2, Oriented \[Rule] True, opts}, 
          Evaluate@FilterOptions[Graphics3D, opts]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["The Oriented option", "Subsubtitle"],

Cell[BoxData[{
    \(\(Unprotect[Plot];\)\), "\[IndentingNewLine]", 
    \(Plot[f_, x_, opts1___?OptionQ, Oriented \[Rule] a_, opts2___?OptionQ, 
        Oriented \[Rule] _, opts3___?OptionQ] := 
      Plot[f, x, opts1, Oriented \[Rule] a, opts2, opts3]; 
    Plot[f_, x_, opts1___?OptionQ, Oriented \[Rule] True, opts2___?OptionQ] := 
      OrientedPlot[f, x, opts1, opts2];\), "\[IndentingNewLine]", 
    \(\(Plot[f_, x_, opts1___?OptionQ, 
          Oriented \[Rule] \((smthng_ /; Not[TrueQ[smthng]])\), 
          opts2___?OptionQ] := 
        Plot[f, x, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(Protect[Plot];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Unprotect[ParametricPlot];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot[f_, x_, opts1___?OptionQ, Oriented \[Rule] a_, 
          opts2___?OptionQ, Oriented \[Rule] _, opts3___?OptionQ] := 
        ParametricPlot[f, x, opts1, Oriented \[Rule] a, opts2, 
          opts3];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot[f_, x_, opts1___?OptionQ, Oriented \[Rule] True, 
          opts2___?OptionQ] := 
        OrientedParametricPlot[f, x, opts1, 
          opts2];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot[f_, x_, opts1___?OptionQ, 
          Oriented \[Rule] \((smthng_ /; Not[TrueQ[smthng]])\), 
          opts2___?OptionQ] := 
        ParametricPlot[f, x, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(Protect[ParametricPlot];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Unprotect[Plot3D];\)\), "\[IndentingNewLine]", 
    \(\(Plot3D[f_, x_List, y_List, opts1___?OptionQ, Oriented \[Rule] a_, 
          opts2___?OptionQ, Oriented \[Rule] _, opts3___?OptionQ] := 
        Plot3D[f, x, y, opts1, Oriented \[Rule] a, opts2, 
          opts3];\)\), "\[IndentingNewLine]", 
    \(\(Plot3D[f_, x_List, y_List, opts1___?OptionQ, Oriented \[Rule] True, 
          opts2___?OptionQ] := 
        OrientedPlot3D[f, x, y, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(Plot3D[f_, x_List, y_List, opts1___?OptionQ, 
          Oriented \[Rule] \((smthng_ /; Not[TrueQ[smthng]])\), 
          opts2___?OptionQ] := 
        Plot3D[f, x, y, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(Protect[Plot3D];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(Unprotect[DrawGraphics`DrawingCube`Draw3D]; 
    DrawGraphics`DrawingCube`Draw3D[data1__, Oriented \[Rule] True, 
        data2___] := 
      First[Plot3D[data1, Oriented \[Rule] True, data2, 
          DisplayFunction \[Rule] Identity]];\), "\[IndentingNewLine]", 
    \(\(Protect[DrawGraphics`DrawingCube`Draw3D];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Unprotect[ParametricPlot3D];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[f_, x_, opts1___?OptionQ, Oriented \[Rule] a_, 
          opts2___?OptionQ, Oriented \[Rule] _, opts3___?OptionQ] := 
        ParametricPlot3D[f, x, opts1, Oriented \[Rule] a, opts2, 
          opts3];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[f_, x_List, opts1___?OptionQ, Oriented \[Rule] True, 
          opts2___?OptionQ] := 
        OrientedParametricPlot3D[f, x, opts1, 
          opts2];\)\), "\[IndentingNewLine]", 
    \(\(\(ParametricPlot3D[f_, x_List, opts1___?OptionQ, 
          Oriented \[Rule] \((smthng_ /; Not[TrueQ[smthng]])\), 
          opts2___?OptionQ] := 
        ParametricPlot3D[f, x, opts1, opts2];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[f_, x_, y_List, opts1___?OptionQ, 
          Oriented \[Rule] a_, opts2___?OptionQ, Oriented \[Rule] _, 
          opts3___?OptionQ] := 
        ParametricPlot3D[f, x, y, opts1, Oriented \[Rule] a, opts2, 
          opts3];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[f_, x_List, y_List, opts1___?OptionQ, 
          Oriented \[Rule] True, opts2___?OptionQ] := 
        OrientedParametricPlot3D[f, x, y, opts1, 
          opts2];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[f_, x_List, y_List, opts1___?OptionQ, 
          Oriented \[Rule] \((smthng_ /; Not[TrueQ[smthng]])\), 
          opts2___?OptionQ] := 
        ParametricPlot3D[f, x, y, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(Protect[ParametricPlot3D];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Clipping lines and adapting arrows to the display area", "Subsubtitle"],

Cell[TextData[{
  "Determining whether two points are not in the same (weak) side of the \
plane with respect to at least one of the straight lines ",
  Cell[BoxData[
      \(TraditionalForm\`x = xMin\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x = xMax\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`y = yMin\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y = yMax\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\(crossingQ[{xMin_, xMax_}, {yMin_, yMax_}]\)[{{x1_?NumericQ, 
              y1_}, {x2_?NumericQ, y2_}}] := 
        Or[x1 < xMin < x2, x2 < xMin < x1, x1 < xMax < x2, x2 < xMax < x1, 
          y1 < yMin < y2, y2 < yMin < y1, y1 < yMax < y2, 
          y2 < yMax < y1];\)\)], "Input",
  InitializationCell->True],

Cell["Three-dimensional case:", "Text"],

Cell[BoxData[
    \(\(\(crossingQ[{xMin_, xMax_}, {yMin_, yMax_}, {zMin_, 
              zMax_}]\)[{{x1_?NumericQ, y1_, z1_}, {x2_?NumericQ, y2_, 
              z2_}}] := Or[x1 < xMin < x2, x2 < xMin < x1, x1 < xMax < x2, 
          x2 < xMax < x1, y1 < yMin < y2, y2 < yMin < y1, y1 < yMax < y2, 
          y2 < yMax < y1, z1 < zMin < z2, z2 < zMin < z1, z1 < zMax < z2, 
          z2 < zMax < z1];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "When two points make ",
  StyleBox["crossingQ", "Input"],
  " true, find the intersection between the earliest found crossed straight \
line and the segment joining the two points:"
}], "Text"],

Cell[BoxData[
    \(\(addCrossingPoint[{{x1_, y1_}, {x2_, y2_}}, {_, xMax_}, _] /; 
          Or[x1 < xMax < x2, x2 < xMax < x1] := 
        With[{t = \(-\((\((x2 - xMax)\)/\((x1 - 
                        x2)\))\)\)}, \[IndentingNewLine]{{xMax, 
              t*y1 + \((1 - t)\) y2}, {x2, y2}}];\)\)], "Input"],

Cell[BoxData[
    \(\(addCrossingPoint[{pt1 : {x1_?NumericQ, __}, pt2 : {x2_, __}}, {_, 
              xMax_}, __] /; 
          Or[x1 < xMax < x2, 
            x2 < xMax < x1] := \[IndentingNewLine]{t*pt1 + \((1 - t)\) pt2, 
            pt2} /. t \[Rule] \(-\((\((x2 - xMax)\)/\((x1 - 
                      x2)\))\)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(addCrossingPoint[{{x1_, y1_}, {x2_, y2_}}, {xMin_, _}, _] /; 
          Or[x1 < xMin < \ x2, x2 < xMin < x1] := 
        With[{t = \(-\((\((x2 - xMin)\)/\((x1 - 
                        x2)\))\)\)}, \[IndentingNewLine]{{xMin, 
              t*y1 + \((1 - t)\) y2}, {x2, y2}}];\)\)], "Input"],

Cell[BoxData[
    \(\(addCrossingPoint[{pt1 : {x1_?NumericQ, __}, 
              pt2 : {x2_, __}}, {xMin_, _}, __] /; 
          Or[x1 < xMin < \ x2, 
            x2 < xMin < x1] := \[IndentingNewLine]{t*pt1 + \((1 - t)\) pt2, 
            pt2} /. t \[Rule] \(-\((\((x2 - xMin)\)/\((x1 - 
                      x2)\))\)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(addCrossingPoint[{{x1_, y1_}, {x2_, y2_}}, _, {_, yMax_}] /; 
          Or[y1 < yMax < y2, y2 < yMax < y1] := 
        With[{t = \(-\((\((y2 - yMax)\)/\((y1 - 
                        y2)\))\)\)}, \[IndentingNewLine]{{t*x1 + \((1 - t)\) 
                  x2, yMax}, {x2, y2}}];\)\)], "Input"],

Cell[BoxData[
    \(\(addCrossingPoint[{pt1 : {_, y1_?NumericQ, ___}, 
              pt2 : {_, y2_, ___}}, _, {_, yMax_}, ___] /; 
          Or[y1 < yMax < y2, 
            y2 < yMax < y1] := \[IndentingNewLine]{t*pt1 + \((1 - t)\) pt2, 
            pt2} /. t \[Rule] \(-\((\((y2 - yMax)\)/\((y1 - 
                      y2)\))\)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(addCrossingPoint[{{x1_, y1_}, {x2_, y2_}}, _, {yMin_, _}] /; 
          Or[y1 < yMin < \ y2, y2 < yMin < y1] := 
        With[{t = \(-\((\((y2 - yMin)\)/\((y1 - 
                        y2)\))\)\)}, \[IndentingNewLine]{{t*x1 + \((1 - t)\) 
                  x2, yMin}, {x2, y2}}];\)\)], "Input"],

Cell[BoxData[
    \(\(addCrossingPoint[{pt1 : {_, y1_?NumericQ, ___}, 
              pt2 : {_, y2_, ___}}, _, {yMin_, _}, ___] /; 
          Or[y1 < yMin < \ y2, 
            y2 < yMin < y1] := \[IndentingNewLine]{t*pt1 + \((1 - t)\) pt2, 
            pt2} /. t \[Rule] \(-\((\((y2 - yMin)\)/\((y1 - 
                      y2)\))\)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(addCrossingPoint[{pt1 : {_, _, z1_?NumericQ}, 
              pt2 : {_, _, z2_}}, _, _, {_, zMax_}] /; 
          Or[z1 < zMax < z2, 
            z2 < zMax < z1] := \[IndentingNewLine]{t*pt1 + \((1 - t)\) pt2, 
            pt2} /. t \[Rule] \(-\((\((z2 - zMax)\)/\((z1 - 
                      z2)\))\)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(addCrossingPoint[{pt1 : {_, _, z1_?NumericQ}, 
              pt2 : {_, _, z2_}}, _, _, {zMin_, _}] /; 
          Or[z1 < zMin < z2, 
            z2 < zMin < z1] := \[IndentingNewLine]{t*pt1 + \((1 - t)\) pt2, 
            pt2} /. t \[Rule] \(-\((\((z2 - zMin)\)/\((z1 - 
                      z2)\))\)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(addCrossingPoint[cplpts_, lts__] /; 
          Not[\(crossingQ[lts]\)[cplpts]] := {Last[cplpts]};\)\)], "Input",
  InitializationCell->True],

Cell["Determining where a point is with respect to a rectangle:", "Text"],

Cell[BoxData[
    \(\(\(strictlyInsideQ[{xMin_, xMax_}, {yMin_, yMax_}]\)[{x_?NumericQ, 
            y_}] := And[xMin < x < xMax, yMin < y < yMax];\)\)], "Input"],

Cell[BoxData[
    \(\(\(strictlyInsideQ[varRange__]\)[pt_] := 
        And @@ \(Less @@@ 
            Transpose@Insert[Transpose[{varRange}], pt, 2]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(weaklyInsideQ[{xMin_, xMax_}, {yMin_, yMax_}]\)[{x_?NumericQ, y_}] := 
        And[xMin \[LessEqual] \ x \[LessEqual] xMax, 
          yMin \[LessEqual] y \[LessEqual] yMax];\)\)], "Input"],

Cell[BoxData[
    \(\(\(weaklyInsideQ[varRange__]\)[pt_] := 
        And @@ \(LessEqual @@@ 
            Transpose@Insert[Transpose[{varRange}], pt, 2]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(weaklyOutsideQ[varRange__]\)[pt_] := 
        Not[\(strictlyInsideQ[varRange]\)[pt]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(strictlyOutsideQ[varRange__]\)[pt_] := 
        Not[\(weaklyInsideQ[varRange]\)[pt]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Clipping the part of a curve lying outside a rectangle, and then \
placing arrow heads along it:\
\>", "Text"],

Cell[BoxData[
    \(\(clipAndPlaceArrows[gr_, lts__List, inversionCriterion_, 
          arrowDensityParameter_?NonNegative, opts___?OptionQ] := 
        Module[{strOuts, wklIn, adjClosedPaths, provisional, subdivided, 
            clipped, wrongDirectionQ, directedTraj, 
            r}, \[IndentingNewLine]strOuts[a_] := 
            PatternTest[a, 
              Evaluate[strictlyOutsideQ[lts]]]; \[IndentingNewLine]wklIn[a_] := 
            PatternTest[a, 
              Evaluate[
                weaklyInsideQ[
                  lts]]]; \[IndentingNewLine]adjClosedPaths = \(\(gr /. 
                  Line[{a_, b___, a_}] \[RuleDelayed] 
                    provisional[{a, b, a}]\) /. 
                provisional[{a___, strOuts[b_], c___}] \[RuleDelayed] 
                  provisional[{b, c, a}]\) /. 
              provisional \[Rule] Line; \[IndentingNewLine]subdivided = 
            adjClosedPaths //. 
              Line[pts_] \[RuleDelayed] 
                Line[Join[{First[pts]}, 
                    Flatten[
                      Map[addCrossingPoint[#, lts] &, Partition[pts, 2, 1]], 
                      1]]]; \[IndentingNewLine]tst = 
            Or[And[\(strictlyOutsideQ[lts]\)[#1], \(strictlyOutsideQ[
                      lts]\)[#2]], 
                And[\(weaklyInsideQ[lts]\)[#1], \(weaklyInsideQ[
                      lts]\)[#2]]] &; \[IndentingNewLine]clipped = \
\(subdivided /. Line[pts_] \[RuleDelayed] 
                  Map[Line, 
                    Split[pts, tst]]\) /. {Line[{strOuts[__]}] \[RuleDelayed] 
                  Sequence @@ {}, 
                Line[{a_}] \[RuleDelayed] 
                  Sequence @@ {}}; \[IndentingNewLine]r[pts_] /; 
              lineLength[pts] > $MachineEpsilon := \(r[pts] = 
              Ceiling[arrowDensityParameter*\((lineLength[pts]/
                        Sqrt[Apply[Plus, Apply[Subtract, {lts}, 1]^2]] - 
                      1/15)\)]\); \[IndentingNewLine]r[pts_] /; 
              lineLength[pts] \[LessEqual] $MachineEpsilon := 
            1; \[IndentingNewLine]arwShftLngth = \(ArrowShaftLength /. {opts}\
\) /. ArrowShaftLength \[Rule] Automatic; \[IndentingNewLine]arwShftLngth = 
            If[TrueQ[arwShftLngth \[GreaterEqual] 0], 
              arwShftLngth, \(maxLineExcursion[clipped]*
                    Graphics`Arrow`HeadLength /. {opts}\) /. 
                Options[HamiltonianPlot]]; \[IndentingNewLine]clipped /. 
            Line[pts_List] \[RuleDelayed] 
              Sequence @@ {Line[
                    If[TrueQ@inversionCriterion[pts], Reverse@pts, pts]], 
                  insertArrows[pts, 
                    normalizedArrowPositions[Automatic, r[pts]], 
                    ReverseOrientation \[Rule] inversionCriterion[pts], 
                    ArrowShaftLength \[Rule] arwShftLngth, 
                    opts]}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["The Oriented option for ContourPlot", "Subsubtitle"],

Cell[BoxData[
    \(\(Options[HamiltonianPlot] = {ReverseOrientation \[Rule] False, 
          ShowField \[Rule] False, ArrowDensity \[Rule] 1, 
          Graphics`Arrow`HeadScaling \[Rule] Automatic, 
          Graphics`Arrow`HeadLength \[Rule] 1/20, 
          ArrowShaftLength \[Rule] Automatic, 
          ArrowsAcrossSubdivisions \[Rule] True};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(HamiltonianPlot[
          h_, {x_Symbol, xMin_, xMax_}, {y_Symbol, yMin_, yMax_}, 
          opts___?OptionQ] := 
        Module[{levelData, showFieldQ, arwDnsty, revDirQ, approx, grad, a, b, 
            sympMat, wrongDirectionQ, allTrajs, lateralMargin, 
            topBottomMargin, fld}, \[IndentingNewLine]levelData = 
            ContourPlot[h, {x, xMin, xMax}, {y, yMin, yMax}, 
              DisplayFunction \[Rule] Identity, 
              Evaluate[FilterOptions[ContourPlot, opts]], 
              ContourShading \[Rule] False]; \[IndentingNewLine]{showFieldQ, 
              arwDnsty, 
              revDirQ} = \({ShowField, ArrowDensity, 
                  ReverseOrientation} /. {opts}\) /. 
              Options[HamiltonianPlot]; \[IndentingNewLine]approx = 
            ListInterpolation[
              Transpose[
                levelData[\([1]\)]], {{xMin, xMax}, {yMin, 
                  yMax}}]; \[IndentingNewLine]grad[{a_, b_}] := 
            Through[{\(Derivative[1, 0]\)[approx], \(Derivative[0, 1]\)[
                    approx]}[a, b]]; \[IndentingNewLine]sympMat = {{0, 
                1}, {\(-1\), 0}}; \[IndentingNewLine]wrongDirectionQ[
              pts_List] := \((If[TrueQ[revDirQ], \(-1\), 
                    1]*\(byArcLength[pts]'\)[
                      0] . \((sympMat . grad[First[pts]])\) < 
                0)\); \[IndentingNewLine]allTrajs = 
            clipAndPlaceArrows[
              Graphics[levelData], {xMin, xMax}, {yMin, yMax}, 
              wrongDirectionQ, arwDnsty, opts, 
              Sequence @@ 
                Options[HamiltonianPlot]]; \[IndentingNewLine]{lateralMargin, 
              topBottomMargin} = {xMax - xMin, yMax - yMin}/
              40; \[IndentingNewLine]fld := 
            PlotVectorField[
              sympMat . grad[{a, b}], {a, xMin + lateralMargin, 
                xMax - lateralMargin}, {b, yMin + topBottomMargin, 
                yMax - topBottomMargin}, 
              DisplayFunction \[Rule] 
                Identity]; \[IndentingNewLine]Show[{allTrajs, 
              If[showFieldQ, fld, Sequence @@ {}]}, 
            FilterOptions[Graphics, opts], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Unprotect[ContourPlot];\)\), "\[IndentingNewLine]", 
    \(\(ContourPlot[h_, {x_Symbol, xMin_, xMax_}, {y_Symbol, yMin_, yMax_}, 
          opts1___?OptionQ, Oriented \[Rule] a_, opts2___?OptionQ, 
          Oriented \[Rule] _, opts3___?OptionQ] := 
        ContourPlot[h, {x, xMin, xMax}, {y, yMin, yMax}, opts1, 
          Oriented \[Rule] a, opts2, opts3];\)\), "\[IndentingNewLine]", 
    \(\(ContourPlot[h_, {x_Symbol, xMin_, xMax_}, {y_Symbol, yMin_, yMax_}, 
          opts1___?OptionQ, Oriented \[Rule] True, opts2___?OptionQ] := 
        HamiltonianPlot[h, {x, xMin, xMax}, {y, yMin, yMax}, opts1, 
          opts2];\)\), "\[IndentingNewLine]", 
    \(\(ContourPlot[h_, {x_Symbol, xMin_, xMax_}, {y_Symbol, yMin_, yMax_}, 
          opts1___?OptionQ, 
          Oriented \[Rule] \((smthg_ /; Not[TrueQ[smthg]])\), 
          opts2___?OptionQ] := 
        ContourPlot[h, {x, xMin, xMax}, {y, yMin, yMax}, opts1, 
          opts2];\)\), "\[IndentingNewLine]", 
    \(\(Protect[ContourPlot];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NDSolvePlot", "Subsubtitle"],

Cell[BoxData[
    \(\(Options[NDSolvePlot] = {PlotStyle \[Rule] Automatic};\)\)], "Input",
  InitializationCell->True],

Cell["The case of a system with two unknown functions:", "Text"],

Cell[BoxData[
    \(\(NDSolvePlot[eqs_, {x1_, x2_}, {t_, tMin_, tMax_}, opts___?OptionQ] := 
        Module[{solRule, sol, f, ortdQ, tMinEffective, tMaxEffective, t1, 
            t2}, \[IndentingNewLine]solRule = 
            NDSolve[eqs, {x1, x2}, {t, tMin, tMax}, 
              FilterOptions[NDSolve, opts]]; \[IndentingNewLine]sol = {x1, 
                x2} /. solRule[\([1]\)]; \[IndentingNewLine]f = 
            If[Head[sol[\([1]\)]] === InterpolatingFunction, Through[sol[t]], 
              sol]; \[IndentingNewLine]ortdQ = 
            TrueQ[\(Oriented /. {opts}\) /. 
                Oriented \[Rule] True]; \[IndentingNewLine]{{tMinEffective, 
                tMaxEffective}} = 
            Cases[sol, 
              InterpolatingFunction[{{t1_, t2_}}, ___] \[RuleDelayed] {t1, 
                  t2}, {1, Infinity}, 1]; \[IndentingNewLine]{solRule, 
            ParametricPlot[Evaluate[f], {t, tMinEffective, tMaxEffective}, 
              Evaluate[
                FilterOptions[
                  If[ortdQ, OrientedParametricPlot, ParametricPlot], opts, 
                  Oriented \[Rule] True]]]}];\)\)], "Input",
  InitializationCell->True],

Cell["The case of a system with three unknown functions:", "Text"],

Cell[BoxData[
    \(\(NDSolvePlot[eqs_, {x1_, x2_, x3_}, {t_, tMin_, tMax_}, 
          opts___?OptionQ] := 
        Module[{solRule, sol, f, ortdQ, tMinEffective, tMaxEffective, t1, 
            t2}, \[IndentingNewLine]solRule = 
            NDSolve[eqs, {x1, x2, x3}, {t, tMin, tMax}, 
              FilterOptions[NDSolve, opts]]; \[IndentingNewLine]sol = {x1, 
                x2, x3} /. 
              solRule[\([1]\)]; \[IndentingNewLine]{{tMinEffective, 
                tMaxEffective}} = 
            Cases[sol, 
              InterpolatingFunction[{{t1_, t2_}}, ___] \[RuleDelayed] {t1, 
                  t2}, {1, Infinity}, 1]; \[IndentingNewLine]ortdQ = 
            TrueQ[\(Oriented /. {opts}\) /. 
                Oriented \[Rule] True]; \[IndentingNewLine]f = 
            If[Head[sol[\([1]\)]] === InterpolatingFunction, Through[sol[t]], 
              sol]; \[IndentingNewLine]{solRule, 
            OrientedParametricPlot3D[
              Evaluate[f], {t, tMinEffective, tMaxEffective}, opts, 
              Oriented \[Rule] True]}];\)\)], "Input",
  InitializationCell->True],

Cell["The case of a single unknown function:", "Text"],

Cell[BoxData[
    \(\(NDSolvePlot[eqs_, x_ /; Head[x] =!= List, {t_, tMin_, tMax_}, 
          opts___?OptionQ] := 
        Module[{solRule, sol, f, tMinEffective, tMaxEffective, t1, t2}, 
          solRule = 
            NDSolve[eqs, x, {t, tMin, tMax}, 
              FilterOptions[NDSolve, opts]]; \[IndentingNewLine]sol = 
            x /. solRule[\([1]\)]; \[IndentingNewLine]{{tMinEffective, 
                tMaxEffective}} = 
            Cases[sol, 
              InterpolatingFunction[{{t1_, t2_}}, ___] \[RuleDelayed] {t1, 
                  t2}, {0, Infinity}, 1, 
              Heads \[Rule] True]; \[IndentingNewLine]f = 
            If[Head[sol] === InterpolatingFunction, sol[t], 
              sol]; \[IndentingNewLine]ortdQ = 
            TrueQ[\(Oriented /. {opts}\) /. 
                Oriented \[Rule] False]; \[IndentingNewLine]{solRule, 
            ParametricPlot[
              Evaluate[{t, f}], {t, tMinEffective, tMaxEffective}, 
              Evaluate[
                FilterOptions[
                  If[ortdQ, OrientedParametricPlot, ParametricPlot], 
                  opts]]]}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NDSolvePlot[eqs_, {x_}, {t_, tMin_, tMax_}, opts___?OptionQ] := 
        NDSolvePlot[eqs, x, {t, tMin, tMax}, opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NDSolveDraw[x__] := 
        Block[{$DisplayFunction = Identity, sol, plt}, {sol, plt} = 
            NDSolvePlot[x]; \[IndentingNewLine]{sol, 
            First[plt]}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(\(Unprotect[NDSolve];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(NDSolve[eqs_, x_ /; Head[x] =!= List, {t_, tMin_, tMax_}, 
          opts1___?OptionQ, PlotSolution \[Rule] True, 
          opts2___?OptionQ] := \[IndentingNewLine]NDSolvePlot[eqs, 
          x, {t, tMin, tMax}, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(NDSolve[eqs_, 
          x_List /; 1 \[LessEqual] Length[x] \[LessEqual] 3, {t_, tMin_, 
            tMax_}, opts1___?OptionQ, PlotSolution \[Rule] True, 
          opts2___?OptionQ] := \[IndentingNewLine]NDSolvePlot[eqs, 
          x, {t, tMin, tMax}, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(\(NDSolve[eqs_, x_, t_List, opts1___?OptionQ, 
          PlotSolution \[Rule] value /; Not@TrueQ[value], opts2___?OptionQ] := 
        NDSolve[eqs, x, t, opts1, opts2];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(NDSolve[eqs_, x_ /; Head[x] =!= List, {t_, tMin_, tMax_}, 
          opts1___?OptionQ, DrawSolution \[Rule] True, 
          opts2___?OptionQ] := \[IndentingNewLine]NDSolveDraw[eqs, 
          x, {t, tMin, tMax}, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(NDSolve[eqs_, 
          x_List /; 1 \[LessEqual] Length[x] \[LessEqual] 3, {t_, tMin_, 
            tMax_}, opts1___?OptionQ, DrawSolution \[Rule] True, 
          opts2___?OptionQ] := \[IndentingNewLine]NDSolveDraw[eqs, 
          x, {t, tMin, tMax}, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(\(NDSolve[eqs_, x_, t_List, opts1___?OptionQ, 
          DrawSolution \[Rule] value /; Not@TrueQ[value], opts2___?OptionQ] := 
        NDSolve[eqs, x, t, opts1, opts2];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Protect[NDSolve];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PhasePlot", "Subsubtitle"],

Cell[BoxData[
    \(\(Options[PhasePlot] = {GridPoints \[Rule] 5, 
          InitialPoints \[Rule] Automatic, OrientedCurve \[Rule] True, 
          Frame \[Rule] True, \ ArrowDensity \[Rule] 1, 
          ShowField \[Rule] False, 
          Graphics`Arrow`HeadScaling \[Rule] Automatic, 
          Graphics`Arrow`HeadLength \[Rule] 1/20, 
          DrawGraphics`DrawingArrows`HeadScaling3D \[Rule] Automatic, 
          DrawGraphics`DrawingArrows`HeadLength3D \[Rule] 1/20, 
          PlotStyle \[Rule] Automatic, ColorFunctionScaling \[Rule] True, 
          ShowListPlot \[Rule] False, ListPlotStyle \[Rule] PointSize[ .02], 
          Arrow3DColor \[Rule] Automatic};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PhasePlot::"\<BadPlotPoints\>" = "\<Bad PlotPoints\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(PhasePlot[{{xComponent_}, {yComponent_}}, \
\[IndentingNewLine]{x_Symbol, xMin_?NumericQ, 
            xMax_?NumericQ}, \[IndentingNewLine]{y_Symbol, yMin_?NumericQ, 
            yMax_?NumericQ}, \[IndentingNewLine]{tMin_?NonPositive, 
            tMax_?NonNegative}, \[IndentingNewLine]opts___?
            OptionQ] := \[IndentingNewLine]PhasePlot[{xComponent, 
            yComponent}, {x, xMin, xMax}, {y, yMin, yMax}, {tMin, tMax}, 
          opts];\)\), "\[IndentingNewLine]", 
    \(\(PhasePlot[{{xComponent_}, {yComponent_}, {zComponent_}}, \
\[IndentingNewLine]{x_Symbol, xMin_?NumericQ, 
            xMax_?NumericQ}, \[IndentingNewLine]{y_Symbol, yMin_?NumericQ, 
            yMax_?NumericQ}, \[IndentingNewLine]{z_Symbol, zMin_?NumericQ, 
            zMax_?NumericQ}, \[IndentingNewLine]{tMin_?NonPositive, 
            tMax_?NonNegative}, \[IndentingNewLine]opts___?
            OptionQ] := \[IndentingNewLine]PhasePlot[{xComponent, yComponent, 
            zComponent}, {x, xMin, xMax}, {y, yMin, yMax}, {z, zMin, 
            zMax}, {tMin, tMax}, opts];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PhasePlot[field_List /; Head[field[\([1]\)]] =!= List, 
            variableLimits : {_Symbol, _?NumericQ, _?NumericQ} ..  /; 
              And @@ Map[Less @@ Rest[#] &, {variableLimits}], {tMin_?
                NonPositive, tMax_?NonNegative}, opts___?OptionQ] /; 
          2 \[LessEqual] Length[field] === 
            Length[{variableLimits}] \[LessEqual] 3 := 
        Module[{dim, var, lmts, howManyPts, shwArrsQ, arwDnsty, colorSclng, 
            arwColor, shwLstPlt, lstPltSty, margins, pts, intlPts, strtPts, 
            eq, t, u, v, w, x0, sol, allSols, hdscl3D, allTrajs, 
            gr}, \[IndentingNewLine]dim = 
            Length[field]; \[IndentingNewLine]var = {variableLimits}[\([All, 
                1]\)]; \[IndentingNewLine]lmts = 
            Map[Rest, {variableLimits}]; \[IndentingNewLine]{howManyPts, 
              intlPts, shwArrsQ, arwDnsty, sty, colorSclng, arwColor, 
              shwLstPlt, 
              lstPltSty} = \({GridPoints, InitialPoints, OrientedCurve, 
                  ArrowDensity, PlotStyle, ColorFunctionScaling, 
                  Arrow3DColor, ShowListPlot, ListPlotStyle} /. {opts}\) /. 
              Options[PhasePlot]; \[IndentingNewLine]margins = \(-Subtract @@@ 
                  lmts\)/40; \[IndentingNewLine]pts = 
            Which[\[IndentingNewLine]MatchQ[howManyPts, 
                l : {__Integer?\((# \[GreaterEqual] 2 &)\)} /; 
                  Length[l] \[Equal] dim], 
              howManyPts, \[IndentingNewLine]MatchQ[
                howManyPts, _Integer?\((# \[GreaterEqual] 2 &)\)], 
              Table[howManyPts, {dim}], \[IndentingNewLine]True, 
              Message[PhasePlot::BadPlotPoints]; 
              Abort[]]; \[IndentingNewLine]strtPts = 
            If[\[IndentingNewLine]intlPts === Automatic, 
              Flatten[Outer[
                  List, \[IndentingNewLine]Sequence @@ \((Apply[
                        Range[#1, #2, \((#2 - #1)\)/\((#3 - 1)\)] &, 
                        Transpose[
                          Append[Transpose[lmts] + {margins, \(-margins\)}, 
                            pts]], 1])\)], 
                dim - 1], \[IndentingNewLine]intlPts]; \
\[IndentingNewLine]scaledStrtPts := 
            Map[\((# - lmts[\([All, 1]\)])\)/\((lmts[\([All, 2]\)] - 
                        lmts[\([All, 1]\)])\) &, strtPts] /. 
              x_?NumericQ \[RuleDelayed] 
                Min[Max[x, 0], 1]; \[IndentingNewLine]Which[
            sty === Automatic, 
            sty = {{}}, \[IndentingNewLine]Or[Head[sty] === Function, 
              dim === 3 && MemberQ[{CMYColor, RGBColor}, sty]], 
            sty = Apply[Flatten[{sty[##]}] &, 
                If[TrueQ@colorSclng, scaledStrtPts, strtPts], 
                1], \[IndentingNewLine]Not@MatchQ[sty, {__List}], 
            sty = {sty}]; \[IndentingNewLine]If[
            dim === 3, \[IndentingNewLine]If[Not@DrawGraphicsInstalledQ, 
              Message[Oriented::"\<DrawGraphics not installed\>"]]; \
\[IndentingNewLine]Which[arwColor === Automatic, 
              sty = sty /. \((col : colorSpecPattern)\) \[RuleDelayed] 
                    Sequence @@ {col, 
                        SurfaceColor[col]}, \[IndentingNewLine]Or[
                Head[arwColor] === Function, 
                MemberQ[{CMYColor, RGBColor}, arwColor]], 
              arwColor = 
                Apply[SurfaceColor[arwColor[##]] &, 
                  If[TrueQ@colorSclng, scaledStrtPts, strtPts], 
                  1], \[IndentingNewLine]Not@MatchQ[arwColor, {__List}], 
              arwColor = {arwColor}]]; \[IndentingNewLine]If[
            arwColor =!= Automatic, 
            arwColor = 
              arwColor /. \((col : colorSpecPattern)\) \[RuleDelayed] 
                  SurfaceColor[col]]; \[IndentingNewLine]Which[
            lstPltSty === Automatic, 
            lstPltSty = {{}}, \[IndentingNewLine]Or[
              Head[lstPltSty] === Function, 
              dim === 3 && MemberQ[{CMYColor, RGBColor}, lstPltSty]], 
            lstPltSty = 
              lstPltSty @@@ 
                If[TrueQ@colorSclng, scaledStrtPts, 
                  strtPts], \[IndentingNewLine]Not@
              MatchQ[lstPltSty, {__List}], 
            lstPltSty = {lstPltSty}]; \[IndentingNewLine]lstPlt := 
            MapIndexed[
                Flatten@{cyclicPart[sty, #2], cyclicPart[lstPltSty, #2], 
                      Point[#1]} &, strtPts] /. 
              Automatic \[RuleDelayed] Sequence @@ {}; \[IndentingNewLine]eq[
              x0_List, {i_Integer}] := {Flatten[{Thread[
                      Take[{\(u'\)[t], \(v'\)[t], \(w'\)[t]}, dim] \[Equal] 
                        field] /. 
                    Thread[var \[Rule] Take[{u[t], v[t], w[t]}, dim]], 
                  Thread[Take[{u[0], v[0], w[0]}, dim] \[Equal] x0]}], 
              Take[{u, v, w}, dim], {t, tMin, tMax}, HowManyArrows \[Rule] 0, 
              DisplayFunction \[Rule] Identity, 
              PlotStyle \[Rule] 
                If[Or[dim === 2, arwColor === Automatic], cyclicPart[sty, i], 
                  Flatten[{cyclicPart[sty, i], cyclicPart[arwColor, i]}]], 
              opts}; \[IndentingNewLine]sol[x0_List, {i_Integer}] := 
            joinChain[\(Apply[NDSolvePlot, eq[x0, {i}]]\)[\([2, 
                    1]\)] /. {} \[Rule] 
                  Sequence @@ {}]; \[IndentingNewLine]allSols = 
            MapIndexed[sol, strtPts] /. 
              Automatic \[RuleDelayed] 
                Sequence @@ {}; \[IndentingNewLine]hdscl3D = 
            automaticHeadScaling3D[Line[lmts // Transpose], opts, 
              Sequence @@ 
                Options[
                  OrientedParametricPlot3D]]; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[allSols, Sequence @@ lmts, False &, 
                arwDnsty, Arrow3DColor \[Rule] None, 
                Sequence @@ DeleteCases[{opts}, PlotStyle \[Rule] _], 
                hdscl3D, Sequence @@ Options[PhasePlot]], 
              allSols]; \[IndentingNewLine]gr = 
            If[dim \[Equal] 2, Graphics, 
              Graphics3D]; \[IndentingNewLine]Show[{gr[
                If[dim \[Equal] 2, 
                  allTrajs, {SurfaceColor[GrayLevel[0]], allTrajs}]], 
              If[TrueQ@shwLstPlt, gr[lstPlt], Sequence @@ {}]}, 
            FilterOptions[gr, opts], PlotRange \[Rule] lmts, 
            FilterOptions[gr, Sequence @@ Options[PhasePlot]]]];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(PhaseDraw[field_List, 
            variableLimits : {_Symbol, _?NumericQ, _?NumericQ} ..  /; 
              And @@ Map[Less @@ Rest[#] &, {variableLimits}], {tMin_?
                NonPositive, tMax_?NonNegative}, opts___?OptionQ] /; 
          2 \[LessEqual] Length[field] === 
            Length[{variableLimits}] \[LessEqual] 3 := \(PhasePlot[field, 
            variableLimits, {tMin, tMax}, DisplayFunction \[Rule] Identity, 
            opts]\)[\([1]\)];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LinearPhasePlot2D", "Subsubtitle"],

Cell[CellGroupData[{

Cell["LinearPhasePlot2D basic tests", "Section"],

Cell["Error messages when a bad matrix is given:", "Text"],

Cell[BoxData[
    \(\(admissibleMatrixQ::"\<notMatrix\>" = "\<Not a 2 by 2 matrix\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(admissibleMatrixQ::"\<nonNumeric\>" = "\<Not a numeric \
matrix\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(admissibleMatrixQ::"\<complex\>" = "\<Complex matrix\>";\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(admissibleMatrixQ::"\<inexactMatrix\>" = "\<Not an exact numeric \
matrix\>";\)\)], "Input",
  InitializationCell->True],

Cell["Determining whether the given matrix is good:", "Text"],

Cell[BoxData[
    \(\(admissibleMatrixQ[mat_?MatrixQ] := \(admissibleMatrixQ[mat] = 
          And[\[IndentingNewLine]If[
              MatrixQ[mat] && Length[mat] === 2 && TensorRank[mat] === 2, 
              True, Message[admissibleMatrixQ::"\<notMatrix\>"]; 
              False], \[IndentingNewLine]If[
              And @@ Map[NumericQ, Flatten[mat]], True, 
              Message[admissibleMatrixQ::"\<nonNumeric\>"]; 
              False], \[IndentingNewLine]If[
              And @@ Map[FreeQ[Chop[N[#]], Complex] &, Flatten[mat]], True, 
              Message[admissibleMatrixQ::"\<complex\>"]; False], 
            If[Precision[mat] === Infinity, True, 
              Message[admissibleMatrixQ::"\<inexactMatrix\>"]; 
              False]]\);\)\)], "Input",
  InitializationCell->True],

Cell["The simplest matrix structure tests:", "Text"],

Cell[BoxData[
    \(\(diagonalQ[mat_?MatrixQ] := 
        Simplify[mat[\([1, 2]\)]] === 0 && 
          Simplify[mat[\([2, 1]\)]] === 0;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(nonNullQ[mat_] := 
        Apply[Or, Map[# =!= 0 &, Simplify[Flatten[{mat}]]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(nullMatrixQ[mat_] := 
        Union[Flatten[Simplify[mat]]] === {0};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LinearPhasePlot2D basic matrix functions", "Section"],

Cell[TextData[{
  "The trace of a matrix requires to test what ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version is running:"
}], "Text"],

Cell[BoxData[
    \(\(matrixTrace = 
        If[$VersionNumber < 4, \((#[\([1, 1]\)] + #[\([2, 2]\)])\) &, 
          Tr];\)\)], "Input",
  InitializationCell->True],

Cell["The discriminant of a 2 by 2 real matrix:", "Text"],

Cell[BoxData[
    \(\(discriminant[mat_] := 
        Simplify[matrixTrace[mat]^2 - 4  Det[mat]];\)\)], "Input",
  InitializationCell->True],

Cell["The real canonical form of a real 2 by 2 matrix:", "Text"],

Cell[BoxData[
    \(\(realCanonicalForm[mat_ /; discriminant[mat] \[GreaterEqual] 0] := 
        JordanDecomposition[m];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(realCanonicalForm[mat_ /; discriminant[mat] < 0] := 
        Module[{complexSim, complexJordan, 
            realSim}, \[IndentingNewLine]{complexSim, complexJordan} = 
            JordanDecomposition[mat]; \[IndentingNewLine]realSim = 
            Transpose[\({Re[#], Im[#]} &\)[\(complexSim // Transpose\) // 
                  First]]; \[IndentingNewLine]{realSim, 
            Inverse[realSim] . mat . realSim}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LinearPhasePlot2D spectral analysis", "Section"],

Cell["The spectral classification of 2 by 2 matrices:", "Text"],

Cell[BoxData[
    \(\(saddleQ[mat_?admissibleMatrixQ] := 
        discriminant[mat] > 0 && Simplify[Det[mat]] < 0;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(nodeQ[mat_?admissibleMatrixQ] := 
        discriminant[mat] > 0 && Simplify[Det[mat]] > 0;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(singularDistinctEigenvaluesQ[mat_?admissibleMatrixQ] := 
        discriminant[mat] > 0 && Simplify[Det[mat]] === 0;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(improperNodeQ[mat_?admissibleMatrixQ] := 
        discriminant[mat] === 0 && 
          Simplify[matrixTrace[mat]] =!= 
            0 && \(! diagonalQ[mat]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(nonNullMultipleOfIdentity[mat_?admissibleMatrixQ] := 
        discriminant[mat] === 0 && diagonalQ[mat] && 
          nonNullQ[mat];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(nonNullNilpotentQ[mat_?admissibleMatrixQ] := 
        discriminant[mat] === 0 && Simplify[matrixTrace[mat]] === 0 && 
          nonNullQ[mat];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(centerQ[mat_?admissibleMatrixQ] := 
        discriminant[mat] < 0 && 
          Simplify[matrixTrace[mat]] === 0;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(spiralQ[mat_?admissibleMatrixQ] := 
        discriminant[mat] < 0 && 
          Simplify[matrixTrace[mat]] =!= 0;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LinearPhasePlot2D main", "Section"],

Cell[CellGroupData[{

Cell["preamble", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(Options[
          LinearPhasePlot2D] = {PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
          AspectRatio \[Rule] Automatic, Frame \[Rule] True, 
          FrameTicks \[Rule] {{0}, {0}}, 
          NotableLineStyle \[Rule] RGBColor[1, 0, 0], 
          NumberOfTrajectories \[Rule] 5, WriteReport \[Rule] True, 
          ShowField \[Rule] False, Oriented \[Rule] True, \ 
          ArrowDensity \[Rule] 1, 
          ArrowsAcrossSubdivisions \[Rule] True};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(inverseRange[s_?MatrixQ] := 
        Map[Max, 
          Inverse[s] . {{1, \(-1\), \(-1\), 1}, {1, 
                1, \(-1\), \(-1\)}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(equil = {PointSize[ .03], Point[{0, 0}], GrayLevel[1], 
          PointSize[ .02], Point[{0, 0}]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(\(wrongDirectionQ[mat_?MatrixQ]\)[{pt1_List, 
            pt2_, ___}] := \((\((pt2 - pt1)\) . \((mat . \((pt1 + pt2)\)/
                  2)\) < 0)\);\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Node (two nonvanishing real eigenvalues of the same sign)", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?nodeQ, opts___Rule] := 
        Module[{sim, diag, \[Lambda]1, \[Lambda]2, wrtRptQ, shwFldQ, 
            shwArrsQ, arwDnsty, n, style, fld, xmax, ymax, sol, vert, orizz, 
            r, coeffList, basicTrajs, 
            allTrajs}, \[IndentingNewLine]{sim, diag} = 
            JordanDecomposition[
              mat]; \[IndentingNewLine]{\[Lambda]1, \[Lambda]2} = 
            Transpose[diag, {1, 1}]; \[IndentingNewLine]{wrtRptQ, shwFldQ, 
              shwArrsQ, arwDnsty, n, 
              style} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  NumberOfTrajectories + 1, NotableLineStyle} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print[If[\[Lambda]1 > 
                    0, "\<Repulsive\>", "\<Attractive\>"] <> "\< node\>"], 
            Null]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]{xmax, 
              ymax} = N[inverseRange[sim]]; \[IndentingNewLine]sol[c_] := 
            Map[N[sim] . # &, \(Plot[c*Abs[x]^\((\[Lambda]2/\[Lambda]1)\), 
                    Evaluate[{x, \(-Min[xmax, r]\), Min[xmax, r]} /. 
                        r \[RuleDelayed] \((ymax/
                                Abs[c])\)^\((\[Lambda]1/\[Lambda]2)\)], 
                    DisplayFunction \[Rule] Identity]\)[\([1, 1, 1]\)] /. 
                Line[{a___, {x1_?NonPositive, y1_}, {x2_?NonNegative, y2_}, 
                      b___}] \[RuleDelayed] {Line[{a, {x1, y1}, {0, 0}}], 
                    Line[{{0, 0}, {x2, y2}, 
                        b}]}, {3}]; \[IndentingNewLine]vert = {style, 
                Map[N[sim] . # &, {Line[{{0, \(-ymax\)}, \(-{0, 0}\)/10^3}], 
                    Line[{{0, 0}/10^3, {0, ymax}}]}, {3}]} // 
              Flatten; \[IndentingNewLine]orizz = {style, 
                Map[N[sim] . # &, {Line[{{\(-xmax\), 0}, { .01,  .01}}], 
                    Line[{{0, 0}/10^3, {xmax, 0}}]}, {3}]} // 
              Flatten; \[IndentingNewLine]coeffList = \(Join[#, \(-#\)] &\)[
              Table[\((1 - r)\)*
                  ymax/\((r*xmax)\)^\((\[Lambda]2/\[Lambda]1)\), {r, 1/n, 
                  1 - 1/n, 1/n}]]; \[IndentingNewLine]basicTrajs = {Map[sol, 
                coeffList], vert, orizz, 
              equil}; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                wrongDirectionQ[mat], arwDnsty, opts], 
              basicTrajs]; \[IndentingNewLine]Show[{If[shwFldQ, fld, 
                Sequence @@ {}], Graphics[allTrajs]}, 
            PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Saddle (two nonvanishing real eigenvalues with opposite \
signs)\
\>", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?saddleQ, opts___Rule] := 
        Module[{sim, diag, \[Lambda]1, \[Lambda]2, wrtRptQ, shwFldQ, 
            shwArrsQ, arwDnsty, n, style, fld, xmax, ymax, sol0, sol, 
            coeffList, vert, orizz, basicTrajs, 
            allTrajs}, \[IndentingNewLine]{sim, diag} = 
            JordanDecomposition[
              mat]; \[IndentingNewLine]{\[Lambda]1, \[Lambda]2} = {diag[\([1, 
                  1]\)], diag[\([2, 2]\)]}; \[IndentingNewLine]{wrtRptQ, 
              shwFldQ, shwArrsQ, arwDnsty, n, 
              style} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  NumberOfTrajectories + 1, NotableLineStyle} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print["\<Saddle\>"], Null]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]{xmax, 
              ymax} = N[inverseRange[sim]]; \[IndentingNewLine]sol0[
              c_] := \(Plot[c*Abs[x]^\((\[Lambda]2/\[Lambda]1)\), 
                Evaluate[{x, Abs[ymax/c]^\((\[Lambda]1/\[Lambda]2)\), 
                    Min[xmax, 1]}], DisplayFunction \[Rule] Identity]\)[\([1, 
                1, 1]\)]; \[IndentingNewLine]sol[
              c_] := {Map[N[sim] . # &, sol0[c], {2}], 
              Map[N[sim] . {{\(-1\), 0}, {0, 1}} . # &, 
                sol0[c], {2}]}; \[IndentingNewLine]coeffList = \(Join[#, \(-#\
\)] &\)[Table[r*ymax/\((r*xmax)\)^\((\[Lambda]2/\[Lambda]1)\), {r, 1/n, 
                  1 - 1/n, 1/n}]]; \[IndentingNewLine]vert = {style, 
                Map[N[sim] . # &, {Line[{{0, \(-ymax\)}, {0, 0}}], 
                    Line[{{0, 0}, {0, ymax}}]}, {3}]} // 
              Flatten; \[IndentingNewLine]orizz = {style, 
                Map[N[sim] . # &, {Line[{{\(-xmax\), 0}, {0, 0}}], 
                    Line[{{0, 0}, {xmax, 0}}]}, {3}]} // 
              Flatten; \[IndentingNewLine]basicTrajs = {Map[sol, coeffList], 
              vert, orizz, equil}; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                wrongDirectionQ[mat], arwDnsty, opts], basicTrajs]; 
          Show[{If[shwFldQ, fld, Sequence @@ {}], Graphics[allTrajs]}, 
            PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Two distinct real eigenvalues, one vanishing", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?singularDistinctEigenvaluesQ, 
          opts___?OptionQ] := 
        Module[{sim, canon, \[Lambda], wrtRptQ, shwFldQ, shwArrsQ, arwDnsty, 
            n, style, fld, trasf, xmax, ymax, sol, vert, coeffList, 
            basicTrajs, allTrajs}, \[IndentingNewLine]{sim, canon} = 
            JordanDecomposition[
              mat]; \[IndentingNewLine]\[Lambda] = \(Select[
                Flatten[canon], # =!= 0 &, 
                1]\)[\([1]\)]; \[IndentingNewLine]{wrtRptQ, shwFldQ, 
              shwArrsQ, arwDnsty, n, 
              style} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  NumberOfTrajectories, NotableLineStyle} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print["\<One null eigenvalue, the other one \>" <> 
                If[\[Lambda] > 0, "\<positive\>", "\<negative\>"]], 
            Null]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]trasf = 
            N[sim] . 
                If[canon[\([1, 1]\)] === \[Lambda], 
                  IdentityMatrix[
                    2], {{0, 1}, {1, 0}}] . # &; \[IndentingNewLine]{xmax, 
              ymax} = N[inverseRange[sim]]; \[IndentingNewLine]sol[c_] := 
            Map[trasf, {Line[{{\(-xmax\), c}, {0, c}}], 
                Line[{{0, c}, {xmax, 
                      c}}]}, {3}]; \[IndentingNewLine]vert = {{GrayLevel[1], 
                Thickness[ .04], 
                Line[trasf /@ {{0, \(-ymax\)}, {0, ymax}}]}, {RGBColor[1, 0, 
                    0], Dashing[{ .02,  .02}], Thickness[ .01], style, 
                  Line[trasf /@ {{0, \(-ymax\)}, {0, ymax}}]} // 
                Flatten}; \[IndentingNewLine]coeffList = 
            ymax*Range[\(-n\), n]/n; \[IndentingNewLine]basicTrajs = 
            Map[sol, coeffList]; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                wrongDirectionQ[mat], arwDnsty, opts], basicTrajs]; 
          Show[{If[shwFldQ, fld, Sequence @@ {}], 
              Graphics[{allTrajs, vert, equil}]}, 
            PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Improper node (two real coincident eigenvalues, but the matrix is \
not diagonal)\
\>", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?improperNodeQ, opts___Rule] := 
        Module[{sim, canon, \[Lambda], wrtRptQ, shwFldQ, shwArrsQ, arwDnsty, 
            n, style, fld, xmax, ymax, sol, u, coeffList, orizz, basicTrajs, 
            allTrajs}, \[IndentingNewLine]{sim, canon} = 
            N[JordanDecomposition[mat]]; \[IndentingNewLine]\[Lambda] = 
            canon[\([1, 1]\)]; \[IndentingNewLine]{wrtRptQ, shwFldQ, 
              shwArrsQ, arwDnsty, n, 
              style} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  2  NumberOfTrajectories, NotableLineStyle} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print[If[\[Lambda] > 
                    0, "\<Repulsive\>", "\<Attractive\>"] <> "\< improper \
node\>"], Null]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]{xmax, 
              ymax} = N[inverseRange[sim]]; \[IndentingNewLine]sol[c_] := 
            Map[N[sim] . 
                  Reverse[#] &, \(Plot[
                    c*y + y*
                        Log[Max[
                              Abs[y],  .000001  
                                ymax]]/\[Lambda], {y, \(-ymax\), ymax}, 
                    DisplayFunction \[Rule] Identity]\)[\([1, 1, 1]\)] /. 
                Line[{a___, {y1_?NonPositive, x1_}, {y2_?NonNegative, x2_}, 
                      b___}] \[RuleDelayed] {Line[{a, {y1, x1}, {0, 0}}], 
                    Line[{{0, 0}, {y2, x2}, 
                        b}]}, {3}]; \[IndentingNewLine]u = 
            Min[xmax, ymax]; \[IndentingNewLine]coeffList = 
            Table[\((Sin[r]*u - Cos[r]*u*Log[Cos[r]*u]/\[Lambda])\)/\((Cos[r]*
                    u)\), {r, \(-Pi\)/2 + Pi/n, Pi/2 - Pi/n, 
                Pi/n}]; \[IndentingNewLine]orizz = {style, 
                Map[N[sim] . # &, {Line[{{\(-xmax\), 0}, {0, 0}}], 
                    Line[{{0, 0}, {xmax, 0}}]}, {3}]} // 
              Flatten; \[IndentingNewLine]basicTrajs = {Map[sol, coeffList], 
              orizz, equil}; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                wrongDirectionQ[mat], arwDnsty, opts], basicTrajs]; 
          Show[{If[shwFldQ, fld, Sequence @@ {}], Graphics[allTrajs]}, 
            PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Nonvanishing multiple of the identity matrix", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?nonNullMultipleOfIdentity, opts___Rule] := 
        Module[{\[Lambda], wrtRptQ, shwFldQ, shwArrsQ, arwDnsty, n, fld, sol, 
            coeffList, basicTrajs, allTrajs}, \[IndentingNewLine]\[Lambda] = 
            mat[\([1, 1]\)]; \[IndentingNewLine]{wrtRptQ, shwFldQ, shwArrsQ, 
              arwDnsty, 
              n} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  NumberOfTrajectories} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print[If[\[Lambda] > 
                    0, "\<Repulsive\>", "\<Attractive\>"] <> "\< node with \
coincident eigenvalues\>"]]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]sol[
              c_] := {Line[2 {\(-{Cos[c], Sin[c]}\), {0, 0}}], 
              Line[2 {{0, 0}, {Cos[c], 
                      Sin[c]}}]}; \[IndentingNewLine]coeffList = 
            N[Pi*Range[
                    2  n]/\((2  n)\)]; \[IndentingNewLine]basicTrajs = {Map[
                sol, coeffList], equil}; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                wrongDirectionQ[mat], arwDnsty, opts], basicTrajs]; 
          Show[{If[shwFldQ, fld, Sequence @@ {}], Graphics[allTrajs]}, 
            PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Two null eigenvalues but the matrix is not null", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?nonNullNilpotentQ, opts___Rule] := 
        Module[{sim, canon, xmax, ymax, wrtRptQ, shwFldQ, shwArrsQ, arwDnsty, 
            n, style, fld, sol, orizz, provisional, coeffList, basicTrajs, 
            allTrajs}, \[IndentingNewLine]{sim, canon} = 
            JordanDecomposition[mat]; \[IndentingNewLine]{xmax, ymax} = 
            N[inverseRange[sim]]; \[IndentingNewLine]{wrtRptQ, shwFldQ, 
              shwArrsQ, arwDnsty, n, 
              style} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  NumberOfTrajectories, NotableLineStyle} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print["\<Two null eigenvalues\>"], Null]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]sol[c_] := 
            Map[N[sim] . # &, {Line[{{\(-xmax\), c}, {0, c}}], 
                Line[{{0, c}, {xmax, 
                      c}}]}, {3}]; \[IndentingNewLine]orizz = {{GrayLevel[1], 
                Thickness[ .04], 
                provisional[\((N[sim] . # &)\) /@ {{\(-xmax\), 0}, {xmax, 
                        0}}]}, {RGBColor[1, 0, 0], Dashing[{ .02,  .02}], 
                  Thickness[ .01], style, 
                  provisional[\((N[sim] . # &)\) /@ {{\(-xmax\), 0}, {xmax, 
                          0}}]} // Flatten}; \[IndentingNewLine]coeffList = 
            ymax*Complement[Range[\(-n\), n], {0}]/
                n; \[IndentingNewLine]basicTrajs = {Map[sol, coeffList], 
              orizz, equil}; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
                clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                  wrongDirectionQ[mat], arwDnsty, opts], basicTrajs] /. 
              provisional \[Rule] Line; 
          Show[{If[shwFldQ, fld, Sequence @@ {}], Graphics[allTrajs]}, 
            PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Null matrix", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?nullMatrixQ, 
          opts___Rule] := \[IndentingNewLine]Show[Graphics[equil], 
          PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
          FilterOptions[Plot, 
            opts], \[IndentingNewLine]If[\(WriteReport /. {opts}\) /. 
              Options[LinearPhasePlot2D], Print["\<Null matrix\>"], 
            Null]; \[IndentingNewLine]FilterOptions[Plot, 
            Options[LinearPhasePlot2D]], 
          DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Center (purely imaginary conjugated eigenvalues)", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?centerQ, opts___Rule] := 
        Module[{sim, canon, xmax, ymax, wrtRptQ, shwFldQ, shwArrsQ, arwDnsty, 
            n, style, fld, symAxes, \[Theta]0, unitCirc, sol, coeffList, 
            basicTrajs, allTrajs, ax}, \[IndentingNewLine]{sim, canon} = 
            realCanonicalForm[mat]; \[IndentingNewLine]{xmax, ymax} = 
            N[inverseRange[sim]]; \[IndentingNewLine]{wrtRptQ, shwFldQ, 
              shwArrsQ, arwDnsty, n, 
              style} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  1 + NumberOfTrajectories, NotableLineStyle} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print["\<Center (periodic orbits)\>"], 
            Null]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] 
                Identity]; \[IndentingNewLine]symAxes = \(Eigensystem[
                Transpose[sim] . 
                  sim]\)[\([2]\)]; \[IndentingNewLine]\[Theta]0 = 
            N[ArcTan @@ symAxes[\([1]\)]] + Pi/2; 
          unitCirc = 
            Line[Table[{Cos[\[Theta]], 
                    Sin[\[Theta]]}, {\[Theta], \[Theta]0, \[Theta]0 + 2  Pi - 
                      2  Pi/80. , 2  Pi/80. }]~
                Join~{{Cos[\[Theta]0], 
                    Sin[\[Theta]0]}}]; \[IndentingNewLine]sol[c_] := 
            Map[c*N[sim] . # &, 
              unitCirc, {2}]; \[IndentingNewLine]coeffList = 
            Max[xmax, ymax]*
              Range[2, n]^2/n^2; \[IndentingNewLine]basicTrajs = 
            Map[sol, coeffList]; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                wrongDirectionQ[mat], arwDnsty, opts], basicTrajs]; 
          ax[i_] := {Dashing[{ .02,  .02}], style, 
                Map[N[sim] . # &, 
                  Line[Sqrt[2] 
                      Max[xmax, ymax]/
                        Sqrt[symAxes[\([i]\)] . 
                            symAxes[\([i]\)]] {\(-symAxes[\([i]\)]\), 
                        symAxes[\([i]\)]}], {2}]} // 
              Flatten; \[IndentingNewLine]Show[{If[shwFldQ, fld, 
                Sequence @@ {}], Graphics[{allTrajs, ax[1], ax[2], equil}]}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Spiral (complex conjugate eigenvalues with nonvanishing real \
part)\
\>", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?spiralQ, opts___Rule] := 
        Module[{sim, canon, xmax, ymax, \[Alpha], \[Beta], wrtRptQ, shwFldQ, 
            shwArrsQ, arwDnsty, n, style, fld, basicSpir, sol, coeffList, 
            basicTrajs, allTrajs, symAxes, 
            ax}, \[IndentingNewLine]{sim, canon} = 
            realCanonicalForm[mat]; {xmax, ymax} = 
            N[inverseRange[
                sim]]; \[IndentingNewLine]{\[Alpha], \[Beta]} = {canon[\([1, 
                  1]\)], canon[\([2, 1]\)]}; \[IndentingNewLine]{wrtRptQ, 
              shwFldQ, shwArrsQ, arwDnsty, n, 
              style} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  2  NumberOfTrajectories, NotableLineStyle} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print[If[\[Alpha] > 
                    0, "\<Repulsive\>", "\<Attractive\>"] <> "\< spirals\>"], 
            Null]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] 
                Identity]; \[IndentingNewLine]basicSpir = \(ParametricPlot[
                Exp[\[Alpha]*\[Theta]] {Cos[\[Beta]*\[Theta]], 
                    Sin[\[Beta]*\[Theta]]}, 
                Evaluate[{\[Theta], Log[ .01  Min[xmax, ymax]]/\[Alpha], 
                    Log[Sqrt[xmax^2 + ymax^2]]/\[Alpha]}], 
                DisplayFunction \[Rule] Identity]\)[\([1, 1, 
                1]\)]; \[IndentingNewLine]sol[c_] := 
            Map[N[sim] . {{Cos[c], Sin[c]}, {\(-Sin[c]\), Cos[c]}} . # &, 
              basicSpir, {2}]; 
          coeffList = Range[n]*2  Pi/n; \[IndentingNewLine]basicTrajs = 
            Map[sol, coeffList]; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                wrongDirectionQ[mat], arwDnsty, opts], basicTrajs]; 
          symAxes = \(Eigensystem[Transpose[sim] . sim]\)[\([2]\)]; 
          ax[i_] := {Dashing[{ .02,  .02}], style, 
                Map[N[sim] . # &, 
                  Line[Sqrt[2] 
                      Max[xmax, ymax]/
                        Sqrt[symAxes[\([i]\)] . 
                            symAxes[\([i]\)]] {\(-symAxes[\([i]\)]\), 
                        symAxes[\([i]\)]}], {2}]} // 
              Flatten; \[IndentingNewLine]Show[{If[shwFldQ, fld, 
                Sequence @@ {}], Graphics[{allTrajs, ax[1], ax[2], equil}]}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Trig Interpolation curves", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Open curve TrigInterpolation", "Section"],

Cell["A utility:", "Text"],

Cell[BoxData[
    \(\(trigFunctionsAndValueMatrix[conditionsStructure_List, timesList_List, 
          t_Symbol, periodLength_: \((2  Pi)\)] := 
        Module[{numberOfConditions, baseFunctions, f, 
            g}, \[IndentingNewLine]numberOfConditions = \(conditionsStructure \
// Flatten\) // Length; \[IndentingNewLine]baseFunctions[r_] = 
            Take[Flatten[
                Join[{1}, 
                  Table[{Cos[2  Pi*k*r/periodLength], 
                      Sin[2  Pi*k*r/periodLength]}, {k, 
                      Ceiling[numberOfConditions/2] + 1}]]], 
              numberOfConditions + 1]; \[IndentingNewLine]f[
              a_, {k_, j_:  1}] := \(\(Derivative[j - 1]\)[g]\)[
              timesList[\([k]\)]]; \[IndentingNewLine]{g[t], 
              Flatten[MapIndexed[f, conditionsStructure, {\(-1\)}]]} /. 
            g \[Rule] baseFunctions];\)\)], "Input",
  InitializationCell->True],

Cell["Cartesian one-dimensional case:", "Text"],

Cell[BoxData[{
    \(\(Options[TrigInterpolation] = 
        Join[{EvaluateOnCoefficients \[Rule] Identity, 
            Period \[Rule] Automatic}, 
          Options[LinearSolve]];\)\), "\[IndentingNewLine]", 
    \(\(TrigInterpolation[
          pointList : {{_?NumericQ, __?NumericQ | {__?NumericQ}} .. }, 
          t_Symbol, opts___?OptionQ] := 
        Module[{funct, xlist, derivativesList, xmin, xmax, pl, periodLength, 
            derivativesListStructure, trigValueMatrix, 
            coeff}, \[IndentingNewLine]funct = \(EvaluateOnCoefficients /. \
{opts}\) /. Options[TrigInterpolation]; \[IndentingNewLine]xlist = 
            Map[First, pointList]; \[IndentingNewLine]derivativesList = 
            Map[Flatten[Rest[#]] &, pointList]; \[IndentingNewLine]{xmin, 
              xmax} = {Min[xlist], 
              Max[xlist]}; \[IndentingNewLine]pl = \(Period /. {opts}\) /. 
              Options[TrigInterpolation]; \[IndentingNewLine]periodLength = 
            Which[pl === Automatic, \((xmax - xmin)\)*3, 
              Element[N[pl], Reals] === True, pl, 
              True, \((xmax - 
                    xmin)\)*3]; \[IndentingNewLine]derivativesListStructure = 
            derivativesList /. _?NumericQ \[Rule] 
                1; \[IndentingNewLine]{baseFunctions, trigValueMatrix} = 
            trigFunctionsAndValueMatrix[derivativesListStructure, xlist, t, 
              periodLength]; \[IndentingNewLine]coeff = 
            Map[funct, 
              LinearSolve[trigValueMatrix, Flatten[derivativesList], 
                FilterOptions[LinearSolve, opts]]]; \[IndentingNewLine]If[
            Head[coeff] === LinearSolve, Null, 
            coeff . baseFunctions]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolation[pointList : {__?NumericQ}, t_Symbol, 
          opts___?OptionQ] := 
        TrigInterpolation[Transpose[{Range[Length[pointList]], pointList}], 
          t, opts];\)\)], "Input",
  InitializationCell->True],

Cell["Case of interpolating parametric curve in the plane:", "Text"],

Cell[BoxData[{
    \(\(Options[OpenCurveInterpolation] = 
        Join[{EvaluateOnCoefficients \[Rule] Identity, 
            ShowTimesListQ \[Rule] False, Period \[Rule] Automatic}, 
          Options[LinearSolve]];\)\), "\[IndentingNewLine]", 
    \(\(OpenCurveInterpolation[
          pointList : {\(({_?NumericQ, _?
                        NumericQ} | {{_?NumericQ, _?NumericQ} .. })\) .. }, 
          t_Symbol, opts___?OptionQ] := 
        Module[{stlQ, funct, x, y, conditionsStructure, conditionsPerPoint, 
            timesList, tmax, pl, periodLength, baseFunctions, 
            trigValueMatrix, coeffx, coeffy, 
            result}, \[IndentingNewLine]stlQ = \((\((\(ShowTimesListQ /. \
{opts}\) /. Options[ClosedCurveInterpolation])\) === 
                True)\); \[IndentingNewLine]funct = \(EvaluateOnCoefficients /. \
{opts}\) /. Options[ClosedCurveInterpolation]; \[IndentingNewLine]x = 
            pointList /. {a_?NumericQ, _} \[RuleDelayed] 
                a; \[IndentingNewLine]y = 
            pointList /. {_, b_?NumericQ} \[RuleDelayed] 
                b; \[IndentingNewLine]conditionsStructure = 
            x /. _?NumericQ \[Rule] 
                1; \[IndentingNewLine]conditionsPerPoint = 
            Map[Length[Flatten[#]] &, pointList]/
              2; \[IndentingNewLine]timesList = 
            FoldList[Plus, 0, ListConvolve[{1, 1}, conditionsPerPoint]]; 
          tmax = Last[
              timesList]; \[IndentingNewLine]pl = \(Period /. {opts}\) /. 
              Options[OpenCurveInterpolation]; \
\[IndentingNewLine]periodLength = 
            Which[pl === Automatic, tmax*3, Element[N[pl], Reals] === True, 
              pl, True, tmax*3]; \[IndentingNewLine]{baseFunctions, 
              trigValueMatrix} = 
            trigFunctionsAndValueMatrix[conditionsStructure, timesList, t, 
              periodLength]; \[IndentingNewLine]coeffx = 
            Map[funct, 
              LinearSolve[trigValueMatrix, Flatten[x], 
                FilterOptions[LinearSolve, 
                  opts]]]; \[IndentingNewLine]coeffy = 
            Map[funct, 
              LinearSolve[trigValueMatrix, Flatten[y], 
                FilterOptions[LinearSolve, 
                  opts]]]; \[IndentingNewLine]result = \
\[IndentingNewLine]{baseFunctions . coeffx, 
              baseFunctions . coeffy}; \[IndentingNewLine]If[
            Or[Head[coeffx] === LinearSolve, Head[coeffy] === LinearSolve], 
            Null, {result, 
              If[stlQ, timesList, Sequence @@ {}]}]];\)\)}], "Input",
  InitializationCell->True],

Cell["\<\
Case of interpolating parametric curve in the the three-dimensional \
case:\
\>", "Text"],

Cell[BoxData[
    \(\(OpenCurveInterpolation[
          pointList : {\(({_?NumericQ, _?NumericQ, _?
                        NumericQ} | {{_?NumericQ, _?NumericQ, _?
                            NumericQ} .. })\) .. }, t_Symbol, 
          opts___?OptionQ] := 
        Module[{stlQ, funct, x, y, conditionsStructure, conditionsPerPoint, 
            timesList, tmax, pl, periodLength, baseFunctions, 
            trigValueMatrix, coeffx, coeffy, 
            result}, \[IndentingNewLine]stlQ = \((\((\(ShowTimesListQ /. \
{opts}\) /. Options[ClosedCurveInterpolation])\) === 
                True)\); \[IndentingNewLine]funct = \(EvaluateOnCoefficients /. \
{opts}\) /. Options[ClosedCurveInterpolation]; \[IndentingNewLine]x = 
            pointList /. {a_?NumericQ, __} \[RuleDelayed] 
                a; \[IndentingNewLine]y = 
            pointList /. {_, b_?NumericQ, _} \[RuleDelayed] 
                b; \[IndentingNewLine]z = 
            pointList /. {_, _, c_?NumericQ} \[RuleDelayed] 
                c; \[IndentingNewLine]conditionsStructure = 
            x /. _?NumericQ \[Rule] 
                1; \[IndentingNewLine]conditionsPerPoint = 
            Map[Length[Flatten[#]] &, pointList]/
              2; \[IndentingNewLine]timesList = 
            FoldList[Plus, 0, ListConvolve[{1, 1}, conditionsPerPoint]]; 
          tmax = Last[
              timesList]; \[IndentingNewLine]pl = \(Period /. {opts}\) /. 
              Options[OpenCurveInterpolation]; \
\[IndentingNewLine]periodLength = 
            Which[pl === Automatic, tmax*3, Element[N[pl], Reals] === True, 
              pl, True, tmax*3]; \[IndentingNewLine]{baseFunctions, 
              trigValueMatrix} = 
            trigFunctionsAndValueMatrix[conditionsStructure, timesList, t, 
              periodLength]; \[IndentingNewLine]coeffx = 
            Map[funct, 
              LinearSolve[trigValueMatrix, Flatten[x], 
                FilterOptions[LinearSolve, 
                  opts]]]; \[IndentingNewLine]coeffy = 
            Map[funct, 
              LinearSolve[trigValueMatrix, Flatten[y], 
                FilterOptions[LinearSolve, 
                  opts]]]; \[IndentingNewLine]coeffz = 
            Map[funct, 
              LinearSolve[trigValueMatrix, Flatten[z], 
                FilterOptions[LinearSolve, 
                  opts]]]; \[IndentingNewLine]result = \
\[IndentingNewLine]{baseFunctions . coeffx, baseFunctions . coeffy, 
              baseFunctions . coeffz}; \[IndentingNewLine]If[
            Or[Head[coeffx] === LinearSolve, Head[coeffy] === LinearSolve], 
            Null, {result, 
              If[stlQ, timesList, Sequence @@ {}]}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Closed curve TrigInterpolation", "Section"],

Cell["Two-dimensional case:", "Text"],

Cell[BoxData[{
    \(\(Options[ClosedCurveInterpolation] = 
        Join[{EvaluateOnCoefficients \[Rule] Identity, 
            ShowTimesListQ \[Rule] False}, 
          Options[LinearSolve]];\)\), "\[IndentingNewLine]", 
    \(\(ClosedCurveInterpolation[
          pointList : {\(({_?NumericQ, _?
                        NumericQ} | {{_?NumericQ, _?NumericQ} .. })\) .. }, 
          t_Symbol, opts___?OptionQ] := 
        Module[{stlQ, funct, x, y, conditionsStructure, conditionsPerPoint, 
            timesList, r, f, g, baseFunctions, trigValueMatrix, coeffx, 
            coeffy, result}, \[IndentingNewLine]stlQ = \((\((\(ShowTimesListQ \
/. {opts}\) /. Options[ClosedCurveInterpolation])\) === 
                True)\); \[IndentingNewLine]funct = \(EvaluateOnCoefficients /. \
{opts}\) /. Options[ClosedCurveInterpolation]; \[IndentingNewLine]x = 
            pointList /. {a_?NumericQ, _} \[RuleDelayed] 
                a; \[IndentingNewLine]y = 
            pointList /. {_, b_?NumericQ} \[RuleDelayed] 
                b; \[IndentingNewLine]conditionsStructure = 
            x /. _?NumericQ \[Rule] 
                1; \[IndentingNewLine]conditionsPerPoint = 
            Map[Length[Flatten[#]] &, pointList]/
              2; \[IndentingNewLine]timesList = 
            2  Pi \((Drop[#, \(-1\)]/Last[#] &)\)[
                FoldList[Plus, 0, 
                  ListConvolve[{1, 1}, 
                    conditionsPerPoint, {1, 
                      1}]]]; \[IndentingNewLine]{baseFunctions, 
              trigValueMatrix} = 
            trigFunctionsAndValueMatrix[conditionsStructure, timesList, 
              t]; \[IndentingNewLine]coeffx = 
            Map[funct, 
              LinearSolve[trigValueMatrix, Flatten[x], 
                FilterOptions[LinearSolve, 
                  opts]]]; \[IndentingNewLine]coeffy = 
            Map[funct, 
              LinearSolve[trigValueMatrix, Flatten[y], 
                FilterOptions[LinearSolve, 
                  opts]]]; \[IndentingNewLine]result = \
\[IndentingNewLine]{baseFunctions . coeffx, 
              baseFunctions . coeffy}; \[IndentingNewLine]If[
            Or[Head[coeffx] === LinearSolve, Head[coeffy] === LinearSolve], 
            Null, If[stlQ, {result, timesList}, result]]];\)\)}], "Input",
  InitializationCell->True],

Cell["Three-dimensional case:", "Text"],

Cell[BoxData[
    \(\(ClosedCurveInterpolation[
          pointList : {\(({_?NumericQ, _?NumericQ, _?
                        NumericQ} | {{_?NumericQ, _?NumericQ, _?
                            NumericQ} .. })\) .. }, t_Symbol, 
          opts___?OptionQ] := 
        Module[{stlQ, funct, x, y, conditionsStructure, conditionsPerPoint, 
            timesList, r, f, g, baseFunctions, trigValueMatrix, coeffx, 
            coeffy, result}, \[IndentingNewLine]stlQ = \((\((\(ShowTimesListQ \
/. {opts}\) /. Options[ClosedCurveInterpolation])\) === 
                True)\); \[IndentingNewLine]funct = \(EvaluateOnCoefficients /. \
{opts}\) /. Options[ClosedCurveInterpolation]; \[IndentingNewLine]x = 
            pointList /. {a_?NumericQ, __} \[RuleDelayed] 
                a; \[IndentingNewLine]y = 
            pointList /. {_, b_?NumericQ, _} \[RuleDelayed] 
                b; \[IndentingNewLine]z = 
            pointList /. {_, _, c_?NumericQ} \[RuleDelayed] 
                c; \[IndentingNewLine]conditionsStructure = 
            x /. _?NumericQ \[Rule] 
                1; \[IndentingNewLine]conditionsPerPoint = 
            Map[Length[Flatten[#]] &, pointList]/
              2; \[IndentingNewLine]timesList = 
            2  Pi \((Drop[#, \(-1\)]/Last[#] &)\)[
                FoldList[Plus, 0, 
                  ListConvolve[{1, 1}, 
                    conditionsPerPoint, {1, 
                      1}]]]; \[IndentingNewLine]{baseFunctions, 
              trigValueMatrix} = 
            trigFunctionsAndValueMatrix[conditionsStructure, timesList, 
              t]; \[IndentingNewLine]coeffx = 
            Map[funct, 
              LinearSolve[trigValueMatrix, Flatten[x], 
                FilterOptions[LinearSolve, 
                  opts]]]; \[IndentingNewLine]coeffy = 
            Map[funct, 
              LinearSolve[trigValueMatrix, Flatten[y], 
                FilterOptions[LinearSolve, 
                  opts]]]; \[IndentingNewLine]coeffz = 
            Map[funct, 
              LinearSolve[trigValueMatrix, Flatten[z], 
                FilterOptions[LinearSolve, 
                  opts]]]; \[IndentingNewLine]result = \
\[IndentingNewLine]{baseFunctions . coeffx, baseFunctions . coeffy, 
              baseFunctions . coeffz}; \[IndentingNewLine]If[
            Or[Head[coeffx] === LinearSolve, Head[coeffy] === LinearSolve], 
            Null, If[stlQ, {result, timesList}, result]]];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "A single function that combines ",
  StyleBox["OpenCurveInterpolation", "Input"],
  " and ",
  StyleBox["ClosedCurveInterpolation", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(checkDimensions[pointList_] := 
        MemberQ[{{2}, {3}}, 
          Union@Map[Length, Level[pointList, {\(-2\)}]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(ParametricTrigInterpolation[
        pointList : {\(({__?NumericQ} | {{__?NumericQ} .. })\) .. } /; 
          checkDimensions[pointList], t_Symbol, 
        opts___?OptionQ] := \[IndentingNewLine]If[
        TrueQ[ClosedCurve /. {opts}], 
        ClosedCurveInterpolation[pointList, t, 
          opts], \[IndentingNewLine]OpenCurveInterpolation[pointList, t, 
          opts]]\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigInterpolation curve plot", "Section"],

Cell["One-dimensional cartesian curve case:", "Text"],

Cell[BoxData[{
    \(\(Options[TrigInterpolationPlot] = {ShowListPlot \[Rule] False, 
          ListPlotStyle \[Rule] PointSize[ .02], 
          ShowFormula \[Rule] False};\)\), "\[IndentingNewLine]", 
    \(\(TrigInterpolationPlot[
          pointList : {{_?NumericQ, __?NumericQ | {__?NumericQ}} .. }, 
          xmin_?NumericQ, xmax_?NumericQ, opts___?OptionQ] := 
        Module[{slpQ, sformQ, interpFunct, t, curve, listPl, 
            finalPlot}, \[IndentingNewLine]{slpQ, sformQ} = 
            Map[TrueQ, \({ShowListPlot, ShowFormula} /. {opts}\) /. 
                Options[
                  TrigInterpolationPlot]]; \[IndentingNewLine]interpFunct = 
            TrigInterpolation[pointList, t, 
              FilterOptions[TrigInterpolation, opts]]; \[IndentingNewLine]If[
            interpFunct === Null, Return[Null]]; \[IndentingNewLine]curve = 
            Plot[interpFunct, {t, xmin, xmax}, 
              DisplayFunction \[Rule] Identity, 
              Evaluate[
                FilterOptions[Plot, opts]]]; \[IndentingNewLine]listPl := 
            ListPlot[
              Map[Take[#, 2] &, 
                pointList /. {n_?NumberQ, {m__?NumberQ}} \[RuleDelayed] {n, 
                      m}], PlotStyle \[Rule] \((\(ListPlotStyle /. {opts}\) /. 
                    Options[TrigInterpolationPlot])\), 
              DisplayFunction \[Rule] 
                Identity]; \[IndentingNewLine]finalPlot := 
            Show[If[slpQ, {curve, listPl}, curve], 
              Evaluate[
                FilterOptions[Graphics, opts, 
                  DisplayFunction \[Rule] $DisplayFunction]]]; \
\[IndentingNewLine]If[
            sformQ, {finalPlot, 
              Evaluate[interpFunct /. t \[Rule] Slot[1]] &}, 
            finalPlot]];\)\)}], "Input",
  InitializationCell->True],

Cell["Parametric case, in either 2 and 3 dimensional space:", "Text"],

Cell[BoxData[{
    \(\(\(Options[TrigInterpolationParametricPlot] = 
        Join[{OrientedCurve \[Rule] False, ClosedCurve \[Rule] False, 
            FilledClosedCurve \[Rule] False, ShowListPlot \[Rule] False, 
            ListPlotStyle \[Rule] PointSize[ .02], ShowFormula \[Rule] False, 
            ShowTimesListQ \[Rule] False}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(TrigInterpolationParametricPlot[
          pointList : {\(({__?NumericQ} | {{__?NumericQ} .. })\) .. } /; 
            checkDimensions[pointList], 
          opts___?OptionQ] := \[IndentingNewLine]Module[{dimen, orntdQ, 
            clsdQ, filledclsdQ, slpQ, sformQ, stlstQ, paramCurve, tmax, 
            basicPlot, pointsPlot, 
            endPlot}, \[IndentingNewLine]dimen = \(Level[
                  pointList, {\(-2\)}] // First\) // 
              Length; \[IndentingNewLine]{orntdQ, clsdQ, filledclsdQ, slpQ, 
              sformQ, stlstQ} = 
            Map[TrueQ, \({OrientedCurve, ClosedCurve, FilledClosedCurve, 
                    ShowListPlot, ShowFormula, ShowTimesListQ} /. {opts}\) /. 
                Options[InterpolationParametricPlot]]; \[IndentingNewLine]If[
            TrueQ[0 < HowManyArrows /. {opts}], 
            orntdQ = True]; \[IndentingNewLine]If[
            TrueQ[MatchQ[
                ArrowPositions /. {opts}, {__?NumericQ} | _?NumericQ]], 
            orntdQ = True]; \[IndentingNewLine]If[filledclsdQ, 
            clsdQ = True]; \[IndentingNewLine]If[
            Not@clsdQ, {paramCurve, tlst} = 
              OpenCurveInterpolation[pointList, t, 
                ShowTimesListQ \[Rule] True, 
                Evaluate[
                  FilterOptions[OpenCurveInterpolation, 
                    opts]]]]; \[IndentingNewLine]If[
            clsdQ, {paramCurve, tlst} = 
              ClosedCurveInterpolation[pointList, t, 
                ShowTimesListQ \[Rule] True, 
                Evaluate[
                  FilterOptions[ClosedCurveInterpolation, 
                    opts]]]]; \[IndentingNewLine]If[paramCurve === Null, 
            Return[Null]]; \[IndentingNewLine]tmax = 
            If[clsdQ, 2  Pi, Last@tlst]; \[IndentingNewLine]If[
            dimen \[Equal] 2, 
            basicPlot = 
              OrientedParametricPlot[
                  Evaluate@\(Chop@\(N@paramCurve\)\), {t, 0, tmax}, 
                  DisplayFunction \[Rule] Identity, 
                  Evaluate[
                    If[orntdQ, Sequence @@ {}, HowManyArrows \[Rule] 0]], 
                  Evaluate[FilterOptions[OrientedParametricPlot, opts]]] /. 
                If[filledclsdQ, 
                  Line[pts_] \[RuleDelayed] {{Sequence @@ 
                          Flatten[{\(Graphics`FilledPlot`Fills /. {opts}\) /. \
{Graphics`FilledPlot`Fills \[Rule] GrayLevel[ .5]}}], Polygon[pts]}, 
                      Line[pts]}, {}]]; \[IndentingNewLine]If[
            dimen \[Equal] 3, \[IndentingNewLine]If[
              And[orntdQ, Not@DrawGraphicsInstalledQ], 
              Message[Oriented::"\<DrawGraphics not installed\>"]]; \
\[IndentingNewLine]Off[
              Oriented::"\<DrawGraphics not installed\>"]; \
\[IndentingNewLine]basicPlot = 
              OrientedParametricPlot3D[
                Evaluate@\(Chop@\(N@paramCurve\)\), {t, 0, tmax}, 
                DisplayFunction \[Rule] Identity, 
                Evaluate[
                  If[orntdQ, Sequence @@ {}, HowManyArrows \[Rule] 0]], 
                Evaluate[
                  FilterOptions[OrientedParametricPlot3D, 
                    opts]]]; \[IndentingNewLine]On[
              Oriented::"\<DrawGraphics not installed\>"]]; \
\[IndentingNewLine]pointsPlot := \(If[dimen \[Equal] 2, Graphics, 
                Graphics3D]\)[{Sequence @@ 
                  Flatten[{\(ListPlotStyle /. {opts}\) /. 
                        Options[TrigInterpolationParametricPlot]}], 
                Map[Point[Take[Flatten[#], dimen]] &, 
                  pointList]}]; \[IndentingNewLine]endPlot := 
            Show[If[slpQ, {basicPlot, 
                  pointsPlot}, \[IndentingNewLine]basicPlot], \
\[IndentingNewLine]Evaluate[FilterOptions[Graphics, opts]], 
              DisplayFunction \[Rule] $DisplayFunction]; \
\[IndentingNewLine]info := \(If[stlstQ, {#, tlst}, #] &\)[
              Evaluate[
                  paramCurve /. t \[Rule] Slot[1]] &]; \[IndentingNewLine]If[
            sformQ, {endPlot, info}, endPlot]];\)\)}], "Input",
  InitializationCell->True],

Cell[TextData[{
  "In 3D-space we provide a separate function, just for naming consistency, \
even if ",
  StyleBox["TrigInterpolationPlot", "Input"],
  " already does the job:"
}], "Text"],

Cell[BoxData[
    \(\(TrigInterpolationParametricPlot3D[
          pointList : {\(({_?NumericQ, _?NumericQ, _?
                        NumericQ} | {{_?NumericQ, _?NumericQ, _?
                            NumericQ} .. })\) .. }, 
          opts___] := \[IndentingNewLine]InterpolationParametricPlot[
          pointList, opts];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The ",
  StyleBox["Draw", "Input"],
  " parallels to ",
  StyleBox["Plot", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(TrigInterpolationDraw[
          pointList : {{_?NumericQ, __?NumericQ | {__?NumericQ}} .. }, 
          xmin_?NumericQ, xmax_?NumericQ, opts___?OptionQ] := 
        Block[{$DisplayFunction = 
              Identity}, \[IndentingNewLine]TrigInterpolationPlot[pointList, 
              xmin, xmax, opts] /. 
            Graphics[gr_, ___] \[RuleDelayed] gr];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationParametricDraw[
          pointList : {\(({__?NumericQ} | {{__?NumericQ} .. })\) .. } /; 
            checkDimensions[pointList], opts___?OptionQ] := 
        Block[{$DisplayFunction = 
              Identity}, \[IndentingNewLine]TrigInterpolationParametricPlot[
              pointList, opts] /. {Graphics[gr_, ___] \[RuleDelayed] gr, 
              Graphics3D[gr_, ___] \[RuleDelayed] gr}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationParametricDraw3D[
          pointList : {\(({_?NumericQ, _?NumericQ, _?
                          NumericQ} | {{_?NumericQ, _?NumericQ, _?
                              NumericQ} .. })\) .. } /; 
            checkDimensions[pointList], opts___?OptionQ] := 
        Block[{$DisplayFunction = 
              Identity}, \[IndentingNewLine]TrigInterpolationParametricPlot3D[
              pointList, opts] /. {Graphics[gr_, ___] \[RuleDelayed] gr, 
              Graphics3D[gr_, ___] \[RuleDelayed] gr}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Level set polynomial TrigInterpolation", "Section"],

Cell["\<\
Given a set of points (and possibly of tangent vectors, \
acceleration vectors etc.) in the plain, PolynomialLevelSetInterpolation \
attempts to find a two-variable polynomial whose 0-level set interpolates the \
given points.\
\>", "Text"],

Cell[BoxData[
    \(\(Options[PolynomialLevelSetTrigInterpolation] = 
        Options[ClosedCurveInterpolation];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PolynomialLevelSetTrigInterpolation::"\<NonExactInput\>" = \
"\<PolynomialLevelSetInterpolation is designed only for exact (infinite \
precision) numeric input.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PolynomialLevelSetTrigInterpolation[
          pointList : {\(({_?NumericQ, _?
                          NumericQ} | {{_?NumericQ, _?NumericQ} .. })\) .. } /; 
            Precision[pointList] < Infinity, t_Symbol, x_Symbol, y_Symbol, 
          opts___Rule] := \((Message[
            PolynomialLevelSetInterpolation::"\<NonExactInput\>"]; \
\[IndentingNewLine]Module[{closedQ, funct, parametricContour, maxDenom, poly, 
              a, b, simplifiedPoly}, \[IndentingNewLine]{closedQ, 
                funct} = \({ClosedCurve, EvaluateOnCoefficients} /. {opts}\) /. 
                Options[
                  ClosedCurveInterpolation]; \
\[IndentingNewLine]parametricContour = 
              ParametricTrigInterpolation[pointList, t, 
                opts]; \[IndentingNewLine]If[parametricContour === Null, 
              Return[Null]]; \[IndentingNewLine]maxDenom := 
              Max[1, Cases[parametricContour, 
                  Cos[Pi*t*Rational[_, n_]] | 
                      Sin[Pi*t*Rational[1, n_]] \[RuleDelayed] n, {0, 
                    Infinity}]]; \[IndentingNewLine]poly = 
              Eliminate[
                  Join[Thread[{x, y} == 
                          TrigExpand[
                            Take[Flatten[parametricContour], 2] /. 
                              If[TrueQ[closedQ], {}, 
                                t \[Rule] t*maxDenom/Pi]] /. {Cos[t] \[Rule] 
                            a, Sin[t] \[Rule] b}], {a^2 + b^2 \[Equal] 
                        1}], {a, b}] /. 
                Equal \[Rule] Subtract; \[IndentingNewLine]simplifiedPoly = 
              Collect[poly, {x^\((_ : 1)\) y^\((_ : 1)\), x^\((_ : 1)\), 
                  y^\((_ : 1)\)}, 
                funct]; \[IndentingNewLine]{parametricContour, 
              simplifiedPoly}])\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PolynomialLevelSetTrigInterpolation[
          pointList : {\(({_?NumericQ, _?
                          NumericQ} | {{_?NumericQ, _?NumericQ} .. })\) .. } /; 
            Precision[pointList] \[Equal] Infinity, t_Symbol, x_Symbol, 
          y_Symbol, opts___Rule] := 
        Module[{closedQ, funct, parametricContour, maxDenom, poly, a, b, 
            simplifiedPoly}, \[IndentingNewLine]{closedQ, 
              funct} = \({ClosedCurve, EvaluateOnCoefficients} /. {opts}\) /. 
              Options[ClosedCurveInterpolation]; \
\[IndentingNewLine]parametricContour = 
            ParametricTrigInterpolation[pointList, t, 
              opts]; \[IndentingNewLine]If[parametricContour === Null, 
            Return[Null]]; \[IndentingNewLine]maxDenom := 
            Max[1, Cases[parametricContour, 
                Cos[Pi*t*Rational[_, n_]] | 
                    Sin[Pi*t*Rational[1, n_]] \[RuleDelayed] n, {0, 
                  Infinity}]]; 
          poly = Eliminate[
                Join[Thread[{x, y} == 
                        TrigExpand[
                          Take[Flatten[parametricContour], 2] /. 
                            If[TrueQ[closedQ], {}, 
                              t \[Rule] t*maxDenom/Pi]] /. {Cos[t] \[Rule] a, 
                        Sin[t] \[Rule] b}], {a^2 + b^2 \[Equal] 1}], {a, b}] /. 
              Equal \[Rule] Subtract; \[IndentingNewLine]simplifiedPoly = 
            Collect[poly, {x^\((_ : 1)\) y^\((_ : 1)\), x^\((_ : 1)\), 
                y^\((_ : 1)\)}, 
              funct]; \[IndentingNewLine]{parametricContour, 
            simplifiedPoly}];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["LinearClipPlot3D", "Subsubtitle"],

Cell[BoxData[
    \(\(SetAttributes[LinearClipPlot3D, \ HoldRest];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[LinearClipPlot3D] = {PrepareForSlices \[Rule] False, 
          ReverseOrientation \[Rule] False, 
          ContourStyle \[Rule] Automatic};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipPlot3D[obj_SurfaceGraphics, other___] := 
        LinearClipPlot3D[Graphics3D[obj], other];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipPlot3D[obj_Graphics3D, 
          rel_ /; Or[
              MemberQ[{Less, LessEqual, Greater, GreaterEqual}, Head[rel]] && 
                Length[rel] > 2, Head[rel] === Inequality], var__Symbol, 
          opts___Rule] := 
        LinearClipPlot3D[obj, Evaluate@LogicalExpand[rel], var, 
            opts] //. {a___Rule, b_ \[Rule] c_, d___Rule, b_ \[Rule] f_, 
              g___Rule} \[RuleDelayed] {a, b \[Rule] c, d, g};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipPlot3D[obj_Graphics3D, rel_And, var__Symbol, opts___Rule] := 
        Show[Fold[
              LinearClipPlot3D[#1, #2, var, DisplayFunction \[Rule] Identity, 
                  opts] &, obj, 
              List @@ rel], \[IndentingNewLine]FilterOptions[Graphics3D, 
              opts], \[IndentingNewLine]Sequence @@ Rest[obj]] //. {a___Rule, 
              b_ \[Rule] c_, d___Rule, b_ \[Rule] f_, 
              g___Rule} \[RuleDelayed] {a, b \[Rule] c, d, g};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipPlot3D[obj_Graphics3D, 
            rel_ /; MemberQ[{Less, LessEqual, Greater, GreaterEqual}, 
                  Head[rel]] && Length[rel] \[Equal] 2, var__Symbol, 
            opts___Rule] /; \((PolynomialQ[Subtract @@ rel, {var}] && 
              Max[\((Exponent[Expand[Subtract @@ rel], #1] &)\) /@ {var}] === 
                1)\) := Module[{ratObj, strictRel, weakRel, strictNegRel, 
            weakNegRel, eqRel, interiorQ, weakInteriorQ, exteriorQ, 
            weakExteriorQ, onBoundaryQ, interiorQList, weakInteriorQList, 
            exteriorQList, weakExteriorQList, borderTouchingQ, flatOnPlaneQ, 
            toThrowQ, winnowed, inters, clipLine, removeDuplicatePts, 
            clipContour, beyondClipLine, beyondClipContour, prepareQ, 
            boundaryLine, crossPr, parallelPolygons, normalVectorToPolygon, 
            normalVectorToClipPlane, positivelyOrientedQ, 
            rulesForConnectingSegments, dontReverseQ, 
            removeDuplicateEndPoints, boundaryStyle, boundary, 
            withoutBoundary, 
            withClippedPolygons}, \[IndentingNewLine]ratObj = 
            Rationalize[obj, 1/10^6]; \[IndentingNewLine]If[
            Not[MatchQ[ratObj, Graphics3D[_List, ___]]], 
            MapAt[List, ratObj, 1]]; \[IndentingNewLine]strictRel = 
            Rationalize[
              rel /. \[InvisibleSpace]{LessEqual \[Rule] Less, 
                  GreaterEqual \[Rule] Greater}, 
              1/10^6]; \[IndentingNewLine]weakRel = 
            strictRel /. {Less \[Rule] LessEqual, 
                Greater \[Rule] 
                  GreaterEqual}; \[IndentingNewLine]strictNegRel = 
            strictRel /. {Less \[Rule] Greater, 
                Greater \[Rule] Less}; \[IndentingNewLine]weakNegRel = 
            strictNegRel /. {Less \[Rule] LessEqual, 
                Greater \[Rule] GreaterEqual}; \[IndentingNewLine]eqRel = 
            strictRel /. {Less \[Rule] Equal, 
                Greater \[Rule] Equal}; \[IndentingNewLine]interiorQ[
              pt_List] := 
            strictRel /. \[InvisibleSpace]Thread[{var} \[Rule] 
                  pt]; \[IndentingNewLine]weakInteriorQ[pt_List] := 
            weakRel /. \[InvisibleSpace]Thread[{var} \[Rule] 
                  pt]; \[IndentingNewLine]exteriorQ[pt_List] := 
            strictNegRel /. 
              Thread[{var} \[Rule] pt]; \[IndentingNewLine]weakExteriorQ[
              pt_List] := 
            weakNegRel /. \[InvisibleSpace]Thread[{var} \[Rule] pt]; 
          onBoundaryQ[pt_List] := 
            eqRel /. Thread[{var} \[Rule] 
                  pt]; \[IndentingNewLine]interiorQList[pts_List] := 
            interiorQ /@ pts; \[IndentingNewLine]weakInteriorQList[pts_List] := 
            weakInteriorQ /@ pts; \[IndentingNewLine]exteriorQList[pts_List] := 
            exteriorQ /@ pts; \[IndentingNewLine]weakExteriorQList[pts_List] := 
            weakExteriorQ /@ pts; 
          flatOnPlaneQ[pts_List] := 
            And[And @@ weakInteriorQList[pts], 
              And @@ weakExteriorQList[
                  pts]]; \[IndentingNewLine]borderTouchingQ[pts_List] := 
            And[Or @@ weakInteriorQList[pts], Or @@ weakExteriorQList[pts], 
              Not[flatOnPlaneQ[pts]]]; \[IndentingNewLine]toThrowQ[
              Polygon[pts_List]] := 
            Or[And @@ exteriorQList[pts]]; \[IndentingNewLine]winnowed = 
            ratObj /. \[InvisibleSpace]pol_Polygon?toThrowQ \[RuleDelayed] 
                Sequence @@ {}; \[IndentingNewLine]inters[pt1_List, 
              pt2_List] := 
            t\ pt1 + \((1 - t)\)\ pt2 /. \[InvisibleSpace]\(Solve[
                  eqRel /. \[InvisibleSpace]Thread[{var} \[Rule] 
                        t*pt1 + \((1 - t)\)\ pt2], t]\)[\([1]\)]; 
          clipLine[pt1_List?exteriorQ, pt2_List?exteriorQ] := Sequence @@ {}; 
          clipLine[pt1_List?interiorQ, pt2_List?weakExteriorQ] := {pt1, 
              inters[pt1, pt2]}; 
          clipLine[pt1_List?weakInteriorQ, pt2_List?exteriorQ] := {pt1, 
              inters[pt1, pt2]}; 
          clipLine[pt1_List?weakExteriorQ, 
              pt2_List?interiorQ] := {inters[pt1, pt2], pt2}; 
          clipLine[pt1_List?exteriorQ, 
              pt2_List?weakInteriorQ] := {inters[pt1, pt2], 
              pt2}; \[IndentingNewLine]clipLine[pt1_List?weakInteriorQ, 
              pt2_List?weakInteriorQ] := {pt1, 
              pt2}; \[IndentingNewLine]removeDuplicatePts = \(({a___, b_List, 
                  b_, c___} \[RuleDelayed] {a, b, 
                  c})\); \[IndentingNewLine]clipContour[pts_List] := 
            Flatten[Apply[clipLine, Partition[Append[pts, First[pts]], 2, 1], 
                  1], 1] //. 
              removeDuplicatePts; \[IndentingNewLine]beyondClipLine[
              pt1_List?interiorQ, pt2_List?interiorQ] := Sequence @@ {}; 
          beyondClipLine[pt1_List?weakInteriorQ, 
              pt2_List?exteriorQ] := {inters[pt1, pt2], 
              pt2}; \[IndentingNewLine]beyondClipLine[pt1_List?interiorQ, 
              pt2_List?weakExteriorQ] := {inters[pt1, pt2], pt2}; 
          beyondClipLine[pt1_List?exteriorQ, pt2_List?weakInteriorQ] := {pt1, 
              inters[pt1, pt2]}; 
          beyondClipLine[pt1_List?weakExteriorQ, pt2_List?interiorQ] := {pt1, 
              inters[pt1, pt2]}; 
          beyondClipLine[pt1_List?weakExteriorQ, 
              pt2_List?weakExteriorQ] := {pt1, 
              pt2}; \[IndentingNewLine]beyondClipContour[pts_List] := 
            Flatten[Apply[beyondClipLine, 
                  Partition[Append[pts, First[pts]], 2, 1], 1], 1] //. 
              removeDuplicatePts; \[IndentingNewLine]prepareQ = \
\(PrepareForSlices /. \[InvisibleSpace]{opts}\) /. \[InvisibleSpace]Options[
                LinearClipPlot3D]; 
          boundaryLine[clipCtr_List] := 
            Cases[Partition[clipCtr, 2, 
                1], {p__List?onBoundaryQ} \[RuleDelayed] 
                Line[{p}]]; \[IndentingNewLine]normalVectorToPolygon[
              polyPts_List] := 
            Cross @@ Map[
                Last[#] - First[#] &, {polyPts, 
                  RotateLeft[
                    polyPts]}]; \[IndentingNewLine]normalVectorToClipPlane = 
            Outer[D, {Subtract @@ rel}, {var}] // 
              First; \[IndentingNewLine]positivelyOrientedQ[polyPts_List, 
              boundaryPts_List] := 
            Positive[
              Det[{normalVectorToPolygon[polyPts], 
                  Last[boundaryPts] - First[boundaryPts], 
                  normalVectorToClipPlane}]]; \
\[IndentingNewLine]positivelyOrientedQ[polyPts_List, {}] := 
            False; \[IndentingNewLine]rulesForConnectingSegments = {\(({a___, 
                      Line[{b_List, c1_, c___}], d___, Line[{e___, e1_, b_}], 
                      f___} /; c1 =!= 
                      e1)\) \[RuleDelayed] \[IndentingNewLine]{Line[{e, e1, 
                      b, c1, c}], a, d, 
                  f}, \(({a___, Line[{c___, c1_, b_List}], d___, 
                      Line[{b_, e1_, e___}], f___} /; 
                    c1 =!= e1)\) \[RuleDelayed] {Line[{c, c1, b, e1, e}], a, 
                  d, f}}; \[IndentingNewLine]dontReverseQ = 
            Not@TrueQ[\(ReverseOrientation /. {opts}\) /. 
                  Options[
                    LinearClipPlot3D]]; \
\[IndentingNewLine]removeDuplicateEndPoints = 
            Polygon[{a_, b___, a_}] \[RuleDelayed] 
              Polygon[{a, 
                  b}]; \[IndentingNewLine]boundaryStyle = \(ContourStyle /. \
{opts}\) /. Options[LinearClipPlot3D]; \[IndentingNewLine]If[
            boundaryStyle === Automatic, 
            boundaryStyle = {}]; \[IndentingNewLine]crossPr[{a_, b_, 
                c_}, {e_, f_, g_}] = {\(-c\)\ f + b\ g, 
              c\ e - a\ g, \(-b\)\ e + 
                a\ f}; \[IndentingNewLine]parallelPolygons[{pt1_, pt2_, pt3_, 
                pts___}] := 
            With[{normal = crossPr[pt1 - pt2, pt2 - pt3]/10^10}, {Polygon[
                  Map[# + normal &, {pt1, pt2, pt3, pts}]], 
                Polygon[
                  Map[# - normal &, {pt1, pt2, pt3, 
                      pts}]]}]; \[IndentingNewLine]boundary = {}; \
\[IndentingNewLine]withoutBoundary := \(withoutBoundary = \(winnowed \
/. \[InvisibleSpace]{Polygon[
                        pts_List /; 
                          Length[pts] > 2 && 
                            flatOnPlaneQ[pts]] \[RuleDelayed] \((AppendTo[
                          boundary, parallelPolygons[pts]]; 
                        Polygon[pts])\), \[IndentingNewLine]Polygon[
                        pts_List?borderTouchingQ] \[RuleDelayed] 
                      Module[{clCon = clipContour[pts], 
                          bClCon = beyondClipContour[pts], 
                          bndLine}, \[IndentingNewLine]bndLine = 
                          Union[boundaryLine[
                                Join[clCon, bClCon] //. removeDuplicatePts] /. 
                              Line[segment_ /; 
                                    Not@positivelyOrientedQ[pts, 
                                        segment]] \[RuleDelayed] 
                                Line[Reverse[
                                    segment]]]; \[IndentingNewLine]AppendTo[
                          boundary, 
                          bndLine]; \[IndentingNewLine]Sequence @@ {Polygon[
                              clCon], Polygon[bClCon]}]}\) /. 
                removeDuplicateEndPoints\); \
\[IndentingNewLine]withClippedPolygons := 
            Show[{withoutBoundary; winnowed, 
                Graphics3D[
                  Join[{Sequence @@ 
                        Flatten[{If[FreeQ[boundary, Polygon], boundaryStyle, 
                              If[FreeQ[boundaryStyle, 
                                  colorSpecPattern], {boundaryStyle, 
                                  EdgeForm[], 
                                  SurfaceColor[
                                    GrayLevel[0]]}, {boundaryStyle, 
                                  EdgeForm[], 
                                  SurfaceColor[
                                    Last@Cases[boundaryStyle, 
                                        colorSpecPattern, {0, 
                                        Infinity}]]}]]}]}, 
                    Union[Flatten[boundary]] //. 
                      rulesForConnectingSegments]]}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[
            If[prepareQ, 
              withClippedPolygons, \(winnowed /. \[InvisibleSpace]Polygon[
                      pts_List?borderTouchingQ] \[RuleDelayed] 
                    Polygon[clipContour[pts]]\) /. removeDuplicateEndPoints], 
            FilterOptions[Graphics3D, opts, 
              Sequence @@ Rest[obj]]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SetAttributes[LinearClipDraw3D, HoldRest];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipDraw3D[obj_Graphics3D, 
            rel_ /; MemberQ[{Less, LessEqual, Greater, GreaterEqual}, 
                  Head[rel]] && Length[rel] \[Equal] 2, var__Symbol, 
            opts___Rule] /; \((PolynomialQ[Subtract @@ rel, {var}] && 
              Max[\((Exponent[Expand[Subtract @@ rel], #1] &)\) /@ {var}] === 
                1)\) := Block[{$DisplayFunction = 
              Identity}, \[IndentingNewLine]\(LinearClipPlot3D[obj, rel, var, 
              opts]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipDraw3D[obj_SurfaceGraphics, other___] := 
        LinearClipDraw3D[Graphics3D[obj], other];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipDraw3D[obj_Graphics3D, 
          rel_ /; Or[
              MemberQ[{Less, LessEqual, Greater, GreaterEqual}, Head[rel]] && 
                Length[rel] > 2, Head[rel] === Inequality], var__Symbol, 
          opts___Rule] := 
        Block[{$DisplayFunction = Identity}, \(LinearClipPlot3D[obj, 
              Evaluate@LogicalExpand[rel], var, 
              opts]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipDraw3D[obj_Graphics3D, rel_And, var__Symbol, opts___Rule] := 
        Block[{$DisplayFunction = Identity}, \(Fold[
              LinearClipPlot3D[#1, #2, var, DisplayFunction \[Rule] Identity, 
                  opts] &, obj, List @@ rel]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SliceSurfacePlot3D", "Subsubtitle"],

Cell[BoxData[
    \(\(SetAttributes[SliceSurfacePlot3D, \ HoldRest];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[SliceSurfacePlot3D] = 
        Join[{Contours \[Rule] 11, SurfaceStyle \[Rule] {EdgeForm[]}, 
            ContourStyle \[Rule] Automatic, 
            ColorFunctionScaling \[Rule] True, OrientedCurve \[Rule] False, 
            ShowProjectedLevelSets \[Rule] False, ProjectAt \[Rule] 0, 
            ArrowDensity \[Rule] 1, ArrowPositions \[Rule] Automatic, 
            ReverseOrientation \[Rule] 
              False, \[IndentingNewLine]ShowSurface \[Rule] True, 
            ShowCurves \[Rule] True, Arrow3DColor \[Rule] Automatic, 
            DrawGraphics`DrawingArrows`HeadScaling3D \[Rule] Automatic, 
            DrawGraphics`DrawingArrows`HeadLength3D \[Rule] 1/10}, 
          Options[ParametricPlot3D]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SliceSurfacePlot3D[obj_SurfaceGraphics, other___] := 
        SliceSurfacePlot3D[Graphics3D[obj], other];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SliceSurfacePlot3D[obj_Graphics3D, linForm_, x_Symbol, y_Symbol, 
            z_Symbol, 
            opts___?OptionQ] /; \((PolynomialQ[linForm, {x, y, z}] && 
              Max[Map[Exponent[Expand[linForm], #] &, {x, y, z}]] === 1)\) := 
        Module[{projQ, zlev, sl, mshsty, ratObj, vertList, extremaOfLinForm, 
            linearFormExcursion, lnsty, colorScalingQ, sliceList, 
            sliceLineList, centralVal, srf, cntr, sliceLines, grad, 
            gradNormalized, squishedLinesAdded, plotWithoutArrows, arwDnsty, 
            pos, orientedQ, arw3Dcolor, maxLevelLineLength, howManyArrows, 
            arrowPos, normalizedArrowPos, hdscl3D, addArrows, 
            plotWithArrows}, \[IndentingNewLine]{projQ, 
              zlev} = \({ShowProjectedLevelSets, ProjectAt} /. {opts}\) /. 
              Options[SliceSurfacePlot3D]; \[IndentingNewLine]sl = \(Contours \
/. {opts}\) /. Options[SliceSurfacePlot3D]; \[IndentingNewLine]mshsty = 
            Flatten[\({SurfaceStyle} /. {opts}\) /. 
                Options[SliceSurfacePlot3D]]; \[IndentingNewLine]ratObj = 
            Rationalize[obj[\([1]\)], 
              1/10^6]; \[IndentingNewLine]triangulized = 
            ratObj /. Polygon[{pt1_List, pts___}] \[RuleDelayed] 
                Sequence @@ 
                  Map[Polygon[Join[{pt1}, #]] &, 
                    Partition[{pts}, 2, 1]]; \[IndentingNewLine]vertList = 
            Cases[ratObj, 
              Polygon[pts_List] \[RuleDelayed] Sequence @@ pts, {1, 
                Infinity}]; \[IndentingNewLine]extremaOfLinForm = \({Min[#], 
                  Max[#]} &\)[
              linForm /. 
                Map[Thread[{x, y, z} \[Rule] #] &, 
                  vertList]]; \[IndentingNewLine]linearFormExcursion = 
            Abs[Subtract @@ extremaOfLinForm]; \[IndentingNewLine]If[
            Chop@linearFormExcursion === 0, 
            Print["\<The object is flat in the direction of the slices\>"]; 
            Abort[]]; \[IndentingNewLine]{lnsty, 
              colorScalingQ} = \({ContourStyle, 
                  ColorFunctionScaling} /. {opts}\) /. 
              Options[SliceSurfacePlot3D]; \[IndentingNewLine]If[
            MatchQ[lnsty, Hue | GrayLevel | _Function], 
            If[TrueQ@colorScalingQ, 
              lnsty = Evaluate[
                    lnsty[\((# - First@extremaOfLinForm)\)/
                        linearFormExcursion]] &], 
            lnsty = \((Evaluate[lnsty] &)\)]; \[IndentingNewLine]sliceList = 
            Which[IntegerQ[sl] && sl > 0, 
              Drop[Rest[
                  Range @@ \((extremaOfLinForm~
                        Join~{Abs[
                              Subtract @@ extremaOfLinForm]/\((sl + 
                                1)\)})\)], \(-1\)], 
              MatchQ[sl, {val__?\((\((NumericQ[#] && 
                            FreeQ[N[#], Complex])\) &)\)}], 
              sl, \[IndentingNewLine]True, 
              Print["\<can't handle these contours\>"]; 
              Abort[]]; \[IndentingNewLine]sliceList = 
            Sort[sliceList, 
              Less]; \[IndentingNewLine]sliceLineList = {}; \
\[IndentingNewLine]{Graphics3D[triangulized], 
              sliceList} //. {{gr_Graphics3D, 
                  valueList_List /; 
                    Length[valueList] \[GreaterEqual] 
                      2} \[RuleDelayed] \((centralVal = 
                    Floor[Length[valueList]/2]; {{srf, cntr} = 
                      LinearClipPlot3D[gr, 
                          linForm \[LessEqual] valueList[\([centralVal]\)], 
                          x, y, z, DisplayFunction \[Rule] Identity, 
                          PrepareForSlices \[Rule] True, 
                          ContourStyle \[Rule] 
                            lnsty[valueList[\([centralVal]\)]]] // 
                        First; \[IndentingNewLine]AppendTo[
                      sliceLineList, {valueList[\([centralVal]\)], 
                        cntr}]; \[IndentingNewLine]If[
                      centralVal > 1, {Graphics3D[srf], 
                        Take[valueList, centralVal - 1]}, 
                      Sequence @@ {}], \[IndentingNewLine]{srf, cntr} = 
                      LinearClipPlot3D[gr, 
                          linForm \[GreaterEqual] 
                            valueList[\([centralVal + 1]\)], x, y, z, 
                          DisplayFunction \[Rule] Identity, 
                          PrepareForSlices \[Rule] True, 
                          ContourStyle \[Rule] 
                            lnsty[valueList[\([centralVal + 1]\)]]] // 
                        First; \[IndentingNewLine]AppendTo[
                      sliceLineList, {valueList[\([centralVal + 1]\)], 
                        cntr}]; \[IndentingNewLine]If[
                      centralVal + 1 < Length[valueList], {Graphics3D[srf], 
                        Drop[valueList, centralVal + 1]}, 
                      Sequence @@ {}]})\), \[IndentingNewLine]{gr_Graphics3D, \
{value_}} \[RuleDelayed] \(({srf, cntr} = 
                    LinearClipPlot3D[gr, linForm \[LessEqual] value, x, y, z, 
                        DisplayFunction \[Rule] Identity, 
                        PrepareForSlices \[Rule] True, 
                        ContourStyle \[Rule] lnsty[value]] // First; 
                  AppendTo[sliceLineList, {value, cntr}]; 
                  Sequence @@ {})\)}; \[IndentingNewLine]sliceLines = \(Sort[
                sliceLineList, 
                First[#1] < 
                    First[#2] &]\)[\([All, \(-1\)]\)]; \
\[IndentingNewLine]grad = \(Outer[
                D, {linForm}, {x, y, 
                  z}]\)[\([1]\)]; \[IndentingNewLine]gradNormalized = 
            grad/Sqrt[grad . grad]; \[IndentingNewLine]squishedLinesAdded := 
            sliceLines /. \((hd : \((Line | Polygon)\))\)[
                  pts_] \[RuleDelayed] {hd[pts], 
                  hd[Map[# - \((gradNormalized . #)\) gradNormalized + 
                          zlev*grad/\((linForm /. 
                                  Thread[{x, y, z} \[Rule] grad])\) &, 
                      pts]]}; \[IndentingNewLine]{shwSrf, 
              shwCrv} = \({ShowSurface, ShowCurves} /. {opts}\) /. 
              Options[SliceSurfacePlot3D]; \
\[IndentingNewLine]plotWithoutArrows = 
            Graphics3D[{If[TrueQ@shwSrf, Join[mshsty, ratObj], {}], 
                If[TrueQ@shwCrv, 
                  If[TrueQ@projQ, squishedLinesAdded, 
                    sliceLines], {}]}]; \[IndentingNewLine]{arwDnsty, pos, 
              orientedQ, 
              arw3Dcolor} = \({ArrowDensity, ArrowPositions, OrientedCurve, 
                  Arrow3DColor} /. {opts}\) /. 
              Options[LevelPlot3D]; \[IndentingNewLine]returnWithoutArrows := 
            Show[plotWithoutArrows, FilterOptions[Graphics3D, opts], 
              DisplayFunction \[Rule] $DisplayFunction, 
              BoxRatios \[Rule] Automatic, 
              Rest[List @@ obj]]; \[IndentingNewLine]If[
            Not[TrueQ[orientedQ]], 
            Return[returnWithoutArrows]]; \[IndentingNewLine]If[
            Not@DrawGraphicsInstalledQ, 
            Message[Oriented::"\<DrawGraphics not installed\>"]; 
            Return[returnWithoutArrows]]; \[IndentingNewLine]If[
            MatchQ[arw3Dcolor, Hue | GrayLevel | _Function], 
            If[TrueQ@colorScalingQ, 
              arw3Dcolor = 
                Evaluate[
                    arw3Dcolor[\((# - First@extremaOfLinForm)\)/
                        linearFormExcursion]] &], 
            arw3Dcolor = \((Evaluate[
                    arw3Dcolor] &)\)]; \[IndentingNewLine]maxLevelLineLength := 
            Max @@ N[
                Cases[plotWithoutArrows, 
                  l_Line \[RuleDelayed] lineLength @@ l, Infinity]]; 
          howManyArrows[pts_] := 
            Round[arwDnsty*3 
                 lineLength[pts]/
                  maxLevelLineLength]; \[IndentingNewLine]arrowPos[
              pts_ /; pos === 
                  Automatic] := \[IndentingNewLine]\((Range[1, 2  # - 1, 2]/
                    Max[2  #, 1] &)\)[
              howManyArrows[pts]]; \[IndentingNewLine]arrowPos[
              pts_ /; pos =!= Automatic] := 
            Flatten[{pos}]; \[IndentingNewLine]normalizedArrowPos[
              pts_] := \((\((# - Min[#, 0])\)/\((Max[#, 1] - 
                        Min[#, 0])\) &)\)[
              arrowPos[pts]]; \[IndentingNewLine]hdscl3D = 
            automaticHeadScaling3D[plotWithoutArrows, opts, 
              Sequence @@ 
                Options[SliceSurfacePlot3D]]; \[IndentingNewLine]addArrows[
              pts_, linFormValue_] := {Line[pts], 
              insertArrows[pts, normalizedArrowPos[pts], hdscl3D, 
                Arrow3DColor \[Rule] arw3Dcolor[linFormValue], 
                PlotStyle \[Rule] lnsty[linFormValue], opts, 
                FilterOptions[DrawGraphics`DrawingArrows`Arrow3D, 
                  Options[
                    SliceSurfacePlot3D]]]}; \[IndentingNewLine]plotWithArrows \
= Graphics3D[{First@plotWithoutArrows, 
                Last@plotWithoutArrows /. \[IndentingNewLine]If[
                    TrueQ@projQ, \[IndentingNewLine]{Line[pts1_], 
                        Line[pts2_]} \[RuleDelayed] \((linFormValue = 
                          linForm /. 
                            Thread[{x, y, z} \[Rule] First[pts1]]; {addArrows[
                            pts1, linFormValue], 
                          addArrows[pts2, 
                            linFormValue]})\), \[IndentingNewLine]Line[
                        pts_] \[RuleDelayed] 
                      Sequence @@ 
                        addArrows[pts, 
                          linForm /. 
                            Thread[{x, y, z} \[Rule] 
                                First[pts]]]]}]; \[IndentingNewLine]Show[
            plotWithArrows, 
            FilterOptions[Graphics3D, opts, BoxRatios \[Rule] Automatic, 
              DisplayFunction \[Rule] $DisplayFunction, 
              Rest[List @@ obj]]]\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SliceSurfaceDraw3D[obj_Graphics3D, linForm_, x_Symbol, y_Symbol, 
            z_Symbol, 
            opts___?OptionQ] /; \((PolynomialQ[linForm, {x, y, z}] && 
              Max[Map[Exponent[Expand[linForm], #] &, {x, y, z}]] === 1)\) := 
        Block[{$DisplayFunction = 
              Identity}, \[IndentingNewLine]\(SliceSurfacePlot3D[obj, 
              linForm, x, y, z, opts]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LevelPlot3D", "Subsubtitle"],

Cell[BoxData[
    \(\(SetAttributes[LevelPlot3D, HoldAll];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[LevelPlot3D] = 
        Join[{Contours \[Rule] 11, SurfaceStyle \[Rule] {EdgeForm[]}, 
            ContourStyle \[Rule] Automatic, 
            ShowProjectedLevelSets \[Rule] False, ProjectAt \[Rule] 0, 
            OrientedCurve \[Rule] False, ArrowDensity \[Rule] 1, 
            ArrowPositions \[Rule] Automatic, 
            ReverseOrientation \[Rule] False, ShowSurface \[Rule] True, 
            ShowCurves \[Rule] True, Arrow3DColor \[Rule] Automatic, 
            DrawGraphics`DrawingArrows`HeadScaling3D \[Rule] Automatic, 
            DrawGraphics`DrawingArrows`HeadLength3D \[Rule] 1/30}, 
          Options[ParametricPlot3D]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LevelPlot3D[f_, {x_Symbol, xMin_, xMax_}, {y_Symbol, yMin_, yMax_}, 
          opts___] := 
        Module[{z}, \[IndentingNewLine]SliceSurfacePlot3D[
            Plot3D[f, {x, xMin, xMax}, {y, yMin, yMax}, 
              DisplayFunction \[Rule] Identity, 
              Evaluate[FilterOptions[Plot3D, opts]]], z, x, y, z, 
            opts]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LevelDraw3D[x__] := 
        Block[{$DisplayFunction = Identity}, \[IndentingNewLine]\(LevelPlot3D[
              x]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Tail end", "Subsubtitle"],

Cell[BoxData[
    \(\(End[];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Protect["\<`*\>"];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(EndPackage[];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(On[General::"\<spell1\>"]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(On[General::"\<spell\>"]\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Basic usage examples", "Subtitle"],

Cell["A parabola with arrow on it:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{\(x\^2\), ",", \({x, \(-1\), 1}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["A circle with arrow on it:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot", "[", 
        RowBox[{\({Cos[x], Sin[x]}\), ",", \({x, 0, 3  \[Pi]/2}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["A helix with arrow on it:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x\/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The contour lines of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) \[RightTeeArrow] x\^2 + y\^2\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x\^2 + y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["\<\
Numerical solution and plot of a differential equation in the \
plane:\
\>", "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {
                StyleBox[\(\(x'\)[t] \[Equal] x[t]\/10 - y[t]\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]},
              {
                StyleBox[\(\(y'\)[t] \[Equal] y[t]\/10 + x[t]\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]},
              {
                StyleBox[\(x[0] \[Equal] 1\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]},
              {
                StyleBox[\(y[0] \[Equal] 0\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
        ",", \({t, 0, 10}\), ",", 
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell["\<\
Numerical solution and plot of a differential equation in 3D space:\
\
\>", "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x''\)[t] \[Equal] \(-x[t]\) \((1 + x[t]\^2)\)\)},
              {\(\(y''\)[
                    t] \[Equal] \(-y[t]\) \((1 + x[t]\^2 - x[t]\^4)\)\)},
              {\(\(z'\)[t] \[Equal] 1\/3\)},
              {\(x[0] \[Equal] 1\)},
              {\(y[0] \[Equal] 0\)},
              {\(\(x'\)[0] \[Equal] 0\)},
              {\(\(y'\)[0] \[Equal] 1\)},
              {\(z[0] \[Equal] 0\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y, z}\), 
        ",", \({t, 0, 10}\), ",", 
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell["Force lines of a vector field in the plane:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["PhasePlot",
          FontColor->RGBColor[1, 0, 0]], "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(1\/\(1 + x\^2\)\)},
                {\(\(-y\) + x\)}
                }], ")"}], ",", \({x, \(-1\), 1}\), ",", \({y, \(-1\), 1}\), 
          ",", \({\(-3\), 3}\)}], "]"}], ";"}]], "Input"],

Cell["Force lines of a vector field in 3D space:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["PhasePlot",
          FontColor->RGBColor[1, 0, 0]], "[", 
        RowBox[{
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"1", "2", "3"},
                  {"4", "3", "2"},
                  {"3", "1", "2"}
                  }], ")"}], ".", 
            RowBox[{"(", GridBox[{
                  {"x"},
                  {"y"},
                  {"z"}
                  }], ")"}]}], ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({z, \(-1\), 1}\), 
          ",", \({\(-2\), 2}\), ",", \(GridPoints \[Rule] 4\), 
          ",", \(PlotStyle \[Rule] RGBColor\)}], "]"}], ";"}]], "Input"],

Cell["\<\
Phase portrait of a linear autonomous differential equation in the \
plane:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["LinearPhasePlot2D",
          FontColor->RGBColor[1, 0, 0]], "[", 
        RowBox[{"(", GridBox[{
              {"1", \(1\/2\)},
              {\(1\/5\), "2"}
              }], ")"}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-level lines on the surface plot of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) \[RightTeeArrow] x\^2 - y\^2\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["LevelPlot3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \(x\^2 - y\^2, {x, \(-1\), 1}, {y, \(-1\), 1}\), "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-level lines, with arrows along them, on the surface plot of the function \
",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) \[RightTeeArrow] x\^2 - y\^2\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["LevelPlot3D",
          FontColor->RGBColor[1, 0, 0]], "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["The intersection curve between two surfaces:", "Text"],

Cell[BoxData[{\(surf1 = 
        ParametricPlot3D[{Cos[t], Sin[t], z}, {t, 0, 2  Pi}, {z, \(-2\), 2}, 
          PlotPoints \[Rule] {13, 2}, 
          DisplayFunction \[Rule] 
            Identity];\), "\[IndentingNewLine]", \(surf2 = 
        ParametricPlot3D[{Cos[t], y, Sin[t]}, {t, 0, 2  Pi}, {y, \(-2\), 2}, 
          PlotPoints \[Rule] {13, 2}, 
          DisplayFunction \[Rule] Identity];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["SurfaceIntersectionPlot3D",
          FontColor->RGBColor[1, 0, 0]], "[", \(surf1, surf2, 
        PlotStyle \[Rule] {Red, Thickness[ .015]}, Oriented \[Rule] True\), 
        "]"}], ";"}]}], "Input"],

Cell["The self-intersection of a surface:", "Text"],

Cell[BoxData[
    RowBox[{\(surf = 
        ParametricPlot3D[{\((1 + u\ Sin[\[Phi]\/5])\)\ Sin[\[Phi]], 
            Cos[\[Phi]]\ \((1 + u\ Sin[\[Phi]\/5])\), 
            u\ Cos[\[Phi]\/5]}, {u, \(-1\)/2, 1/2}, {\[Phi], \(-\[Pi]\), 
            2  \[Pi]}, PlotPoints \[Rule] {2, 31}, 
          DisplayFunction \[Rule] Identity]\), ";", 
      RowBox[{
        StyleBox["SurfaceSelfIntersectionPlot3D",
          FontColor->RGBColor[1, 0, 0]], "[", \(surf, 
        PlotStyle \[Rule] {Red, Thickness[ .015]}, Oriented \[Rule] True\), 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The parametric spiral ",
  Cell[BoxData[
      \(TraditionalForm\`t \[RightTeeArrow] \((t\ cos\ 10  t, 
          t\ sin\ 10  t)\)\)]],
  " \"lifted\" on the surface plot of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) \[RightTeeArrow] 
        1\/\(1 + x\^2 + y\^2\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["PlotCurveOnSurface3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \({1\/\(1 + x\^2 + y\^2\), {x, \(-2\), 2}, {y, \(-2\), 
            2}}, {{t*Cos[10  t], t*Sin[10  t]}, {t, 0, 2}, 
          PlotPoints \[Rule] 100, Oriented \[Rule] True}\), "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "The contour lines of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) \[RightTeeArrow] x\^2 - y\^2\)]],
  " \"lifted\" on the surface plot of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) \[RightTeeArrow] 
        1\/\(1 + x\^2 + y\^2\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["PlotCurveOnSurface3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \({1\/\(1 + x\^2 + y\^2\), {x, \(-2\), 2}, {y, \(-2\), 
            2}}, {x\^2 - y\^2, {x, \(-2\), 2}, {y, \(-2\), 2}, 
          Contours \[Rule] 5}\), "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The (oriented) contour lines of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y, z)\) \[RightTeeArrow] z + y\^2\)]],
  " on the cylinder ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 + z\^2 = 1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["PlotCurveOnSurface3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \({{Cos[v], u, Sin[v]}, {u, \(-1\), 1}, {v, \(-Pi\), Pi}, 
          PlotPoints \[Rule] {2, 41}}, {Sin[v] + u\^2, {u, \(-1\), 
            1}, {v, \(-Pi\), Pi}, Oriented \[Rule] True, 
          PlotPoints \[Rule] 35}\), "]"}], ";"}]], "Input"],

Cell["A text written on a surface:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["PlotCurveOnSurface3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \({\(-Sin[x]\) + Sin[y], {x, \(-4\), 4}, {y, \(-4\), 
            4}}, \[IndentingNewLine]Graphics[{Text["\<surface\>", {0, 0}]}]\),
         "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Advanced examples", "Subtitle"],

Cell["\<\
Evaluate the input cells below to see the package in action and \
learn its usage.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["The ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Oriented", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" option for curves in the plane",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubtitle"],

Cell[TextData[{
  "The package adds new options to ",
  ButtonBox["Plot",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["ParametricPlot",
    ButtonStyle->"RefGuideLink"],
  " making it easy to place arrow heads along the lines. The basic option is \
",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{\(x\^2\), ",", \({x, 0, 1}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "By default the number of arrow placed on the curve is the ratio of the \
length of the curve to the length of the smallest ",
  ButtonBox["Rectangle",
    ButtonStyle->"RefGuideLink"],
  " that contains the curve, rounded up by excess. You can ask for a \
different number through the option ",
  StyleBox["HowManyArrows", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot", "[", 
        RowBox[{\({Cos[x], Sin[x]}\), ",", \({x, 0, 3  \[Pi]/2}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(HowManyArrows \[Rule] 3\),
            FontColor->RGBColor[1, 0, 0]], 
          ",", \(AspectRatio \[Rule] Automatic\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can change the appearance of the arrows with the options described in \
the ",
  ButtonBox["Graphics`Arrow`",
    ButtonStyle->"AddOnsLink"],
  " package documentation. For example, you can make the arrow heads bigger \
or smaller by setting ",
  StyleBox["HeadLength", "Input",
    Background->RGBColor[1, 1, 0]],
  " to a value larger or smaller than the default ",
  StyleBox["1/20", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot", "[", 
        RowBox[{\({Cos[x], Sin[x]}\), ",", \({x, 0, 3  \[Pi]/2}\), 
          ",", \(Oriented \[Rule] True\), 
          ",", \(AspectRatio \[Rule] Automatic\), ",", 
          StyleBox[\(HeadLength \[Rule] 1/10\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["\<\
The default placement of the arrows along the cuve is designed to \
get them equally spaced when the curve is a loop:\
\>", "Text"],

Cell[BoxData[
    \(\(ParametricPlot[{Cos[x], Sin[x]}, {x, 0, 2  \[Pi]}, 
        Oriented \[Rule] True, AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell["A more complicated curve:", "Text"],

Cell[BoxData[
    \(\(ParametricPlot[{Cos[x] + Sin[3  x]/3, Sin[x]}, {x, 0, 2  \[Pi]}, 
        Oriented \[Rule] True, HowManyArrows \[Rule] 4, 
        AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell[TextData[{
  "You can override the default placement of the arrows along the curve with \
",
  StyleBox["ArrowPositions", "Input",
    Background->RGBColor[1, 1, 0]],
  ". Values must be between 0 and 1, and will place arrow heads \
proportionally with respect to arc length (allow for distoriton the more ",
  StyleBox["AspectRatio", "Input"],
  " is far from ",
  StyleBox["Automatic", "Input"],
  ")."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot", "[", 
        RowBox[{\({Cos[x], Sin[x]}\), ",", \({x, 0, 3  \[Pi]/2}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ArrowPositions \[Rule] {1/4, 1/2, 1}\),
            FontColor->RGBColor[1, 0, 0]], 
          ",", \(AspectRatio \[Rule] Automatic\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can reverse the direction of the arrows without changing \
parameterization with the option ",
  StyleBox["ReverseOrientation", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot", "[", 
        RowBox[{\({Cos[x], Sin[x]}\), ",", \({x, 0, 3  \[Pi]/2}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ReverseOrientation \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["More of one curve on the same plot is allowed:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              StyleBox["t",
                FontColor->RGBColor[1, 0, 0]], ",", 
              StyleBox[\(t/2\),
                FontColor->RGBColor[0, 0, 1]]}], "}"}], ",", \({t, 0, 1}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          RowBox[{"HowManyArrows", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1",
                  FontColor->RGBColor[1, 0, 0]], ",", 
                StyleBox["2",
                  FontColor->RGBColor[0, 0, 1]]}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["Red",
                  FontColor->RGBColor[1, 0, 0]], ",", 
                StyleBox["Blue",
                  FontColor->RGBColor[0, 0, 1]]}], "}"}]}]}], "]"}], 
      ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              StyleBox[\({Cos[x], Sin[x]}\),
                FontColor->RGBColor[1, 0, 0]], ",", 
              StyleBox[\({2  Cos[x], 2  Sin[x]}\),
                FontColor->RGBColor[0, 1, 0]]}], "}"}], 
          ",", \({x, 0, 3  \[Pi]/2}\), ",", \(Oriented \[Rule] True\), 
          ",", \(HowManyArrows \[Rule] 2\), ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"{", 
                  StyleBox["Red",
                    FontColor->RGBColor[1, 0, 0]], "}"}], ",", 
                RowBox[{"{", 
                  StyleBox["Green",
                    FontColor->RGBColor[0, 1, 0]], "}"}]}], "}"}]}], 
          ",", \(AspectRatio \[Rule] Automatic\), ",", 
          RowBox[{"Prolog", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"Blue", ",", \(PointSize[ .04]\), ",", 
                StyleBox[\(Point[{0, 0}]\),
                  FontColor->RGBColor[0, 0, 1]]}], "}"}]}]}], "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "All the options can be given also to ",
  ButtonBox["Draw",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["ParametricDraw",
    ButtonStyle->"AddOnsLink"],
  ": if you have ",
  StyleBox["DrawGraphics", "Input"],
  " installed:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Draw2D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"Red", ",", 
              RowBox[{"ParametricDraw", "[", 
                RowBox[{
                  StyleBox[\({Cos[x], Sin[x]}\),
                    FontColor->RGBColor[1, 0, 0]], 
                  ",", \({x, 0, 3  \[Pi]/2}\), 
                  ",", \(Oriented \[Rule] True\)}], "]"}], ",", 
              "\[IndentingNewLine]", "Green", ",", 
              RowBox[{"ParametricDraw", "[", 
                RowBox[{
                  StyleBox[\({2  Cos[x], 2  Sin[x]}\),
                    FontColor->RGBColor[0, 1, 0]], ",", \({x, 0, 2  \[Pi]}\), 
                  ",", \(Oriented \[Rule] True\)}], "]"}], ",", 
              "\[IndentingNewLine]", "Blue", ",", \(PointSize[ .04]\), ",", 
              StyleBox[\(Point[{0, 0}]\),
                FontColor->RGBColor[0, 0, 1]]}], "}"}], ",", 
          "\[IndentingNewLine]", \(AspectRatio \[Rule] Automatic\)}], "]"}], 
      ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["The ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Oriented", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" option for curves in 3D-space (DrawGraphics needed)",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubtitle"],

Cell[TextData[{
  "The package adds new options to ",
  ButtonBox["ParametricPlot3D",
    ButtonStyle->"RefGuideLink"],
  " making it easy to place arrow heads along lines in 3D-space. The main \
option is ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  ", exactly as in the plane:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), ",",
           
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "By default the number of arrow placed on the curve is the ratio of the \
length of the curve to the length of the smallest ",
  ButtonBox["Cuboid",
    ButtonStyle->"RefGuideLink"],
  " that contains the curve, rounded up by excess. Just as in the plance, you \
can choose the number of arrows with ",
  StyleBox["HowManyArrows", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(HowManyArrows \[Rule] 3\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Consult the documentation of the package ",
  ButtonBox["Arrow3D",
    ButtonStyle->"AddOnsLink"],
  " to learn how to change the shape of 3D arrows.  Here by default, ",
  StyleBox["HeadLength3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " is set to ",
  StyleBox["1/10", "Input"],
  " of the lenght of the largest edge of the smallest ",
  ButtonBox["Cuboid",
    ButtonStyle->"RefGuideLink"],
  " that encloses the curve (or curves, if there are more than one; the \
option ",
  StyleBox["HeadScaling3D", "Input"],
  " is set internally to that length by default; if you write ",
  StyleBox["HeadScaling3D\[Rule]Relative", "Input"],
  " it will be ignored; only numeric values are taken into account). You can \
give a different length:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(HeadLength3D \[Rule] 1/5\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can dictate the exact placement of the arrows along the curve with ",
  StyleBox["ArrowPositions", "Input",
    Background->RGBColor[1, 1, 0]],
  ". Values must be between 0 and 1, and will place arrow heads \
proportionally with respect to arc length (allow for some distoriton when ",
  StyleBox["AspectRatio", "Input"],
  " or ",
  StyleBox["BoxRatios", "Input"],
  " is not set to ",
  StyleBox["Automatic", "Input"],
  ")."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ArrowPositions \[Rule] {1/4, 1/2, 1}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The ",
  StyleBox["default",
    FontSlant->"Italic"],
  " ",
  StyleBox["Automatic", "Input"],
  " setting of ",
  StyleBox["ArrowPositions", "Input"],
  " is meant to give evenly spaced arrows when the curve is a loop:"
}], "Text"],

Cell[BoxData[
    \(\(ParametricPlot3D[{Cos[x] + Sin[3  x]/3, Sin[x], Sin[x]}, {x, 0, 
          2  \[Pi]}, Oriented \[Rule] True];\)\)], "Input"],

Cell[TextData[{
  "The option ",
  ButtonBox["PlotStyle",
    ButtonStyle->"RefGuideLink"],
  " sets the style for the curve. The arrow is colored the same way as the \
curve, unless an arrow color is independently assigned through the options ",
  StyleBox["Arrow3DColor", "Input",
    Background->RGBColor[1, 1, 0]],
  " (and, if you want to see the polygons making up the arrows, also ",
  StyleBox["Arrow3DEdgeForm", "Input",
    Background->RGBColor[1, 1, 0]],
  "). Arrows of different colors along one curve are not supported."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(PlotStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["\<\
The 3D arrows are surface objects, as you realize in the following \
picture:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(Arrow3DColor \[Rule] {}\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[\(Arrow3DEdgeForm \[Rule] EdgeForm[Black]\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Keep in mind that an ",
  StyleBox["Arrow3D", "Input"],
  " is a solid object whose appearance is affected by the ",
  StyleBox["AspectRatio", "Input"],
  " or ",
  StyleBox["BoxRatios", "Input"],
  " (",
  StyleBox["un",
    FontSlant->"Italic"],
  "like a 2D ",
  StyleBox["Arrow", "Input"],
  "). They look best when ",
  StyleBox["BoxRatios", "Input"],
  " are ",
  StyleBox["Automatic", "Input"],
  " (default) or almost so. Otherwise they may get flattened and stretched in \
the display, as in the following example:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({x, x/30, x}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", \(Oriented \[Rule] True\), ",", \(PlotPoints \[Rule] 2\), ",", 
          
          StyleBox[\(BoxRatios \[Rule] {1, 1, 1}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The same 3D objects as in the previous example, but displayed at the \
default ",
  StyleBox["BoxRatios", "Input"],
  StyleBox["\[Rule]Automatic", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(ParametricPlot3D[{x, x/30, x}, {x, 0, 2  \[Pi]}, 
        Oriented \[Rule] True, PlotPoints \[Rule] 2];\)\)], "Input"],

Cell[TextData[{
  "You can reverse the direction of the arrows without changing \
parameterization with the option ",
  StyleBox["ReverseOrientation\[Rule]True", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ReverseOrientation \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "More of one curve on the same plot is allowed, just as in ",
  StyleBox["ParametricPlot3D", "Input"],
  ". The ",
  StyleBox["HeadScaling3D", "Input"],
  " is again taken as the length of the largest edge of the smallest ",
  ButtonBox["Cuboid",
    ButtonStyle->"RefGuideLink"],
  " that encloses the curves. The options ",
  StyleBox["HowManyArrows", "Input"],
  ", ",
  StyleBox["PlotStyle", "Input"],
  " and  ",
  StyleBox["Arrow3DColor", "Input"],
  " accept lists as values. ",
  StyleBox["ArrowPositions", "Input"],
  " also accepts a list of lists as a value."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              StyleBox[\({Cos[x], Sin[x], x}\),
                FontColor->RGBColor[1, 0, 0]], ",", 
              StyleBox[\({2  Cos[x], 2  Sin[x], Sin[x]}\),
                FontColor->RGBColor[0, 0, 1]]}], "}"}], 
          ",", \({x, 0, 2  \[Pi]}\), ",", \(Oriented \[Rule] True\), ",", 
          RowBox[{"HowManyArrows", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["2",
                  FontColor->RGBColor[1, 0, 0]], ",", 
                StyleBox["1",
                  FontColor->RGBColor[0, 0, 1]]}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"{", 
                  StyleBox["Red",
                    FontColor->RGBColor[1, 0, 0]], "}"}], ",", 
                RowBox[{"{", 
                  StyleBox["Blue",
                    FontColor->RGBColor[0, 0, 1]], "}"}]}], "}"}]}]}], "]"}], 
      ";"}]], "Input"],

Cell["One more example:", "Text"],

Cell[BoxData[
    \(\(ParametricPlot3D[{Cos[t], Sin[t], Cos[t]^2}, {t, 0, 2  \[Pi]}, 
        Oriented \[Rule] True];\)\)], "Input"],

Cell["A helix path around a cylinder:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{
          RowBox[{"{", 
            
            RowBox[{\(ParametricPlot3D[{Cos[t]/2, Sin[t]/2, z, 
                  EdgeForm[]}, {t, 0, 2  \[Pi]}, {z, 0, 6}, 
                PlotPoints \[Rule] {17, 2}, 
                DisplayFunction \[Rule] Identity]\), ",", 
              "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["ParametricPlot3D",
                  FontColor->RGBColor[1, 0, 0]], "[", 
                
                RowBox[{\({Cos[t], Sin[t], t/\[Pi]}\), 
                  ",", \({t, 0, 6  \[Pi]}\), ",", 
                  StyleBox[\(Oriented \[Rule] True\),
                    FontColor->RGBColor[1, 0, 0]], 
                  ",", \(HowManyArrows \[Rule] 9\), 
                  ",", \(HeadLength3D \[Rule] 1/20\), 
                  ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], "}"}],
           ",", "\[IndentingNewLine]", \(Boxed \[Rule] False\), 
          ",", \(Axes \[Rule] False\), 
          ",", \(DisplayFunction \[Rule] $DisplayFunction\)}], "]"}], 
      ";"}]], "Input"],

Cell["and a helix around a torus:", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Geometry`Rotations`\>"];\)\), "\n", 
    \(\(rot[u_, v_, \[Phi]_] = 
        Geometry`Rotations`Rotate3D[{u, 0, v}, \[Phi], 0, 0];\)\), "\n", 
    \(\(Show[{{ParametricPlot3D[
              Evaluate[
                rot[2 + Cos[t]/2, Sin[t]/2, \[Phi]]~
                  Join~{EdgeForm[]}], {\[Phi], 0, 2  \[Pi]}, {t, 0, 
                2  \[Pi]}, PlotPoints \[Rule] {37, 13}, 
              DisplayFunction \[Rule] 
                Identity]}, \[IndentingNewLine]ParametricPlot3D[
            Evaluate@rot[2 + Cos[t], Sin[t], t/6], {t, 0, 12  \[Pi]}, 
            PlotPoints \[Rule] 150, Oriented \[Rule] True, 
            HowManyArrows \[Rule] 12, HeadLength3D \[Rule] 1/20, 
            DisplayFunction \[Rule] Identity]}, Boxed \[Rule] False, 
        Axes \[Rule] False, ImageSize \[Rule] 300, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[TextData[{
  "You can use the option ",
  StyleBox["Oriented", "Input"],
  " with ",
  ButtonBox["ParametricDraw3D",
    ButtonStyle->"AddOnsLink"],
  ": here is the same helix around a cylinder as above, but going the ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " way:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Draw3DItems", "[", 
        RowBox[{
          RowBox[{"{", 
            
            RowBox[{\({EdgeForm[], 
                ParametricDraw3D[{Cos[t]/2, Sin[t]/2, z}, {t, 0, 
                    2  \[Pi]}, {z, 0, 6}, PlotPoints \[Rule] {17, 2}]}\), ",",
               "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["ParametricDraw3D",
                  FontColor->RGBColor[1, 0, 0]], "[", 
                
                RowBox[{\({Cos[t], Sin[t], t/\[Pi]}\), 
                  ",", \({t, 0, 6  \[Pi]}\), ",", 
                  StyleBox[\(Oriented \[Rule] True\),
                    FontColor->RGBColor[1, 0, 0]], 
                  ",", \(HowManyArrows \[Rule] 9\), 
                  ",", \(HeadLength3D \[Rule] 1/20\)}], "]"}]}], "}"}], 
          ",", \(Boxed \[Rule] False\)}], "]"}], ";"}]], "Input"],

Cell["and the helix around a torus:", "Text"],

Cell[BoxData[{\(Needs["\<Geometry`Rotations`\>"];\), "\n", \(rot[u_, 
          v_, \[Phi]_] = 
        Geometry`Rotations`Rotate3D[{u, 0, v}, \[Phi], 0, 0];\), "\n", 
    RowBox[{
      RowBox[{"Draw3DItems", "[", 
        RowBox[{
          RowBox[{"{", 
            
            RowBox[{\({EdgeForm[], 
                ParametricDraw3D[
                  Evaluate[rot[2 + Cos[t]/2, Sin[t]/2, \[Phi]]], {\[Phi], 0, 
                    2  \[Pi]}, {t, 0, 2  \[Pi]}, 
                  PlotPoints \[Rule] {37, 13}]}\), ",", "\[IndentingNewLine]",
               
              RowBox[{
                StyleBox["ParametricDraw3D",
                  FontColor->RGBColor[1, 0, 0]], "[", 
                
                RowBox[{\(Evaluate@rot[2 + Cos[t], Sin[t], t/6]\), 
                  ",", \({t, 0, 12  \[Pi]}\), ",", \(PlotPoints \[Rule] 150\),
                   ",", 
                  StyleBox[\(Oriented \[Rule] True\),
                    FontColor->RGBColor[1, 0, 0]], 
                  ",", \(HowManyArrows \[Rule] 12\), 
                  ",", \(HeadLength3D \[Rule] 1/20\)}], "]"}]}], "}"}], ",", 
          "\[IndentingNewLine]", \(Boxed \[Rule] False\), 
          ",", \(ImageSize \[Rule] 300\)}], "]"}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["The ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Oriented", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" option for surfaces (DrawGraphics needed)",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubtitle"],

Cell[TextData[{
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["ParametrciPlot3D",
    ButtonStyle->"RefGuideLink"],
  " can be used to plot a ",
  StyleBox["surface",
    FontSlant->"Italic"],
  ". In that case the new option ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " draws arrows along the contour of the surface:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{\(\(-x^2\) + y^2\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "By default the surface mesh is suppressed. The arrows and the contour are \
less visible if we reinstate the mesh (keep in mind that the mesh syntax is \
quite different for ",
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["ParametricPlot3D",
    ButtonStyle->"RefGuideLink"],
  ")"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{\(\(-x^2\) + y^2\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(MeshStyle \[Rule] Black\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", \(\(-x^2\) + y^2\), ",", 
              StyleBox[\(EdgeForm[Black]\),
                FontColor->RGBColor[1, 0, 0]]}], "}"}], 
          ",", \({x, \(-1\)/3, 1}\), ",", \({y, 0, 1}\), 
          ",", \(Oriented \[Rule] True\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Consult the documentation of the package ",
  ButtonBox["Arrow3D",
    ButtonStyle->"AddOnsLink"],
  " to learn how to change the shape of 3D arrows.  Here by default, ",
  StyleBox["HeadLength3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " is set to ",
  StyleBox["1/10", "Input"],
  " of the length of the largesst edge of the smallest ",
  ButtonBox["Cuboid",
    ButtonStyle->"RefGuideLink"],
  " that encloses the edges. You can give a different length:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({x, y, \(-x^2\) + y^2}\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(HeadLength3D \[Rule] 1/4\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The color and thickness of the contour can be changed with ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{\({x, y, \(-x^2\) + y^2}\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ContourStyle \[Rule] {Red, Thickness[ .015]}\),
            FontColor->RGBColor[1, 0, 0]], 
          ",", \(HeadLength3D \[Rule] 1/6\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  " The number of arrows along each edge (ordered counterclockwise starting \
from the bottom, in the parameter space) can be assigned with ",
  StyleBox["HowManyArrows", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", \(\(-x^2\) + y^2\), ",", 
              StyleBox[\(EdgeForm[Green]\),
                FontColor->RGBColor[0, 1, 0]]}], "}"}], 
          ",", \({x, \(-1\)/3, 1}\), ",", \({y, 0, 1}\), 
          ",", \(Oriented \[Rule] True\), ",", \(PlotPoints \[Rule] 25\), 
          ",", \(HeadLength3D \[Rule] 1/9\), ",", 
          StyleBox[\(HowManyArrows \[Rule] {1, 2, 3, 4}\),
            FontColor->RGBColor[1, 0, 0]], 
          ",", \(ContourStyle \[Rule] Red\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can dictate the positions of the arrows along each edge with ",
  StyleBox["ArrowPositions", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", \(\(-x^2\) + y^2\), ",", 
              StyleBox[\(EdgeForm[Blue]\),
                FontColor->RGBColor[0, 0, 1]]}], "}"}], 
          ",", \({x, \(-1\)/3, 1}\), ",", \({y, 0, 1}\), 
          ",", \(Oriented \[Rule] True\), ",", \(HeadLength3D \[Rule] 1/5\), 
          ",", \(ContourStyle \[Rule] Thickness[ .02]\), ",", 
          StyleBox[\(ArrowPositions \[Rule] {{1/3}, {1/2}, {1/5}, {7/10}}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  " can also be different along the four edges. In particular, the value ",
  StyleBox["None", "Input"],
  " suppresses the edge line:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{\(\(-x^2\) + y^2\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", \(Oriented \[Rule] True\), ",", 
          
          StyleBox[\(ContourStyle \[Rule] {{None}, {Thickness[ .01]}, {None}, \
{None}}\),
            FontColor->RGBColor[1, 0, 0]], 
          ",", \(HowManyArrows \[Rule] {0, 1, 0, 0}\)}], "]"}], 
      ";"}]], "Input"],

Cell["You can have edges without arrows and arrows without edges:", "Text"],

Cell[BoxData[
    \(\(Plot3D[\(-x^2\) + y^2, {x, \(-1\)/3, 1}, {y, 0, 1}, 
        Oriented \[Rule] True, Mesh \[Rule] False, 
        ContourStyle \[Rule] {{None}, {Thickness[ .012]}, {None}, {}}, 
        HowManyArrows \[Rule] {0, 1, 2, 0}, 
        PlotRange \[Rule] All];\)\)], "Input"],

Cell["A perhaps more meaningfule example:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({r*Cos[t], r*Sin[t], r^2}\), ",", \({r, 0, 1}\), 
          ",", \({t, 0, 2  \[Pi]}\), ",", \(Oriented \[Rule] True\), ",", 
          
          StyleBox[\(ContourStyle \[Rule] {{None}, {Thickness[ .01], 
                  PermanentGreen}, {None}, {None}}\),
            FontColor->RGBColor[1, 0, 0]], 
          ",", \(PlotPoints \[Rule] {8, 21}\), 
          ",", \(HowManyArrows \[Rule] {0, 3, 0, 0}\)}], "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "You can reverse the orientation of the contour with the option ",
  StyleBox["ReverseOrientation", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({x, y, \(-x^2\) + y^2}\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", \(Oriented \[Rule] True\), ",", " ", 
          StyleBox[\(ReverseOrientation \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["You can reverse the orientation on an edge-by-edge basis:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{\(\(-x^2\) + y^2\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", \(Oriented \[Rule] True\), ",", " ", 
          
          StyleBox[\(ReverseOrientation \[Rule] {True, False, False, False}\),
            
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", \(\(-x^2\) + y^2\), ",", 
              StyleBox[\(EdgeForm[Blue]\),
                FontColor->RGBColor[0, 0, 1]]}], "}"}], 
          ",", \({x, \(-1\)/3, 1}\), ",", \({y, 0, 1}\), 
          ",", \(Oriented \[Rule] True\), ",", " ", 
          
          StyleBox[\(ReverseOrientation \[Rule] {True, False, False, False}\),
            
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can give shading to the surface, as with the regular ",
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"y", ",", 
              StyleBox[\(Hue[\((x + y)\)/2]\),
                FontColor->RGBColor[1, 0, 0]]}], "}"}], 
          ",", \({x, \(-1\)/3, 1}\), ",", \({y, 0, 1}\), 
          ",", \(Oriented \[Rule] True\), ",", \(PlotPoints \[Rule] 5\)}], 
        "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{\(\(-x^2\) + y^2\), ",", 
              StyleBox[\(RGBColor[\((x + 1/3)\) 3/4, y, 0]\),
                FontColor->RGBColor[1, 0, 0]]}], "}"}], 
          ",", \({x, \(-1\)/3, 1}\), ",", \({y, 0, 1}\), 
          ",", \(Oriented \[Rule] True\), ",", \(HeadLength3D \[Rule] 1/5\)}],
         "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can omit the surface and show only the level sets with the option ",
  StyleBox["ShowSurface\[Rule]False", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{\(\(-x^2\) + y^2\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", \(Oriented \[Rule] True\), ",", " ", 
          RowBox[{
            StyleBox["ShowSurface",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["\[Rule]",
              "Input",
              FontColor->RGBColor[1, 0, 0],
              Background->RGBColor[1, 1, 0]], 
            StyleBox["False",
              FontColor->RGBColor[1, 0, 0]]}]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can even show the surface without showing the level sets: just use the \
option ",
  StyleBox["ShowCurves\[Rule]False", "Input",
    Background->RGBColor[1, 1, 0]],
  ". Why would you want to do that? Well, ",
  StyleBox["SliceSurfacePlot", "Input"],
  " does not usually return exactly the same surface it gets from you: it \
first applies ",
  StyleBox["Rationalize[]", "Input"],
  " to it: the level sets lie exactly flat on the rationalized version, \
likely not on the original surface. There may be times when the level sets \
are not the only thing you want to do with your surface. Whatever other \
manipulations you do on the surface, you may be better off with the version \
that comes with ",
  StyleBox["ShowCurves\[Rule]False", "Input"],
  "."
}], "Text"],

Cell[TextData[{
  "The option ",
  StyleBox["Oriented", "Input"],
  ", and all the associated ones, can be given to ",
  ButtonBox["Draw2D",
    ButtonStyle->"AddOnsLink"],
  " too:"
}], "Text"],

Cell[BoxData[{\(Clear[x, y, f, 
        normalVec];\), "\[IndentingNewLine]", \(f = \(-x^2\) + 
          y^2;\), "\[IndentingNewLine]", \(normalVec = \(Outer[
            D, {z - f}, {x, y, z}]\)[\([1]\)];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Draw3DItems", "[", 
        RowBox[{
          RowBox[{"{", 
            
            RowBox[{\({Blue, PointSize[ .02], Point[{x, y, f}], EdgeForm[], 
                  SurfaceColor[Blue], Thickness[ .01], 
                  Arrow3D[{x, y, f}, {x, y, f} + normalVec, 
                    HeadWidth3D \[Rule]  .3, 
                    HeadLength3D \[Rule]  .2]} /. {x \[Rule] 1/2, 
                  y \[Rule] 1/2}\), ",", "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["Draw3D",
                  FontColor->RGBColor[1, 0, 0]], "[", 
                RowBox[{
                "f", ",", \({x, \(-1\)/3, 1}\), ",", \({y, 0, 1}\), ",", 
                  StyleBox[\(Oriented \[Rule] True\),
                    FontColor->RGBColor[1, 0, 0]], 
                  ",", \(MeshStyle \[Rule] Gainsboro\)}], "]"}], ",", 
              "\[IndentingNewLine]", \(Text[
                DisplayForm@
                  GridBox[{{"\<normal\>"}, {"\<vector\>"}}], {x, y, f} + 
                    normalVec /. {x \[Rule] 1/2, y \[Rule] 1/2}, {\(-1\), 
                  0}]\)}], "}"}], ",", 
          "\[IndentingNewLine]", \(Boxed \[Rule] False\)}], "]"}], 
      ";"}]}], "Input"],

Cell["Some more examples:", "Text"],

Cell["A cylinder:", "Text"],

Cell[BoxData[
    \(\(With[{a = \(-\[Pi]\)/
                2 +  .6}, \[IndentingNewLine]ParametricPlot3D[{Cos[t], 
            Sin[t], u}, {t, a, a + 2  \[Pi] -  .3}, {u, 0, 1}, 
          PlotPoints \[Rule] {25, 2}, Oriented \[Rule] True, 
          Boxed \[Rule] False, Axes \[Rule] False]];\)\)], "Input"],

Cell["A cut-open sphere:", "Text"],

Cell[BoxData[
    \(\(With[{a = \(-\[Pi]\)/2 +  .7, b =  .7, 
          c =  .3}, \[IndentingNewLine]ParametricPlot3D[{Cos[t] Sin[u], 
            Sin[t] Sin[u], Cos[u]}, {t, a, a + 2  \[Pi] - b}, {u, 
            c, \[Pi] - c}, Oriented \[Rule] True, HowManyArrows \[Rule] 1, 
          ContourStyle \[Rule] Thickness[ .005], 
          ViewPoint -> {1.2, \ \(-3\), \ 1}, Boxed \[Rule] False, 
          Axes \[Rule] False]];\)\)], "Input"],

Cell["A cut-open M\[ODoubleDot]bius strip:", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Geometry`Rotations`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[
        Geometry`Rotations`Rotate3D[
          Rotate3D[{0, 1, u}, 0, \[Phi]/2, 0, {0, 1, 0}], \[Phi], 0, 
          0], {u, \(-1\)/2, 1/2}, {\[Phi], 0, 2  \[Pi] -  .3}, 
        Oriented \[Rule] True, ContourStyle \[Rule] Thickness[ .005], 
        PlotPoints \[Rule] {2, 31}, Boxed \[Rule] False, 
        Axes \[Rule] False];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["The ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Oriented", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" option for ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["ContourPlot", "Input",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubtitle"],

Cell[TextData[{
  "This package adds the option ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " to ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"],
  " . When that is set to ",
  StyleBox["True", "Input"],
  ", arrows will be placed along the contour lines:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + y^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  " option affects the color of the arrows too:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + y^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ContourStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + y^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ContourStyle \[Rule] Table[{Hue[n/11]}, {n, 11}]\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can change the style of the arrows with the options described in the \
",
  ButtonBox["Graphics`Arrow`",
    ButtonStyle->"AddOnsLink"],
  " package documentation By default ",
  ButtonBox["HeadScaling",
    ButtonStyle->"AddOnsLink"],
  " is set to ",
  StyleBox["Automatic", "Input"],
  " (other settings will be ignored). You can make the arrow heads bigger or \
smaller by setting ",
  ButtonBox["HeadLength",
    ButtonStyle->"AddOnsLink"],
  " to a value larger or smaller than the default ",
  StyleBox["1/20", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + y^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(HeadLength \[Rule] 1/30\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "By default the contour lines are oriented  so that the function is larger \
on the left of the curve, and smaller on the right. You reverse this \
behaviour with ",
  StyleBox["ReverseOrientation", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + y^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ReverseOrientation \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You have some control on how many arrows are drawn with the option ",
  StyleBox["ArrowDensity", "Input",
    Background->RGBColor[1, 1, 0]],
  ". The default value is 1."
}], "Text"],

Cell[BoxData[
    \(\(ContourPlot[x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Oriented \[Rule] True, ArrowDensity \[Rule] 2];\)\)], "Input"],

Cell["\<\
Contour lines in regions where the function is rather flat can get \
the algorithm a bit confused:\
\>", "Text"],

Cell[BoxData[
    \(\(ContourPlot[y*x^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Oriented \[Rule] True, Contours \[Rule] 9];\)\)], "Input"],

Cell[BoxData[
    \(\(ContourPlot[y*x^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Oriented \[Rule] True, Contours \[Rule] 9, 
        ArrowDensity \[Rule] 5];\)\)], "Input"],

Cell[TextData[{
  "The default settings are meant to give reasonably good results when ",
  ButtonBox["AspectRatio",
    ButtonStyle->"RefGuideLink"],
  " is ",
  StyleBox["Automatic", "Input"],
  " and the contours have radius of curvature not too small. Otherwise the \
arrows may not lie nicely along the curves. For example, the arrow shaft may \
become visible:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + \((y/10)\)^2\), ",", \({x, \(-1\), 1}\), ",", 
          StyleBox[\({y, \(-10\), 10}\),
            FontColor->RGBColor[1, 0, 0]], ",", \(Oriented \[Rule] True\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Some option tweaking may come to help in such cases. For example, try to \
set ",
  StyleBox["ArrowShaftLength", "Input",
    Background->RGBColor[1, 1, 0]],
  " to a small enough value:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + \((y/10)\)^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-10\), 10}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ArrowShaftLength \[Rule] 1/10\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "To get a better understanding of what ",
  StyleBox["ArrowShaftLength", "Input"],
  " means, try setting it to a value comparable to the size of the graph:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + y^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[\(ArrowShaftLength -> 1/2\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "If you set ",
  StyleBox["ArrowsAcrossSubdivisions", "Input",
    Background->RGBColor[1, 1, 0]],
  " to ",
  StyleBox["False", "Input"],
  " (the default is ",
  StyleBox["True", "Input"],
  "), you constrain the arrow shafts to be inside one of the straight line \
segments of which the line is made of. In practice, the arrows will be ",
  StyleBox["tangent",
    FontSlant->"Italic"],
  " to the line. This may not be so nice when the radius of curvature is \
comparable or smaller than the arrow head size. In the following case the \
radius of curvature is not too small, and the result looks the same as we got \
from just setting a small ",
  StyleBox["ArrowShaftLength", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + \((y/10)\)^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-10\), 10}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ArrowsAcrossSubdivisions \[Rule] False\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can add the direction field (not specially nice) with ",
  StyleBox["ShowField", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + y^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ShowField \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["Example: the trajectories of the pendulum system:", "Text"],

Cell[BoxData[
    \(\(ContourPlot[\(-Cos[x]\) + 
          y^2/2, {x, \(-\[Pi]\), \[Pi]}, {y, \(-\[Pi]\), \[Pi]}, 
        Oriented \[Rule] True];\)\)], "Input"],

Cell[TextData[{
  "Increasing the option ",
  ButtonBox["PlotPoints",
    ButtonStyle->"RefGuideLink"],
  " you can make the curves less jagged:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(\(-Cos[x]\) + y^2/2\), ",", \({x, \(-\[Pi]\), \[Pi]}\), 
          ",", \({y, \(-\[Pi]\), \[Pi]}\), ",", \(Oriented \[Rule] True\), 
          ",", 
          StyleBox[\(PlotPoints \[Rule] 30\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "By default ",
  ButtonBox["ContourShading",
    ButtonStyle->"RefGuideLink"],
  " is set to ",
  StyleBox["False", "Input"],
  " when ",
  StyleBox["Oriented", "Input"],
  " is ",
  StyleBox["True", "Input"],
  ", but you can change that:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(\(-Cos[x]\) + y^2/2\), ",", \({x, \(-\[Pi]\), \[Pi]}\), 
          ",", \({y, \(-\[Pi]\), \[Pi]}\), ",", \(Oriented \[Rule] True\), 
          ",", 
          StyleBox[\(ContourShading \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["With a color function that avoids deep blacks:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(\(-Cos[x]\) + y^2/2\), ",", \({x, \(-\[Pi]\), \[Pi]}\), 
          ",", \({y, \(-\[Pi]\), \[Pi]}\), ",", \(Oriented \[Rule] True\), 
          ",", 
          StyleBox[\(ContourShading \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          
          StyleBox[\(ColorFunction \[Rule] \((GrayLevel[\((1 + 2  #)\)/
                      3] &)\)\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["A psychedelic effect:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(\(-Cos[x]\) + y^2/2\), ",", \({x, \(-\[Pi]\), \[Pi]}\), 
          ",", \({y, \(-\[Pi]\), \[Pi]}\), ",", \(Oriented \[Rule] True\), 
          ",", 
          StyleBox[\(ContourShading \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[\(ColorFunction \[Rule] Hue\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "To catch a singular point you have to be careful with ",
  ButtonBox["PlotPoints",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["Contours",
    ButtonStyle->"RefGuideLink"],
  ": (disregard the warning messages)"
}], "Text"],

Cell[BoxData[
    \(\(ContourPlot[x*y, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Oriented \[Rule] True];\)\)], "Input"],

Cell[BoxData[
    \(\(ContourPlot[x*y, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Oriented \[Rule] True, Contours \[Rule] 9];\)\)], "Input"],

Cell[TextData[{
  "This plot is better with ",
  StyleBox["ArrowDensity", "Input",
    Background->RGBColor[1, 1, 0]],
  " higher than the default value of 1:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x*y\), ",", \({x, \(-1\), 1}\), ",", \({y, \(-1\), 1}\), 
          ",", \(Oriented \[Rule] True\), ",", \(Contours \[Rule] 9\), 
          ",", \(PlotPoints \[Rule] {21, 21}\), ",", 
          StyleBox[\(ArrowDensity \[Rule] 2\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The ",
  StyleBox["Oriented", "Input"],
  " option also works with ",
  ButtonBox["ContourDraw",
    ButtonStyle->"AddOnsLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Draw2D", "[", 
        RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
            
            RowBox[{\(DensityDraw[x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
                Mesh \[Rule] False, PlotPoints \[Rule] 50, 
                ColorFunction \[Rule] \((GrayLevel[2  #/3 + 1/3] &)\)]\), ",",
               
              RowBox[{
                StyleBox["ContourDraw",
                  FontColor->RGBColor[1, 0, 0]], 
                "[", \(x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
                Oriented \[Rule] True\), "]"}], ",", "\[IndentingNewLine]", 
              "Red", ",", \(Text["\<center\>", {0, 0}, 
                Background \[Rule] Yellow]\)}], "}"}], ",", 
          "\[IndentingNewLine]", \(AspectRatio \[Rule] Automatic\), 
          ",", \(Frame \[Rule] True\)}], "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["The ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["PlotSolution", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" option for ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["NDSolve", "Input",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubtitle"],

Cell[TextData[{
  ButtonBox["NDSolve",
    ButtonStyle->"RefGuideLink"],
  " gives a numeric solution to a system of differential equations. Plotting \
the solution however is a little tricky for a beginner. This package adds the \
new option ",
  StyleBox["PlotSolution", "Input",
    Background->RGBColor[1, 1, 0]],
  ", which makes a plot of the solution when there is one independent \
variable and at most 3 unknonwn functions."
}], "Text"],

Cell["A first-order planar system:", "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {
                StyleBox[\(\(x'\)[t] \[Equal] x[t]/10 - y[t]\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]},
              {
                StyleBox[\(\(y'\)[t] \[Equal] y[t]/10 + x[t]\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]},
              {
                StyleBox[\(x[0] \[Equal] 1\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]},
              {
                StyleBox[\(y[0] \[Equal] 0\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
        ",", \({t, 0, 10}\), ",", 
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[TextData[{
  "The output is a list ",
  Cell[BoxData[
      \(TraditionalForm\`{NDSolve\ output, \ \[SkeletonIndicator]Graphics\
\[SkeletonIndicator]}\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The option ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " is ",
  StyleBox["True", "Input"],
  " by default when the unknown functions are two or three. You can turn the \
arrows off:"
}], "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x'\)[t] \[Equal] x[t]/10 - y[t]\)},
              {\(\(y'\)[t] \[Equal] y[t]/10 + x[t]\)},
              {\(x[0] \[Equal] 1\)},
              {\(y[0] \[Equal] 0\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
        ",", \({t, 0, 10}\), ",", \(PlotSolution \[Rule] True\), ",", 
        StyleBox[\(Oriented \[Rule] False\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell["A second-order planar system:", "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x''\)[t] \[Equal] \(-x[t]\) \((1 + x[t]\^2)\)\)},
              {\(\(y''\)[
                    t] \[Equal] \(-y[t]\) \((1 + x[t]\^2 - x[t]\^4)\)\)},
              {\(x[0] \[Equal] 1\)},
              {\(y[0] \[Equal] 0\)},
              {\(\(x'\)[0] \[Equal] 0\)},
              {\(\(y'\)[0] \[Equal] 1\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
        ",", \({t, 0, 10}\), ",", 
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell["The motion of a damped pendulum:", "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {
                RowBox[{
                  RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], 
                  "==", \(y[t]\)}]},
              {
                RowBox[{
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], 
                  "==", \(\(- .03\)\ y[t] - Sin[x[t]]\)}]},
              {\(x[0] == 0\)},
              {\(y[0] == 2.1\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
        ",", \({t, 0, 30}\), ",", 
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[TextData[{
  "In dimension 2 the color of the curve is controlled with ",
  ButtonBox["PlotStyle",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x''\)[t] \[Equal] \(-x[t]\) \((1 + x[t]\^2)\)\)},
              {\(\(y''\)[
                    t] \[Equal] \(-y[t]\) \((1 + x[t]\^2 - x[t]\^4)\)\)},
              {\(x[0] \[Equal] 1\)},
              {\(y[0] \[Equal] 0\)},
              {\(\(x'\)[0] \[Equal] 0\)},
              {\(\(y'\)[0] \[Equal] 1\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
        ",", \({t, 0, 10}\), ",", \(PlotSolution \[Rule] True\), ",", 
        StyleBox[\(PlotStyle \[Rule] Red\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[TextData[{
  "You can give the same options as with ",
  ButtonBox["ParametricPlot",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x'\)[t] \[Equal] y[t]\)},
              {\(\(y'\)[t] \[Equal] 1\)},
              {\(x[0] \[Equal] 0\)},
              {\(y[0] \[Equal] 0\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
        ",", \({t, 0, 1}\), ",", \(PlotSolution \[Rule] True\), ",", 
        StyleBox[\(ArrowPositions \[Rule] {1/2, 1}\),
          FontColor->RGBColor[1, 0, 0]], ",", 
        StyleBox[\(PlotStyle \[Rule] Red\),
          FontColor->RGBColor[1, 0, 0]], ",", 
        StyleBox[\(Prolog \[Rule] {Red, PointSize[ .03], Point[{0, 0}]}\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[TextData[{
  "A system in three unknown functions is displayed as a 3D curve, and it \
will have 3D arrows if you have ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " installed. The arrow options are the same as for ",
  ButtonBox["ParametricPlot3D",
    ButtonStyle->"RefGuideLink"],
  ". with the ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " option, described above. "
}], "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x''\)[t] \[Equal] \(-x[t]\) \((1 + x[t]\^2)\)\)},
              {\(\(y''\)[
                    t] \[Equal] \(-y[t]\) \((1 + x[t]\^2 - x[t]\^4)\)\)},
              {\(\(z'\)[t] \[Equal] 1/3\)},
              {\(x[0] \[Equal] 1\)},
              {\(y[0] \[Equal] 0\)},
              {\(\(x'\)[0] \[Equal] 0\)},
              {\(\(y'\)[0] \[Equal] 1\)},
              {\(z[0] \[Equal] 0\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y, z}\), 
        ",", \({t, 0, 10}\), ",", 
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[TextData[{
  "Also in dimension 3 the style of the curve is controlled with ",
  ButtonBox["PlotStyle",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x''\)[t] \[Equal] \(-x[t]\) \((1 + x[t]\^2)\)\)},
              {\(\(y''\)[
                    t] \[Equal] \(-y[t]\) \((1 + x[t]\^2 - x[t]\^4)\)\)},
              {\(\(z'\)[t] \[Equal] 1/3\)},
              {\(x[0] \[Equal] 1\)},
              {\(y[0] \[Equal] 0\)},
              {\(\(x'\)[0] \[Equal] 0\)},
              {\(\(y'\)[0] \[Equal] 1\)},
              {\(z[0] \[Equal] 0\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y, z}\), 
        ",", \({t, 0, 10}\), ",", \(PlotSolution \[Rule] True\), ",", 
        StyleBox[\(PlotStyle \[Rule] Red\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[TextData[{
  ButtonBox["Lorenz equations",
    ButtonStyle->"MasterIndexLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x'\)[t] \[Equal] \(-3\)\ \((x[t] - y[t])\)\)},
              {\(\(y'\)[t] \[Equal] \(-x[t]\)\ z[t] + 26.5\ x[t] - y[t]\)},
              {\(\(z'\)[t] \[Equal] x[t]\ y[t] - z[t]\)},
              {\(x[0] \[Equal] z[0] \[Equal] 0\)},
              {\(y[0] \[Equal] 1\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y, z}\), 
        ",", \({t, 0, 9.1}\), ",", 
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]], ",", \(PlotPoints \[Rule] 600\), 
        ",", \(ImageSize \[Rule] 300\), ",", \(HeadLength3D \[Rule] 1/30\)}], 
      "]"}]], "Input"],

Cell[TextData[{
  ButtonBox["R\[ODoubleDot]ssler equations"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x'\)[t] \[Equal] \(-y[t]\) - z[t]\)},
              {\(\(y'\)[t] \[Equal] x[t] +  .425\ y[t]\)},
              {\(\(z'\)[t] \[Equal] 2 - z[t]\ \((4 - x[t])\)\)},
              {\(x[0] \[Equal] \(-0.04\)\)},
              {\(y[0] \[Equal] \(-0.30\)\)},
              {\(z[0] \[Equal] 0.52\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y, z}\), 
        ",", \({t, 0, 25}\), ",", \(Method \[Rule] ExplicitRungeKutta\), ",", 
        
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]], ",", \(PlotPoints \[Rule] 400\), 
        ",", \(PlotRange \[Rule] All\)}], "]"}]], "Input"],

Cell["\<\
A second-order scalar equation (the default for scalar equations is \
without arrows):\
\>", "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x''\)[t] + \(x'\)[t]/2 \[Equal] \(-x[t]\)\)},
              {\(x[0] \[Equal] 1\)},
              {\(\(x'\)[0] \[Equal] 0\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", "x", ",", \({t, 0, 10}\), 
        ",", \(PlotSolution \[Rule] True\), ",", \(PlotRange \[Rule] All\)}], 
      "]"}]], "Input"],

Cell["Same as above, but with arrows:", "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x''\)[t] + \(x'\)[t]/2 \[Equal] \(-x[t]\)\)},
              {\(x[0] \[Equal] 1\)},
              {\(\(x'\)[0] \[Equal] 0\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \(x[t]\), 
        ",", \({t, 0, 10}\), ",", \(PlotSolution \[Rule] True\), ",", 
        StyleBox[\(Oriented \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]], ",", \(PlotRange \[Rule] All\), 
        ",", \(HowManyArrows \[Rule] 3\)}], "]"}]], "Input"],

Cell[TextData[{
  "With the option ",
  StyleBox["DrawSolution", "Input",
    Background->RGBColor[1, 1, 0]],
  " the output is of the form {NDsolve solution, graphics primitives of the \
plot}, and the display is inhibited. The following example needs ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  ":"
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\({{sol}, pl}\), "=", 
        RowBox[{"NDSolve", "[", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {\(\(x'\)[t] \[Equal] x[t]/10 - y[t]\)},
                  {\(\(y'\)[t] \[Equal] y[t]/10 + x[t]\)},
                  {\(x[0] \[Equal] 1\)},
                  {\(y[0] \[Equal] 0\)}
                  },
                ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
            ",", \({t, 0, 10}\), ",", 
            StyleBox[\(DrawSolution \[Rule] True\),
              FontColor->RGBColor[1, 0, 0]]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Draw2D[{Text["\<start\>", {1, 0}], 
          Text["\<end\>", {x[10], y[10]} /. sol], pl}];\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["PhasePlot", "Input",
  FontColor->RGBColor[1, 0, 0]]], "Subsubtitle"],

Cell[TextData[{
  StyleBox["PhasePlot", "Input",
    Background->RGBColor[1, 1, 0]],
  " draws trajectories of a 2D or 3D autonomous system of ordinary \
differential equations, placing arrows along the curves:"
}], "Text"],

Cell[BoxData[
    \(\(PhasePlot[{1\/\(1 + x\^2\), \(-y\) + x}, {x, \(-1\), 1}, {y, \(-1\), 
          1}, {\(-3\), 3}];\)\)], "Input"],

Cell[TextData[{
  "For a system of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["{",
            SpanMaxSize->Infinity,
            GridBoxOptions->{ColumnAlignments->{Left}}], 
          StyleBox[GridBox[{
                {\(x' \((t)\) \[Equal] f(x(t), y(t))\)},
                {\(y' \((t)\) \[Equal] g(x(t), y(t))\)},
                {\(x\_min \[LessEqual] x \[LessEqual] x\_max\)},
                {\(y\_min \[LessEqual] y \[LessEqual] y\_max\)},
                {\(t\_min \[LessEqual] t \[LessEqual] t\_max\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{ColumnAlignments->{Left}}]}], 
        TraditionalForm]]],
  " the syntax is ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(PhasePlot[{f[x, y], g[x, y]}, {x, x\_min, x\_max}, {y, 
              y\_min, y\_max}, {t\_min, t\_max}, options]\),
          "Input"], TraditionalForm]]],
  ". This is made to resemble the syntax of ",
  ButtonBox["PlotField",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text"],

Cell["\<\
You can give the vector fiels as a column vector, instead of a row \
vector, to the same effect:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(1\/\(1 + x\^2\)\)},
                {\(\(-y\) + x\)}
                }], ")"}], ",", \({x, \(-1\), 1}\), ",", \({y, \(-1\), 1}\), 
          ",", \({\(-3\), 3}\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "When positioning the arrows along the solution curves, ",
  StyleBox["PhasePlot", "Input"],
  " only takes into accout the portion of the curves contained in the display \
area ",
  Cell[BoxData[
      FormBox[
        StyleBox[\({x, x\_min, x\_max}, {y, y\_min, y\_max}\),
          "Input"], TraditionalForm]]],
  ". Anything outside is clipped."
}], "Text"],

Cell["The pendulum system:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"y"},
                {\(-Sin[x]\)}
                }], ")"}], ",", \({x, \(-2\) \[Pi], 2  \[Pi]}\), 
          ",", \({y, \(-2\), 2}\), ",", \({0, 2}\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "By default the starting points are a 5x5 rectangular grid. You can change \
the density of the grid with the option ",
  StyleBox["GridPoints", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(1/\((1 + x^2)\)\)},
                {\(\(-y\) + x\)}
                }], ")"}], ",", \({x, \(-1\), 1}\), ",", \({y, \(-1\), 1}\), 
          ",", \({\(-3\), 3}\), ",", 
          StyleBox[\(GridPoints \[Rule] 3\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can see the starting points with the option ",
  StyleBox["ShowListPlot", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({1/\((1 + x^2)\), \(-y\) + x}\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({\(-3\), 3}\), 
          ",", \(GridPoints \[Rule] 3\), ",", 
          StyleBox[\(ShowListPlot \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can give an arbitrary set of starting points with the option ",
  StyleBox["InitialPoints", "Input",
    Background->RGBColor[1, 1, 0]],
  ". In the next example they are along a semi-circle, which seems to give a \
more nicely spaced-out plot:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({1/\((1 + x^2)\), \(-y\) + x}\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({\(-3\), 2}\), ",", 
          
          StyleBox[\(InitialPoints \[Rule] 
              Table[{1 + Cos[\[Theta]], Sin[\[Theta]]}, {\[Theta], \[Pi]/2, 
                  3  \[Pi]/2, \[Pi]/12}]\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can color the curves with ",
  ButtonBox["PlotStyle",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({1/\((1 + x^2)\), \(-y\) + x}\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({\(-3\), 3}\), 
          ",", \(GridPoints \[Rule] 3\), ",", 
          StyleBox[\(PlotStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(\(-x\) - y\)},
                {\(\(-y\) + x\)}
                }], ")"}], ",", \({x, \(-1\), 1}\), ",", \({y, \(-1\), 1}\), 
          ",", \({0, 2  \[Pi]}\), ",", \(GridPoints \[Rule] 2\), ",", 
          StyleBox[\(PlotStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can assign a function to ",
  ButtonBox["PlotStyle",
    ButtonStyle->"RefGuideLink"],
  ". Every curve will get as style the function evaluated at the starting \
point:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({\(-x\) - y, \(-y\) + x}\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({0, 2  \[Pi]}\), 
          ",", \(GridPoints \[Rule] 2\), ",", 
          
          StyleBox[\(PlotStyle \[Rule] 
              Function[{x, y}, RGBColor[x, y, 1/3]]\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Actually, unless ",
  ButtonBox["ColorFunctionScaling",
    ButtonStyle->"RefGuideLink"],
  " is reset to ",
  ButtonBox["False",
    ButtonStyle->"RefGuideLink"],
  ", the ",
  Cell[BoxData[
      \(TraditionalForm\`x, y\)]],
  " values fed into ",
  ButtonBox["PlotStyle",
    ButtonStyle->"RefGuideLink"],
  " will be scaled to the display area. See the documentation for ",
  ButtonBox["DensityPlot",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"],
  "."
}], "Text"],

Cell[TextData[{
  "You can give to ",
  ButtonBox["PlotStyle",
    ButtonStyle->"RefGuideLink"],
  " also a list of list of directives, that will be applied cyclically to the \
curves:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({\(-x\) - y, \(-y\) + x}\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({0, 2  \[Pi]}\), 
          ",", \(GridPoints \[Rule] 2\), ",", 
          
          StyleBox[\(PlotStyle \[Rule] {{Red}, {Dashing[{ .02,  .02}]}, \
{Thickness[ .01]}, {Dashing[{ .01,  .01}], Blue}}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The arrows will inherit the color of the curve it is on. Other ",
  ButtonBox["Arrow",
    ButtonStyle->"AddOnsLink"],
  " options can only be set globally, and not on a curve-by-curve basis:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({\(-x\) - y, \(-y\) + x}\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({0, 2  \[Pi]}\), 
          ",", \(GridPoints \[Rule] 2\), 
          ",", \(PlotStyle \[Rule] Function[{x, y}, RGBColor[x, y, 0]]\), ",",
           
          StyleBox[\(HeadLength \[Rule]  .1\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The points of ",
  StyleBox["ShowListPlot", "Input"],
  " inherit the color of the curve that starts from them:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({1, Sqrt[2]}\), ",", \({x, 0, 1}\), ",", \({y, 0, 1}\), 
          ",", \({0, 1}\), 
          ",", \(PlotStyle \[Rule] Function[{x, y}, RGBColor[x, y, 0]]\), ",",
           
          StyleBox[\(ShowListPlot \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can change their style otherwise with ",
  StyleBox["ListPlotStyle", "Input",
    Background->RGBColor[1, 1, 0]],
  ", that also accepts a function as value:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({1, Sqrt[2]}\), ",", \({x, 0, 1}\), ",", \({y, 0, 1}\), 
          ",", \({0, 1}\), ",", \(ShowListPlot \[Rule] True\), ",", 
          
          StyleBox[\(ListPlotStyle \[Rule] 
              Function[{x, y}, {RGBColor[x, y, 0], PointSize[ .04]}]\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({1, Sqrt[2]}\), ",", \({x, 0, 1}\), ",", \({y, 0, 1}\), 
          ",", \({0, 1}\), ",", \(ShowListPlot \[Rule] True\), ",", 
          StyleBox[\(ListPlotStyle \[Rule] {Red, PointSize[ .04]}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({1, Sqrt[2]}\), ",", \({x, 0, 1}\), ",", \({y, 0, 1}\), 
          ",", \({0, 1}\), 
          ",", \(PlotStyle \[Rule] Function[{x, y}, RGBColor[x, y, 0]]\), 
          ",", \(ShowListPlot \[Rule] True\), ",", 
          StyleBox[\(ListPlotStyle \[Rule] PointSize[ .04]\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["Force lines of a dipole field:", "Text"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(dist1 = \@\(x\^2 + y\^2\);\)\), "\[IndentingNewLine]", 
    \(\(dist2 = \@\(x\^2 + \((y - 1)\)\^2\);\)\), "\[IndentingNewLine]", 
    \(\(potential = 1\/dist1 - 1\/dist2;\)\), "\[IndentingNewLine]", 
    \(\(field = {D[potential, x], D[potential, y]}*\(dist1\^3\) 
            dist2\^3/\((1 + dist1\^3 + dist2\^3)\) // 
          Expand;\)\), "\[IndentingNewLine]", 
    \(\(With[{r = 1/4, d\[Theta] = \[Pi]/8}, 
        PhasePlot[field, {x, \(-3\), 3}, {y, \(-2\), 3}, {\(-10\), 10}, 
          InitialPoints \[Rule] 
            Table[{r\ Cos[\[Theta]], 
                  1 + r\ Sin[\[Theta]]}, {\[Theta], \[Pi]/2, 
                  5  \[Pi]/2 - d\[Theta], d\[Theta]}]~Join~
              Table[{r\ Cos[\[Theta]], 0 + r\ Sin[\[Theta]]}, {\[Theta], 
                  3  \[Pi]/2 - 2  d\[Theta], 3  \[Pi]/2 + 2  d\[Theta], 
                  d\[Theta]}], PlotStyle \[Rule] {Black}, 
          AspectRatio \[Rule] Automatic, 
          HeadLength \[Rule]  .02]];\)\)}], "Input"],

Cell[TextData[{
  "You can also drape the force lines onto the potential surface: see the \
example at the section on ",
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " below."
}], "Text"],

Cell[TextData[{
  StyleBox["PhasePlot", "Input"],
  " can also draw a phase portrait of a 3D autonomous system;you will get 3D \
arrows if ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " is installed. For example a linear system:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"1", "2", "3"},
                  {"4", "3", "2"},
                  {"3", "1", "2"}
                  }], ")"}], ".", 
            RowBox[{"(", GridBox[{
                  {"x"},
                  {"y"},
                  {"z"}
                  }], ")"}]}], ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({z, \(-1\), 1}\), 
          ",", \({\(-2\), 2}\), ",", \(GridPoints \[Rule] 3\), 
          ",", \(PlotStyle \[Rule] RGBColor\)}], "]"}], ";"}]], "Input"],

Cell["A stereogram of the same plot:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{
          RowBox[{"Block", "[", 
            
            RowBox[{\({$DisplayFunction = Identity}\), ",", 
              "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{"gr", "=", 
                  RowBox[{"PhasePlot", "[", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", GridBox[{
                              {"1", "2", "3"},
                              {"4", "3", "2"},
                              {"3", "1", "2"}
                              }], ")"}], ".", 
                        RowBox[{"(", GridBox[{
                              {"x"},
                              {"y"},
                              {"z"}
                              }], ")"}]}], ",", \({x, \(-1\), 1}\), 
                      ",", \({y, \(-1\), 1}\), ",", \({z, \(-1\), 1}\), 
                      ",", \({\(-2\), 2}\), ",", \(GridPoints \[Rule] 3\), 
                      ",", \(PlotStyle \[Rule] RGBColor\)}], "]"}]}], ";", 
                "\[IndentingNewLine]", \(GraphicsArray[{Show[gr, 
                      ViewPoint \[Rule] {1.300, \ \(-2.400\), \ 2}, 
                      ViewCenter \[Rule] {1, 1, 1}/2], 
                    Show[gr, ViewPoint \[Rule] {1.6, \ \(-2.2\), \ 2}, 
                      ViewCenter \[Rule] {1, 1, 1}/2]}]\)}]}], "]"}], 
          ",", \(ImageSize \[Rule] 800\), 
          ",", \(GraphicsSpacing \[Rule]  .15\)}], "]"}], ";"}]], "Input"],

Cell["Another phase portrait in 3D:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", "0", "0"},
                    {"0", \(-\(1\/2\)\), \(-1\)},
                    {"0", "1", \(-\(1\/2\)\)}
                    }], ")"}], ".", 
              RowBox[{"(", GridBox[{
                    {"x"},
                    {"y"},
                    {"z"}
                    }], ")"}]}], "+", 
            RowBox[{"(", GridBox[{
                  {"1"},
                  {"0"},
                  {"0"}
                  }], ")"}]}], ",", \({x, 0, 2  \[Pi]}\), 
          ",", \({y, \(-1\), 1}\), ",", \({z, \(-1\), 1}\), 
          ",", \({0, 2  \[Pi]}\), 
          ",", \(InitialPoints \[Rule] 
            Table[{ .1, Cos[t], Sin[t]}, {t, 0, 2  \[Pi], \[Pi]/3}]\), 
          ",", \(ImageSize \[Rule] 600\)}], "]"}], ";"}]], "Input"],

Cell["Same as above, but with colored curves:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", "0", "0"},
                    {"0", \(-\(1\/2\)\), \(-1\)},
                    {"0", "1", \(-\(1\/2\)\)}
                    }], ")"}], ".", 
              RowBox[{"(", GridBox[{
                    {"x"},
                    {"y"},
                    {"z"}
                    }], ")"}]}], "+", 
            RowBox[{"(", GridBox[{
                  {"1"},
                  {"0"},
                  {"0"}
                  }], ")"}]}], ",", \({x, 0, 2  \[Pi]}\), 
          ",", \({y, \(-1\), 1}\), ",", \({z, \(-1\), 1}\), 
          ",", \({0, 2  \[Pi]}\), 
          ",", \(InitialPoints \[Rule] 
            Table[{ .1, Cos[t], Sin[t]}, {t, 0, 2  \[Pi], \[Pi]/3}]\), ",", 
          StyleBox[\(PlotStyle \[Rule] RGBColor\),
            FontColor->RGBColor[1, 0, 0]], ",", \(ImageSize \[Rule] 600\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  StyleBox["PhaseDraw", "Input",
    Background->RGBColor[1, 1, 0]],
  " is the ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " companion to ",
  StyleBox["PhasePlot", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Draw2D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"PhaseDraw", "[", 
                RowBox[{
                  RowBox[{"(", GridBox[{
                        {\(x*y \((1 - y)\)\)},
                        {\(\(-x\)*y \((1 - x)\)\)}
                        }], ")"}], ",", \({x, 0, 2}\), ",", \({y, 0, 2}\), 
                  ",", \({0, 3}\), 
                  ",", \(PlotStyle \[Rule] Function[{x, y}, Hue[x + y]]\)}], 
                "]"}], ",", \(Text["\<equilibrium\>", {1, 
                  1}, {0, \(-1.5\)}]\)}], "}"}], ",", \(Frame \[Rule] True\), 
          ",", \(AspectRatio \[Rule] Automatic\)}], "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["LinearPhasePlot2D", "Input",
  FontColor->RGBColor[1, 0, 0]]], "Subsubtitle"],

Cell["\<\
LinearPhasePlot2D takes a two-by-two real matrix as argument, plus \
options.The matrix must be made of exact numbers, not of floating-point \
numbers.\
\>", "Text"],

Cell[TextData[{
  "The function ",
  "LinearPhasePlot2D",
  " accepts all ",
  StyleBox["Plot", "Input"],
  " options, but it ignores ",
  StyleBox["PlotRange", "Input"],
  ". "
}], "Text"],

Cell[TextData[{
  "With the option ",
  StyleBox["NotableLineStyle", "Input",
    Background->RGBColor[1, 1, 0]],
  " you can control how the following special lines are drawn: the \
eigenspaces when the eigenvalues are real, and the symmetry axes of the \
ellipse image of the unit circle when the eigenvalues are complex."
}], "Text"],

Cell[TextData[{
  "With the option ",
  StyleBox["NumberOfTrajectories", "Input",
    Background->RGBColor[1, 1, 0]],
  " you can control how many trajectories are drawn. The default value is ",
  StyleBox["5", "Input"],
  ", which was found to be reasonable. If you want less trajectories try a \
value of 4 or 3; if you want more try 6 or 7."
}], "Text"],

Cell[TextData[{
  "With the option ",
  StyleBox["WriteReport", "Input",
    Background->RGBColor[1, 1, 0]],
  " set to ",
  StyleBox["True", "Input"],
  " (the default) you get a classification of the kind of equilibrium the \
origin is."
}], "Text"],

Cell["Try out the following examples:", "Text"],

Cell["Repulsive node:", "Text"],

Cell[BoxData[
    \(\(LinearPhasePlot2D[{{1, 0}, {0, 2}}];\)\)], "Input"],

Cell["With 2-dimensional input form:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{"(", GridBox[{
              {"1", "0"},
              {"0", "2"}
              }], ")"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{"(", GridBox[{
              {"1", \(1\/2\)},
              {\(1\/5\), "2"}
              }], ")"}], "]"}], ";"}]], "Input"],

Cell["Same as above, with the field:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"1", \(1\/2\)},
                {\(1\/5\), "2"}
                }], ")"}], ",", 
          StyleBox[\(ShowField \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Same as above, with eigenspaces colored ",
  StyleBox["greeen",
    FontColor->RGBColor[0, 1, 0]],
  " instead of the defaule ",
  StyleBox["red",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"1", \(1\/2\)},
                {\(1\/5\), "2"}
                }], ")"}], ",", 
          StyleBox[\(NotableLineStyle \[Rule] Green\),
            FontColor->RGBColor[0, 1, 0]]}], "]"}], ";"}]], "Input"],

Cell["\<\
By turning off the insertion of arrow along the curves (as distinct \
from the grid-arrows of the field) the computation is faster:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"1", \(1\/2\)},
                {\(1\/5\), "2"}
                }], ")"}], ",", 
          StyleBox[\(Oriented \[Rule] False\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["Saddle:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{"(", GridBox[{
              {\(-1\), "0"},
              {"1", "1"}
              }], ")"}], "]"}], ";"}]], "Input"],

Cell["Saddle with the field:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(-1\), "0"},
                {"1", "1"}
                }], ")"}], ",", 
          StyleBox[\(ShowField \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["One null eigenvalue, the other one positive:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"With", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"m", "=", 
              RowBox[{"(", GridBox[{
                    {"1", "2"},
                    {"3", "4"}
                    }], ")"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"LinearPhasePlot2D", "[", 
            RowBox[{"m", ".", 
              RowBox[{"(", GridBox[{
                    {"1", "0"},
                    {"0", "0"}
                    }], ")"}], ".", \(Inverse[m]\)}], "]"}]}], "]"}], 
      ";"}]], "Input"],

Cell["Improper node:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{"(", GridBox[{
              {"2", "1"},
              {\(-1\), "4"}
              }], ")"}], "]"}], ";"}]], "Input"],

Cell["Identity matrix:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{"-", 
          RowBox[{"(", GridBox[{
                {"1", "0"},
                {"0", "1"}
                }], ")"}]}], "]"}], ";"}]], "Input"],

Cell["Two null eigenvalues:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"With", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"m", "=", 
              RowBox[{"(", GridBox[{
                    {"1", "2"},
                    {"3", "4"}
                    }], ")"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"LinearPhasePlot2D", "[", 
            RowBox[{"m", ".", 
              RowBox[{"(", GridBox[{
                    {"0", "1"},
                    {"0", "0"}
                    }], ")"}], ".", \(Inverse[m]\)}], "]"}]}], "]"}], 
      ";"}]], "Input"],

Cell["Null matrix:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{"(", GridBox[{
              {"0", "0"},
              {"0", "0"}
              }], ")"}], "]"}], ";"}]], "Input"],

Cell["Center:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"With", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"m", "=", 
              RowBox[{"(", GridBox[{
                    {"1", "2"},
                    {"3", "1"}
                    }], ")"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"LinearPhasePlot2D", "[", 
            RowBox[{"m", ".", 
              RowBox[{"(", GridBox[{
                    {"0", "1"},
                    {\(-1\), "0"}
                    }], ")"}], ".", \(Inverse[m]\)}], "]"}]}], "]"}], 
      ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"With", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"m", "=", 
              RowBox[{"(", GridBox[{
                    {"1", "2"},
                    {"3", "1"}
                    }], ")"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"LinearPhasePlot2D", "[", 
            RowBox[{"m", ".", 
              RowBox[{"(", GridBox[{
                    {"0", "1"},
                    {\(-1\), "0"}
                    }], ")"}], ".", \(Inverse[m]\)}], "]"}]}], "]"}], 
      ";"}]], "Input"],

Cell["\<\
Spiral (it seems to take more time to compute than the other \
examples):\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{"(", GridBox[{
              {\(1\/2\), \(-1\)},
              {"1", \(1\/2\)}
              }], ")"}], "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["LevelPlot3D", "Input"]], "Subsubtitle",
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
  "With ",
  StyleBox["LevelPlot3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " you can draw level sets of a function (it takes a while for a default \
mesh). The basic syntax is the same as for ",
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["LevelPlot3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \(x\^2 - y\^2, {x, \(-1\), 1}, {y, \(-1\), 1}\), "]"}], 
      ";"}]], "Input"],

Cell["\<\
The computation is rather slow.  Try a rougher mesh for faster \
results:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["LevelPlot3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \(x\^2 - y\^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] 5\), "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The default ",
  StyleBox["SurfaceStyle", "Input",
    Background->RGBColor[1, 1, 0]],
  " is ",
  StyleBox["EdgeForm[]", "Input"],
  ", that suppresses the edges of the polygons. You can revert to the usual \
behaviour of ",
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  " in the following way, but you may agree it's not a good idea:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(SurfaceStyle \[Rule] {}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "With the option ",
  ButtonBox["Contours",
    ButtonStyle->"RefGuideLink"],
  " you can control the level sets to be drawn the same way as you do with ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"],
  ". If you set it to an integer, the level sets will be equally spaced \
between the supremum and the infimum of the function on the domain. The \
default is ",
  StyleBox["Contours->11", "Input"],
  ". ",
  ButtonBox["Contours",
    ButtonStyle->"RefGuideLink"],
  " can also be an explicit list of values."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(Contours \[Rule] 3\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(Contours \[Rule] {0, 1/6}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can choose a style for the level lines with ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(ContourStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Within ",
  StyleBox["LevelPlot3D", "Input"],
  ", beside fixed directives, ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  " accepts a ",
  StyleBox["function",
    FontSlant->"Italic"],
  " as value. For each contour the function will be evaluated at the \
corresponding ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", and that will be the style of that contour. Actually, not exactly the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " value, rather the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " value scaled linearly to range between 0 and\[NonBreakingSpace]1, if ",
  ButtonBox["ColorFunctionScaling",
    ButtonStyle->"RefGuideLink"],
  " is set to the default ",
  StyleBox["True", "Input"],
  "."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(ContourStyle \[Rule] Hue\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          
          StyleBox[\(ContourStyle \[Rule] \(({GrayLevel[1 - #], 
                    Dashing[{ .01,  .02}], Thickness[ .01]} &)\)\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "With the option ",
  StyleBox["ShowProjectedLevelSets", "Input",
    Background->RGBColor[1, 1, 0]],
  " set to ",
  StyleBox["True", "Input"],
  " the level lines are shown both on the surface and projected onto a \
horizontal plane:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 + y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(ShowProjectedLevelSets \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The horizontal plane is by default at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ". You can choose a different value of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " with the option ",
  StyleBox["ProjectAt", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), 
          ",", \(ShowProjectedLevelSets \[Rule] True\), ",", 
          StyleBox[\(ProjectAt \[Rule] 1\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "With the option ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " set to ",
  StyleBox["True", "Input"],
  ", and if you have ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " installed, arrows will be placed along the contour lines, oriented so \
that the higher ground will be to the left hand side of the curve, seen from \
above:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can adjust the arrow size with ",
  StyleBox["HeadLength3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " and other options from ",
  ButtonBox["Arrow3D",
    ButtonStyle->"AddOnsLink"],
  ", Here by default, ",
  StyleBox["HeadLength3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " is set to ",
  StyleBox["1/10", "Input"],
  " of the lenght of the largest edge of the smallest ",
  ButtonBox["Cuboid",
    ButtonStyle->"RefGuideLink"],
  " that encloses the contours:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(HeadLength3D \[Rule] 1/20\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can reverse the arrow orientation with ",
  StyleBox["ReverseOrientation", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ReverseOrientation \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Any colors from ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  " will be applied to the arrows, too, unless a separate ",
  StyleBox["Arrow3DColor", "Input",
    Background->RGBColor[1, 1, 0]],
  " option is explicitly given, if for any reason you want to try:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ContourStyle \[Rule] Hue\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ContourStyle \[Rule] Hue\),
            FontColor->RGBColor[1, 0, 0]], ",", 
          StyleBox[\(Arrow3DColor \[Rule] \((Hue[1 - #] &)\)\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "There are ",
  StyleBox["\"pathological cases\"",
    FontSlant->"Italic"],
  " to keep in mind. In flat areas the level lines are not lines any more. \
The output in these cases can be confusing at first sight: the level line \
expands into triangles. First an example with a spaced-out grid to show the \
triangles better:"
}], "Text"],

Cell[BoxData[
    \(\(LevelPlot3D[y*x\^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] 5, PlotRange \[Rule] All];\)\)], "Input"],

Cell[BoxData[
    \(\(LevelPlot3D[y*x\^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] 5, PlotRange \[Rule] All, 
        ShowProjectedLevelSets \[Rule] True, 
        ProjectAt \[Rule] \(-1.5\)];\)\)], "Input"],

Cell["\<\
then an example with a normally spaced grid, where the flat \
triangles are small but still noticeable:\
\>", "Text"],

Cell[BoxData[
    \(\(LevelPlot3D[y*x\^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        ContourStyle \[Rule] Hue];\)\)], "Input"],

Cell[TextData[{
  "Sometimes the function can be larger ",
  StyleBox["on both sides",
    FontSlant->"Italic"],
  " of a level line.  In this case arrows pointing in opposite direction get \
superimposed on each other:"
}], "Text"],

Cell[BoxData[
    \(\(LevelPlot3D[x\^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Oriented \[Rule] True, Contours \[Rule] {0}, 
        PlotPoints \[Rule] {11, 2}, PlotRange \[Rule] All];\)\)], "Input"],

Cell["The two \"pathologies\" together:", "Text"],

Cell[BoxData[
    \(\(LevelPlot3D[y*x^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Oriented \[Rule] True, Contours \[Rule] 1, PlotPoints \[Rule] 7, 
        PlotRange \[Rule] All];\)\)], "Input"],

Cell[TextData[{
  "When ",
  StyleBox["ShowProjectedLevelSets", "Input"],
  " is ",
  StyleBox["True", "Input"],
  ", also the ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  " and the arrows will be projected:"
}], "Text"],

Cell[BoxData[
    \(\(LevelPlot3D[x + y, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] 2, Oriented \[Rule] True, 
        ContourStyle \[Rule] Hue, ShowProjectedLevelSets \[Rule] True, 
        ProjectAt \[Rule] \(-3\)];\)\)], "Input"],

Cell[TextData[{
  "You can give shading to the surface, too, just as in ",
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{\(y - x\), ",", 
              StyleBox[\(Hue[\((x + y)\)/4]\),
                FontColor->RGBColor[1, 0, 0]]}], "}"}], 
          ",", \({x, \(-1\), 1}\), ",", \({y, \(-1\), 1}\), 
          ",", \(Oriented \[Rule] True\), ",", \(PlotPoints \[Rule] 5\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "As an example, here are the trajectories of the ",
  StyleBox["pendulum",
    FontSlant->"Italic"],
  " system, plotted on the energy surface: first a quick-and-dirty version:"
}], "Text"],

Cell[BoxData[
    \(\(LevelPlot3D[\(-Cos[x]\) + y\^2\/2, {x, \(-\[Pi]\), 
          3  \[Pi]}, {y, \(-2\), 2.5}, Oriented \[Rule] True, 
        PlotPoints \[Rule] 5, Contours \[Rule] 3, 
        HeadLength3D \[Rule] 1/25];\)\)], "Input"],

Cell["and then a slower, smoother plot:", "Text"],

Cell[BoxData[
    \(\(LevelPlot3D[\(-Cos[x]\) + y\^2\/2, {x, \(-\[Pi]\), 
          3  \[Pi]}, {y, \(-2\), 2.5}, Oriented \[Rule] True, 
        PlotPoints \[Rule] 30, Contours \[Rule] 8, HeadLength3D \[Rule] 1/25, 
        PlotLabel \[Rule] "\<Pendulum Phase Portrait\>", 
        AxesLabel \[Rule] {"\<\[Theta]\>", "\<v\>", "\<E\>"}, 
        Ticks \[Rule] {PiScale[\(-\[Pi]\), 3  \[Pi]], Automatic, Automatic}, 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[TextData[{
  "You can omit the surface and show only the level sets with the option ",
  StyleBox["ShowSurface\[Rule]False", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{
        "x", ",", \({x, 0, 1}\), ",", \({y, 0, 1}\), 
          ",", \(PlotPoints \[Rule] 2\), ",", 
          StyleBox[\(ShowSurface \[Rule] False\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(ShowSurface \[Rule] False\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], \(ContourStyle \[Rule] Hue\), 
          ",", \(Ticks \[Rule] None\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can even show the surface without showing the level sets: just use the \
option ",
  StyleBox["ShowCurves\[Rule]False", "Input",
    Background->RGBColor[1, 1, 0]],
  ". Why would you want to do that? Well, ",
  StyleBox["SliceSurfacePlot", "Input"],
  " does not usually return exactly the same surface it gets from you: it \
first applies ",
  StyleBox["Rationalize[]", "Input"],
  " to it: the level sets lie exactly flat on the rationalized version, \
likely not on the original surface. There may be times when the level sets \
are not the only thing you want to do with your surface. Whatever other \
manipulations you do on the surface, you may be better off with the version \
that comes with ",
  StyleBox["ShowCurves\[Rule]False", "Input"],
  "."
}], "Text"],

Cell[TextData[{
  "There is also ",
  StyleBox["LevelDraw3D", "Input",
    Background->RGBColor[1, 1, 0]],
  ", the ",
  ButtonBox["Draw",
    ButtonStyle->"AddOnsLink"],
  " companion to ",
  StyleBox["LevelPlot3D", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Draw3DItems", "[", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              StyleBox["LevelDraw3D",
                FontColor->RGBColor[1, 0, 0]], 
              "[", \(x\^2 - y\^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
              Oriented \[Rule] True, Contours \[Rule] 3, 
              ContourStyle \[Rule] Hue, ArrowDensity \[Rule]  .5\), "]"}], 
            ",", \(Text["\<saddle\>", {1/2, 1/2, 1}, {0, \(-1\)}]\), 
            ",", \(SurfaceColor[Black]\), ",", \(Thickness[ .01]\), 
            ",", \(Arrow3D[{1/2, 1/2, 1}, {0, 0, 0}, HeadScaling3D \[Rule] 2, 
              HeadLength3D \[Rule] 1/10]\)}], "}"}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  StyleBox["LevelPlot3D", "Input"],
  " has the same purpose as the function ",
  ButtonBox["DrawContourLines",
    ButtonStyle->"AddOnsLink"],
  " from the ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " package, but its inner workings are quite different. ",
  StyleBox["LevelPlot3D", "Input"],
  " first ",
  ButtonBox["Rationalize",
    ButtonStyle->"RefGuideLink"],
  "s the surface, then computes the intersections of the horizontal planes \
with every triangle the surface is made of , using exact rational \
arithmetics. This way the contour lines are perfectly embedded within the \
surface; they will be visible from every ",
  ButtonBox["ViewPoint",
    ButtonStyle->"RefGuideLink"],
  ", because they don't hover above, or below, the surface, much the less do \
they cross it. There ",
  StyleBox["is",
    FontSlant->"Italic"],
  " a draw-back however: ",
  StyleBox["LevelPlot3D", "Input"],
  " is slower. Compare anyway the following plots with the one from the ",
  ButtonBox["DrawContourLines",
    ButtonStyle->"AddOnsLink"],
  " documentation example:"
}], "Text"],

Cell[BoxData[{
    \(\(energy = v\^2/2 + 1/r\^2 - 4/r;\)\), "\[IndentingNewLine]", 
    \(\(Draw3DItems[\[IndentingNewLine]{LevelDraw3D[
            energy, {r, 0.1, 1}, {v, \(-5\), 5}, 
            Contours \[Rule] Join[Range[\(-3\), 2, 1/2], {3, 4, 5, 6, 7}], 
            PlotPoints \[Rule] {10, 31}, 
            ContourStyle \[Rule] White], \[IndentingNewLine]LevelDraw3D[
            energy, {r, 1, 7}, {v, \(-5\), 5}, 
            Contours \[Rule] Join[Range[\(-3\), 2, 1/2], {3, 4, 5, 6, 7}], 
            PlotPoints \[Rule] {30, 31}, 
            ContourStyle \[Rule] 
              White]}, \[IndentingNewLine]PlotRange \[Rule] {All, 
            All, {\(-4\), 8}}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
            0.5}, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]AxesLabel \[Rule] {r, 
            v, "\<E\>"}, \[IndentingNewLine]AxesEdge \[Rule] {{\(-1\), \
\(-1\)}, {1, \(-1\)}, {\(-1\), \(-1\)}}, 
        ViewPoint -> {1.348, \ \(-0.997\), \ 2.939}, 
        Background \[Rule] 
          GrayLevel[
            0.2], \[IndentingNewLine]TextStyle \[Rule] {FontFamily \[Rule] \
"\<Helvetica\>", FontSize \[Rule] 12, FontWeight \[Rule] "\<Bold\>"}, 
        PlotRegion \[Rule] {{0.05, 0.95}, {0, 
              1}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Keplerian Radial \
Phase Portrait\>", \[IndentingNewLine]ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[TextData[{
  "A variation on the theme, with oriented trajectories: (to make sure the \
arrows are of the same size in the two halfs of the plot we set an explicit \
",
  StyleBox["HeadScaling3D", "Input"],
  ")"
}], "Text"],

Cell[BoxData[{
    \(\(energy = v\^2/2 + 1/r\^2 - 4/r;\)\), "\[IndentingNewLine]", 
    \(\(Draw3DItems[\[IndentingNewLine]{LevelDraw3D[
            energy, {r, 0.1, 1}, {v, \(-5\), 5}, 
            Contours \[Rule] 
              Union[Range[\(-3\), 0, 1/2], Range[\(-1\), 7, 2]], 
            PlotPoints \[Rule] {10, 31}, Oriented \[Rule] True, 
            ArrowDensity \[Rule]  .5, HeadScaling3D \[Rule] 10, 
            HeadLength3D \[Rule] 1/25], \[IndentingNewLine]LevelDraw3D[
            energy, {r, 1, 7}, {v, \(-5\), 5}, 
            Contours \[Rule] 
              Union[Range[\(-3\), 0, 1/2], Range[\(-1\), 7, 2]], 
            PlotPoints \[Rule] {30, 31}, Oriented \[Rule] True, 
            ArrowDensity \[Rule]  .5, HeadScaling3D \[Rule] 10, 
            HeadLength3D \[Rule] 
              1/25]}, \[IndentingNewLine]PlotRange \[Rule] {All, 
            All, {\(-4\), 8}}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
            0.5}, \[IndentingNewLine]Axes \[Rule] True, 
        ImageSize \[Rule] 500, 
        ViewPoint \[Rule] {3, \ \(-1\), \ 4}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["SliceSurfacePlot3D", "Input"]], "Subsubtitle",
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
  "The function ",
  StyleBox["SliceSurfacePlot3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " is more general than ",
  StyleBox["LevelPlot3D", "Input"],
  ", because you can give an arbitrary surface and slice it in an arbitrary \
direction. You give a take a pre-computed surface and specify a linear \
expression in ",
  Cell[BoxData[
      \(TraditionalForm\`x, y, z\)]],
  ": ",
  StyleBox["SliceSurfacePlot3D", "Input"],
  " will draw the level lines of the linear function over any polygon of the \
surface. The options are mostly the same as with ",
  StyleBox["LevelPlot3D", "Input"],
  "."
}], "Text"],

Cell[TextData[{
  "Here we draw the level lines of the linear form ",
  Cell[BoxData[
      \(TraditionalForm\`x - 2  y + z\)]],
  " over an ellipsoid:"
}], "Text"],

Cell[BoxData[{\(mySurface = 
        ParametricPlot3D[{4  Cos[u] Cos[v], 3  Sin[u] Cos[v], 2  Sin[v]}, {u, 
            0, 2  \[Pi]}, {v, \(-\[Pi]\)/2, \[Pi]/2}, Ticks \[Rule] None, 
          PlotPoints \[Rule] {25, 15}];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{"mySurface", ",", 
          StyleBox[\(x - 2  y + z\),
            FontColor->RGBColor[1, 0, 0]], ",", "x", ",", "y", ",", "z"}], 
        "]"}], ";"}]}], "Input"],

Cell[TextData[{
  "The option ",
  ButtonBox["Contours",
    ButtonStyle->"RefGuideLink"],
  " directs how many (or exactly which) level lines will be drawn: here is \
the same ellipsoid sliced with 2 level lines of the form ",
  Cell[BoxData[
      \(TraditionalForm\`x + z\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{
        "mySurface", ",", \(x + z\), ",", "x", ",", "y", ",", "z", ",", 
          StyleBox[\(Contours \[Rule] 2\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The option ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  " can be given to govern the style of the contour lines:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{
        "mySurface", ",", \(x + z\), ",", "x", ",", "y", ",", "z", 
          ",", \(Contours \[Rule] 2\), ",", 
          StyleBox[\(ContourStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "With the option ",
  StyleBox["Oriented\[Rule]True", "Input",
    Background->RGBColor[1, 1, 0]],
  ", arrows will be placed along the level lines, if you have ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " installed:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{
        "mySurface", ",", \(x - z\), ",", "x", ",", "y", ",", "z", 
          ",", \(Contours \[Rule] 2\), ",", " ", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The default orientation of the arrows can be reversed either by giving the \
opposite linear form, or by setting ",
  StyleBox["ReverseOrientation\[Rule]True", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{
        "mySurface", ",", \(x - z\), ",", "x", ",", "y", ",", "z", 
          ",", \(Contours \[Rule] 2\), ",", " ", \(Oriented \[Rule] True\), 
          ",", 
          StyleBox[\(ReverseOrientation \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The size of the arrows can be controlled with ",
  StyleBox["HeadLength3D", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{
        "mySurface", ",", \(x - z\), ",", "x", ",", "y", ",", "z", 
          ",", \(Contours \[Rule] 2\), ",", " ", \(Oriented \[Rule] True\), 
          ",", 
          StyleBox[\(HeadLength3D \[Rule] 1/5\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can increase the number of arrows by setting ",
  StyleBox["ArrowDensity", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(SliceSurfacePlot3D[mySurface, x + 2  y - z, x, y, z, 
        Oriented \[Rule] True, ArrowDensity \[Rule] 2];\)\)], "Input"],

Cell[TextData[{
  "With the option ",
  StyleBox["ShowProjectedLevelSets", "Input",
    Background->RGBColor[1, 1, 0]],
  " you can get a separate plot of the level lines orthogonally projected on \
a single level line of the linear form. The level set on which the lines are \
projected is by default 0, but can be set with the option ",
  StyleBox["ProjectAt", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{
        "mySurface", ",", \(x + 2  y - z\), ",", "x", ",", "y", ",", "z", 
          ",", \(ContourStyle \[Rule] Hue\), ",", 
          StyleBox[\(ShowProjectedLevelSets \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[\(ProjectAt \[Rule] 15\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can omit the surface and show only the level sets with the option ",
  StyleBox["ShowSurface\[Rule]False", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{
        "mySurface", ",", \(x - 2  y + z\), ",", "x", ",", "y", ",", "z", ",",
           
          StyleBox[\(ShowSurface \[Rule] False\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can even show the surface without showing the level sets: just use the \
option ",
  StyleBox["ShowCurves\[Rule]False", "Input",
    Background->RGBColor[1, 1, 0]],
  ". Why would you want to do that? Well, ",
  StyleBox["SliceSurfacePlot", "Input"],
  " does not usually return exactly the same surface it gets from you: it \
first applies ",
  StyleBox["Rationalize[]", "Input"],
  " to it: the level sets lie exactly flat on the rationalized version, \
likely not on the original surface. There may be times when the level sets \
are not the only thing you want to do with your surface. Whatever other \
manipulations you do on the surface, you may be better off with the version \
that comes with ",
  StyleBox["ShowCurves\[Rule]False", "Input"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["LinearClipPlot3D", "Input"]], "Subsubtitle",
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
  "The function ",
  StyleBox["LinearClipPlot3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " is mainly an engine for ",
  StyleBox["SliceSurfacePlot3D", "Input"],
  ", but it can be used independently. It draws the intersection of a surface \
with a half-space. See also the functions ",
  ButtonBox["TrimPolygons",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["RaiseTo3D",
    ButtonStyle->"AddOnsLink"],
  " from ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " for an alternative approach."
}], "Text"],

Cell["Start with a paraboloid:", "Text"],

Cell[BoxData[
    \(\(paraboloid = 
        ParametricPlot3D[
          r {Cos[t], Sin[t], r}, {r, 0, 1}, {t, 0, 2  \[Pi]}];\)\)], "Input"],

Cell["The paraboloid cut by a plane:", "Text"],

Cell[BoxData[
    \(\(Show[{paraboloid, \[IndentingNewLine]Plot3D[
            x\/4 + y\/3 + 1\/3, {x, \(-1\), 1}, {y, \(-1\), 1}, 
            PlotPoints \[Rule] 2, 
            DisplayFunction \[Rule] Identity]}];\)\)], "Input"],

Cell["The part of the paraboloid above the plane:", "Text"],

Cell[BoxData[
    \(\(LinearClipPlot3D[paraboloid, z \[GreaterEqual] \ x\/4 + y\/3 + 1\/3, 
        x, y, z];\)\)], "Input"],

Cell["The part of the paraboloid below the plane:", "Text"],

Cell[BoxData[
    \(\(LinearClipPlot3D[paraboloid, z \[LessEqual] x\/4 + y\/3 + 1\/3, x, y, 
        z];\)\)], "Input"],

Cell[TextData[{
  "Instead of a single inequality you can give an ",
  StyleBox["And", "Input"],
  " combination, to intersect the surface with more than one half-space:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearClipPlot3D", "[", 
        RowBox[{"paraboloid", ",", 
          StyleBox[
            RowBox[{
              FractionBox[
                StyleBox["y",
                  FontColor->RGBColor[1, 0, 0]], "2"], "\[LessEqual]", "z", 
              "\[LessEqual]", " ", \(x\/4 + y\/3 + 1\/3\)}],
            FontColor->RGBColor[1, 0, 0]], ",", "x", ",", "y", ",", "z"}], 
        "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearClipPlot3D", "[", 
        RowBox[{"paraboloid", ",", 
          
          StyleBox[\(x - y \[GreaterEqual] \(-\(1\/4\)\) \[And] 
              2  z \[LessEqual] \(-x\) + y + 1\),
            FontColor->RGBColor[1, 0, 0]], ",", "x", ",", "y", ",", "z"}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "There is also ",
  StyleBox["LinearClipDraw3D", "Input",
    Background->RGBColor[1, 1, 0]],
  ", the ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " companion to ",
  StyleBox["LinearClipPlot3D", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Draw3DItems", "[", 
        RowBox[{"{", 
          RowBox[{\(SurfaceColor[Red]\), ",", 
            RowBox[{
              StyleBox["LinearClipDraw3D",
                FontColor->RGBColor[1, 0, 0]], "[", \(paraboloid, 
              z \[LessEqual] \ x\/4 + y\/3 + 1\/3, x, y, z\), "]"}], ",", 
            "\[IndentingNewLine]", \(SurfaceColor[Green]\), ",", 
            RowBox[{
              StyleBox["LinearClipDraw3D",
                FontColor->RGBColor[1, 0, 0]], "[", \(paraboloid, 
              z \[GreaterEqual] x\/4 + y\/3 + 1\/3, x, y, z\), "]"}]}], "}"}],
         "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SurfaceIntersectionPlot3D", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" and ", "Text",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["SurfaceSelfIntersectionPlot3D", "Input",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubtitle"],

Cell[TextData[{
  "When two ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " surfaces cross each other, the intersection line is visible only as the \
transition line between two different-colored areas in the rendered output. \
We have no access to the intersection line. For example, we cannot highlight \
it in a different style:"
}], "Text"],

Cell[BoxData[{
    \(\(surf1 = 
        ParametricPlot3D[{Cos[t], Sin[t], z}, {t, 0, 2  Pi}, {z, \(-2\), 2}, 
          PlotPoints \[Rule] {13, 2}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(surf2 = 
        ParametricPlot3D[{Cos[t], y, Sin[t]}, {t, 0, 2  Pi}, {y, \(-2\), 2}, 
          PlotPoints \[Rule] {13, 2}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[{surf1, surf2}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[TextData[{
  "The function ",
  StyleBox["SurfaceIntersectionPlot3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " calculates the intersection and draws it as actual ",
  StyleBox["Line[]", "Input"],
  " primitives:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["SurfaceIntersectionPlot3D",
        FontColor->RGBColor[1, 0, 0]], "[", \(surf1, surf2\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["SurfaceIntersectionPlot3D",
          FontColor->RGBColor[1, 0, 0]], "[", \(surf1, surf2\), "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  StyleBox["Beware",
    FontSlant->"Italic"],
  ": the computing time increases rapidly with the number of polygons in the \
two surfaces. The routine will check all possible polygon of the first \
surface against any polygon from the second.If you have pictures with lots of \
polygons, you may want to make trials on simplified prototypes first, and run \
the high-resolution computation overnight."
}], "Text"],

Cell[TextData[{
  "You can change the default style of the intersection line with the option \
",
  StyleBox["PlotStyle", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SurfaceIntersectionPlot3D", "[", 
        RowBox[{"surf1", ",", "surf2", ",", "\[IndentingNewLine]", 
          StyleBox[\(PlotStyle \[Rule] {Red, Thickness[ .01]}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can place arrows along the intersection line with the option ",
  StyleBox["Oriented", "Input"],
  ", if you have ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " installed:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SurfaceIntersectionPlot3D", "[", 
        RowBox[{
        "surf1", ",", "surf2", ",", 
          "\[IndentingNewLine]", \(PlotStyle \[Rule] {Red, 
              Thickness[ .005]}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The style of the arrows can be controlled the same way as for ",
  StyleBox["ParametricPlot3D", "Input"],
  ": with ",
  StyleBox["HeadLength3D", "Input"],
  ", ",
  StyleBox["HeadScaling3D", "Input"],
  ", ",
  StyleBox["ArrowDensity", "Input"],
  ", ",
  StyleBox["HowManyArrows", "Input"],
  ", ",
  StyleBox["ReverseOrientation", "Input"],
  " etc:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SurfaceIntersectionPlot3D", "[", 
        RowBox[{
        "surf1", ",", "surf2", ",", 
          "\[IndentingNewLine]", \(PlotStyle \[Rule] {Red, 
              Thickness[ .005]}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(HeadLength3D \[Rule] 1/5\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "By default the mesh of the surfaces is not drawn. You can restore the mesh \
with ",
  StyleBox["SurfaceStyle\[Rule]{}", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SurfaceIntersectionPlot3D", "[", 
        RowBox[{"surf1", ",", "surf2", ",", "\[IndentingNewLine]", 
          StyleBox[\(SurfaceStyle \[Rule] {}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["or give any style you like:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SurfaceIntersectionPlot3D", "[", 
        RowBox[{"surf1", ",", "surf2", ",", "\[IndentingNewLine]", 
          StyleBox[\(SurfaceStyle \[Rule] {EdgeForm[LightGray]}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["You can give different styles to the two surfaces:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SurfaceIntersectionPlot3D", "[", 
        RowBox[{"surf1", ",", "surf2", ",", "\[IndentingNewLine]", 
          
          StyleBox[\(SurfaceStyle \[Rule] {{EdgeForm[DeepPink]}, {EdgeForm[
                    CobaltGreen]}}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["The simplest case is the intersection of two triangles:", "Text"],

Cell[BoxData[
    \(\(SurfaceIntersectionPlot3D[Polygon[{{0, 0, 0}, {1, 0, 0}, {0, 2, 0}}], 
        Polygon[{{0, \(-1\)/3, \(-1\)}, {1/2, 1, \(-1\)}, {1/2, 0, 
              1}}], \[IndentingNewLine]PlotStyle \[Rule] {Red, 
            Thickness[ .01]}, PlotRange \[Rule] All];\)\)], "Input"],

Cell[TextData[{
  "You can omit one or both of the surfaces with the option ",
  StyleBox["ShowSurface\[Rule]False", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SurfaceIntersectionPlot3D", "[", 
        RowBox[{\(Polygon[{{0, 0, 0}, {1, 0, 0}, {0, 2, 0}}]\), 
          ",", \(Polygon[{{0, \(-1\)/3, \(-1\)}, {1/2, 1, \(-1\)}, {1/2, 0, 
                1}}]\), ",", 
          "\[IndentingNewLine]", \(PlotStyle \[Rule] {Red, Thickness[ .01]}\),
           ",", \(PlotRange \[Rule] {{0, 1}, {\(-1\)/3, 2}, {\(-1\), 1}}\), 
          ",", 
          StyleBox[\(ShowSurface \[Rule] False\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SurfaceIntersectionPlot3D", "[", 
        RowBox[{\(Polygon[{{0, 0, 0}, {1, 0, 0}, {0, 2, 0}}]\), 
          ",", \(Polygon[{{0, \(-1\)/3, \(-1\)}, {1/2, 1, \(-1\)}, {1/2, 0, 
                1}}]\), ",", 
          "\[IndentingNewLine]", \(PlotStyle \[Rule] {Red, Thickness[ .01]}\),
           ",", \(PlotRange \[Rule] {{0, 1}, {\(-1\)/3, 2}, {\(-1\), 1}}\), 
          ",", 
          StyleBox[\(ShowSurface \[Rule] {True, False}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SurfaceIntersectionPlot3D", "[", 
        RowBox[{\(Polygon[{{0, 0, 0}, {1, 0, 0}, {0, 2, 0}}]\), 
          ",", \(Polygon[{{0, \(-1\)/3, \(-1\)}, {1/2, 1, \(-1\)}, {1/2, 0, 
                1}}]\), ",", 
          "\[IndentingNewLine]", \(PlotStyle \[Rule] {Red, Thickness[ .01]}\),
           ",", \(PlotRange \[Rule] {{0, 1}, {\(-1\)/3, 2}, {\(-1\), 1}}\), 
          ",", 
          StyleBox[\(ShowSurface \[Rule] {False, True}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can even show the surfaces without showing the intersection lines: \
just use the option ",
  StyleBox["ShowCurves\[Rule]False", "Input",
    Background->RGBColor[1, 1, 0]],
  ". Why would you want to do that? Well, ",
  StyleBox["SurfaceIntersectionPlot3D", "Input"],
  " does not usually return exactly the same surfaces it gets from you: it \
first applies ",
  StyleBox["Rationalize[]", "Input"],
  " to them: the intersection curve lies exactly flat on the rationalized \
version, while it probably crisscrosses the original surface. There may be \
times when the level sets are not the only thing you want to do with your \
surface. Whatever other manipulations you do on the surface, you may be \
better off with the version that comes with ",
  StyleBox["ShowCurves\[Rule]False", "Input"],
  "."
}], "Text"],

Cell["\<\
You can have more than two surfaces, and draw the pairwise \
intersections, and give different styles to them:\
\>", "Text"],

Cell[BoxData[
    \(\(SurfaceIntersectionPlot3D[Polygon[{{0, 0, 0}, {1, 0, 0}, {0, 2, 0}}], 
        Polygon[{{0, \(-1\)/3, \(-1\)}, {1/2, 1, \(-1\)}, {1/2, 0, 1}}], 
        Polygon[{{0, 0, 1}, {1, 0, \(-1\)/2}, {1, 
              1, \(-1\)/2}}], \[IndentingNewLine]PlotStyle \[Rule] {{Red, 
              Thickness[ .015]}, {Green, Thickness[ .015]}, {Blue, 
              Thickness[ .015]}}, PlotRange \[Rule] All];\)\)], "Input"],

Cell["The pairwise intersections of three cylinders:", "Text"],

Cell[BoxData[
    \(\(Needs["\<Geometry`Rotations`\>"];\)\)], "Input"],

Cell[BoxData[{\(Block[{$DisplayFunction = Identity}, 
        surf1 = ParametricPlot3D[{Cos[t], Sin[t], z}, {t, 0, 
              2  Pi}, {z, \(-2\), 4}, 
            PlotPoints \[Rule] {21, 2}]; \[IndentingNewLine]surf2 = 
          ParametricPlot3D[
            Evaluate[
              RotationMatrix3D[\(-1\), 2, 1/2] . {1.1  Cos[t], 
                  y,  .8  Sin[t]}], {t, 0, 2  Pi}, {y, \(-6\), 2}, 
            PlotPoints \[Rule] {21, 2}]; \[IndentingNewLine]surf3 = 
          ParametricPlot3D[{x,  .7  Cos[t], 3 +  .7  Sin[t]}, {t, 0, 
              2  Pi}, {x, \(-2\), 5}, 
            PlotPoints \[Rule] {21, 2}]];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["SurfaceIntersectionPlot3D",
          FontColor->RGBColor[1, 0, 0]], "[", \(surf1, surf2, 
        surf3, \[IndentingNewLine]Oriented \[Rule] True, 
        PlotStyle \[Rule] {{Red, Thickness[ .005]}, {Blue, 
              Thickness[ .005]}, {Green, Thickness[ .005]}}, 
        HeadLength3D \[Rule] 1/5, Boxed \[Rule] False\), "]"}], 
      ";"}]}], "Input"],

Cell["More examples, that take long to calculate:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["SurfaceIntersectionPlot3D",
          FontColor->RGBColor[1, 0, 0]], "[", 
        "\[IndentingNewLine]", \(Plot3D[\[ExponentialE]\^\(-\((x\^2 + y\^2)\)\
\), {x, \(-3\), 3}, {y, \(-3\), 3}, PlotPoints \[Rule] 13, 
          DisplayFunction \[Rule] 
            Identity], \[IndentingNewLine]Plot3D[\(-4\) + 
            8  \[ExponentialE]\^\(\(-2\) \((\((x - 2)\)\^2 + y\^2/6)\)\), {x, 
            0, 4}, {y, \(-3\), 3}, PlotPoints \[Rule] 21, 
          DisplayFunction \[Rule] 
            Identity], \[IndentingNewLine]PlotStyle \[Rule] {White}, 
        SurfaceStyle \[Rule] {{SurfaceColor[Red], 
              EdgeForm[]}, {SurfaceColor[GrayLevel[ .5]], EdgeForm[]}}, 
        PlotRange \[Rule] All, DisplayFunction \[Rule] $DisplayFunction\), 
        "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["SurfaceIntersectionPlot3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \(Plot3D[x\^2 + y\^2, {x, \(-1\), 1}, {y, 0, 1}, 
          PlotPoints \[Rule] 9, DisplayFunction \[Rule] Identity], 
        Plot3D[1/2 + \((x\^2 + y\^2)\)/3, {x, \(-1.2\), 1.2}, {y, 0, 1.3}, 
          PlotPoints \[Rule] 9, 
          DisplayFunction \[Rule] 
            Identity], \[IndentingNewLine]PlotRange \[Rule] All, 
        SurfaceStyle \[Rule] {{SurfaceColor[Moccasin], 
              EdgeForm[SaddleBrown]}, {SurfaceColor[LightBlue], 
              EdgeForm[Cobalt]}}, PlotStyle \[Rule] {DeepCadmiumRed}, 
        Oriented \[Rule] True, DisplayFunction \[Rule] $DisplayFunction\), 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can draw the self-intersection of a curve with ",
  StyleBox["SurfaceSelfIntersectionPlot3D", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{\(surf = 
        ParametricPlot3D[{\((1 + u\ Sin[\[Phi]\/5])\)\ Sin[\[Phi]], 
            Cos[\[Phi]]\ \((1 + u\ Sin[\[Phi]\/5])\), 
            u\ Cos[\[Phi]\/5]}, {u, \(-1\)/2, 1/2}, {\[Phi], \(-\[Pi]\), 
            2  \[Pi]}, PlotPoints \[Rule] {2, 31}, 
          DisplayFunction \[Rule] Identity]\), ";", 
      RowBox[{
        StyleBox["SurfaceSelfIntersectionPlot3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \(surf, \[IndentingNewLine]PlotStyle \[Rule] {Red, 
            Thickness[ .005]}, Oriented \[Rule] True\), "]"}], ";"}]], "Input"],

Cell["\<\
The self-intersection ignores the intersection of any two polygons \
that share one side. This is why the following example misses the \
self-intersection:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["SurfaceSelfIntersectionPlot3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \(ParametricPlot3D[{u\^3 - u, v, u\^2}, {u, \(-\(7\/6\)\), 
            7\/6}, {v, 0, 1}, PlotPoints \[Rule] {15, 2}, 
          DisplayFunction \[Rule] 
            Identity], \[IndentingNewLine]PlotStyle \[Rule] {Red, 
            Thickness[ .01]}\), "]"}], ";"}]], "Input"],

Cell[TextData[{
  " If your intersection happens exactly along the edge of the polygon, a \
workaround may be to simply change slightly the ",
  ButtonBox["PlotPoints",
    ButtonStyle->"RefGuideLink"],
  " setting:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["SurfaceSelfIntersectionPlot3D",
          FontColor->RGBColor[1, 0, 0]], "[", 
        RowBox[{
          RowBox[{"ParametricPlot3D", "[", 
            
            RowBox[{\({u\^3 - u, v, u\^2}\), 
              ",", \({u, \(-\(7\/6\)\), 7\/6}\), ",", \({v, 0, 1}\), ",", 
              RowBox[{"PlotPoints", "\[Rule]", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox["14",
                      FontColor->RGBColor[1, 0, 0]], ",", "2"}], "}"}]}], 
              ",", \(DisplayFunction \[Rule] Identity\)}], "]"}], ",", 
          "\[IndentingNewLine]", \(PlotStyle \[Rule] {Red, 
              Thickness[ .01]}\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  StyleBox["SurfaceIntersectionDraw3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " and ",
  StyleBox["SurfaceSelfIntersectionDraw3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " are also available: as usual they extract the graphics primitives from \
the corresponding ",
  ButtonBox["Plot",
    ButtonStyle->"RefGuideLink"],
  " functions."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " (for parametric curves)"
}], "Subsubtitle",
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
The na\[IDoubleDot]ve way of plotting a curve over a 3D surface, \
with the curve that submarines behind the surface:\
\>", "Text"],

Cell[BoxData[{\(Clear[f, u, v, 
        t];\), "\[IndentingNewLine]", \(f[u_, v_] = {4  Cos[u] Cos[v], 
          3  Sin[u] Cos[v], 2  Sin[v]};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["surface",
          FontColor->RGBColor[0, 0, 1]], 
        "=", \(ParametricPlot3D[
          Evaluate[f[u, v]~Join~{EdgeForm[]}], {u, 0, 
            2  \[Pi]}, {v, \(-\[Pi]\)/2, \[Pi]/2}, 
          PlotPoints \[Rule] {51, 41}, Ticks \[Rule] None, 
          PlotRange \[Rule] {{\(-4\), 4}, {\(-3\), 3}, {\(-2\), 2}}]\)}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["curve",
          FontColor->RGBColor[1, 0, 0]], 
        "=", \(ParametricPlot3D[
          Evaluate[f[t*Cos[30  t] - \[Pi]/2, t*Sin[30  t] + \[Pi]/6]], {t, 0, 
            1}, PlotPoints \[Rule] 150, Ticks \[Rule] None, 
          PlotRange \[Rule] {{\(-4\), 4}, {\(-3\), 3}, {\(-2\), 2}}]\)}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              StyleBox["surface",
                FontColor->RGBColor[0, 0, 1]], ",", 
              StyleBox["curve",
                FontColor->RGBColor[1, 0, 0]]}], "}"}], 
          ",", \(Ticks \[Rule] None\)}], "]"}], ";"}]}], "Input"],

Cell[BoxData[{
    \(\($FormatType = TraditionalForm;\)\), "\[IndentingNewLine]", 
    \(\(Show[
        GraphicsArray[{{Show[surface, PlotLabel \[Rule] "\<surface\>", 
                DisplayFunction \[Rule] Identity], 
              Show[curve, PlotLabel \[Rule] "\<curve\>", 
                DisplayFunction \[Rule] Identity]}, {Show[{surface, curve}, 
                PlotLabel \[Rule] "\<surface and curve\>", 
                DisplayFunction \[Rule] Identity], Graphics[{}]}}], 
        ImageSize \[Rule] 500];\)\)}], "Input"],

Cell[TextData[{
  "With ",
  StyleBox["PlotCurveOnSurface3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " the curve lies exactly on the surface, and it shows all the way (it takes \
a while to compute):"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          
          StyleBox[\({{4  Cos[u] Cos[v], 3  Sin[u] Cos[v], 2  Sin[v]}, {u, 0, 
                2  \[Pi]}, {v, \(-\[Pi]\)/2, \[Pi]/2}, 
              PlotPoints \[Rule] {51, 41}}\),
            FontColor->RGBColor[0, 0, 1]], ",", 
          
          StyleBox[\({{t*Cos[30  t] - \[Pi]/2, t*Sin[30  t] + \[Pi]/6}, {t, 
                0, 1}, PlotPoints \[Rule] 100}\),
            FontColor->RGBColor[1, 0, 0]], ",", \(Ticks \[Rule] None\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "With the option ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " you get arrows along the curve, if ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " is installed:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          
          StyleBox[\({{4  Cos[u] Cos[v], 3  Sin[u] Cos[v], 2  Sin[v]}, {u, 0, 
                2  \[Pi]}, {v, \(-\[Pi]\)/2, \[Pi]/2}, 
              PlotPoints \[Rule] {51, 41}}\),
            FontColor->RGBColor[0, 0, 1]], ",", 
          
          StyleBox[\({{t*Cos[30  t] - \[Pi]/2, t*Sin[30  t] + \[Pi]/6}, {t, 
                0, 1}, PlotPoints \[Rule] 100, Oriented \[Rule] True, 
              HowManyArrows \[Rule] 6}\),
            FontColor->RGBColor[1, 0, 0]], ",", \(Ticks \[Rule] None\)}], 
        "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          
          StyleBox[\({{x, y, x^2 - y^2}, {x, \(-1.5\), 1.5}, {y, \(-1.5\), 
                1.5}, PlotPoints \[Rule] 21}\),
            FontColor->RGBColor[0, 0, 1]], ",", 
          
          StyleBox[\({{Cos[t], Sin[t]}, {t, 0, 2  \[Pi]}, 
              Oriented \[Rule] True, PlotPoints \[Rule] 100, 
              HowManyArrows \[Rule] 4, HeadLength3D \[Rule] 1/5}\),
            FontColor->RGBColor[1, 0, 0]], ",", \(PlotRange \[Rule] All\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "To get a non-jagged look for the curve you need to set rather higher ",
  ButtonBox["PlotPoints",
    ButtonStyle->"RefGuideLink"],
  " for both surface and curve, and be prepared to wait longer..."
}], "Text"],

Cell["The syntax is:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["PlotCurveOnSurface3D",
        "Input"], 
      StyleBox["[",
        "Input"], 
      StyleBox["\[IndentingNewLine]",
        "Input"], 
      RowBox[{
        StyleBox[\({content\ of\ what\ you\ would\ write\ into\ Plot3D\ or\ \
ParametricPlot3D\ to\ get\ the\ surface\ only}\),
          "Input",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[",",
          "Input",
          FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
          StyleBox["{",
            "Input",
            FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
            StyleBox["content",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["of",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["what",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["you",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["would",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["write",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["into",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["ParametricPlot",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["to",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["describe",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["the",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["curve",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["in",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["the",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["2",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["dimensional",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["parameter",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["space",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["of",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["the",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["surface",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]]}], 
          StyleBox["}",
            "Input",
            FontColor->RGBColor[1, 0, 0]]}], 
        StyleBox[",",
          "Input"], 
        StyleBox["\[IndentingNewLine]",
          "Input"], 
        StyleBox[\(optional\ Graphics3D\ options\),
          "Input"]}], 
      StyleBox["]",
        "Input"]}]], "Input",
  Evaluatable->False],

Cell[TextData[{
  "You can do it the ",
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  " way:"
}], "Text"],

Cell[BoxData[{
    RowBox[{\(f = 
          1\/\(1 + \((x + 1)\)\^2 + y\^2\) - 
            1\/\(1 + \((x - 1)\)\^2 + y\^2\);\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          StyleBox[\({f, {x, \(-2\), 2}, {y, \(-2\), 2}, PlotPoints -> 50}\),
            FontColor->RGBColor[0, 0, 1]], ",", 
          
          StyleBox[\({{t*Cos[10  t], t*Sin[10  t]}, {t, 0, 2}, 
              PlotPoints \[Rule] 100, Oriented \[Rule] True}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]}], "Input"],

Cell["\<\
The motion of  the pendulum with friction, drawn on the energy \
function graph\
\>", "Text"],

Cell[BoxData[{
    \(\({sol, plot2D} = 
        NDSolve[{\(x'\)[t] \[Equal] 
              y[t], \(y'\)[t] \[Equal] \(-Sin[x[t]]\) - y[t]/6, 
            x[0] \[Equal] \(-\[Pi]\)/2, y[0] \[Equal] 0}, {x, y}, {t, 0, 20}, 
          PlotSolution \[Rule] True, 
          HowManyArrows \[Rule] 4];\)\), "\[IndentingNewLine]", 
    \(\(PlotCurveOnSurface3D[{y^2/2 - Cos[x], {x, \(-\[Pi]\)/2 // N, 
            1.2}, {y, \(-1\), 1.3}}, 
        Evaluate[{{x[t], y[t]} /. sol[\([1]\)], {t, 0, 20}, 
            Oriented \[Rule] True, PlotPoints \[Rule] 100, 
            HowManyArrows \[Rule] 4}]];\)\)}], "Input"],

Cell["You can also draw more than one curve on the same surface:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          
          StyleBox[\({{\((3 + Cos[u])\) Cos[v], \((3 + Cos[u])\) Sin[v], 
                Sin[u]}, {u, 0, 2  \[Pi]}, {v, 0, 2  \[Pi]}, 
              PlotPoints \[Rule] {15, 41}}\),
            FontColor->RGBColor[0, 0, 1]], ",", 
          RowBox[{"Evaluate", "[", 
            RowBox[{"Sequence", "@@", 
              RowBox[{"Table", "[", 
                RowBox[{
                  
                  StyleBox[\({{Cos[\[Theta]] t + \[Pi]/4, 
                        Sin[\[Theta]] t - \[Pi]/4}, {t, \(-4\), 4}, 
                      PlotPoints \[Rule] 5, 
                      PlotStyle \[Rule] {Thickness[ .002], Hue[\[Theta]]}}\),
                    FontColor->RGBColor[1, 0, 0]], 
                  ",", \({\[Theta], 0, \[Pi], \[Pi]/6}\)}], "]"}]}], "]"}], 
          ",", \(Boxed \[Rule] False\), ",", \(Axes \[Rule] False\)}], "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "You can omit the surface and show only the level sets with the option ",
  StyleBox["ShowSurface\[Rule]False", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{x\^2 + y\^2, {x, \(-1\), 1}, {y, \(-1\), 
            1}}, {{t*Sin[5  t], t*Cos[5  t]}, {t, 0, 1}}, 
        BoxRatios \[Rule] {2, 2, 1}];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({x\^2 + y\^2, {x, \(-1\), 1}, {y, \(-1\), 1}}\), 
          ",", \({{t*Sin[5  t], t*Cos[5  t]}, {t, 0, 1}}\), 
          ",", \(BoxRatios \[Rule] {2, 2, 1}\), ",", 
          StyleBox[\(ShowSurface \[Rule] False\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can even show the surface without showing the level sets: just use the \
option ",
  StyleBox["ShowCurves\[Rule]False", "Input",
    Background->RGBColor[1, 1, 0]],
  ". Why would you want to do that? Well, ",
  StyleBox["SliceSurfacePlot", "Input"],
  " does not usually return exactly the same surface it gets from you: it \
first applies ",
  StyleBox["Rationalize[]", "Input"],
  " to it: the level sets lie exactly flat on the rationalized version, \
likely not on the original surface. There may be times when the level sets \
are not the only thing you want to do with your surface. Whatever other \
manipulations you do on the surface, you may be better off with the version \
that comes with ",
  StyleBox["ShowCurves\[Rule]False", "Input"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["DrawCurveOnSurface3D", "Input",
    Background->RGBColor[1, 1, 0]],
  ", the ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " companion to ",
  StyleBox["PlotCurveOnSurface3D", "Input"],
  ", is also provided. You can even combine ",
  StyleBox["DrawCurveOnSurface3D", "Input"],
  " with ",
  StyleBox["SliceSurfacePlot3D", "Input"],
  ", to show how the energy of a pendulum with friction decreases with time:"
}], "Text"],

Cell[BoxData[{
    RowBox[{\({sol, plot2D} = 
          NDSolve[{\(x'\)[t] \[Equal] 
                y[t], \(y'\)[t] \[Equal] \(-Sin[x[t]]\) - y[t]/6, 
              x[0] \[Equal] \(-\[Pi]\)/2, y[0] \[Equal] 0}, {x, y}, {t, 0, 
              20}, PlotSolution \[Rule] True, HowManyArrows \[Rule] 4];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\({surface, curve}\), "=", 
          RowBox[{
            StyleBox["DrawCurveOnSurface3D",
              FontColor->RGBColor[1, 0, 0]], 
            "[", \({y^2/2 - Cos[x], {x, \(-\[Pi]\)/2 // N, 1.2}, {y, \(-1\), 
                1.3}}, Evaluate[{{x[t], y[t]} /. sol[\([1]\)], {t, 0, 20}, 
                Oriented \[Rule] True, PlotPoints \[Rule] 100, 
                HowManyArrows \[Rule] 4}]\), "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{"Graphics3D", "[", 
          RowBox[{"{", 
            RowBox[{"curve", ",", 
              RowBox[{
                StyleBox["SliceSurfaceDraw3D",
                  FontColor->RGBColor[1, 0, 0]], "[", \(Graphics3D[surface], 
                z, x, y, z, ContourStyle \[Rule] White\), "]"}]}], "}"}], 
          "]"}], "]"}], ";"}]}], "Input"],

Cell[TextData[{
  "An elaborate illustration, combining ",
  StyleBox["DrawCurveOnSurface3D", "Input"],
  " and ",
  StyleBox["TrigInterpolationParametricDraw", "Input"],
  " (described elsewhere in this file):"
}], "Text"],

Cell[BoxData[
    \(\(Block[{t, 
          r = 1 + 1/8, $FormatType = 
            TraditionalForm}, \[IndentingNewLine]parCurve = {{t*Cos[t], 
                t*Sin[t]}/\((3  \[Pi])\), {t, 0, 3  \[Pi]}, 
            Oriented \[Rule] True, HeadScaling3D \[Rule] 2, 
            PlotPoints \[Rule] 50, HowManyArrows \[Rule] 4}; 
        Show[Graphics3D[{{Thickness[ .006], 
                Line[{{\(-3\), 0, 0}, {\(-1.5\), 0, 
                      0}}]}, \[IndentingNewLine]Text[
                StyleForm[\[DoubleStruckCapitalR], 
                  FontSize \[Rule] 14], {\(-3\), 0, 0}, {\(-1\), 
                  2}], \[IndentingNewLine]TrigInterpolationParametricDraw[{{\(\
-2.2\), 1/4, 1/4}, {{\(- .3\), 1, 1/4}, {1, \(-1\), \(-1\)}/2}}, 
                Oriented \[Rule] True, ArrowPositions \[Rule] 1, 
                HeadScaling3D \[Rule] 3], \[IndentingNewLine]Text[
                StyleForm[\[CurlyPhi], FontSize \[Rule] 14], {\(-1.3\), 0, 
                  1.4}], \[IndentingNewLine]Text[
                DisplayForm[
                  StyleForm[
                    GridBox[{{"\<parametric curve\>"}, {"\<in the \
plane\>"}}], FontFamily \[Rule] Times]], {\(-3\), 
                  1.5,  .6}], \[IndentingNewLine]DrawCurveOnSurface3D[{{x, y, 
                    0, EdgeForm[GrayLevel[ .5], Thickness[0]]}, {x, \(-1\), 
                    1}, {y, \(-1\), 1}, PlotPoints \[Rule] 25}, 
                Evaluate[parCurve]], \[IndentingNewLine]Text[
                StyleForm[\[DoubleStruckCapitalR]\^2, 
                  FontSize \[Rule] 14], {\(-1\), \(-1\), 0}, {\(-1\), 
                  2}], \[IndentingNewLine]TrigInterpolationParametricDraw[{{0,\
 1, 1/4}, {{2.5, 1, 1}, {1, \(-1\), \(-1\)}/2}}, Oriented \[Rule] True, 
                ArrowPositions \[Rule] 1, 
                HeadScaling3D \[Rule] 3], \[IndentingNewLine]Text[
                StyleForm[\[Psi], FontSize \[Rule] 14], {1.3, 1, 
                  1.5}], \[IndentingNewLine]DrawCurveOnSurface3D[{{u + 
                      3, \(-u^2\) + v^2 - u*v/2, v, 
                    EdgeForm[GrayLevel[ .5], Thickness[0]]}, {u, \(-1\), 
                    1}, {v, \(-1\), 1}, PlotPoints \[Rule] 25}, 
                Evaluate[parCurve]], \[IndentingNewLine]Text[
                StyleForm[\[DoubleStruckCapitalR]\^3, 
                  FontSize \[Rule] 14], {3 - 
                    r, \(-r\), \(-r\)}, {1.5, \(-2\)}], \
\[IndentingNewLine]Text[
                DisplayForm[
                  StyleForm[
                    GridBox[{{"\<parametric surface\>"}, {"\<in space\>"}}], 
                    FontFamily \[Rule] Times]], {2.8, 1.5, 
                  1.5}], \[IndentingNewLine]Line[{{3 - r, \(-r\), 
                      z}, {3 + r, \(-r\), z}, {3 + r, r, z}, {3 - r, r, 
                      z}, {3 - r, \(-r\), 
                      z}}] /. \[IndentingNewLine]{{z \[Rule] \(-1\)}, {z \
\[Rule] 1}}, \[IndentingNewLine]Table[
                Line[{{x, y, \(-1\)}, {x, y, 1}}], {x, 3 - r, 3 + r, 
                  2  r}, {y, \(-r\), r, 
                  2  r}], \
\[IndentingNewLine]TrigInterpolationParametricDraw[{{\(-2.2\), \(-1\)/
                      4, \(-1\)/4}, {{2.5, \(-1\), \(-1\)}, {1, 1, 1}/2}}, 
                Oriented \[Rule] True, ArrowPositions \[Rule] 1, 
                HeadScaling3D \[Rule] 3], \[IndentingNewLine]Text[
                StyleForm[\[Psi]\[EmptySmallCircle]\[CurlyPhi], 
                  FontSize \[Rule] 14], {0, \(-1\), \(-1.3\)}], 
              Text[DisplayForm[
                  StyleForm[
                    GridBox[{{"\<parametric curve\>"}, {"\<on surface\>"}}], 
                    FontFamily \[Rule] 
                      Times]], {\(-1\), \(-1.5\), \(-1.6\)}]}, \
\[IndentingNewLine]ImageSize \[Rule] 600, Boxed \[Rule] False, 
            ViewPoint -> {1, \ \(-3\), \ 2}]]];\)\)], "Input"],

Cell[BoxData[
    \(\(\(PlotCurveOnSurface3D\)\([\)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " (for contour curves)"
}], "Subsubtitle",
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
  StyleBox["PlotCurveOnSurface3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " can also draw the contour lines of a scalar function over a 3D surface. \
In the following example the surface is the saddle ",
  Cell[BoxData[
      \(TraditionalForm\`z = x\^2 - y\^2\)]],
  " and the scalar function is ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 + y\^2\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          StyleBox[\({x^2 - y^2, {x, \(-1\), 1}, {y, \(-1\), 1}}\),
            FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
          StyleBox[\({x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "It works internally by \"lifting\" the contours made by ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"],
  " and adapting them to the triangulation of the surface. The syntax is:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["PlotCurveOnSurface3D",
        "Input"], 
      StyleBox["[",
        "Input"], 
      StyleBox["\[IndentingNewLine]",
        "Input"], 
      RowBox[{
        StyleBox[\({content\ of\ what\ you\ would\ write\ into\ Plot3D\ or\ \
ParametricPlot3D\ to\ get\ the\ surface\ only}\),
          "Input",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[",",
          "Input",
          FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
          StyleBox["{",
            "Input",
            FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
            StyleBox["content",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["of",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["what",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["you",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["would",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["write",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["into",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["ContourPlot",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["to",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["describe",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["the",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["contours",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["in",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["the",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["2",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["dimensional",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["parameter",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["space",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["of",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["the",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["surface",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]]}], 
          StyleBox["}",
            "Input",
            FontColor->RGBColor[1, 0, 0]]}], 
        StyleBox[",",
          "Input"], 
        StyleBox["\[IndentingNewLine]",
          "Input"], 
        StyleBox[\(optional\ Graphics3D\ options\),
          "Input"]}], 
      StyleBox["]",
        "Input"]}]], "Input",
  Evaluatable->False],

Cell[TextData[{
  "The contour lines can be oriented, if ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " is installed:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", "\[IndentingNewLine]", 
        RowBox[{
          StyleBox[\({x^2 - y^2, {x, \(-1\), 1}, {y, \(-1\), 1}}\),
            FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
          
          StyleBox[\({x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
              Contours \[Rule] 3, Oriented \[Rule] True}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", "\[IndentingNewLine]", 
        RowBox[{
          
          StyleBox[\({{Cos[u], v, Sin[u]}, {u, 0, 2  \[Pi]}, {v, \(-1\), 1}, 
              PlotPoints -> {50, 2}}\),
            FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
          
          StyleBox[\({Sin[u] + v^2, {u, 0, 2  \[Pi]}, {v, \(-1\), 1}, 
              Oriented \[Rule] True, PlotPoints \[Rule] {31, 31}}\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox["\[IndentingNewLine]",
            FontColor->RGBColor[1, 0, 
            0]], \(ViewPoint \[Rule] {1, \ \(-2.5\), \ 1.5}\), 
          ",", \(Boxed \[Rule] False\), ",", \(Axes \[Rule] False\)}], "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "You can draw the contour lines of two or more scalar functions on the same \
surface, and make them of different colors with the option ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          StyleBox[\({x^2 - y^2, {x, \(-1\), 1}, {y, \(-1\), 1}}\),
            FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
          
          StyleBox[\({x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
              ContourStyle \[Rule] Red}\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          
          StyleBox[\({x*y, {x, \(-1\), 1}, {y, \(-1\), 1}, 
              ContourStyle \[Rule] Blue}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can give different ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  "s to the various contour lines of a single scalar function:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          StyleBox[\({x^2 - y^2, {x, \(-1\), 1}, {y, \(-1\), 1}}\),
            FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
          
          StyleBox[\({x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
              PlotPoints \[Rule] {15, 15}, 
              ContourStyle \[Rule] Table[{Hue[i/11]}, {i, 11}]}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "One more example: contour lines of ",
  Cell[BoxData[
      \(TraditionalForm\`x\ y\ z\)]],
  " over a half sphere:"
}], "Text"],

Cell[BoxData[{\(Needs["\<Geometry`Rotations`\>"];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Module", "[", 
        RowBox[{\({x, y, z}\), ",", "\[IndentingNewLine]", 
          
          RowBox[{\({x, y, z} = 
              Geometry`Rotations`Rotate3D[{1, 0, 0}, \[Phi], \[Theta], 0]\), 
            ";", "\[IndentingNewLine]", 
            RowBox[{"PlotCurveOnSurface3D", "[", 
              RowBox[{
                RowBox[{"{", 
                  
                  StyleBox[\({x, y, z}, {\[Phi], 0, 
                      Pi}, {\[Theta], \(-Pi\)/2, Pi/2}\),
                    FontColor->RGBColor[0, 0, 1]], 
                  StyleBox["}",
                    FontColor->RGBColor[0, 0, 1]]}], ",", 
                "\[IndentingNewLine]", 
                
                StyleBox[\({x*y*z, {\[Phi], 0, Pi}, {\[Theta], \(-Pi\)/2, 
                      Pi/2}, ContourStyle \[Rule] 
                      Table[{Hue[i/11]}, {i, 11}]}\),
                  FontColor->RGBColor[1, 0, 0]]}], "]"}]}]}], "]"}], 
      ";"}]}], "Input"],

Cell["The contour lines can be oriented:", "Text"],

Cell[BoxData[{\(Needs["\<Geometry`Rotations`\>"];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Module", "[", 
        RowBox[{\({x, y, z}\), ",", "\[IndentingNewLine]", 
          
          RowBox[{\({x, y, z} = 
              Geometry`Rotations`Rotate3D[{1, 0, 0}, \[Phi], \[Theta], 0]\), 
            ";", "\[IndentingNewLine]", 
            RowBox[{"PlotCurveOnSurface3D", "[", 
              RowBox[{
                RowBox[{"{", 
                  
                  StyleBox[\({x, y, z}, {\[Phi], 0, 
                      Pi}, {\[Theta], \(-Pi\)/2, Pi/2}\),
                    FontColor->RGBColor[0, 0, 1]], 
                  StyleBox["}",
                    FontColor->RGBColor[0, 0, 1]]}], ",", 
                "\[IndentingNewLine]", 
                
                StyleBox[\({x*y*z, {\[Phi], 0, Pi}, {\[Theta], \(-Pi\)/2, 
                      Pi/2}, ContourStyle \[Rule] 
                      Table[{Hue[i/11]}, {i, 11}], Oriented \[Rule] True}\),
                  FontColor->RGBColor[1, 0, 0]]}], "]"}]}]}], "]"}], 
      ";"}]}], "Input"],

Cell["\<\
You can have contour curves and parametric curves at the same time:\
\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          StyleBox[\({x^2 - y^2, {x, \(-1\), 1}, {y, \(-1\), 1}}\),
            FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
          
          StyleBox[\({x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
              ContourStyle \[Rule] Red}\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          
          StyleBox[\({{t, \(-t^2\)}, {t, \(-1\), 1}, PlotStyle \[Rule] Blue, 
              Oriented \[Rule] True}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The command ",
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " sorts out from the input syntax whether you are asking for a parametric \
curve or for contour lines."
}], "Text"],

Cell[TextData[{
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " can make plots very similar-looking to the ones you get from ",
  StyleBox["LevelPlot3D", "Input"],
  " and ",
  StyleBox["SliceSurfacePlot3D", "Input"],
  ", and it's up to you to choose which one to use for your purposes. \
Internally, they make totally different calculations. From the final user \
point of view, perhaps the main difference is that the contour lines made by \
",
  StyleBox["LevelPlot3D", "Input"],
  " and ",
  StyleBox["SliceSurfacePlot3D", "Input"],
  " are exactly planar, even for rough surface grids, while with ",
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " you may need to crank up ",
  ButtonBox["PlotPoints",
    ButtonStyle->"RefGuideLink"],
  " in both the surface and the curves to get rid of jaggies."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " (for text, lines, points)"
}], "Subsubtitle",
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
  "You can give an arbitrary 2D ",
  ButtonBox["Line",
    ButtonStyle->"RefGuideLink"],
  " in the parameter space of a surface: ",
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " will map the line onto the surface. The syntax is"
}], "Text"],

Cell[TextData[{
  StyleBox["PlotCurveOnSurface3D[surface,Graphics[{", "Input"],
  StyleBox["2D graphics primitives", "Input",
    FontSlant->"Italic"],
  StyleBox["}],options]", "Input"]
}], "Text",
  TextAlignment->-0.5],

Cell[TextData[{
  "Here is a very quick and simple example with a parametric surface with \
just one polygon and a ",
  ButtonBox["Line",
    ButtonStyle->"RefGuideLink"],
  " with two segments:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({{x, y, x + y}, {x, \(-2\), 2}, {y, \(-2\), 2}, 
            PlotPoints \[Rule] {2, 2}}\), ",", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              StyleBox[\(Line[{{0, 0}, {1, 1}, {1, \(-1\)}}]\),
                FontColor->RGBColor[1, 0, 0]], "}"}], "]"}]}], "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "The same graph, but here the surface is written in cartesian form and the \
",
  ButtonBox["Line",
    ButtonStyle->"RefGuideLink"],
  " is red:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({x + y, {x, \(-2\), 2}, {y, \(-2\), 2}, 
            PlotPoints \[Rule] {2, 2}}\), ",", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["Red",
                  FontColor->RGBColor[1, 0, 0]], 
                ",", \(Line[{{0, 0}, {1, 1}, {1, \(-1\)}}]\)}], "}"}], 
            "]"}]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  ButtonBox["Dashing",
    ButtonStyle->"RefGuideLink"],
  " works:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({x + y, {x, \(-2\), 2}, {y, \(-2\), 2}, 
            PlotPoints \[Rule] {2, 2}}\), ",", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              RowBox[{
                StyleBox[\(Dashing[{ .1,  .1}]\),
                  FontColor->RGBColor[1, 0, 0]], 
                ",", \(Line[{{0, 0}, {1, 1}, {1, \(-1\)}}]\)}], "}"}], 
            "]"}]}], "]"}], ";"}]], "Input"],

Cell["\<\
but it behaves differently in 3D than in 2D. In 3D it seems to be \
applied to each segment separately. If the segments are too short it just \
won't show:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({x + y, {x, \(-2\), 2}, {y, \(-2\), 2}, 
            PlotPoints \[Rule] {2, 2}}\), ",", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              RowBox[{\(Dashing[{ .1,  .1}]\), ",", 
                RowBox[{"Line", "[", 
                  RowBox[{"Table", "[", 
                    RowBox[{\({x, x}\), ",", 
                      RowBox[{"{", 
                        RowBox[{"x", ",", "0", ",", "1", ",", 
                          StyleBox["1",
                            FontColor->RGBColor[1, 0, 0]]}], "}"}]}], "]"}], 
                  "]"}]}], "}"}], "]"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({x + y, {x, \(-2\), 2}, {y, \(-2\), 2}, 
            PlotPoints \[Rule] {2, 2}}\), ",", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              RowBox[{\(Dashing[{ .1,  .1}]\), ",", 
                RowBox[{"Line", "[", 
                  RowBox[{"Table", "[", 
                    RowBox[{\({x, x}\), ",", 
                      RowBox[{"{", 
                        RowBox[{"x", ",", "0", ",", "1", ",", 
                          StyleBox[\(1/5\),
                            FontColor->RGBColor[1, 0, 0]]}], "}"}]}], "]"}], 
                  "]"}]}], "}"}], "]"}]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can give 2D ",
  ButtonBox["Point",
    ButtonStyle->"RefGuideLink"],
  "s to be mapped onto the surface:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({x + y, {x, \(-2\), 2}, {y, \(-2\), 2}, 
            PlotPoints \[Rule] {2, 2}}\), ",", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              RowBox[{\(PointSize[ .05]\), ",", 
                StyleBox[\(Point[{0, 0}]\),
                  FontColor->RGBColor[1, 0, 0]], ",", "Red", 
                ",", \(Line[{{0, 0}, {1, 1}, {1, \(-1\)}}]\)}], "}"}], 
            "]"}]}], "]"}], ";"}]], "Input"],

Cell["\<\
A thick straight line and a green point mapped onto a \
cylinder:\
\>", "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{{Cos[\[Theta]], Sin[\[Theta]], z}, {\[Theta], 
            0, 2  \[Pi]}, {z, \(-1\)/2, 1/2}, 
          PlotPoints \[Rule] {33, 2}}, \[IndentingNewLine]Graphics[{{Green, 
              PointSize[ .03], Point[{\[Pi]/2, 0}]}, Thickness[ .01], 
            Line[{{0, \(-1\)/2}, {2  \[Pi], 1/2}}]}]];\)\)], "Input"],

Cell["\<\
A point and a red two-segment line mapped onto a cartesian surface:\
\
\>", "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{\(Sin[2  x] + Sin[y]\)\/2, {x, \(-2\), 
            2}, {y, \(-2\), 
            2}}, \[IndentingNewLine]Graphics[{PointSize[ .05], Point[{0, 0}], 
            Red, Line[{{0, 0}, {1, 1}, {\(-2\), 0}}]}]];\)\)], "Input"],

Cell[TextData[{
  "Also an ",
  ButtonBox["Arrow",
    ButtonStyle->"AddOnsLink"],
  " can be draped onto a surface:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({\(Sin[2  x] + Sin[y]\)\/2, {x, \(-2\), 2}, {y, \(-2\), 
              2}}\), ",", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              RowBox[{"Black", ",", 
                RowBox[{
                  StyleBox["Arrow",
                    FontColor->RGBColor[1, 0, 0]], 
                  "[", \({\(-2\), \(-2\)}, {1, 0}\), "]"}]}], "}"}], "]"}]}], 
        "]"}], ";"}]], "Input"],

Cell["You can control the color and size of the arrow:", "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{\(Sin[2  x] + Sin[y]\)\/2, {x, \(-2\), 
            2}, {y, \(-2\), 2}}, 
        Graphics[{Red, Arrow[{\(-2\), \(-2\)}, {1, 0}]}], 
        HeadScaling3D \[Rule] 6];\)\)], "Input"],

Cell[TextData[{
  "In addition to ",
  ButtonBox["Line",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["Point",
    ButtonStyle->"RefGuideLink"],
  ", also 2D ",
  ButtonBox["Text",
    ButtonStyle->"RefGuideLink"],
  " can be mapped onto a surface, if you have ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " installed. Here is a very simple example with \"abc\" written onto the \
middle of a surface reduced to just one polygon:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({x + y, {x, \(-2\), 2}, {y, \(-2\), 2}, 
            PlotPoints \[Rule] {2, 2}}\), ",", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              StyleBox[\(Text["\<abc\>", {0, 0}]\),
                FontColor->RGBColor[1, 0, 0]], "}"}], "]"}]}], "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "Internally, ",
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " treatment of text is built on top of ",
  ButtonBox["Text3D",
    ButtonStyle->"AddOnsLink"],
  " from ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  ".\n",
  ButtonBox["Text3D",
    ButtonStyle->"AddOnsLink"],
  " is called to translate ",
  ButtonBox["Text",
    ButtonStyle->"RefGuideLink"],
  " into ",
  ButtonBox["Line",
    ButtonStyle->"RefGuideLink"],
  "s, which are then mapped to the surface. The syntax for ",
  ButtonBox["Text",
    ButtonStyle->"RefGuideLink"],
  " in ",
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " is a hybrid of mostly 2D ",
  ButtonBox["Text",
    ButtonStyle->"RefGuideLink"],
  " syntax with some ",
  ButtonBox["Text3D",
    ButtonStyle->"AddOnsLink"],
  " features thrown in."
}], "Text"],

Cell["\<\
Here is the text \"abc\" centered at the parameter point {0,1} \
(hightlighted in red) instead of {0,0}:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({x + y, {x, \(-2\), 2}, {y, \(-2\), 2}, 
            PlotPoints \[Rule] {2, 2}}\), ",", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Text", "[", 
                  RowBox[{"\"\<abc\>\"", ",", 
                    StyleBox[\({0, 1}\),
                      FontColor->RGBColor[1, 0, 0]]}], "]"}], ",", "Red", 
                ",", \(PointSize[ .02]\), ",", " ", \(Point[{0, 1}]\)}], 
              "}"}], "]"}], ",", \(PlotRange \[Rule] All\)}], "]"}], 
      ";"}]], "Input"],

Cell["\<\
Here is the text \"abc\" centered at the parameter point {1,1} \
(hightlighted in red):\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({x + y, {x, \(-2\), 2}, {y, \(-2\), 2}, 
            PlotPoints \[Rule] {2, 2}}\), ",", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Text", "[", 
                  RowBox[{"\"\<abc\>\"", ",", 
                    StyleBox[\({1, 1}\),
                      FontColor->RGBColor[1, 0, 0]]}], "]"}], ",", "Red", 
                ",", \(PointSize[ .02]\), ",", " ", \(Point[{1, 1}]\)}], 
              "}"}], "]"}], ",", \(PlotRange \[Rule] All\)}], "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "The ",
  ButtonBox["Text",
    ButtonStyle->"RefGuideLink"],
  " will be made of ordinary ",
  ButtonBox["Line",
    ButtonStyle->"RefGuideLink"],
  " primitives, that you can modify with color and ",
  ButtonBox["Thickness",
    ButtonStyle->"RefGuideLink"],
  " directives:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({x + y, {x, \(-2\), 2}, {y, \(-2\), 2}, 
            PlotPoints \[Rule] {2, 2}}\), ",", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["Red",
                  FontColor->RGBColor[1, 0, 0]], ",", 
                StyleBox[\(Thickness[ .02]\),
                  FontColor->RGBColor[1, 0, 0]], 
                ",", \(Text["\<abc\>", {0, 0}]\)}], "}"}], "]"}]}], "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "The default 3D font is ",
  StyleBox["FuturaFont3D", "Input"],
  ", a sans-serif font. You can switch the font to the serif ",
  StyleBox["TimesFont3D", "Input"],
  " with the ",
  StyleBox["Font3D", "Input"],
  " option, borrowed from ",
  ButtonBox["Text3D",
    ButtonStyle->"AddOnsLink"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{x + y, {x, \(-2\), 2}, {y, \(-2\), 2}, 
          PlotPoints \[Rule] {2, 
              2}}, \[IndentingNewLine]Graphics[{Text["\<abc\>", {0, 0}, 
              Font3D \[Rule] TimesFont3D]}]];\)\)], "Input"],

Cell[TextData[{
  "For the character set available in the 3D fonts see the documentation in \
",
  ButtonBox["Text3D",
    ButtonStyle->"AddOnsLink"],
  ". Here is a Greek letter example:"
}], "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{x + y, {x, \(-2\), 2}, {y, \(-2\), 2}, 
          PlotPoints \[Rule] {2, 
              2}}, \[IndentingNewLine]Graphics[{Text["\<\[Alpha]\[Beta]\
\[Gamma]\>", {0, 0}]}]];\)\)], "Input"],

Cell[TextData[{
  "Before being mapped onto the surface, the text can be scaled in the \
parameter space, with scale factors in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " directions independently. The syntax for the scaling factor is ",
  StyleBox["Text[string, {xposition,yposition},{", "Input"],
  StyleBox["xscale", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[",", "Input"],
  StyleBox["yscale", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["},options]", "Input"],
  " (yes, this is a departure from the ordinary 2D ",
  ButtonBox["Text",
    ButtonStyle->"RefGuideLink"],
  " syntax). In the followint example the text is shrinked to a half in the \
",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " direction:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({x + y, {x, \(-2\), 2}, {y, \(-2\), 2}, 
            PlotPoints \[Rule] {2, 2}}\), ",", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              RowBox[{"Text", "[", 
                RowBox[{"\"\<abc\>\"", ",", \({0, 0}\), ",", 
                  StyleBox[\({1/2, 2}\),
                    FontColor->RGBColor[1, 0, 0]]}], "]"}], "}"}], "]"}], 
          ",", \(PlotRange \[Rule] All\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Here the text is shrinked in the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " direction:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({x + y, {x, \(-2\), 2}, {y, \(-2\), 2}, 
            PlotPoints \[Rule] {2, 2}}\), ",", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              RowBox[{"Text", "[", 
                RowBox[{"\"\<abc\>\"", ",", \({0, 0}\), ",", 
                  StyleBox[\({1, 1/2}\),
                    FontColor->RGBColor[1, 0, 0]]}], "]"}], "}"}], "]"}], 
          ",", \(PlotRange \[Rule] All\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can rotate the ",
  ButtonBox["Text",
    ButtonStyle->"RefGuideLink"],
  " in the parameter space before mapping it to the surface. The syntax for \
the rotation is the same as that for 2D ",
  ButtonBox["Text",
    ButtonStyle->"RefGuideLink"],
  ": ",
  StyleBox["Text[string,{xposition,yposition},{xscale,yscale},{", "Input"],
  StyleBox["directionVectorX", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[",", "Input"],
  StyleBox["directionVectorY", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["},options]", "Input"],
  ". Here is an example with direction vector {1,-1}:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{\({x + y, {x, \(-2\), 2}, {y, \(-2\), 2}, 
            PlotPoints \[Rule] {2, 2}}\), ",", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              RowBox[{"Text", "[", 
                RowBox[{
                "\"\<abc\>\"", ",", \({0, 0}\), ",", \({1, 1}\), ",", 
                  StyleBox[\({1, \(-1\)}\),
                    FontColor->RGBColor[1, 0, 0]]}], "]"}], "}"}], "]"}], 
          ",", \(PlotRange \[Rule] All\)}], "]"}], ";"}]], "Input"],

Cell["\<\
Text rotated along the direction vector {1,1} and then mapped onto \
a curved surface:\
\>", "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{{2  x, 
            2  y, \(-Sin[2  x]\) + Sin[y]}, {x, \(-2\), 2}, {y, \(-2\), 
            2}}, \[IndentingNewLine]Graphics[{Text["\<abc\>", {0, 0}, {1, 
                1}, {1, 1}]}]];\)\)], "Input"],

Cell[TextData[{
  "By default the ",
  ButtonBox["Text",
    ButtonStyle->"RefGuideLink"],
  " centered around the {x,y} position in the parameter space. With the \
option ",
  StyleBox["Align3D", "Input"],
  " (borrowed from Tex3D) you can choose to align ",
  StyleBox["Left", "Input"],
  " or ",
  StyleBox["Right", "Input"],
  ": Here is an elaborate example showing a left-aligned red text, a centered \
green text, and a right-alined blue text, with alignment points and line \
hightlighted:"
}], "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{\(Sin[2  x] + Sin[y]\)\/2, {x, \(-4\), 
            4}, {y, \(-2\), 
            2}}, \[IndentingNewLine]Graphics[{Line[{{0, \(-2\)}, {0, 2}}], 
            PointSize[ .02], \[IndentingNewLine]{Red, Point[{0, 1}], 
              Text["\<left\>", {0, 1}, Align3D \[Rule] Left]}, {Green, 
              Thickness[ .01], Point[{0, 0}], 
              Text["\<center\>", {0, 0}, 
                Align3D \[Rule] Center]}, \[IndentingNewLine]{Blue, 
              Point[{0, \(-1\)}], 
              Text["\<right\>", {0, \(-1\)}, 
                Align3D \[Rule] Right]}}]];\)\)], "Input"],

Cell["Text wrapped around a cylinder:", "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{{Cos[\[Theta]], Sin[\[Theta]], 
            z}, {\[Theta], \(-\[Pi]\)/2, 3  \[Pi]/2}, {z, \(-1\)/2, 1/2}, 
          PlotPoints \[Rule] {33, 
              2}}, \[IndentingNewLine]Graphics[{Text["\<around and around and \
\>", {\(-\[Pi]\)/2, 0}, {2  \[Pi]/22, 2  \[Pi]/22}, 
              Align3D \[Rule] Left]}]];\)\)], "Input"],

Cell[TextData[{
  "You can show the text without the surface with the option ",
  StyleBox["ShowSurface\[Rule]False", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{{Cos[\[Theta]], Sin[\[Theta]], 
            z}, {\[Theta], \(-\[Pi]\)/2, 3  \[Pi]/2}, {z, \(-1\)/2, 1/2}, 
          PlotPoints \[Rule] {33, 
              2}}, \[IndentingNewLine]Graphics[{Text["\<around and around and \
\>", {\(-\[Pi]\)/2, 0}, {2  \[Pi]/22, 2  \[Pi]/22}, Align3D \[Rule] Left]}], 
        ShowSurface \[Rule] False];\)\)], "Input"],

Cell[TextData[{
  "If you compare with the examples from ",
  ButtonBox["Using Text3D",
    ButtonStyle->"AddOnsLink"],
  ", you will notice that PlotCurveOnSurface3D etches the text (and lines) \
into the surface, so that it will be visible from any direction. The \
techniques described in ",
  ButtonBox["Using Text3D",
    ButtonStyle->"AddOnsLink"],
  " will draw text hovering a short distance on one side of the surface: it \
won't show from the other side."
}], "Text"],

Cell[TextData[{
  "On a parametric surface you can mix parametric lines, contour lines, ",
  ButtonBox["Point",
    ButtonStyle->"RefGuideLink"],
  "s,  ",
  ButtonBox["Line",
    ButtonStyle->"RefGuideLink"],
  "s and ",
  ButtonBox["Text",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(With[{x = Cos[t] Sin[u], y = Sin[t] Sin[u], 
          z = Cos[\[Pi] - u]}, \[IndentingNewLine]PlotCurveOnSurface3D[{{x, 
              y, z}, {t, \(-\[Pi]\)/2, 3  \[Pi]/2}, {u, 
              0, \[Pi]}}, \[IndentingNewLine]{{t, \[Pi]/2 + 
                Sin[4  t]/2}, {t, \(-\[Pi]\)/2, 3  \[Pi]/2}, 
            PlotPoints \[Rule] 40, 
            PlotStyle \[Rule] {Red, 
                Thickness[ .01]}}, \[IndentingNewLine]{x - 
              y\^2, {t, \(-\[Pi]\)/2, 3  \[Pi]/2}, {u, 0, \[Pi]}, 
            Contours \[Rule] 5, 
            ContourStyle \[Rule] 
              Table[{Hue[i/6]}, {i, 
                  5}]}, \[IndentingNewLine]Graphics[{{White, 
                Line[{{\(-\[Pi]\)/2, \[Pi]/2}, {3  \[Pi]/2, \[Pi]/
                        2}}]}, {PointSize[ .02], Point[{0, 0}], 
                Point[{0, \[Pi]}]}, Thickness[ .01], 
              Text["\<sphere\>", {\(-\[Pi]\)/2, \[Pi]/2}, {1/3, 1/3}, 
                Align3D \[Rule] 
                  Left]}], \[IndentingNewLine]ViewPoint \[Rule] {2.663, \ \
\(-1.879\), \ 0.910}, Boxed \[Rule] False, Axes \[Rule] False]];\)\)], "Input"],

Cell["\<\
You can drape the force lines of a 2D vector field onto a surface. \
Here are the force lines of a dipole field drawn onto the potential surface, \
which are the same as the lines of steepest ascent on the surface:\
\>", \
"Text"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(dist1 = \@\(x\^2 + y\^2\);\)\), "\[IndentingNewLine]", 
    \(\(dist2 = \@\(x\^2 + \((y - 1)\)\^2\);\)\), "\[IndentingNewLine]", 
    \(\(potential = 1\/dist1 - 1\/dist2;\)\), "\[IndentingNewLine]", 
    \(\(field = \(-{D[potential, x], D[potential, y]}\)*\(dist1\^3\) 
            dist2\^3/\((1 + dist1\^3 + dist2\^3)\) // 
          Expand;\)\), "\[IndentingNewLine]", 
    \(\(forceLines2D = 
        With[{r = 1/4, d\[Theta] = \[Pi]/8}, 
          PhasePlot[field, {x, \(-3\), 3}, {y, \(-2\), 3}, {\(-10\), 10}, 
            InitialPoints \[Rule] 
              Table[{r\ Cos[\[Theta]], 
                    1 + r\ Sin[\[Theta]]}, {\[Theta], \[Pi]/2, 
                    5  \[Pi]/2 - d\[Theta], d\[Theta]}]~Join~
                Table[{r\ Cos[\[Theta]], 0 + r\ Sin[\[Theta]]}, {\[Theta], 
                    3  \[Pi]/2 - 2  d\[Theta], 3  \[Pi]/2 + 2  d\[Theta], 
                    d\[Theta]}], PlotStyle \[Rule] {Black}, 
            AspectRatio \[Rule] Automatic]];\)\), "\[IndentingNewLine]", 
    \(\(PlotCurveOnSurface3D[{\(-potential\), {x, \(-3\), 3}, {y, \(-2\), 
            3}}, \[IndentingNewLine]Evaluate[forceLines2D], 
        HeadScaling3D \[Rule] 3, 
        PlotRange \[Rule] {\(-2\), 2}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(With[{r = 1/4, d\[Theta] = \[Pi]/8}, 
      PhasePlot[field, {x, \(-3\), 3}, {y, \(-2\), 3}, {\(-10\), 10}, 
        InitialPoints \[Rule] 
          Table[{r\ Cos[\[Theta]], 1 + r\ Sin[\[Theta]]}, {\[Theta], \[Pi]/2, 
                5  \[Pi]/2 - d\[Theta], d\[Theta]}]~Join~
            Table[{r\ Cos[\[Theta]], 0 + r\ Sin[\[Theta]]}, {\[Theta], 
                3  \[Pi]/2 - 2  d\[Theta], 3  \[Pi]/2 + 2  d\[Theta], 
                d\[Theta]}], PlotStyle \[Rule] {Black}, 
        AspectRatio \[Rule] Automatic, HeadLength \[Rule]  .02]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0.333333 0.166667 [
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .16667 -12 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .33333 -6 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66667 -6 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .83333 -6 -4.5 ]
[-0.0125 .83333 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .83333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16667 m
.00625 .16667 L
s
[(-1)] -0.0125 .16667 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(0)] -0.0125 .33333 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(1)] -0.0125 .5 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(2)] -0.0125 .66667 1 0 Mshowa
0 .83333 m
.00625 .83333 L
s
[(3)] -0.0125 .83333 1 0 Mshowa
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .13333 m
.00375 .13333 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .3 m
.00375 .3 L
s
0 .36667 m
.00375 .36667 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .53333 m
.00375 .53333 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
0 .8 m
.00375 .8 L
s
.25 Mabswid
0 0 m
0 .83333 L
s
0 .82708 m
0 .83333 L
s
.16667 .82708 m
.16667 .83333 L
s
.33333 .82708 m
.33333 .83333 L
s
.5 .82708 m
.5 .83333 L
s
.66667 .82708 m
.66667 .83333 L
s
.83333 .82708 m
.83333 .83333 L
s
.125 Mabswid
.03333 .82958 m
.03333 .83333 L
s
.06667 .82958 m
.06667 .83333 L
s
.1 .82958 m
.1 .83333 L
s
.13333 .82958 m
.13333 .83333 L
s
.2 .82958 m
.2 .83333 L
s
.23333 .82958 m
.23333 .83333 L
s
.26667 .82958 m
.26667 .83333 L
s
.3 .82958 m
.3 .83333 L
s
.36667 .82958 m
.36667 .83333 L
s
.4 .82958 m
.4 .83333 L
s
.43333 .82958 m
.43333 .83333 L
s
.46667 .82958 m
.46667 .83333 L
s
.53333 .82958 m
.53333 .83333 L
s
.56667 .82958 m
.56667 .83333 L
s
.6 .82958 m
.6 .83333 L
s
.63333 .82958 m
.63333 .83333 L
s
.7 .82958 m
.7 .83333 L
s
.73333 .82958 m
.73333 .83333 L
s
.76667 .82958 m
.76667 .83333 L
s
.8 .82958 m
.8 .83333 L
s
.86667 .82958 m
.86667 .83333 L
s
.9 .82958 m
.9 .83333 L
s
.93333 .82958 m
.93333 .83333 L
s
.96667 .82958 m
.96667 .83333 L
s
.25 Mabswid
0 .83333 m
1 .83333 L
s
.99375 0 m
1 0 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .33333 m
1 .33333 L
s
.99375 .5 m
1 .5 L
s
.99375 .66667 m
1 .66667 L
s
.125 Mabswid
.99625 .03333 m
1 .03333 L
s
.99625 .06667 m
1 .06667 L
s
.99625 .1 m
1 .1 L
s
.99625 .13333 m
1 .13333 L
s
.99625 .2 m
1 .2 L
s
.99625 .23333 m
1 .23333 L
s
.99625 .26667 m
1 .26667 L
s
.99625 .3 m
1 .3 L
s
.99625 .36667 m
1 .36667 L
s
.99625 .4 m
1 .4 L
s
.99625 .43333 m
1 .43333 L
s
.99625 .46667 m
1 .46667 L
s
.99625 .53333 m
1 .53333 L
s
.99625 .56667 m
1 .56667 L
s
.99625 .6 m
1 .6 L
s
.99625 .63333 m
1 .63333 L
s
.99625 .7 m
1 .7 L
s
.99625 .73333 m
1 .73333 L
s
.99625 .76667 m
1 .76667 L
s
.99625 .8 m
1 .8 L
s
.25 Mabswid
1 0 m
1 .83333 L
s
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
.5 .83333 m
.5 .80515 L
.5 .70426 L
.5 .62139 L
.5 .57023 L
.5 .54192 L
.5 .52498 L
.5 .51562 L
.5 .5097 L
.5 .50622 L
.5 .50409 L
.5 .50264 L
.5 .50173 L
.5 .50111 L
.5 .50073 L
.5 .50049 L
.5 .50032 L
.5 .50021 L
s
.5 .67177 m
.5 .66177 L
s
% Start of user PostScript
0. 2.030628 0. 1.9706469 MAarrowhead1
% End of user PostScript
.29492 .83333 m
.35681 .75818 L
.4111 .67869 L
.45073 .60904 L
.47265 .56418 L
.48396 .53872 L
.4905 .52325 L
.49406 .5146 L
.49631 .50909 L
.49763 .50584 L
.49844 .50384 L
.499 .50248 L
.49934 .50163 L
.49958 .50105 L
.49972 .50069 L
.49981 .50046 L
.49988 .5003 L
.49992 .5002 L
s
.40997 .68034 m
.41506 .67174 L
s
% Start of user PostScript
-0.54016501 2.0820341 -0.50966963 2.030421 MAarrowhead1
% End of user PostScript
0 .5848 m
.02192 .60104 L
.05561 .6194 L
.07626 .62794 L
.09635 .6346 L
.11836 .6402 L
.12943 .6424 L
.13978 .6441 L
.1491 .64535 L
.15944 .64643 L
.16449 .64684 L
.16993 .6472 L
.17294 .64736 L
.17569 .64749 L
.17829 .64758 L
.1811 .64767 L
.18402 .64773 L
.18676 .64777 L
.18944 .64779 L
.1919 .64779 L
.19458 .64776 L
.19751 .64772 L
.19899 .64768 L
.20058 .64764 L
.20344 .64755 L
.20902 .6473 L
.21431 .64699 L
.22421 .64619 L
.23591 .64491 L
.24668 .64339 L
.27075 .63885 L
.29177 .63357 L
.31086 .62767 L
.35129 .61157 L
.38552 .59377 L
.4113 .57754 L
.44931 .54853 L
.46971 .53025 L
.48182 .51851 L
.48857 .51173 L
.49287 .50734 L
.49542 .50472 L
.49699 .50311 L
.49806 .502 L
.49873 .50132 L
.49915 .50088 L
.49944 .50057 L
.49963 .50038 L
.49976 .50025 L
.49984 .50016 L
Mistroke
Mfstroke
.25924 .64102 m
.26906 .63917 L
s
% Start of user PostScript
-1.4445815 1.846139 -1.3856393 1.8350237 MAarrowhead1
% End of user PostScript
.47438 .32235 m
.45952 .31667 L
.44821 .31284 L
.43181 .30815 L
.42276 .30603 L
.4118 .30394 L
.40598 .30304 L
.40018 .3023 L
.39472 .30175 L
.38854 .30128 L
.38538 .30111 L
.38357 .30104 L
.38191 .30099 L
.38035 .30095 L
.37863 .30092 L
.37699 .30091 L
.37546 .3009 L
.37452 .30091 L
.3735 .30092 L
.37164 .30095 L
.36981 .301 L
.36811 .30106 L
.36422 .30126 L
.36005 .30156 L
.35621 .30192 L
.35205 .3024 L
.34446 .30352 L
.33532 .30533 L
.32695 .30744 L
.31126 .31273 L
.29718 .31917 L
.2826 .32795 L
.26855 .33915 L
.2578 .35041 L
.24813 .36385 L
.24443 .37041 L
.24106 .37755 L
.23846 .38428 L
.23645 .39075 L
.23552 .39446 L
.23467 .39851 L
.23409 .40189 L
.2336 .40563 L
.23338 .40773 L
.23322 .4097 L
.23309 .41178 L
.23304 .41294 L
.23301 .41401 L
.23297 .41591 L
.23298 .41798 L
Mistroke
.23303 .41994 L
.2331 .42175 L
.23322 .42358 L
.23338 .42555 L
.23377 .42911 L
.23427 .43257 L
.23485 .43573 L
.23653 .44287 L
.23889 .45027 L
.24512 .46424 L
.24952 .4717 L
.25406 .47821 L
.26363 .48939 L
.27533 .49999 L
.28908 .50959 L
.30277 .51693 L
.31819 .52316 L
.32712 .52594 L
.33553 .52805 L
.34364 .52967 L
.3511 .53081 L
.35876 .53166 L
.36274 .53198 L
.36493 .53211 L
.36693 .53222 L
.36863 .53229 L
.37048 .53235 L
.37233 .53239 L
.37333 .53241 L
.37426 .53242 L
.37597 .53243 L
.37752 .53242 L
.37929 .5324 L
.38095 .53237 L
.38243 .53233 L
.38398 .53228 L
.38674 .53215 L
.38966 .53198 L
.39282 .53175 L
.39903 .53116 L
.40526 .53039 L
.41557 .52873 L
.43503 .52435 L
.45942 .5167 L
.47488 .51078 L
.48388 .50703 L
.48981 .50448 L
.4934 .50291 L
.49563 .50193 L
.49717 .50125 L
Mistroke
.49814 .50082 L
.49875 .50055 L
.49918 .50036 L
.49946 .50024 L
.49965 .50016 L
.49977 .5001 L
.49978 .5001 L
Mfstroke
.23337 .42547 m
.23478 .43536 L
s
% Start of user PostScript
-1.5997887 0.55279634 -1.5913357 0.61215417 MAarrowhead1
% End of user PostScript
.49141 .33309 m
.48953 .33304 L
.48709 .33299 L
.48402 .33293 L
.48197 .3329 L
.48097 .33289 L
.47982 .33288 L
.47924 .33287 L
.47861 .33287 L
.47806 .33286 L
.47773 .33286 L
.47743 .33286 L
.47712 .33286 L
.47683 .33286 L
.47651 .33286 L
.47633 .33286 L
.47617 .33286 L
.47585 .33286 L
.47557 .33286 L
.47523 .33286 L
.47491 .33286 L
.47462 .33286 L
.4743 .33286 L
.47364 .33287 L
.47301 .33287 L
.47241 .33288 L
.471 .33289 L
.46941 .33292 L
.46762 .33296 L
.46588 .33301 L
.4639 .33307 L
.46158 .33317 L
.45734 .33339 L
.45232 .33376 L
.44687 .33428 L
.44135 .33497 L
.43469 .33602 L
.42697 .33758 L
.41948 .3395 L
.41091 .34223 L
.39441 .34952 L
.38503 .35522 L
.37522 .3629 L
.36677 .37164 L
.36009 .38091 L
.35736 .38577 L
.35485 .39122 L
.35291 .39656 L
.35153 .40157 L
.35088 .40466 L
Mistroke
.35041 .40755 L
.3502 .40919 L
.35004 .41074 L
.34996 .4116 L
.3499 .41253 L
.34985 .41337 L
.34982 .41415 L
.34978 .41561 L
.34977 .41639 L
.34977 .41722 L
.34978 .41809 L
.34981 .41891 L
.34988 .42045 L
.34998 .42188 L
.3501 .42321 L
.35046 .4262 L
.35095 .42907 L
.35151 .43168 L
.35313 .43746 L
.35497 .44241 L
.3573 .44745 L
.36344 .45742 L
.37162 .46701 L
.38044 .47477 L
.38889 .48062 L
.3989 .4861 L
.40792 .49 L
.42395 .49503 L
.43152 .49672 L
.43882 .498 L
.44468 .4988 L
.45038 .4994 L
.45523 .4998 L
.45924 .50005 L
.46335 .50024 L
.46678 .50035 L
.46844 .50039 L
.47017 .50043 L
.47101 .50044 L
.47188 .50045 L
.47262 .50046 L
.47339 .50046 L
.47377 .50047 L
.47412 .50047 L
.47446 .50047 L
.47476 .50047 L
.47505 .50047 L
.47535 .50047 L
.47565 .50047 L
.47597 .50047 L
Mistroke
.47615 .50047 L
.47632 .50047 L
.47663 .50047 L
.4768 .50047 L
.47696 .50047 L
.47732 .50047 L
.47762 .50047 L
.4779 .50047 L
.47851 .50047 L
.47967 .50046 L
.48085 .50045 L
.48282 .50042 L
.48609 .50037 L
.48887 .50031 L
.49254 .50022 L
.49513 .50014 L
.49677 .5001 L
.49791 .50006 L
.49862 .50004 L
.49908 .50003 L
.4994 .50002 L
.4996 .50001 L
.49973 .50001 L
Mfstroke
.34978 .41583 m
.35042 .42579 L
s
% Start of user PostScript
-0.90134981 0.49496314 -0.89750986 0.5547616 MAarrowhead1
% End of user PostScript
.49424 .3355 m
.49144 .33656 L
.48688 .33831 L
.48053 .34082 L
.47181 .34448 L
.45887 .35062 L
.4425 .36049 L
.43244 .36854 L
.42783 .37307 L
.42312 .37851 L
.41912 .38408 L
.41527 .39086 L
.41382 .39402 L
.41244 .39754 L
.41142 .4007 L
.41052 .40416 L
.41008 .40625 L
.40976 .40817 L
.40949 .4101 L
.40931 .41194 L
.40923 .41299 L
.40919 .41356 L
.40917 .4141 L
.40913 .41504 L
.40912 .41554 L
.40911 .41608 L
.40911 .41666 L
.40911 .41729 L
.40912 .41788 L
.40914 .41843 L
.40915 .41892 L
.40918 .41947 L
.40924 .42057 L
.40932 .42156 L
.40942 .42259 L
.40965 .42444 L
.40996 .42642 L
.41039 .42857 L
.41134 .43236 L
.41245 .4358 L
.41561 .44316 L
.41931 .44954 L
.42745 .45987 L
.43694 .46865 L
.4455 .4749 L
.4614 .484 L
.47297 .48936 L
.48177 .49301 L
.48764 .49531 L
.49187 .49694 L
Mistroke
.4946 .49797 L
.49636 .49863 L
.49762 .4991 L
.49842 .49941 L
.49898 .49962 L
.49933 .49975 L
.49955 .49983 L
.4997 .49989 L
Mfstroke
.40915 .41458 m
.40967 .42455 L
s
% Start of user PostScript
-0.54510997 0.48747454 -0.54199399 0.54729351 MAarrowhead1
% End of user PostScript
.49577 .33731 m
.49377 .3392 L
.49058 .34223 L
.48629 .34636 L
.48069 .35191 L
.47295 .36007 L
.46404 .37079 L
.4593 .37757 L
.45442 .38602 L
.45238 .39037 L
.45047 .39523 L
.44909 .39957 L
.4479 .40452 L
.44744 .40713 L
.4471 .40964 L
.44698 .41074 L
.44688 .41191 L
.44683 .41259 L
.44679 .4132 L
.44677 .41377 L
.44674 .4144 L
.44672 .41508 L
.44671 .41544 L
.4467 .41579 L
.4467 .4164 L
.4467 .41707 L
.4467 .41744 L
.44671 .41784 L
.44672 .41822 L
.44673 .41857 L
.44675 .41924 L
.44678 .41995 L
.44687 .42122 L
.44697 .42242 L
.44728 .42513 L
.44766 .4275 L
.44817 .43007 L
.44949 .43512 L
.45102 .43963 L
.45267 .44364 L
.46142 .45892 L
.47111 .4712 L
.47913 .47984 L
.48517 .48588 L
.4899 .49045 L
.49312 .49352 L
.49529 .49557 L
.49687 .49706 L
.4979 .49803 L
.49863 .49871 L
Mistroke
.49909 .49915 L
.49939 .49943 L
.4996 .49963 L
.49973 .49975 L
Mfstroke
.44674 .41438 m
.44719 .42435 L
s
% Start of user PostScript
-0.31956178 0.48625907 -0.31684894 0.54610839 MAarrowhead1
% End of user PostScript
.49764 .33873 m
.49655 .34124 L
.49483 .34519 L
.4926 .3504 L
.48978 .35711 L
.4861 .36632 L
.48217 .37728 L
.48019 .38361 L
.47824 .39098 L
.47744 .39457 L
.4767 .39848 L
.47611 .40222 L
.47568 .40568 L
.47551 .4074 L
.47536 .40929 L
.47529 .41032 L
.47523 .41128 L
.47519 .41227 L
.47515 .41319 L
.47513 .41405 L
.47511 .41451 L
.47511 .41499 L
.4751 .41539 L
.47509 .41584 L
.47509 .41624 L
.47509 .41662 L
.47509 .41709 L
.4751 .41754 L
.4751 .41795 L
.47511 .41838 L
.47512 .41886 L
.47513 .41937 L
.47516 .42027 L
.47519 .42119 L
.47524 .42216 L
.47535 .42389 L
.4755 .42574 L
.47569 .42776 L
.47666 .43463 L
.47737 .43839 L
.4781 .44174 L
.47997 .44894 L
.48397 .46128 L
.48774 .47119 L
.49117 .47955 L
.49375 .48563 L
.49561 .48994 L
.49703 .4932 L
.49798 .49539 L
.49867 .49697 L
Mistroke
.49912 .49798 L
.49941 .49864 L
.49961 .49911 L
.49974 .49941 L
.49983 .49962 L
.49983 .49962 L
Mfstroke
.47512 .41441 m
.47539 .42439 L
s
% Start of user PostScript
-0.14929909 0.4864311 -0.14766779 0.54636508 MAarrowhead1
% End of user PostScript
.5 .33929 m
.5 .34204 L
.5 .34632 L
.5 .35191 L
.5 .359 L
.5 .3685 L
.5 .37943 L
.5 .39256 L
.5 .40613 L
.5 .41954 L
.5 .43369 L
.5 .44672 L
.5 .45821 L
.5 .46882 L
.5 .47719 L
.5 .48409 L
.5 .48898 L
.5 .49238 L
.5 .4949 L
.5 .49657 L
.5 .49776 L
.5 .49852 L
.5 .49901 L
.5 .49935 L
.5 .49956 L
s
.5 .41443 m
.5 .42442 L
s
% Start of user PostScript
0. 0.48656061 0. 0.5465417 MAarrowhead1
% End of user PostScript
.50236 .33873 m
.50345 .34124 L
.50517 .34519 L
.5074 .3504 L
.51022 .35711 L
.5139 .36632 L
.51783 .37728 L
.51981 .38361 L
.52176 .39098 L
.52256 .39457 L
.5233 .39848 L
.52389 .40222 L
.52432 .40568 L
.52449 .4074 L
.52464 .40929 L
.52471 .41032 L
.52477 .41128 L
.52481 .41227 L
.52485 .41319 L
.52487 .41405 L
.52489 .41451 L
.52489 .41499 L
.5249 .41539 L
.52491 .41584 L
.52491 .41624 L
.52491 .41662 L
.52491 .41709 L
.5249 .41754 L
.5249 .41795 L
.52489 .41838 L
.52488 .41886 L
.52487 .41937 L
.52484 .42027 L
.52481 .42119 L
.52476 .42216 L
.52465 .42389 L
.5245 .42574 L
.52431 .42776 L
.52334 .43463 L
.52263 .43839 L
.5219 .44174 L
.52003 .44894 L
.51603 .46128 L
.51226 .47119 L
.50883 .47955 L
.50625 .48563 L
.50439 .48994 L
.50297 .4932 L
.50202 .49539 L
.50133 .49697 L
Mistroke
.50088 .49798 L
.50059 .49864 L
.50039 .49911 L
.50026 .49941 L
.50017 .49962 L
.50017 .49962 L
Mfstroke
.52488 .41441 m
.52461 .42439 L
s
% Start of user PostScript
0.14929909 0.4864311 0.14766779 0.54636508 MAarrowhead1
% End of user PostScript
.50423 .33731 m
.50623 .3392 L
.50942 .34223 L
.51371 .34636 L
.51931 .35191 L
.52705 .36007 L
.53596 .37079 L
.5407 .37757 L
.54558 .38602 L
.54762 .39037 L
.54953 .39523 L
.55091 .39957 L
.5521 .40452 L
.55256 .40713 L
.5529 .40964 L
.55302 .41074 L
.55312 .41191 L
.55317 .41259 L
.55321 .4132 L
.55323 .41377 L
.55326 .4144 L
.55328 .41508 L
.55329 .41544 L
.5533 .41579 L
.5533 .4164 L
.5533 .41707 L
.5533 .41744 L
.55329 .41784 L
.55328 .41822 L
.55327 .41857 L
.55325 .41924 L
.55322 .41995 L
.55313 .42122 L
.55303 .42242 L
.55272 .42513 L
.55234 .4275 L
.55183 .43007 L
.55051 .43512 L
.54898 .43963 L
.54733 .44364 L
.53858 .45892 L
.52889 .4712 L
.52087 .47984 L
.51483 .48588 L
.5101 .49045 L
.50688 .49352 L
.50471 .49557 L
.50313 .49706 L
.5021 .49803 L
.50137 .49871 L
Mistroke
.50091 .49915 L
.50061 .49943 L
.5004 .49963 L
.50027 .49975 L
Mfstroke
.55326 .41438 m
.55281 .42435 L
s
% Start of user PostScript
0.31956178 0.48625907 0.31684894 0.54610839 MAarrowhead1
% End of user PostScript
.50576 .3355 m
.50856 .33656 L
.51312 .33831 L
.51947 .34082 L
.52819 .34448 L
.54113 .35062 L
.5575 .36049 L
.56756 .36854 L
.57217 .37307 L
.57688 .37851 L
.58088 .38408 L
.58473 .39086 L
.58618 .39402 L
.58756 .39754 L
.58858 .4007 L
.58948 .40416 L
.58992 .40625 L
.59024 .40817 L
.59051 .4101 L
.59069 .41194 L
.59077 .41299 L
.59081 .41356 L
.59083 .4141 L
.59087 .41504 L
.59088 .41554 L
.59089 .41608 L
.59089 .41666 L
.59089 .41729 L
.59088 .41788 L
.59086 .41843 L
.59085 .41892 L
.59082 .41947 L
.59076 .42057 L
.59068 .42156 L
.59058 .42259 L
.59035 .42444 L
.59004 .42642 L
.58961 .42857 L
.58866 .43236 L
.58755 .4358 L
.58439 .44316 L
.58069 .44954 L
.57255 .45987 L
.56306 .46865 L
.5545 .4749 L
.5386 .484 L
.52703 .48936 L
.51823 .49301 L
.51236 .49531 L
.50813 .49694 L
Mistroke
.5054 .49797 L
.50364 .49863 L
.50238 .4991 L
.50158 .49941 L
.50102 .49962 L
.50067 .49975 L
.50045 .49983 L
.5003 .49989 L
Mfstroke
.59085 .41458 m
.59033 .42455 L
s
% Start of user PostScript
0.54510997 0.48747454 0.54199399 0.54729351 MAarrowhead1
% End of user PostScript
.50859 .33309 m
.51047 .33304 L
.51291 .33299 L
.51598 .33293 L
.51803 .3329 L
.51903 .33289 L
.52018 .33288 L
.52076 .33287 L
.52139 .33287 L
.52194 .33286 L
.52227 .33286 L
.52257 .33286 L
.52288 .33286 L
.52317 .33286 L
.52349 .33286 L
.52367 .33286 L
.52383 .33286 L
.52415 .33286 L
.52443 .33286 L
.52477 .33286 L
.52509 .33286 L
.52538 .33286 L
.5257 .33286 L
.52636 .33287 L
.52699 .33287 L
.52759 .33288 L
.529 .33289 L
.53059 .33292 L
.53238 .33296 L
.53412 .33301 L
.5361 .33307 L
.53842 .33317 L
.54266 .33339 L
.54768 .33376 L
.55313 .33428 L
.55865 .33497 L
.56531 .33602 L
.57303 .33758 L
.58052 .3395 L
.58909 .34223 L
.60559 .34952 L
.61497 .35522 L
.62478 .3629 L
.63323 .37164 L
.63991 .38091 L
.64264 .38577 L
.64515 .39122 L
.64709 .39656 L
.64847 .40157 L
.64912 .40466 L
Mistroke
.64959 .40755 L
.6498 .40919 L
.64996 .41074 L
.65004 .4116 L
.6501 .41253 L
.65015 .41337 L
.65018 .41415 L
.65022 .41561 L
.65023 .41639 L
.65023 .41722 L
.65022 .41809 L
.65019 .41891 L
.65012 .42045 L
.65002 .42188 L
.6499 .42321 L
.64954 .4262 L
.64905 .42907 L
.64849 .43168 L
.64687 .43746 L
.64503 .44241 L
.6427 .44745 L
.63656 .45742 L
.62838 .46701 L
.61956 .47477 L
.61111 .48062 L
.6011 .4861 L
.59208 .49 L
.57605 .49503 L
.56848 .49672 L
.56118 .498 L
.55532 .4988 L
.54962 .4994 L
.54477 .4998 L
.54076 .50005 L
.53665 .50024 L
.53322 .50035 L
.53156 .50039 L
.52983 .50043 L
.52899 .50044 L
.52812 .50045 L
.52738 .50046 L
.52661 .50046 L
.52623 .50047 L
.52588 .50047 L
.52554 .50047 L
.52524 .50047 L
.52495 .50047 L
.52465 .50047 L
.52435 .50047 L
.52403 .50047 L
Mistroke
.52385 .50047 L
.52368 .50047 L
.52337 .50047 L
.5232 .50047 L
.52304 .50047 L
.52268 .50047 L
.52238 .50047 L
.5221 .50047 L
.52149 .50047 L
.52033 .50046 L
.51915 .50045 L
.51718 .50042 L
.51391 .50037 L
.51113 .50031 L
.50746 .50022 L
.50487 .50014 L
.50323 .5001 L
.50209 .50006 L
.50138 .50004 L
.50092 .50003 L
.5006 .50002 L
.5004 .50001 L
.50027 .50001 L
Mfstroke
.65022 .41583 m
.64958 .42579 L
s
% Start of user PostScript
0.90134981 0.49496314 0.89750986 0.5547616 MAarrowhead1
% End of user PostScript
.52562 .32235 m
.54048 .31667 L
.55179 .31284 L
.56819 .30815 L
.57724 .30603 L
.5882 .30394 L
.59402 .30304 L
.59982 .3023 L
.60528 .30175 L
.61146 .30128 L
.61462 .30111 L
.61643 .30104 L
.61809 .30099 L
.61965 .30095 L
.62137 .30092 L
.62301 .30091 L
.62454 .3009 L
.62548 .30091 L
.6265 .30092 L
.62836 .30095 L
.63019 .301 L
.63189 .30106 L
.63578 .30126 L
.63995 .30156 L
.64379 .30192 L
.64795 .3024 L
.65554 .30352 L
.66468 .30533 L
.67305 .30744 L
.68874 .31273 L
.70282 .31917 L
.7174 .32795 L
.73145 .33915 L
.7422 .35041 L
.75187 .36385 L
.75557 .37041 L
.75894 .37755 L
.76154 .38428 L
.76355 .39075 L
.76448 .39446 L
.76533 .39851 L
.76591 .40189 L
.7664 .40563 L
.76662 .40773 L
.76678 .4097 L
.76691 .41178 L
.76696 .41294 L
.76699 .41401 L
.76703 .41591 L
.76702 .41798 L
Mistroke
.76697 .41994 L
.7669 .42175 L
.76678 .42358 L
.76662 .42555 L
.76623 .42911 L
.76573 .43257 L
.76515 .43573 L
.76347 .44287 L
.76111 .45027 L
.75488 .46424 L
.75048 .4717 L
.74594 .47821 L
.73637 .48939 L
.72467 .49999 L
.71092 .50959 L
.69723 .51693 L
.68181 .52316 L
.67288 .52594 L
.66447 .52805 L
.65636 .52967 L
.6489 .53081 L
.64124 .53166 L
.63726 .53198 L
.63507 .53211 L
.63307 .53222 L
.63137 .53229 L
.62952 .53235 L
.62767 .53239 L
.62667 .53241 L
.62574 .53242 L
.62403 .53243 L
.62248 .53242 L
.62071 .5324 L
.61905 .53237 L
.61757 .53233 L
.61602 .53228 L
.61326 .53215 L
.61034 .53198 L
.60718 .53175 L
.60097 .53116 L
.59474 .53039 L
.58443 .52873 L
.56497 .52435 L
.54058 .5167 L
.52512 .51078 L
.51612 .50703 L
.51019 .50448 L
.5066 .50291 L
.50437 .50193 L
.50283 .50125 L
Mistroke
.50186 .50082 L
.50125 .50055 L
.50082 .50036 L
.50054 .50024 L
.50035 .50016 L
.50023 .5001 L
.50022 .5001 L
Mfstroke
.76663 .42547 m
.76522 .43536 L
s
% Start of user PostScript
1.5997887 0.55279634 1.5913357 0.61215417 MAarrowhead1
% End of user PostScript
1 .5848 m
.97808 .60104 L
.94439 .6194 L
.92374 .62794 L
.90365 .6346 L
.88164 .6402 L
.87057 .6424 L
.86022 .6441 L
.8509 .64535 L
.84056 .64643 L
.83551 .64684 L
.83007 .6472 L
.82706 .64736 L
.82431 .64749 L
.82171 .64758 L
.8189 .64767 L
.81598 .64773 L
.81324 .64777 L
.81056 .64779 L
.8081 .64779 L
.80542 .64776 L
.80249 .64772 L
.80101 .64768 L
.79942 .64764 L
.79656 .64755 L
.79098 .6473 L
.78569 .64699 L
.77579 .64619 L
.76409 .64491 L
.75332 .64339 L
.72925 .63885 L
.70823 .63357 L
.68914 .62767 L
.64871 .61157 L
.61448 .59377 L
.5887 .57754 L
.55069 .54853 L
.53029 .53025 L
.51818 .51851 L
.51143 .51173 L
.50713 .50734 L
.50458 .50472 L
.50301 .50311 L
.50194 .502 L
.50127 .50132 L
.50085 .50088 L
.50056 .50057 L
.50037 .50038 L
.50024 .50025 L
.50016 .50016 L
Mistroke
Mfstroke
.74076 .64102 m
.73094 .63917 L
s
% Start of user PostScript
1.4445815 1.846139 1.3856393 1.8350237 MAarrowhead1
% End of user PostScript
.70508 .83333 m
.64319 .75818 L
.5889 .67869 L
.54927 .60904 L
.52735 .56418 L
.51604 .53872 L
.5095 .52325 L
.50594 .5146 L
.50369 .50909 L
.50237 .50584 L
.50156 .50384 L
.501 .50248 L
.50066 .50163 L
.50042 .50105 L
.50028 .50069 L
.50019 .50046 L
.50012 .5003 L
.50008 .5002 L
s
.59003 .68034 m
.58494 .67174 L
s
% Start of user PostScript
0.54016501 2.0820341 0.50966963 2.030421 MAarrowhead1
% End of user PostScript
.49984 .33317 m
.49976 .33309 L
.49963 .33295 L
.49944 .33276 L
.49916 .33247 L
.49871 .33201 L
.49805 .33132 L
.49696 .3302 L
.49531 .3285 L
.49282 .32594 L
.48857 .32161 L
.48178 .31479 L
.47071 .30403 L
.44963 .28507 L
.41298 .25695 L
.38578 .23971 L
.34923 .22081 L
.33015 .21271 L
.30859 .2049 L
.28745 .19858 L
.26741 .19376 L
.24443 .1896 L
.23221 .18798 L
.22596 .18731 L
.21925 .18671 L
.21335 .18628 L
.20796 .18598 L
.20537 .18586 L
.20255 .18575 L
.19991 .18567 L
.19743 .18562 L
.19457 .18557 L
.19305 .18555 L
.19141 .18555 L
.18979 .18554 L
.18808 .18555 L
.18662 .18556 L
.18503 .18558 L
.18216 .18564 L
.18056 .18568 L
.1791 .18572 L
.17361 .18594 L
.16843 .18622 L
.16276 .18663 L
.15137 .18772 L
.14092 .18906 L
.13124 .19061 L
.10986 .1951 L
.08766 .20143 L
.06761 .20874 L
Mistroke
.04682 .21816 L
.01216 .23883 L
0 .24881 L
Mfstroke
.26897 .19413 m
.25916 .19226 L
s
% Start of user PostScript
-1.386153 -0.83520608 -1.4450625 -0.84642244 MAarrowhead1
% End of user PostScript
.49992 .33313 m
.49988 .33303 L
.49981 .33286 L
.49971 .33262 L
.49957 .33227 L
.49934 .3317 L
.49899 .33085 L
.49843 .32945 L
.49756 .32732 L
.49626 .32411 L
.49399 .31856 L
.49031 .30964 L
.48415 .29506 L
.47202 .26778 L
.45001 .2229 L
.40948 .15204 L
.35256 .06949 L
.29485 0 L
s
.41496 .16162 m
.41 .15295 L
s
% Start of user PostScript
-0.51023857 -1.0302504 -0.54001807 -1.0823168 MAarrowhead1
% End of user PostScript
.5 .33312 m
.5 .33301 L
.5 .33284 L
.5 .33258 L
.5 .3322 L
.5 .33159 L
.5 .33069 L
.5 .3292 L
.5 .32693 L
.5 .32349 L
.5 .31753 L
.5 .30786 L
.5 .29191 L
.5 .26156 L
.5 .21032 L
.5 .12588 L
.5 .0207 L
.5 0 L
s
.5 .17156 m
.5 .16156 L
s
% Start of user PostScript
0. -0.97064693 0. -1.030628 MAarrowhead1
% End of user PostScript
.50008 .33313 m
.50012 .33303 L
.50019 .33286 L
.50029 .33262 L
.50043 .33227 L
.50066 .3317 L
.50101 .33085 L
.50157 .32945 L
.50244 .32732 L
.50374 .32411 L
.50601 .31856 L
.50969 .30964 L
.51585 .29506 L
.52798 .26778 L
.54999 .2229 L
.59052 .15204 L
.64744 .06949 L
.70515 0 L
s
.58504 .16162 m
.59 .15295 L
s
% Start of user PostScript
0.51023857 -1.0302504 0.54001807 -1.0823168 MAarrowhead1
% End of user PostScript
.50016 .33317 m
.50024 .33309 L
.50037 .33295 L
.50056 .33276 L
.50084 .33247 L
.50129 .33201 L
.50195 .33132 L
.50304 .3302 L
.50469 .3285 L
.50718 .32594 L
.51143 .32161 L
.51822 .31479 L
.52929 .30403 L
.55037 .28507 L
.58702 .25695 L
.61422 .23971 L
.65077 .22081 L
.66985 .21271 L
.69141 .2049 L
.71255 .19858 L
.73259 .19376 L
.75557 .1896 L
.76779 .18798 L
.77404 .18731 L
.78075 .18671 L
.78665 .18628 L
.79204 .18598 L
.79463 .18586 L
.79745 .18575 L
.80009 .18567 L
.80257 .18562 L
.80543 .18557 L
.80695 .18555 L
.80859 .18555 L
.81021 .18554 L
.81192 .18555 L
.81338 .18556 L
.81497 .18558 L
.81784 .18564 L
.81944 .18568 L
.8209 .18572 L
.82639 .18594 L
.83157 .18622 L
.83724 .18663 L
.84863 .18772 L
.85908 .18906 L
.86876 .19061 L
.89014 .1951 L
.91234 .20143 L
.93239 .20874 L
Mistroke
.95318 .21816 L
.98784 .23883 L
1 .24881 L
Mfstroke
.73103 .19413 m
.74084 .19226 L
s
% Start of user PostScript
1.386153 -0.83520608 1.4450625 -0.84642244 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 239.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001Ib000`400?l00000o`00003ooooooona
ooooo`00oooooonaooooo`00goooool00oojn_[odm?Coo[jnP35ooooo`03onOWioo@d=3om_Kf00Ko
oooo001Looooo`03oeIFE_l0003o000000;o000000?o0P82om;Bd_ooool0>oooool00oojn_[o4Q8B
o`000002o`000003o`820_n^[Zkooooo03Oooooo00Gobl_;oa8B4_lN7Qko4a<Colg=c@0looooo`03
oo[jn_lB4Q;o000000;o000000?o0P82ojj^[_ooool0>oooool00omFEUKo0000o`000002o`000003
o`820_oBd];ooooo03_ooooo00Ko_;blob4Q8Ol10@7o2@T9o`h>3_nOWil5ooooo`00G?ooool00ond
];Co1PH6oiBDU002omKFeP03og1`L?oGemOooooo03cooooo00Goo_knooOgmolN7Qko/K6aoo[jnP0h
ooooo`06ookno_lT92CoTY:BoooooonCTi?o9RHV?Oooool01Oono_komoOgoahN7_na/K7on_[j03go
oooo00?o];Bdo`H61_nDU9@00_oFe]H00om`L73oemOGooooo`0kooooo`07ojRXZ?nMWIgoj^[ZooKf
m_n<S8co10@4omOGe`04ooooo`00Doooool00oo3`l?o/K6aok6a/@03ok6a/@07olG5aOoooooooooo
oooooonSXj?o30`<okNg]`0fooooo`03ol?3`ona/K7o/K6a00?o/K6a00?oaLG5ooooooooool00ooo
ool00olO7aoo^;Rhooooo`0hooooo`07olG5aOl;2`_on?Shooooooohn?So2`/;olK6aP0nooooo`03
oalO7onh^;Sooooo03kooooo00?oXj>So``<3?ng]kL0@oooool00oomoOgo5aLGoijNWP04ooooo`00
Doooool00olR8R;o0000o`000003o`000003ob8R8_oooooooooo00;ooooo00?oXj>So`X:2_o6a/H0
=Oooool00olR8R;o0000o`000003o`000003ob8R8_oooooooooo00?ooooo00?o7alOokRh^?ooool0
>?ooool00onMWIgo<c<cooooo`02ooooo`03oc<c<onMWIgooooo03gooooo00?o7alOokRh^?ooool0
?oooool00onSXj?o2PX:olK6aP12ooooo`03on;Rh_l30`?oc/k>00Cooooo001Cooooo`03onOWiooN
g]kog]kN00?og]kN00?oj>SXooooooooool00oooool00on>SXko5ADEomgMg@0dooooo`03onOWiooN
g]kog]kN00?og]kN00?oj>SXooooooooool00oooool00olO7aoo^;Rhooooo`0hooooo`03ohN7Qom2
@T;ooooo00;ooooo00?o@T92ohN7Qoooool0?Oooool00olO7aoo^;Rhooooo`10ooooo`03ohj>S_lE
5AGogMgM03oooooo00Col?3`og1`L?lD51CoN7Qh1Oooool0063ooooo00?oGEeModA4A?ooool0?ooo
ool00olO7aoo^;Rhooooo`0hooooo`03oiBDU?lV9RKooooo00;ooooo00?o9bLWoiBDU?ooool0?Ooo
ool00olO7aoo^;Rhooooo`11ooooo`03oeeMGOm4A4Cooooo03kooooo00ComOGeog]kNolU9BGo/[:b
1Oooool0063ooooo00?od=3@o`820_oTi>@0?oooool00olO7aoo^;Rhooooo`0hooooo`07ojn_[ol4
10Con_[jooooooojn_[o10@4ojn_[`0nooooo`03oalO7onh^;Sooooo047ooooo00?od=3@o`820_oT
i>@0@?ooool00onn_[ko4Q8Boogmo@04ooooo`00G?ooool01onm_KgoYJFUoooooooooooo_Kfmo`00
0?oQhN40?oooool00olO7aoo^;Rhooooo`0hooooo`07ono_kol61PKocLg=ooooooo>c/ko1`L7ono_
k`0nooooo`03oalO7onh^;Sooooo03gooooo00Oo_KfmojFUYOoooooooooookfm_Ol0003ohN7Q043o
oooo00?o_;blo``<3?oemOD01?ooool005cooooo00Ko[jn_o`P82?n7QhOoZj^[ocHf=_m2@T8noooo
o`04odE5AOmJFU[o3`l?okRh^3[ooooo00GoIVIVoc@d=?nVYZKo=3@dofMWI`0mooooo`04odE5AOmJ
FU[o3`l?okRh^3kooooo00Ko[jn_o`P82?n7QhOoZj^[ocHf=_m2@T8mooooo`06ono_kolO7aooOGem
ojRXZ?lf=SKoIFEU1Oooool005gooooo00GoalO7of][JomHF5SoZZZZooOgm`0nooooo`04onKVi_nS
Xj?oI6ATomOGec[ooooo00Goo?clohZ:R_mCDe?oRh^;ooclo00mooooo`04onKVi_nSXj?oI6ATomOG
ecoooooo00GoalO7of][JomHF5SoZZZZooOgm`0nooooo`05olc<c?mkNg_oEUIFoifMWOo`l?001Ooo
ool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Oooool00?oooooo/Ooo
ool001Soooooool0002Bo`0000Oooooo000Hooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`;o
00003Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo0_l0000<ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`00
6?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
1Oooool001Sooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`05ooooo`006?ooool0
0ol0003oooooooooo`1gooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo
07Sooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
07Sooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0N?ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0N?ooool00ol0003o
ooooooooo`05ooooo`006?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo
000Hooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000
ooooooooool0Noooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0Noooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo07cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07cooooo00?o0000oooooooo
ool01Oooool001Sooooo0ol0001mooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`1looooo`;o00001oooool001Sooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo00Gooooo000Hooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool01Oooool001So
oooo00?o0000ooooooooool0POooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003ooooo
ooooo`21ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`21ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`05
ooooo`006?ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03
o`000?oooooooooo08Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo08Gooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0
QOooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
QOooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo00Gooooo000Hooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool01Oooool0
01Sooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`05ooooo`006?ooool3o`0008Wo
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo08So
oooo0_l00007ooooo`006?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Gooooo
000Hooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000
ooooooooool0Roooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0Roooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2<oooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<oooo
o`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo08cooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000oooooooo
ool01Oooool001Sooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`05ooooo`006?oo
ool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooo
oooo08oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo08oooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0Soooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0Soooool00ol0
003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo00Go
oooo000Hooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool01Oooool001Sooooo00?o
0000ooooooooool0TOooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0TOooool00ol0003oooooooooo`05ooooo`006?ooool3o`0009;ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo097ooooo0_l00007
ooooo`006?ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo00Gooooo000Hooooo`03
o`000?oooooooooo09?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo09?ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0
U?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
U?ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2Eooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2Eooooo`03o`000?oo
oooooooo00Gooooo000Hooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool01Oooool0
01Sooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003o
ooooooooo`2Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`2Gooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo09Sooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo09Sooooo
00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0V?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0V?ooool00ol0003ooooooooo
o`05ooooo`006?ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo00Gooooo000Hoooo
o`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo09[ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000oooooooo
ool0V_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0V_ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2Kooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Kooooo`03o`00
0?oooooooooo00Gooooo000Hooooo`?o0000W?ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0Voooool2o`0000Oooooo000Hooooo`03o`000?oooooo
oooo09cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo09cooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0WOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0WOooool00ol0
003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Go
oooo000Hooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool01Oooool001Sooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2P
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2P
ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo0:7ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0:7ooooo00?o0000oooo
ooooool01Oooool001Sooooo00?o0000ooooooooool0XOooool2o`0002;ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`00
0?oooooooooo0:7ooooo0ol0000Qooooo`03o`000?oooooooooo023ooooo0_l0002Sooooo`03o`00
0?oooooooooo00Gooooo000;ooooo`03oo[jn_lB4Q;o000000;o000000?o0P82ojj^[_ooool01Ooo
ool00ol0003oooooooooo`2Rooooo`?o00008?ooool00ol0003oooooooooo`0Oooooo`;o0000Y?oo
ool00ol0003oooooooooo`05ooooo`003?ooool01Oono_komoOgoahN7_na/K7on_[j00Oooooo00?o
0000ooooooooool0X_ooool4o`0001oooooo00?o0000ooooooooool07_ooool3o`000:Cooooo00?o
0000ooooooooool01Oooool000;ooooo00?o`l?3ok6a/Ona/K400ona/K400oo5aLGoooooooooo`03
ooooo`03oalO7onh^;Sooooo00Oooooo00?o0000ooooooooool0X_ooool5o`0001kooooo00?o0000
ooooooooool07Oooool4o`000:Cooooo00?o0000ooooooooool01Oooool000;ooooo00?o8R8Ro`00
0?l000000ol000000olR8R;oooooooooo`03ooooo`03oalO7onh^;Sooooo00Oooooo1?l0002Qoooo
o`Ko00007Oooool00ol0003oooooooooo`0Looooo`Go0000X_ooool3o`0000Oooooo0002ooooo`03
onOWiooNg]kog]kN00?og]kN00?oj>SXooooooooool00oooool00olO7aoo^;Rhooooo`07ooooo`03
o`000?oooooooooo0:?ooooo0ol0000Nooooo`?o00007_ooool3o`000:Gooooo00?o0000oooooooo
ool01Oooool000kooooo00?o7alOokRh^?ooool01oooool00ol0003oooooooooo`2Sooooo`03o`00
0?oooooo000001kooooo0ol0000Nooooo`03o`000?oooooo00000:Gooooo00?o0000ooooooooool0
1Oooool000kooooo00?o7alOokRh^?ooool01oooool00ol0003oooooooooo`2Vooooo`03o`000?oo
oooooooo01_ooooo0ol0000Mooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool01Ooo
ool000kooooo00?o7alOokRh^?ooool01oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooo
oooo01_ooooo0ol0000Mooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool01Oooool0
00cooooo00CoADE5oeYJF_l?3`oo^;Rh2?ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooo
oooo01Wooooo1Ol0000Kooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool01Oooool0
00cooooo00Coi^KVoj>SXomTI6CoemOG2?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooo
oooo01Sooooo1Ol0000Jooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool01Oooool0
01Sooooo00?o0000ooooooooool0A?ooool;o`0005Wooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo05Oooooo3?l00015ooooo`03o`000?oooooooooo
00Gooooo000Hooooo`03o`000?oooooooooo03Sooooo3?l0000;ooooo`oo0000Boooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0B_ooool>o`0000co
oooo3?l0000iooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo033ooooo
2?l0000Vooooo`Co0000Aoooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0A_ooool4o`0002Kooooo2?l0000aooooo`03o`000?oooooooooo00Gooooo
000Hooooo`03o`000?oooooooooo02_ooooo1Ol0000booooo`co0000??ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0>_ooool=o`0003;ooooo1?l0
000]ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo02Sooooo0ol0000l
ooooo`Oo0000??ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0>_ooool8o`0003_ooooo1?l0000Yooooo`03o`000?oooooooooo00Gooooo000Hoooo
o`03o`000?oooooooooo02Gooooo0ol00011ooooo`Ko0000??ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0>_ooool7o`00047ooooo0ol0000Voooo
o`03o`000?oooooooooo00Gooooo000Hooooo`?o00008_ooool3o`0004Gooooo0ol00002ooooo`Co
0000>Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0=oooool4o`0000;ooooo0ol00016ooooo`?o00008_ooool2o`0000Oooooo000Hooooo`03o`00
0?oooooooooo01oooooo0ol0001:ooooo`03o`000?oooooooooo00Cooooo1Ol0000dooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0cooooo`Co0000
1_ooool00ol0003oooooooooo`19ooooo`;o00008Oooool00ol0003oooooooooo`05ooooo`006?oo
ool00ol0003oooooooooo`0Looooo`?o0000FOooool3o`0003;ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo037ooooo0ol0001Hooooo`?o00007_oo
ool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`0Iooooo`?o0000Goooool3
o`0002oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo02kooooo0ol0001Nooooo`?o00006oooool00ol0003oooooooooo`05ooooo`006?ooool00ol0
003oooooooooo`0Gooooo`;o0000IOooool3o`0002gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02cooooo0ol0001Tooooo`?o00006?ooool00ol0
003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`0Dooooo`?o0000J_ooool2o`0002_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Wo
oooo0ol0001Zooooo`?o00005Oooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003ooooo
ooooo`0Aooooo`?o0000Koooool2o`0002[ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo02Sooooo0_l0001`ooooo`?o00004_ooool00ol0003ooooo
ooooo`05ooooo`006?ooool00ol0003oooooooooo`0?ooooo`;o0000M?ooool2o`0002Wooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0Loooool2o`00013ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`1fooooo`;o00009oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09_ooool2o`0007Sooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`0<oooo
o`;o0000Noooool2o`0002Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo02Gooooo0_l0001kooooo`;o00003Oooool00ol0003oooooooooo`05oooo
o`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07gooooo0_l0000Tooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Sooooo`;o
0000Ooooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`00
0?oooooooooo00Wooooo0_l00022ooooo`;o00008oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool08_ooool2o`0008;ooooo0_l0000:ooooo`03o`00
0?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo00Oooooo0_l00026ooooo`?o00008?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07ooo
ool3o`0008Kooooo0_l00008ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ROooool2o`0001oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo0_l0002;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool001Sooooo0ol00004ooooo`;o0000S_ooool2o`00
01gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01cooooo0_l0002>ooooo`;o00001?ooool2o`0000Oooooo000Hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0T?ooool2o`0001cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01_ooooo0_l0002Booooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool001Sooooo00Co0000oooooooooooooooo0_l0002Eooooo`;o
00006_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool06Oooool2o`0009Gooooo00Go0000ooooooooooooooooo`000007ooooo`006?ooool01?l0003o
ooooooooool0002Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0U_ooool01?l0
003oooooooooool00007ooooo`006?ooool00ol0003oooooo`00002Kooooo`;o00006?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool2o`00
09[ooooo00?o0000ooooool000001oooool001Sooooo0_l0002Nooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Ko
oooo0_l0002Mooooo`;o00001oooool001Sooooo00?o0000ooooooooool0W_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01Oooool001Sooooo00?o
0000ooooooooool0Woooool2o`0001Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01Cooooo0_l0002Qooooo`03o`000?oooooooooo00Gooooo000H
ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Q
ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo0:;ooooo0_l0000Doooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Boooo
o`;o0000Y?ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2Tooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`05ooooo`00
6?ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
YOooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2Vooooo`;o00004Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03ooo
ool2o`000:Sooooo00?o0000ooooooooool01Oooool001Sooooo0ol0002Xooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Yoooool2o`0000Oooooo000Hooooo`03o`000?oooooooooo
0:Wooooo0_l0000?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0=ooooo`;o0000Zoooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003o
ooooooooo`2[ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Zoooool00ol0003o
ooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0[?ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003ooooooooo
o`2]ooooo`;o00003Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02_ooool2o`000:oooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000
ooooooooool0[oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:oooooo00?o0000
ooooooooool01Oooool001Sooooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000oooooooo
ool0/Oooool2o`0000[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`05ooooo`00
6?ooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2dooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`05ooooo`006?ooool0
0ol0003oooooooooo`2eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0]?ooool0
0ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003o
ooooooooo`2gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0]_ooool00ol0003o
ooooooooo`05ooooo`006?ooool3o`000;Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2fooooo`;o00001oooool001Sooooo00?o0000ooooooooool0ROoooolIo`0001Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0EoooooaWo0000R_ooool00ol0003ooooooooo
o`05ooooo`006?ooool00ol0003oooooooooo`22ooooo`Oo00006Oooool3o`0001Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`?o00006Oooool7o`0008?ooooo00?o0000
ooooooooool01Oooool001Sooooo00?o0000ooooooooool0Ooooool3o`0002?ooooo2?l0000>oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03?ooool8o`0002?ooooo1?l0001oooooo`03o`000?oooooo
oooo00Gooooo000Hooooo`03o`000?oooooooooo07cooooo0ol0000^ooooo`?o00003?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00[ooooo0ol0000_ooooo`?o0000O?ooool00ol0003oooooooooo`05
ooooo`006?ooool00ol0003oooooooooo`1iooooo`?o0000=?ooool3o`0000[ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`08ooooo`?o0000=Oooool2o`0007[ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000
ooooooooool0Moooool2o`0003[ooooo0_l00009ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool3o`0003[ooooo
0_l0001hooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo07Gooooo0_l0
000nooooo`?o00001oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool01Oooool2o`0003oooooo00?o0000ooooooooool0MOooool00ol0003o
ooooooooo`05ooooo`006?ooool00ol0003oooooooooo`1cooooo`;o0000@oooool3o`0000Gooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo0ol00012
ooooo`;o0000MOooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`1aoooo
o`;o0000B?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo0000ooooool000000_ooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo04Gooooo0_l0001cooooo`03o`000?oooooo
oooo00Gooooo000=ooooo`03oo[jn_oCdm?on_[j00Sooooo00?o0000ooooooooool0Koooool2o`00
053ooooo00?o0000ooooooooool00_l000001?oooooo0000ooooool0001@ooooo`;o0000LOooool0
0ol0003oooooooooo`05ooooo`003?ooool01Oo;bl_o4Q8BoahN7_lC4a?ocLg=00Oooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo000000;o000000?ooooo
o`000?ooool0D_ooool2o`0006oooooo00?o0000ooooooooool01Oooool000_ooooo00Koo_knob@T
9?nBTY;ooooooi>CTolV9RH7ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0Dooo
ool5o`0005Kooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`05ooooo`002oooool0
1oo5aLGo2`/;ooShn?oooooon?Sho`/;2oo6a/H01_ooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo04Sooooo3?l000001?oooooo0000o`000?l00002ooooo`co0000B_ooool00ol0003o
ooooooooo`1[ooooo`03o`000?oooooooooo00Gooooo000;ooooo`03oifMWOlc<c?ooooo00;ooooo
00?o<c<coifMWOooool01Oooool4o`0006[ooooo00?o0000ooooooooool0?oooool:o`0000cooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`0:ooooo`[o0000@Oooool00ol0003ooooo
ooooo`1Xooooo`?o00001oooool000_ooooo00?oQhN7od92@_ooool00_ooool00om2@T;oQhN7oooo
o`05ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0>_ooool6o`0001Cooooo0_l0
00001_oooooo0000oooooooooooo0000ooooo`;o00005?ooool6o`0003cooooo00?o0000oooooooo
ool0JOooool00ol0003oooooooooo`05ooooo`002oooool00onDU9Co9RHVooooo`02ooooo`03obLW
9onDU9Cooooo00Gooooo00?o0000ooooooooool0J?ooool2o`0003[ooooo0ol0000Hooooo`;o0000
00?oooooo`000?l000000ol000001?oooooo0000ooooooooool2o`0001Sooooo0ol0000jooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool01Oooool000_ooooo00Oo[jn_o`@41?ojn_[o
oooooo[jn_l410Co[jn_00Kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0goooo
o`?o00006?ooool3o`0000;ooooo00?o0000ooooooooool00_l000001?oooooo0000ooooool00003
ooooo`?o00006?ooool3o`0003Sooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`05
ooooo`002oooool01oo_knoo1PH6olg=cOooooooc/k>o`L71oo_knl01_ooool00ol0003ooooooooo
o`1Vooooo`03o`000?oooooooooo03Gooooo0ol0000Hooooo`?o00001Oooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`?o00006?ooool3o`0003Ko
oooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`05ooooo`003?ooool01OmVIVKo=3@d
ojJVY_ld=3CoIfMW00Oooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0dooooo`;o
00006?ooool3o`0000Oooooo00So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo00?o
0000ooooooooool01Oooool3o`0001Sooooo0_l0000eooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool01Oooool000cooooo00Goo?clohZ:R_mCDe?oRh^;ooclo007ooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0<oooool2o`0001Sooooo0_l00009ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`07ooooo`;o
00006?ooool2o`0003Cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`05ooooo`00
6?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo037ooooo0_l0000Hooooo`;o0000
2Oooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`0`ooooo`;o00006Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool2o`0001Sooooo0_l0000booooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo01Oooooo0_l0000:ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`05ooooo`00
6?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`05ooooo`006?ooool3o`00063ooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`1Nooooo`;o00001oooool001Sooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Gooooo0_l0000=ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool2o`0001Sooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
00Gooooo000Hooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`1Mooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo05kooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Gooooo
000Hooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Gooooo000Hoooo
o`03o`000?oooooooooo05gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo00Gooooo000Hooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo00Gooooo000Hooooo`?o0000Foooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo05[ooooo0_l00007ooooo`006?ooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`05ooooo`006?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool04_ooool5o`0000[ooooo1Ol00006ooooo`Go00001Oooool5o`0000Gooooo1Ol0
0007ooooo`Go00002_ooool5o`0001Cooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool0:Oooool5o`0001?ooooo1Ol0000:ooooo`Go00001_ooool5o`0000Gooooo1Ol00005
ooooo`Go00001oooool5o`0000[ooooo1Ol0000Cooooo`Go0000:oooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo05[ooooo00?o0000oooo
ooooool0:_ooool5o`0001?ooooo1Ol0000:ooooo`Go00001_ooool5o`0000Gooooo1Ol00005oooo
o`Go00001oooool4o`0000_ooooo1?l0000Dooooo`Go0000:oooool00ol0003oooooooooo`1Joooo
o`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool0:_ooool5o`0001Cooooo0ol0000<ooooo`?o00002?ooool3o`0000Oooooo0ol00007ooooo`?o
00002?ooool4o`0000_ooooo1?l0000Dooooo`Co0000;?ooool00ol0003oooooooooo`1Jooooo`03
o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo05[ooooo0ol0000[ooooo`?o0000
5Oooool3o`0000cooooo0ol00008ooooo`?o00001oooool3o`0000Oooooo0ol00008ooooo`Co0000
2oooool4o`0001Cooooo1?l0000[ooooo`?o0000Foooool00ol0003oooooooooo`05ooooo`006?oo
ool00ol0003oooooooooo`1Hooooo`Go0000:oooool3o`0001Gooooo0ol0000<ooooo`?o00002?oo
ool3o`0000Oooooo0ol00007ooooo`?o00002Oooool2o`0000gooooo0_l0000Eooooo`Co0000:ooo
ool4o`0005[ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0F?ooool5
o`0002_ooooo0ol0000Eooooo`?o00003?ooool3o`0000Sooooo0ol00007ooooo`?o00001oooool3
o`0000Wooooo0_l0000=ooooo`;o00005_ooool2o`0002cooooo1?l0001Jooooo`03o`000?oooooo
oooo00Gooooo000Hooooo`03o`000?oooooooooo05Wooooo1?l0000[ooooo`?o00005_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0_l0000=ooooo`;o00005_ooool2o`00
02cooooo0ol0001Kooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo05Wo
oooo1?l0000/ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool2o`0002co
oooo0ol0001Kooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo05[ooooo
0_l0000]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`08ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02_ooooo
0_l0001Looooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo05[ooooo0_l0
000^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0[ooooo`;o0000G?ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`1J
ooooo`;o0000;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0:oooool2o`0005cooooo00?o0000ooooooooool01Oooool001Sooooo0ol0001Koooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02_ooooo0_l0001Kooooo`;o00001oooool001Sooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool01Oooool001Sooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0G?oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool01Ooo
ool001Sooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0GOooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool01Oooool001So
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05co
oooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0GOooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool01Oooool001Sooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05gooooo00?o
0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000oooo
ooooool0G_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool01Oooool001Sooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0
1Oooool001Sooooo0ol0001Oooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Fooooo`;o0000<Oooool00ol0003oooooooooo`1Nooooo`;o00001ooo
ool001Sooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo01Kooooo0_l0000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool2
o`0001Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo00Gooooo000Hooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0<Oooool2o`0001Sooooo0_l0000:ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01oooool2o`0001Wooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Gooooo`;o00002Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`;o00006_ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0booooo`;o00006Oooool2o`0000Oooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`0Hooooo`;o0000=?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
00Gooooo000Hooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0<oooool2o`0001Wo
oooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool01Ol0003o
oooooooooooooooo000000Oooooo0_l0000Iooooo`;o0000=Oooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool0=?ooool3o`0001Sooooo0_l00005ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`04
o`000?oooooo0000o`0000Gooooo0ol0000Hooooo`?o0000=_ooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo06Oooooo00?o0000oooooooo
ool0=_ooool3o`0001Oooooo0_l00005ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oo
oooo000000Gooooo0_l0000Hooooo`?o0000=oooool2o`0006Sooooo00?o0000ooooooooool01Ooo
ool001Sooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0hooooo`?o00005_ooool2
o`0000?ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000001?ooool00ol0003o
ooooooooo`0Eooooo`?o0000>Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Go
oooo000;ooooo`03oo[jn_lB4Q;o000000;o000000?o0P82ojj^[_ooool01Oooool00ol0003ooooo
ooooo`1Yooooo`03o`000?oooooooooo03[ooooo1?l0000Dooooo`Go000000Ooooooo`000?l0003o
0000ooooool0003ooooo00Co00005Oooool3o`0003_ooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`05ooooo`003?ooool01Oono_komoOgoahN7_na/K7on_[j00Oooooo00?o0000oooo
ooooool0J_ooool00ol0003oooooooooo`0mooooo`Go00004oooool8o`0001?ooooo1_l0000moooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01Oooool000kooooo00?o7alOokRh^?oo
ool01oooool4o`0006[ooooo0_l00012ooooobko0000@Oooool2o`0006_ooooo0ol00007ooooo`00
3_ooool00olO7aoo^;Rhooooo`07ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
D_ooool7o`0005Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`05ooooo`003_oo
ool00olO7aoo^;Rhooooo`07ooooo`03o`000?oooooooooo06kooooo0_l0001@ooooo`;o000000?o
ooooo`000?l000000ol000001?oooooo0000o`000?l0001@ooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool01Oooool000kooooo00?o7alOokRh^?ooool01oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo04_ooooo0_l00002ooooo`03o`000?oooooo000000;o000000?o
ooooo`000?ooool00_ooool2o`0004gooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`05ooooo`003_ooool00olO7aoo^;Rhooooo`07ooooo`03o`000?oooooooooo077ooooo0_l00019
ooooo`;o00001?ooool02?l0003oooooo`000?l0003oooooo`000?oooooo00001?ooool00ol0003o
ooooooooo`18ooooo`;o0000L_ooool00ol0003oooooooooo`05ooooo`003_ooool00olO7aoo^;Rh
ooooo`07ooooo`03o`000?oooooooooo07?ooooo0_l00015ooooo`;o00001Oooool00ol0003ooooo
ooooo`02o`000005ooooool0003oooooooooool000001?ooool3o`0004Gooooo0_l0001dooooo`03
o`000?oooooooooo00Gooooo000<ooooo`04odE5AOmJFU[o3`l?okRh^0Sooooo00?o0000oooooooo
ool0MOooool00ol0003oooooooooo`0oooooo`?o00001_ooool01_l0003oooooooooool0003ooooo
o`0000;ooooo00Co0000oooooooooooo00001_ooool3o`00043ooooo0_l0001fooooo`03o`000?oo
oooooooo00Gooooo000<ooooo`04onKVi_nSXj?oI6ATomOGe`Sooooo00?o0000ooooooooool0M_oo
ool2o`0003_ooooo1?l00008ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`05
o`000?ooooooooooooooool000002?ooool3o`0003_ooooo0_l0001hooooo`03o`000?oooooooooo
00Gooooo000Hooooo`03o`000?oooooooooo07Sooooo0_l0000fooooo`?o00002_ooool2o`0000?o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo0ol0000fooooo`;o0000N_ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003o
ooooooooo`1jooooo`;o0000<Oooool3o`0000cooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool3o`00
037ooooo0_l0001looooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo07co
oooo0ol0000Zooooo`Co00003_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo1?l0000Zoooo
o`?o0000O_ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`1oooooo`Co
00008_ooool4o`00017ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`Co00008oooool3o`00
087ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0Poooool7o`0001Co
oooo1ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l0000Cooooo`So00005Oooool6o`0008Co
oooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0R_oooolDo`0001[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0HoooooaGo0000R_ooool00ol0003ooooo
ooooo`05ooooo`006?ooool3o`000;Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`2eooooo`;o00001oooool001Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000oooo
ooooool0]Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Cooooo00?o0000oooo
ooooool01Oooool001Sooooo00?o0000ooooooooool0]?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo0;?ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0
/oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
1Oooool001Sooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0;7ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0/?ooool2
o`0000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo0_l0002aooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo
0:oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo
00Gooooo000Hooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`2]ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo0:cooooo
0_l0000>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0<ooooo`;o0000[Oooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003ooooooooo
o`2[ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Z_ooool00ol0003ooooooooo
o`05ooooo`006?ooool00ol0003oooooooooo`2Yooooo`;o00004?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool2o`000:[ooooo00?o0000
ooooooooool01Oooool001Sooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool01Oooool001Sooooo0ol0002Wooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0YOooool2o`0000Oooooo000Hooooo`03o`00
0?oooooooooo0:Gooooo0_l0000Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00ol0003oooooooooo`05ooooo`006?oo
ool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Xooo
ool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0
003oooooooooo`2Qooooo`;o00005Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool05?ooool2o`000:;ooooo00?o0000ooooooooool01Oooool001So
oooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo09oo
oooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0W_ooool2o`0001Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo
0_l0002Oooooo`03o`000?oooooooooo00Gooooo000Hooooo`;o0000WOooool2o`0001Wooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0Voooool2o`0000Oooooo000Hooooo`03o`000?oooooo000009_ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooo000000Oooooo000Hoooo
o`04o`000?ooooooooooo`0009Sooooo0_l0000Kooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`;o0000V?ooool01?l0003oooooooooool0
0007ooooo`006?ooool01?l0003oooooooooooooool2o`0009Gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`2Dooooo`05o`000?ooooooooooooooool000001oooool001Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2@ooooo`;o00007Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06_ooool2o`0009?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo08gooooo0_l0000Nooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Looooo`;o0000T?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo000Hooooo`?o00001Oooool00ol0003oooooooooo`2:oooo
o`;o00008?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool07Oooool2o`0008gooooo00?o0000ooooooooool00oooool2o`0000Oooooo000Hooooo`03
o`000?oooooooooo00Kooooo0_l00028ooooo`;o00008_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool2o`0008Wooooo0_l00007ooooo`03
o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo00Sooooo0_l00025ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo023ooooo0_l00025ooooo`;o00002Oooool00ol0003oooooooooo`05ooooo`006?oo
ool00ol0003oooooooooo`0:ooooo`;o0000POooool2o`0002Cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02;ooooo0_l00021ooooo`;o00002ooo
ool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`0<ooooo`;o0000OOooool2
o`0002Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo02?ooooo0_l0001mooooo`;o00003Oooool00ol0003oooooooooo`05ooooo`006?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo07Sooooo0_l0000Wooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Uooooo`;o0000NOooool2o`00
00oooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool03oooool2o`0007Go
oooo0ol0000Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Vooooo`?o0000M?ooool2o`00017ooooo00?o0000ooooooooool01Oooool001Sooooo
00?o0000ooooooooool04Oooool2o`00073ooooo0ol0000[ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Yooooo`?o0000Koooool2o`0001?ooooo
00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool04oooool2o`0006cooooo0_l0
000]ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0[ooooo`;o0000Joooool2o`0001Gooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000
ooooooooool05Oooool2o`0006Oooooo0ol0000^ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0/ooooo`?o0000I_ooool2o`0001Oooooo00?o0000
ooooooooool01Oooool001Sooooo00?o0000ooooooooool05oooool3o`00067ooooo0ol0000aoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_oooo
o`?o0000HOooool2o`0001Wooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000oooooooo
ool06_ooool2o`0005gooooo0_l0000cooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0aooooo`;o0000GOooool2o`0001_ooooo00?o0000oooooooo
ool01Oooool001Sooooo00?o0000ooooooooool07?ooool3o`0005Oooooo0ol0000eooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0cooooo`?o0000
Eoooool3o`0001gooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool07ooo
ool4o`00053ooooo0ol0000gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0eooooo`?o0000D?ooool4o`00023ooooo00?o0000ooooooooool01Ooo
ool001Sooooo0ol0000Sooooo`Co0000BOooool3o`0003[ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Sooooo0ol00019ooooo`Co00008oooool2
o`0000Oooooo000Hooooo`03o`000?oooooooooo02Oooooo1?l00010ooooo`Go0000??ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0>_ooool4o`00
043ooooo1Ol0000Xooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo02_o
oooo1Ol0000aooooo`[o0000@?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0?Oooool;o`00037ooooo1?l0000]ooooo`03o`000?oooooooooo00Go
oooo000Hooooo`03o`000?oooooooooo033ooooo1?l0000]ooooo`Oo0000@oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@Oooool7o`0002gooooo
1?l0000aooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo03Cooooo2?l0
000Nooooo`co0000A?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0@_ooool=o`0001gooooo2?l0000eooooo`03o`000?oooooooooo00Gooooo000H
ooooo`03o`000?oooooooooo03cooooo7_l00007ooooo`?o0000A_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0@oooool3o`0000Wooooo7Ol0000m
ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00Gooooo000Hooooo`03
o`000?oooooooooo0:Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo0:Sooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0
Z?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
Yoooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2Wooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2Vooooo`03o`000?oo
oooooooo00Gooooo000Hooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool01Oooool0
00_ooooo00?oEUIFo`000?l000000_l000000ol20P;od];Booooo`05ooooo`03o`000?oooooooooo
0:Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
0:Gooooo00?o0000ooooooooool01Oooool000_ooooo00?o];Bdo`H61_nDU9@00_oFe]H00om`L73o
emOGooooo`05ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool01Oooool000cooooo
00?oXj>So``<3?ng]kL02Oooool4o`000:Cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo0:;ooooo0ol00007ooooo`003Oooool00onSXj?o2PX:olK6
aP08ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool07?ooool3o`0001oooooo00?o
0000ooooooooool0Y?ooool00ol0003oooooooooo`05ooooo`003_ooool00on>SXko5ADEomgMg@07
ooooo`03o`000?oooooooooo0:?ooooo0_l0000Oooooo`?o00008?ooool00ol0003oooooooooo`2S
ooooo`03o`000?oooooooooo00Gooooo000?ooooo`03oeeMGOm4A4Cooooo00Kooooo00?o0000oooo
ooooool0X_ooool2o`00023ooooo0ol0000Pooooo`;o0000Y?ooool00ol0003oooooooooo`05oooo
o`003oooool00oo@d=3o0P82onCTi006ooooo`03o`000?oooooooooo0:7ooooo0ol0000Pooooo`?o
00008Oooool2o`000:?ooooo00?o0000ooooooooool01Oooool000_ooooo00Oo_KfmojFUYOoooooo
oooookfm_Ol0003ohN7Q00Kooooo00?o0000ooooooooool0X?ooool3o`00023ooooo1Ol0000Poooo
o`?o0000X_ooool00ol0003oooooooooo`05ooooo`002oooool01_n_[joo20P8ohN7Qon[Zj_o=SHf
od92@POooooo00?o0000ooooooooool0Woooool4o`00023ooooo1Ol0000Pooooo`Co0000XOooool0
0ol0003oooooooooo`05ooooo`003?ooool01Oo7alOoJf][oeQHF?nZZZ[omoOg00Oooooo00?o0000
ooooooooool0W_ooool5o`0002;ooooo00?o0000ooooooooool08Oooool4o`000:3ooooo00?o0000
ooooooooool01Oooool001Sooooo00?o0000ooooooooool0WOooool6o`0002;ooooo00?o0000oooo
ooooool08Oooool5o`0009oooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000oooooooo
ool0Woooool3o`0002?ooooo00?o0000ooooooooool08Oooool3o`000:7ooooo00?o0000oooooooo
ool01Oooool001Sooooo00?o0000ooooooooool0Woooool00ol0003oooooo`00000Sooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooool00000X?ooool00ol0003oooooooooo`05ooooo`006?oo
ool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooo
oooo09kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo09gooooo00?o0000ooooooooool01Oooool001Sooooo0ol0002Mooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Kooooo`;o00001oooool001So
oooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003ooooo
ooooo`2Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`2Jooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo09_ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo09[ooooo00?o
0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`05
ooooo`006?ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00Gooooo000Hooooo`03
o`000?oooooooooo09Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo09Sooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0
V?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
Uoooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Fooooo`03o`000?oo
oooooooo00Gooooo000Hooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool01Oooool0
01Sooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003o
ooooooooo`2Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`2Dooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo09Gooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo09Cooooo
00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0U?ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Toooool00ol0003ooooooooo
o`05ooooo`006?ooool3o`0009?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo097ooooo0_l00007ooooo`006?ooool00ol0003oooooooooo`2Coooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Boooo
o`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo09;ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo097ooooo00?o0000oooooooo
ool01Oooool001Sooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`05ooooo`006?oo
ool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooo
oooo093ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo08oooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0Soooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0S_ooool00ol0
003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Go
oooo000Hooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool01Oooool001Sooooo00?o
0000ooooooooool0SOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0S?ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`2<
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2;
ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo08cooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08_ooooo00?o0000oooo
ooooool01Oooool001Sooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`05ooooo`00
6?ooool3o`0008[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo08Sooooo0_l00007ooooo`006?ooool00ol0003oooooooooo`29ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`28ooooo`03o`000?oo
oooooooo00Gooooo000Hooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool01Oooool0
01Sooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003o
ooooooooo`27ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`26ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo08Kooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo08Gooooo
00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0QOooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`05ooooo`006?ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00Gooooo000Hoooo
o`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo08?ooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`21ooooo`03o`00
0?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool01Ooo
ool001Sooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`05ooooo`006?ooool3o`00
07oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
07kooooo0_l00007ooooo`006?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Go
oooo000Hooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool01Oooool001Sooooo00?o
0000ooooooooool0OOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool0O?ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0003oooooooooo`1l
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1k
ooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo07_ooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo07_ooooo00?o0000oooo
ooooool01Oooool001Sooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`05ooooo`00
6?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oo
oooooooo07Sooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo07Sooooo00?o0000ooooooooool01Oooool001Sooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0Moooool0
0ol0003oooooooooo`05ooooo`003Oooool00ooWinOod=3@ooKfmP08ooooo`03o`000?oooooooooo
07Oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07Oooooo00?o0000ooooooooool01Oooool000_ooooo00Ko_;blob4Q8Ol10@7o2@T9o`h>3_nOWil7
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`05
ooooo`002oooool01onXZ:SoWIfMon[Zj_ofm_KoS8b<o`@41?oGemL01_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`05ooooo`003oooool00oomoOgo5aLGoijNWP06ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`09ooooo`;o00003Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo0_l0000<ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`05ooooo`003oooool00ooRh^;o0`<3olk>cP06oooo
oooo0000T_l00007ooooo`003Oooool01?o`l?3oL71`oa@D5?mhN7Sooooooj3ooooo000=ooooo`04
ooGemOmkNg_o9BDUok:b/_ooooooX?ooool000oooooo00?o_[jnoa8B4_omoOd0oooooonOooooo`00
3oooool00onl_;co30`<ooGem@3ooooooioooooo000;ooooo`06ono_kolO7aooOGemojRXZ?lf=SKo
IFEUoooooonPooooo`003?ooool01Oo<c<coNg]koeIFE_nMWIgol?3`0?ooooooX?ooool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {358.875, 0}} -> {-3.36839, -2.27735, \
0.0224807, 0.0224807}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell["A Moebius strip inscribed with text and oriented contour:", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Geometry`Rotations`\>"];\)\), "\[IndentingNewLine]", 
    \(\(PlotCurveOnSurface3D[{Join[
            Geometry`Rotations`Rotate3D[
              Geometry`Rotations`Rotate3D[{0, 1, \(-u\)}, 0, \(-\[Phi]\)/2, 
                0, {0, 1, 0}], \(-\[Phi]\) + Pi/2, 0, 
              0], {SurfaceColor[Khaki]}], {u, \(-1\)/2, 1/2}, {\[Phi], 0, 
            2  \[Pi]}, PlotPoints \[Rule] {2, 61}, Oriented \[Rule] True, 
          ContourStyle \[Rule] {{None}, {Green}, {None}, {Green}}, 
          HowManyArrows \[Rule] {0, 3, 0, 3}, 
          ReverseOrientation \[Rule] {True, False, True, True}}, 
        Graphics[{Thickness[ .005], 
            Text["\<Moebius strip\>", {0, \[Pi]}, {1/2, 1/2}, {0, 1}]}], 
        Evaluate@
          NeutralLighting[0.4, 0.5, \ 
            0.5], \[IndentingNewLine]Background \[Rule] LightBlue, 
        Boxed \[Rule] False, Axes \[Rule] False, 
        ViewPoint -> {0.757, \ 2.580, \ 2.054}, 
        ViewPoint -> {0.910, \ 2.530, \ 2.054}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Trig Interpolation curves",
  FontColor->RGBColor[1, 0, 0]]], "Subsubtitle"],

Cell[TextData[{
  "I have written some utilities to help me draw pictures of \
\"generic-looking\" smooth functions or curves in the plane, and blob-like \
shapes. I was not satisfied with ",
  Cell[BoxData[
      FormBox[
        ButtonBox["Graphics`Spline",
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  ", because that way you can just spot the junctions, even if they are \
technically smooth. So I turned to trigonometric functions instead of \
polynomials to see what happened."
}], "Text"],

Cell[CellGroupData[{

Cell["TrigInterpolation parametric curves in the plane", "Section"],

Cell[TextData[{
  "The basic function is ",
  StyleBox["TrigInterpolationParametricPlot", "Input",
    Background->RGBColor[1, 1, 0]],
  ", which takes a list of points and connects them with a curve:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["TrigInterpolationParametricPlot",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Just for checking, let us see the points through with we interpolate, with \
the option ",
  StyleBox["ShowListPlot", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(TrigInterpolationParametricPlot[{{0, 0}, {1, 1}, {3, 0}, {1, 0}} // 
          N, ShowListPlot \[Rule] True];\)\)], "Input"],

Cell[TextData[{
  "To every interpolation point ",
  StyleBox["{x,y}", "Input"],
  " you can impose a velocity vector ",
  StyleBox["{vx,vy}", "Input"],
  ", a second order derivative vector ",
  StyleBox["{ax,ay}", "Input"],
  ", etc., by writing ",
  StyleBox["{{x,y},{vx,vy},{ax,ay}...}", "Input"],
  " instead of ",
  StyleBox["{x,y}", "Input"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                StyleBox[\({{0, 0}, {\(-1\), 0}}\),
                  FontColor->RGBColor[1, 0, 0]], ",", \({1, 1}\), 
                ",", \({3, 0}\), ",", \({1, 0}\)}], "}"}], "//", "N"}], 
          ",", \(ShowListPlot \[Rule] True\), ",", \(Frame \[Rule] True\), 
          ",", \(Axes \[Rule] False\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Trig functions are periodic. Hence they are specially suited to make \
closed curves (loops). You get that with the option ",
  StyleBox["ClosedCurve", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), ",", 
          StyleBox[\(ClosedCurve \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can change the appearace of the curve with ",
  StyleBox["PlotStyle", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), ",", 
          StyleBox[\(PlotStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), 
          ",", \(ClosedCurve \[Rule] True\), ",", \(Axes \[Rule] False\), ",",
           
          StyleBox[\(PlotStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The option ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " adds arrows to the curve:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), 
          ",", \(ClosedCurve \[Rule] True\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], ",", \(Axes \[Rule] None\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can fill the closed curve with ",
  StyleBox["FilledClosedCurve", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(TrigInterpolationParametricPlot[{{0, 0}, {1, 1}, {2, 0}, {1, 0}} // 
          N, FilledClosedCurve \[Rule] True];\)\)], "Input"],

Cell[TextData[{
  "You can use the ",
  StyleBox[ButtonBox["AxesFront"], "Input",
    Background->RGBColor[1, 1, 0]],
  " and ",
  StyleBox["Fills", "Input",
    Background->RGBColor[1, 1, 0]],
  " options from ",
  Cell[BoxData[
      FormBox[
        ButtonBox["FilledPlot",
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {2, 0}, {1, 0}} // N\), 
          ",", \(FilledClosedCurve \[Rule] True\), ",", 
          StyleBox[\(AxesFront \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], ",", 
          StyleBox[\(Fills \[Rule] AureolineYellow\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {2, 0}, {1, 0}} // N\), 
          ",", \(FilledClosedCurve \[Rule] True\), ",", 
          StyleBox[\(AxesFront \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], ",", 
          StyleBox[\(Fills \[Rule] AureolineYellow\),
            FontColor->RGBColor[1, 0, 0]], ",", \(Oriented \[Rule] True\), 
          ",", \(PlotStyle \[Rule] {Blue, Thickness[ .01]}\), 
          ",", \(HeadLength \[Rule] 1/10\)}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{{0, 0}, {0, 0}, {0, 1}}, {1, 1}, {0, 1}} // N\), 
          ",", \(FilledClosedCurve \[Rule] True\), 
          ",", \(ShowListPlot \[Rule] True\), ",", 
          StyleBox[\(AxesFront \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[\(Fills \[Rule] CornflowerBlue\),
            FontColor->RGBColor[1, 0, 0]], 
          ",", \(PlotStyle \[Rule] {OrangeRed, Dashing[{ .01,  .02}], 
              Thickness[ .01]}\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "With ",
  StyleBox["ListPlotStyle", "Input",
    Background->RGBColor[1, 1, 0]],
  " you can decide the look of the interpolation points:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), 
          ",", \(ClosedCurve \[Rule] True\), ",", \(Oriented \[Rule] True\), 
          ",", \(HowManyArrows \[Rule] 3\), ",", 
          StyleBox[\(ShowListPlot \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], ",", 
          StyleBox[\(ListPlotStyle \[Rule] {Red, PointSize[ .04]}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "TrigInterpolation relies on ",
  ButtonBox["LinearSolve",
    ButtonStyle->"RefGuideLink"],
  " to give a solution to an under-determined linear system. Sometimes the \
default behaviour of ",
  ButtonBox["LinearSolve",
    ButtonStyle->"RefGuideLink"],
  " gives unpleasant results:"
}], "Text"],

Cell[BoxData[
    \(\(TrigInterpolationParametricPlot[{{{1, 1}, {0, \(-3\)}}, {2, 
              1}, {{4, 2}, {0, 2}}, {3, 7}} // N, ClosedCurve \[Rule] True, 
        ShowListPlot \[Rule] True, ListPlotStyle \[Rule] PointSize[ .03], 
        PlotRange \[Rule] All];\)\)], "Input"],

Cell[TextData[{
  "You get some control on the outcome by giving the option ",
  Cell[BoxData[
      FormBox[
        ButtonBox["Method",
          ButtonStyle->"MasterIndexLink"], TraditionalForm]],
    Background->RGBColor[1, 1, 0]],
  ", that will be passed to ",
  ButtonBox["LinearSolve",
    ButtonStyle->"RefGuideLink"],
  ". Here is an interpolation with the same starting data as the previous \
example, but solved with a different method:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{{1, 1}, {0, \(-3\)}}, {2, 1}, {{4, 2}, {0, 2}}, {3, 7}} // 
            N\), ",", \(ClosedCurve \[Rule] True\), 
          ",", \(ShowListPlot \[Rule] True\), 
          ",", \(ListPlotStyle \[Rule] PointSize[ .03]\), 
          ",", \(PlotRange \[Rule] All\), ",", 
          StyleBox[\(Method \[Rule] DivisionFreeRowReduction\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigInterpolation parametric curves in 3D-space", "Section"],

Cell[TextData[{
  "You get interpolating curves in 3D-space just by giving ",
  StyleBox["triples",
    FontSlant->"Italic"],
  " as interpolating points:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"{", 
              StyleBox[\({0, 0, 0}, {\(-1\), 1, 1}, {0, 2, 0}, {1, 2, 0}\),
                FontColor->RGBColor[1, 0, 0]], "}"}], "//", "N"}], 
          ",", \(ShowListPlot \[Rule] True\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The option ",
  StyleBox["ClosedCurve", "Input",
    Background->RGBColor[1, 1, 0]],
  " makes, well, a closed curve:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0, 0}, {\(-1\), 1, 1}, {0, 2, 0}, {1, 2, 0}} // N\), 
          ",", 
          StyleBox[\(ClosedCurve \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], ",", \(ShowListPlot \[Rule] True\),
           ",", \(Ticks \[Rule] None\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The option ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " places an arrow along the curve, whether it is open or closed, provided \
you have ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " installed:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0, 0}, {\(-1\), 1, 1}, {0, 2, 0}, {1, 2, 0}} // N\), 
          ",", \(ClosedCurve \[Rule] True\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], ",", \(Ticks \[Rule] None\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "In 3D-space you change the style of the interpolating line with ",
  StyleBox["PlotStyle", "Input",
    Background->RGBColor[1, 1, 0]],
  ": and the position of the arrow with ",
  StyleBox["ArrowPositions", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0, 0}, {1, 1, 1}, {2, 0, 1}, {1, 0, 0}} // N\), ",", 
          StyleBox[\(PlotStyle \[Rule] Blue\),
            FontColor->RGBColor[1, 0, 0]], ",", 
          StyleBox[\(ArrowPositions \[Rule] 1\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0, 0}, {\(-1\), 1, 1}, {0, 2, 0}, {1, 2, 0}} // N\), 
          ",", \(ClosedCurve \[Rule] True\), ",", \(Oriented \[Rule] True\), 
          ",", \(HowManyArrows \[Rule] 3\), ",", \(HeadLength3D \[Rule] 1/5\),
           ",", \(Ticks \[Rule] None\), ",", 
          StyleBox[\(PlotStyle \[Rule] {Red, Thickness[ .01]}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{"TrigInterpolationParametricPlot", "[", 
      RowBox[{\({{0, 0, 0}, {0, 1, 1}, {1, 1, 1}, {1, 0, 1}}\), 
        ",", \(Oriented \[Rule] True\), 
        ",", \(ArrowPositions \[Rule] {1/2, 1}\), 
        ",", \(PlotRange \[Rule] All\), ",", 
        StyleBox[\(PlotStyle \[Rule] {Red, Thickness[ .01]}\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigInterpolation cartesian plots", "Section"],

Cell[TextData[{
  "Instead of a parametric curve in the plane, we can make a cartesian plot \
of a one-variable-to-one-variable function with ",
  StyleBox["TrigInterpolationPlot", "Input",
    Background->RGBColor[1, 1, 0]],
  ": as arguments it takes the list of points, the minimum and maximum \
x-values of the plot, and options:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["TrigInterpolationPlot",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \({{0, 0}, {1, 1}, {2, 1}} // N, \(-2\), 5, 
        ShowListPlot \[Rule] True\), "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Here the data follow the syntax ",
  Cell[BoxData[
      \(TraditionalForm\`{{x\_1, f\_1, d\ f\_1, 
          d\ d\ f\_1, \[Ellipsis]}, \[Ellipsis]}\)]],
  "  as in ",
  ButtonBox["InterpolatingPolynomial",
    ButtonStyle->"RefGuideLink"],
  ": "
}], "Text"],

Cell[BoxData[
    \(\(TrigInterpolationPlot[{{0, 0, 0}, {1, 1}, {2, 1}}, \(-2\), 5, 
        ShowListPlot \[Rule] True];\)\)], "Input"],

Cell[TextData[{
  "Here the data follow the syntax ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["{",
            "MR"], 
          RowBox[{
            RowBox[{
              StyleBox["{",
                "MR"], 
              RowBox[{
                FormBox[
                  SubscriptBox[
                    StyleBox["x",
                      "TI"], "1"],
                  "TraditionalForm"], 
                StyleBox[",",
                  "MR"], " ", 
                RowBox[{
                  StyleBox["{",
                    "MR"], 
                  RowBox[{
                    FormBox[
                      SubscriptBox[
                        StyleBox["f",
                          "TI"], "1"],
                      "TraditionalForm"], 
                    StyleBox[",",
                      "MR"], " ", 
                    FormBox[
                      SubscriptBox[
                        StyleBox["df",
                          "TI"], "1"],
                      "TraditionalForm"], 
                    StyleBox[",",
                      "MR"], " ", 
                    FormBox[
                      SubscriptBox[
                        StyleBox["ddf",
                          "TI"], "1"],
                      "TraditionalForm"], 
                    StyleBox[",",
                      "MR"], " ", "\[Ellipsis]"}], " ", 
                  StyleBox["}",
                    "MR"]}]}], 
              StyleBox["}",
                "MR"]}], 
            StyleBox[",",
              "MR"], " ", "\[Ellipsis]"}], " ", 
          StyleBox["}",
            "MR"]}], TraditionalForm]]],
  "  as in ",
  ButtonBox["Interpolation",
    ButtonStyle->"RefGuideLink"],
  ": "
}], "Text"],

Cell[BoxData[
    \(\(TrigInterpolationPlot[{{0, {0, 0}}, {1, 1}, {2, 1}}, \(-2\), 5, 
        ShowListPlot \[Rule] True];\)\)], "Input"],

Cell[TextData[{
  "The option ",
  StyleBox["Period", "Input",
    Background->RGBColor[1, 1, 0]],
  " imposes the period of the interpolation function:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {2, 1}} // N\), ",", \(-4\), ",", "8", 
          ",", \(ShowListPlot \[Rule] True\), ",", 
          StyleBox[\(Period \[Rule] 10\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["\<\
Beware that some period values may be incompatible with the data.\
\
\>", "Text"],

Cell[BoxData[
    \(TrigInterpolationPlot[{{1, 1}, {2, 2}}, 0, 4, 
      Period \[Rule] 1]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\"Drawing paper\" companions", "Section"],

Cell[TextData[{
  "There are also the ",
  ButtonBox["Draw",
    ButtonStyle->"AddOnsLink"],
  " parallels to the ",
  StyleBox["Plot", "Input"],
  " commands:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Draw2D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"Red", ",", 
                  RowBox[{
                    StyleBox["TrigInterpolationParametricDraw",
                      FontColor->RGBColor[1, 0, 0]], 
                    "[", \({{1, 1}, {2, 0}, {4, 1}} // N, 
                    ClosedCurve \[Rule] True\), "]"}]}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"SapGreen", ",", 
                  RowBox[{
                    StyleBox["TrigInterpolationDraw",
                      FontColor->RGBColor[1, 0, 0]], 
                    "[", \({{0, \(-1\)}, {1, 0}, {2, 1}} // N, \(-1\), 5\), 
                    "]"}]}], "}"}], 
              ",", \({Blue, PointSize[ .03], Point[{2, 1}]}\), ",", 
              RowBox[{
                StyleBox["TrigInterpolationParametricDraw",
                  FontColor->RGBColor[1, 0, 0]], 
                "[", \({{{0, 0}, {0, 1}/5}, {{1, 1}, {2, \(-1\)}/2}} // N, 
                Oriented \[Rule] True, ArrowPositions \[Rule] 1, 
                HeadLength \[Rule] 1/15\), "]"}], 
              ",", \(Text[Here, {0, 0}, {0, 1}]\)}], "}"}], 
          ",", \(PlotRange \[Rule] All\), 
          ",", \(Background \[Rule] PaleTurquoise\)}], "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigInterpolation formulas", "Section"],

Cell[TextData[{
  "Are you curious to see the trigonometric functions whose graph you are \
plotting? Use the ",
  StyleBox["ShowFormula", "Input",
    Background->RGBColor[1, 1, 0]],
  " option: the ouput will become a list of the form ",
  Cell[BoxData[
      \(TraditionalForm\`{\[SkeletonIndicator]Graphics\[SkeletonIndicator], 
        formula}\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{"TrigInterpolationParametricPlot", "[", 
      RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), 
        ",", \(ClosedCurve \[Rule] True\), ",", 
        StyleBox[\(ShowFormula \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]], ",", \(Oriented \[Rule] True\), 
        ",", \(HowManyArrows \[Rule] 3\), ",", \(Axes \[Rule] None\)}], 
      "]"}]], "Input"],

Cell[TextData[{
  "From ",
  StyleBox["exact",
    FontSlant->"Italic"],
  " starting points you get an ",
  StyleBox["exact",
    FontSlant->"Italic"],
  " formula. Beware that the time and memory needed to calculate (and to \
display) an exact interpolation formula can be substantial:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["TrigInterpolationPlot",
        FontColor->RGBColor[1, 0, 0]], "[", 
      RowBox[{\({{0, 0}, {1, 1}, {2, 1}}\), ",", \(-2\), ",", "5", ",", 
        StyleBox[\(ShowFormula \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[TextData[{
  "You can get the formulas alone, without plotting, with the commands ",
  StyleBox["TrigInterpolation", "Input",
    Background->RGBColor[1, 1, 0]],
  " and ",
  StyleBox["ParametricTrigInterpolation", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[{\(Clear[t];\), "\[IndentingNewLine]", 
    RowBox[{
      StyleBox["TrigInterpolation",
        FontColor->RGBColor[1, 0, 0]], "[", 
      RowBox[{\({{0, 0}, {1, 1}, {2, 1}}\), ",", 
        StyleBox["t",
          FontColor->RGBColor[1, 0, 0]]}], "]"}]}], "Input"],

Cell[BoxData[{\(Clear[t];\), "\[IndentingNewLine]", 
    RowBox[{
      StyleBox["ParametricTrigInterpolation",
        FontColor->RGBColor[1, 0, 0]], "[", \({{0, 0}, {1, 1}, {2, 1}}, t\), 
      "]"}]}], "Input"],

Cell[TextData[{
  "If you set the option ",
  StyleBox["ShowTimesListQ->True", "Input",
    Background->RGBColor[1, 1, 0]],
  " you will also get the list of times the parametric curve passes through \
the given points. You may need this for further processing:"
}], "Text"],

Cell[BoxData[
    RowBox[{"TrigInterpolationParametricPlot", "[", 
      RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), 
        ",", \(ClosedCurve \[Rule] True\), ",", 
        StyleBox[\(ShowFormula \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]], ",", 
        StyleBox[\(ShowTimesListQ \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]], ",", \(Oriented \[Rule] True\), 
        ",", \(HowManyArrows \[Rule] 3\), ",", \(Axes \[Rule] None\), 
        ",", \(ShowListPlot \[Rule] True\)}], "]"}]], "Input"],

Cell[TextData[{
  "You can try to get an interpolating formula with a different period from \
the default by setting the option ",
  StyleBox["Period", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[{\(Clear[t];\), "\[IndentingNewLine]", 
    RowBox[{"TrigInterpolation", "[", 
      RowBox[{\({{0, 0}, {1, 1}, {2, 1}}\), ",", "t", ",", 
        StyleBox[\(Period \[Rule] 10\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]}], "Input"],

Cell[TextData[{
  "Of course you can ",
  ButtonBox["Simplify",
    ButtonStyle->"RefGuideLink"],
  " the output formula, but then the trigonometric functions may not be \
nicely collected any more. To simplify the coefficients only, instead of the \
formula as a whole, try the option ",
  StyleBox["EvaluateOnCoefficients", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[{\(Clear[t];\), "\[IndentingNewLine]", 
    RowBox[{"TrigInterpolation", "[", 
      RowBox[{\({{0, 0}, {1, 1}, {2, 1}}\), ",", "t", 
        ",", \(Period \[Rule] 10\), ",", 
        StyleBox[\(EvaluateOnCoefficients \[Rule] FullSimplify\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]}], "Input"],

Cell[TextData[{
  "A plane curve given by trigonometric interpolation is always the zero set \
of a two-variable polynomial. The function ",
  StyleBox["PolynomialLevelSetTrigInterpolation", "Input",
    Background->RGBColor[1, 1, 0]],
  " gives both the curve and the polynomial:"
}], "Text"],

Cell[BoxData[
    \(PolynomialLevelSetTrigInterpolation[{{0, 0}, {2, 0}, {1, 1}}, t, x, y, 
      ClosedCurve \[Rule] False]\)], "Input"],

Cell[BoxData[
    \(PolynomialLevelSetTrigInterpolation[{{0, 0}, {2, 0}, {1, 1}}, t, x, y, 
      ClosedCurve \[Rule] True]\)], "Input"],

Cell["\<\
This picture shows that the starting points (in red) do lie on a \
level set (contour) of the polynomial:\
\>", "Text"],

Cell[BoxData[{
    \(\(pts = {{0, 0}, {2, 0}, {1, 1}, {0, 1}};\)\), "\[IndentingNewLine]", 
    \({c, poly} = 
      PolynomialLevelSetTrigInterpolation[pts, t, x, y, 
        ClosedCurve \[Rule] True]\)}], "Input"],

Cell[BoxData[
    \(\(Draw2D[{\[IndentingNewLine]ContourDraw[
            ArcTan[poly], {x, \(-1\), 3}, {y, \(-1\), 3}, 
            Contours \[Rule] 
              ArcTan[{\(-10\), \(-5\), \(-2\), \(-1\), \(-1\)/2, \(-1\)/
                    8, \(-1\)/16, 0, 1/2, 1, 320/256, 343/256}], 
            PlotPoints \[Rule] 33], \[IndentingNewLine]PointSize[ .02], Red, 
          ListDraw[pts]}, \[IndentingNewLine]AspectRatio \[Rule] Automatic, 
        Frame \[Rule] True];\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1440}, {0, 934}},
AutoGeneratedPackage->"False",
WindowSize->{1162, 912},
WindowMargins->{{40, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 31, 0, 132, "Title"],
Cell[1810, 55, 116, 5, 71, "Subtitle"],
Cell[1929, 62, 511, 17, 47, "Text"],
Cell[2443, 81, 172, 5, 47, "Text"],
Cell[2618, 88, 699, 24, 74, "Text"],
Cell[3320, 114, 332, 8, 74, "Text"],
Cell[3655, 124, 287, 5, 73, "Text"],
Cell[3945, 131, 123, 4, 48, "Text"],
Cell[4071, 137, 62, 1, 47, "Text"],
Cell[4136, 140, 1191, 35, 151, "Text"],
Cell[5330, 177, 252, 7, 73, "Text"],
Cell[5585, 186, 422, 8, 100, "Text"],

Cell[CellGroupData[{
Cell[6032, 198, 379, 8, 28, "Input",
  CellOpen->False],
Cell[6414, 208, 566, 16, 51, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7017, 229, 64, 0, 45, "Subsubtitle"],
Cell[7084, 231, 440, 15, 73, "Text"],
Cell[7527, 248, 527, 13, 100, "Text"],
Cell[8057, 263, 107, 2, 39, "Input"],
Cell[8167, 267, 508, 14, 99, "Text"],
Cell[8678, 283, 87, 1, 39, "Input"],
Cell[8768, 286, 261, 6, 73, "Text"],
Cell[9032, 294, 61, 1, 39, "Input"],
Cell[9096, 297, 589, 9, 125, "Text"],
Cell[9688, 308, 97, 2, 39, "Input"],
Cell[9788, 312, 284, 6, 73, "Text"],
Cell[10075, 320, 1734, 26, 453, "Input"],
Cell[11812, 348, 552, 16, 73, "Text"],
Cell[12367, 366, 1438, 34, 230, "Text"],
Cell[13808, 402, 791, 13, 178, "Text"],
Cell[14602, 417, 914, 26, 100, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[15553, 448, 39, 0, 46, "Subsubtitle"],
Cell[15595, 450, 4353, 107, 827, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[19985, 562, 101, 4, 72, "Subtitle"],
Cell[20089, 568, 155, 5, 47, "Text"],

Cell[CellGroupData[{
Cell[20269, 577, 60, 0, 45, "Subsubtitle"],
Cell[20332, 579, 253, 5, 85, "Input",
  InitializationCell->True],
Cell[20588, 586, 86, 2, 39, "Input",
  InitializationCell->True],
Cell[20677, 590, 87, 2, 39, "Input",
  InitializationCell->True],
Cell[20767, 594, 494, 9, 177, "Input",
  InitializationCell->True],
Cell[21264, 605, 144, 3, 62, "Input",
  InitializationCell->True],
Cell[21411, 610, 326, 5, 85, "Input",
  InitializationCell->True],
Cell[21740, 617, 230, 4, 39, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[21995, 625, 98, 3, 53, "Subsection"],
Cell[22096, 630, 471, 7, 177, "Input",
  InitializationCell->True],
Cell[22570, 639, 266, 5, 85, "Input",
  InitializationCell->True],
Cell[22839, 646, 633, 9, 223, "Input",
  InitializationCell->True],
Cell[23475, 657, 802, 12, 269, "Input",
  InitializationCell->True],
Cell[24280, 671, 339, 5, 131, "Input",
  InitializationCell->True],
Cell[24622, 678, 378, 6, 131, "Input",
  InitializationCell->True],
Cell[25003, 686, 499, 7, 177, "Input",
  InitializationCell->True],
Cell[25505, 695, 515, 8, 177, "Input",
  InitializationCell->True],
Cell[26023, 705, 424, 7, 154, "Input",
  InitializationCell->True],
Cell[26450, 714, 366, 6, 131, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[26853, 725, 143, 4, 39, "Subsection"],
Cell[26999, 731, 373, 6, 153, "Input",
  InitializationCell->True],
Cell[27375, 739, 422, 7, 177, "Input",
  InitializationCell->True],
Cell[27800, 748, 673, 11, 268, "Input",
  InitializationCell->True],
Cell[28476, 761, 291, 5, 130, "Input",
  InitializationCell->True],
Cell[28770, 768, 243, 5, 108, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[29050, 778, 39, 0, 39, "Subsection"],
Cell[29092, 780, 324, 5, 111, "Input",
  InitializationCell->True],
Cell[29419, 787, 356, 6, 111, "Input",
  InitializationCell->True],
Cell[29778, 795, 304, 5, 111, "Input",
  InitializationCell->True],
Cell[30085, 802, 364, 6, 135, "Input",
  InitializationCell->True],
Cell[30452, 810, 458, 8, 159, "Input",
  InitializationCell->True],
Cell[30913, 820, 204, 4, 87, "Input",
  InitializationCell->True],
Cell[31120, 826, 691, 11, 207, "Input",
  InitializationCell->True],
Cell[31814, 839, 219, 4, 87, "Input",
  InitializationCell->True],
Cell[32036, 845, 272, 5, 87, "Input",
  InitializationCell->True],
Cell[32311, 852, 223, 4, 87, "Input",
  InitializationCell->True],
Cell[32537, 858, 437, 7, 135, "Input",
  InitializationCell->True],
Cell[32977, 867, 264, 5, 87, "Input",
  InitializationCell->True],
Cell[33244, 874, 280, 5, 87, "Input",
  InitializationCell->True],
Cell[33527, 881, 295, 6, 111, "Input",
  InitializationCell->True],
Cell[33825, 889, 394, 6, 135, "Input",
  InitializationCell->True],
Cell[34222, 897, 377, 6, 135, "Input",
  InitializationCell->True],
Cell[34602, 905, 392, 6, 135, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[35031, 916, 94, 3, 39, "Subsection"],
Cell[35128, 921, 400, 7, 160, "Input",
  InitializationCell->True],
Cell[35531, 930, 225, 4, 88, "Input",
  InitializationCell->True],
Cell[35759, 936, 379, 7, 160, "Input",
  InitializationCell->True],
Cell[36141, 945, 224, 4, 88, "Input",
  InitializationCell->True],
Cell[36368, 951, 99, 2, 40, "Input",
  InitializationCell->True],
Cell[36470, 955, 208, 4, 88, "Input",
  InitializationCell->True],
Cell[36681, 961, 330, 6, 136, "Input",
  InitializationCell->True],
Cell[37014, 969, 224, 4, 112, "Input",
  InitializationCell->True],
Cell[37241, 975, 95, 2, 40, "Input",
  InitializationCell->True],
Cell[37339, 979, 205, 4, 88, "Input",
  InitializationCell->True],
Cell[37547, 985, 281, 5, 112, "Input",
  InitializationCell->True],
Cell[37831, 992, 240, 4, 112, "Input",
  InitializationCell->True],
Cell[38074, 998, 488, 7, 208, "Input",
  InitializationCell->True],
Cell[38565, 1007, 332, 5, 136, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[38934, 1017, 136, 5, 39, "Subsection"],
Cell[39073, 1024, 551, 9, 177, "Input",
  InitializationCell->True],
Cell[39627, 1035, 259, 5, 85, "Input",
  InitializationCell->True],
Cell[39889, 1042, 263, 5, 85, "Input",
  InitializationCell->True],
Cell[40155, 1049, 103, 2, 39, "Input",
  InitializationCell->True],
Cell[40261, 1053, 235, 4, 85, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[40533, 1062, 47, 0, 39, "Subsection"],
Cell[40583, 1064, 339, 6, 177, "Input",
  InitializationCell->True],
Cell[40925, 1072, 254, 5, 108, "Input",
  InitializationCell->True],
Cell[41182, 1079, 276, 5, 132, "Input",
  InitializationCell->True],
Cell[41461, 1086, 278, 5, 156, "Input",
  InitializationCell->True],
Cell[41742, 1093, 314, 5, 177, "Input",
  InitializationCell->True],
Cell[42059, 1100, 312, 5, 177, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[42408, 1110, 46, 0, 39, "Subsection"],
Cell[42457, 1112, 446, 7, 154, "Input",
  InitializationCell->True],
Cell[42906, 1121, 291, 5, 108, "Input",
  InitializationCell->True],
Cell[43200, 1128, 364, 6, 131, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[43601, 1139, 100, 4, 39, "Subsection"],
Cell[43704, 1145, 594, 9, 200, "Input",
  InitializationCell->True],
Cell[44301, 1156, 212, 4, 85, "Input",
  InitializationCell->True],
Cell[44516, 1162, 354, 6, 131, "Input",
  InitializationCell->True],
Cell[44873, 1170, 283, 5, 108, "Input",
  InitializationCell->True],
Cell[45159, 1177, 251, 4, 85, "Input",
  InitializationCell->True],
Cell[45413, 1183, 348, 6, 131, "Input",
  InitializationCell->True],
Cell[45764, 1191, 447, 8, 154, "Input",
  InitializationCell->True],
Cell[46214, 1201, 213, 4, 85, "Input",
  InitializationCell->True],
Cell[46430, 1207, 244, 4, 85, "Input",
  InitializationCell->True],
Cell[46677, 1213, 277, 5, 108, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[46991, 1223, 26, 0, 39, "Subsection"],
Cell[47020, 1225, 88, 2, 39, "Input",
  InitializationCell->True],
Cell[47111, 1229, 157, 3, 62, "Input",
  InitializationCell->True],
Cell[47271, 1234, 218, 4, 85, "Input",
  InitializationCell->True],
Cell[47492, 1240, 136, 3, 39, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[47677, 1249, 34, 0, 45, "Subsubtitle"],
Cell[47714, 1251, 45, 0, 47, "Text"],
Cell[47762, 1253, 177, 5, 39, "Input",
  InitializationCell->True],
Cell[47942, 1260, 126, 3, 47, "Text"],
Cell[48071, 1265, 154, 3, 39, "Input",
  InitializationCell->True],
Cell[48228, 1270, 220, 5, 47, "Text"],
Cell[48451, 1277, 1051, 20, 292, "Input",
  InitializationCell->True],
Cell[49505, 1299, 32, 0, 47, "Text"],
Cell[49540, 1301, 141, 3, 39, "Input",
  InitializationCell->True],
Cell[49684, 1306, 143, 3, 47, "Text"],
Cell[49830, 1311, 337, 6, 85, "Input",
  InitializationCell->True],
Cell[50170, 1319, 136, 3, 39, "Input",
  InitializationCell->True],
Cell[50309, 1324, 3502, 64, 959, "Input",
  InitializationCell->True],
Cell[53814, 1390, 59, 0, 48, "Text"],
Cell[53876, 1392, 211, 4, 64, "Input",
  InitializationCell->True],
Cell[54090, 1398, 90, 1, 48, "Text"],
Cell[54183, 1401, 871, 17, 208, "Input",
  InitializationCell->True],
Cell[55057, 1420, 424, 16, 75, "Text"],
Cell[55484, 1438, 271, 7, 64, "Input",
  InitializationCell->True],
Cell[55758, 1447, 748, 14, 208, "Input",
  InitializationCell->True],
Cell[56509, 1463, 164, 4, 47, "Text"],
Cell[56676, 1469, 1208, 24, 328, "Input",
  InitializationCell->True],
Cell[57887, 1495, 1491, 28, 407, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[59415, 1528, 35, 0, 46, "Subsubtitle"],
Cell[59453, 1530, 330, 6, 87, "Input",
  InitializationCell->True],
Cell[59786, 1538, 97, 2, 39, "Input",
  InitializationCell->True],
Cell[59886, 1542, 666, 13, 159, "Input",
  InitializationCell->True],
Cell[60555, 1557, 2030, 34, 567, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[62622, 1596, 45, 0, 46, "Subsubtitle"],
Cell[62670, 1598, 107, 2, 39, "Input",
  InitializationCell->True],
Cell[62780, 1602, 682, 13, 159, "Input",
  InitializationCell->True],
Cell[63465, 1617, 2179, 36, 615, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[65681, 1658, 55, 0, 46, "Subsubtitle"],
Cell[65739, 1660, 109, 2, 39, "Input",
  InitializationCell->True],
Cell[65851, 1664, 873, 15, 246, "Input",
  InitializationCell->True],
Cell[66727, 1681, 469, 9, 108, "Input",
  InitializationCell->True],
Cell[67199, 1692, 568, 12, 200, "Input",
  InitializationCell->True],
Cell[67770, 1706, 3464, 58, 913, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[71271, 1769, 43, 0, 46, "Subsubtitle"],

Cell[CellGroupData[{
Cell[71339, 1773, 51, 0, 104, "Section"],
Cell[71393, 1775, 431, 11, 102, "Text"],
Cell[71827, 1788, 617, 12, 160, "Input",
  InitializationCell->True],
Cell[72447, 1802, 367, 10, 75, "Text"],
Cell[72817, 1814, 606, 12, 184, "Input",
  InitializationCell->True],
Cell[73426, 1828, 346, 10, 75, "Text"],
Cell[73775, 1840, 384, 8, 112, "Input",
  InitializationCell->True],
Cell[74162, 1850, 310, 9, 75, "Text"],
Cell[74475, 1861, 441, 8, 136, "Input",
  InitializationCell->True],
Cell[74919, 1871, 244, 7, 75, "Text"],
Cell[75166, 1880, 361, 7, 112, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[75564, 1892, 39, 0, 57, "Section"],
Cell[75606, 1894, 255, 7, 75, "Text"],
Cell[75864, 1903, 997, 17, 328, "Input",
  InitializationCell->True],
Cell[76864, 1922, 168, 4, 48, "Text"],
Cell[77035, 1928, 85, 1, 40, "Input"],
Cell[77123, 1931, 615, 12, 160, "Input",
  InitializationCell->True],
Cell[77741, 1945, 611, 12, 160, "Input",
  InitializationCell->True],
Cell[78355, 1959, 314, 10, 75, "Text"],
Cell[78672, 1971, 249, 5, 64, "Input",
  InitializationCell->True],
Cell[78924, 1978, 247, 8, 75, "Text"],
Cell[79174, 1988, 214, 4, 64, "Input",
  InitializationCell->True],
Cell[79391, 1994, 646, 23, 102, "Text"],
Cell[80040, 2019, 106, 2, 40, "Input",
  InitializationCell->True],
Cell[80149, 2023, 584, 10, 208, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[80770, 2038, 24, 0, 57, "Section"],
Cell[80797, 2040, 87, 3, 47, "Text"],
Cell[80887, 2045, 110, 2, 39, "Input",
  InitializationCell->True],
Cell[81000, 2049, 185, 6, 73, "Text"],
Cell[81188, 2057, 668, 11, 315, "Input",
  InitializationCell->True],
Cell[81859, 2070, 660, 10, 338, "Input",
  InitializationCell->True],
Cell[82522, 2082, 65, 0, 47, "Text"],
Cell[82590, 2084, 18368, 333, 7744, "Input",
  InitializationCell->True],
Cell[100961, 2419, 61, 0, 47, "Text"],
Cell[101025, 2421, 2914, 49, 1189, "Input",
  InitializationCell->True],
Cell[103942, 2472, 110, 2, 39, "Input",
  InitializationCell->True],
Cell[104055, 2476, 593, 10, 292, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[104697, 2492, 48, 0, 46, "Subsubtitle"],
Cell[104748, 2494, 70, 0, 48, "Text"],
Cell[104821, 2496, 436, 8, 88, "Input",
  InitializationCell->True],
Cell[105260, 2506, 199, 4, 40, "Input",
  InitializationCell->True],
Cell[105462, 2512, 161, 3, 40, "Input",
  InitializationCell->True],
Cell[105626, 2517, 115, 3, 48, "Text"],
Cell[105744, 2522, 148, 3, 40, "Input",
  InitializationCell->True],
Cell[105895, 2527, 217, 4, 40, "Input",
  InitializationCell->True],
Cell[106115, 2533, 90, 3, 48, "Text"],
Cell[106208, 2538, 203, 4, 40, "Input",
  InitializationCell->True],
Cell[106414, 2544, 1892, 32, 352, "Input",
  InitializationCell->True],
Cell[108309, 2578, 141, 3, 48, "Text"],
Cell[108453, 2583, 264, 5, 40, "Input",
  InitializationCell->True],
Cell[108720, 2590, 209, 4, 40, "Input",
  InitializationCell->True],
Cell[108932, 2596, 68, 0, 48, "Text"],
Cell[109003, 2598, 484, 9, 112, "Input",
  InitializationCell->True],
Cell[109490, 2609, 372, 8, 88, "Input",
  InitializationCell->True],
Cell[109865, 2619, 583, 11, 136, "Input",
  InitializationCell->True],
Cell[110451, 2632, 139, 3, 48, "Text"],
Cell[110593, 2637, 597, 10, 88, "Input",
  InitializationCell->True],
Cell[111193, 2649, 7251, 128, 1336, "Input",
  InitializationCell->True],
Cell[118447, 2779, 395, 8, 75, "Text"],
Cell[118845, 2789, 625, 11, 88, "Input",
  InitializationCell->True],
Cell[119473, 2802, 281, 5, 64, "Input",
  InitializationCell->True],
Cell[119757, 2809, 206, 8, 48, "Text"],
Cell[119966, 2819, 291, 5, 88, "Input",
  InitializationCell->True],
Cell[120260, 2826, 288, 5, 88, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[120585, 2836, 57, 0, 46, "Subsubtitle"],
Cell[120645, 2838, 261, 4, 88, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[120943, 2847, 37, 0, 46, "Subsubtitle"],
Cell[120983, 2849, 99, 2, 39, "Input",
  InitializationCell->True],
Cell[121085, 2853, 251, 4, 87, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[121373, 2862, 42, 0, 46, "Subsubtitle"],
Cell[121418, 2864, 669, 12, 207, "Input",
  InitializationCell->True],
Cell[122090, 2878, 824, 15, 207, "Input",
  InitializationCell->True],
Cell[122917, 2895, 794, 14, 207, "Input",
  InitializationCell->True],
Cell[123714, 2911, 380, 7, 111, "Input",
  InitializationCell->True],
Cell[124097, 2920, 1613, 29, 375, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[125747, 2954, 77, 0, 46, "Subsubtitle"],
Cell[125827, 2956, 424, 15, 75, "Text"],
Cell[126254, 2973, 335, 6, 87, "Input",
  InitializationCell->True],
Cell[126592, 2981, 39, 0, 48, "Text"],
Cell[126634, 2983, 442, 7, 111, "Input",
  InitializationCell->True],
Cell[127079, 2992, 212, 5, 48, "Text"],
Cell[127294, 2999, 311, 5, 87, "Input"],
Cell[127608, 3006, 363, 7, 87, "Input",
  InitializationCell->True],
Cell[127974, 3015, 313, 5, 87, "Input"],
Cell[128290, 3022, 365, 7, 87, "Input",
  InitializationCell->True],
Cell[128658, 3031, 315, 5, 87, "Input"],
Cell[128976, 3038, 375, 7, 87, "Input",
  InitializationCell->True],
Cell[129354, 3047, 317, 5, 87, "Input"],
Cell[129674, 3054, 377, 7, 87, "Input",
  InitializationCell->True],
Cell[130054, 3063, 369, 7, 87, "Input",
  InitializationCell->True],
Cell[130426, 3072, 369, 7, 87, "Input",
  InitializationCell->True],
Cell[130798, 3081, 162, 3, 39, "Input",
  InitializationCell->True],
Cell[130963, 3086, 73, 0, 48, "Text"],
Cell[131039, 3088, 162, 2, 63, "Input"],
Cell[131204, 3092, 194, 4, 39, "Input",
  InitializationCell->True],
Cell[131401, 3098, 213, 3, 63, "Input"],
Cell[131617, 3103, 197, 4, 39, "Input",
  InitializationCell->True],
Cell[131817, 3109, 152, 3, 39, "Input",
  InitializationCell->True],
Cell[131972, 3114, 152, 3, 39, "Input",
  InitializationCell->True],
Cell[132127, 3119, 120, 3, 48, "Text"],
Cell[132250, 3124, 2885, 52, 711, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[135172, 3181, 58, 0, 46, "Subsubtitle"],
Cell[135233, 3183, 392, 7, 87, "Input",
  InitializationCell->True],
Cell[135628, 3192, 2270, 42, 471, "Input",
  InitializationCell->True],
Cell[137901, 3236, 1064, 18, 279, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[139002, 3259, 34, 0, 46, "Subsubtitle"],
Cell[139039, 3261, 118, 2, 39, "Input",
  InitializationCell->True],
Cell[139160, 3265, 64, 0, 47, "Text"],
Cell[139227, 3267, 1160, 20, 269, "Input",
  InitializationCell->True],
Cell[140390, 3289, 66, 0, 47, "Text"],
Cell[140459, 3291, 1093, 20, 246, "Input",
  InitializationCell->True],
Cell[141555, 3313, 54, 0, 47, "Text"],
Cell[141612, 3315, 1152, 23, 269, "Input",
  InitializationCell->True],
Cell[142767, 3340, 181, 3, 62, "Input",
  InitializationCell->True],
Cell[142951, 3345, 234, 5, 85, "Input",
  InitializationCell->True],
Cell[143188, 3352, 1785, 30, 499, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[145010, 3387, 32, 0, 46, "Subsubtitle"],
Cell[145045, 3389, 714, 12, 184, "Input",
  InitializationCell->True],
Cell[145762, 3403, 119, 2, 40, "Input",
  InitializationCell->True],
Cell[145884, 3407, 1133, 18, 376, "Input",
  InitializationCell->True],
Cell[147020, 3427, 6495, 115, 1744, "Input",
  InitializationCell->True],
Cell[153518, 3544, 525, 9, 136, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[154080, 3558, 40, 0, 46, "Subsubtitle"],

Cell[CellGroupData[{
Cell[154145, 3562, 48, 0, 103, "Section"],
Cell[154196, 3564, 58, 0, 48, "Text"],
Cell[154257, 3566, 130, 3, 39, "Input",
  InitializationCell->True],
Cell[154390, 3571, 132, 3, 39, "Input",
  InitializationCell->True],
Cell[154525, 3576, 123, 3, 39, "Input",
  InitializationCell->True],
Cell[154651, 3581, 142, 3, 39, "Input",
  InitializationCell->True],
Cell[154796, 3586, 61, 0, 48, "Text"],
Cell[154860, 3588, 796, 14, 231, "Input",
  InitializationCell->True],
Cell[155659, 3604, 52, 0, 48, "Text"],
Cell[155714, 3606, 179, 4, 39, "Input",
  InitializationCell->True],
Cell[155896, 3612, 144, 3, 39, "Input",
  InitializationCell->True],
Cell[156043, 3617, 133, 3, 39, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[156213, 3625, 59, 0, 58, "Section"],
Cell[156275, 3627, 154, 5, 48, "Text"],
Cell[156432, 3634, 165, 4, 39, "Input",
  InitializationCell->True],
Cell[156600, 3640, 57, 0, 48, "Text"],
Cell[156660, 3642, 139, 3, 39, "Input",
  InitializationCell->True],
Cell[156802, 3647, 64, 0, 48, "Text"],
Cell[156869, 3649, 163, 3, 39, "Input",
  InitializationCell->True],
Cell[157035, 3654, 481, 8, 135, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[157553, 3667, 54, 0, 58, "Section"],
Cell[157610, 3669, 63, 0, 48, "Text"],
Cell[157676, 3671, 157, 3, 39, "Input",
  InitializationCell->True],
Cell[157836, 3676, 155, 3, 39, "Input",
  InitializationCell->True],
Cell[157994, 3681, 180, 3, 63, "Input",
  InitializationCell->True],
Cell[158177, 3686, 223, 5, 63, "Input",
  InitializationCell->True],
Cell[158403, 3693, 197, 4, 63, "Input",
  InitializationCell->True],
Cell[158603, 3699, 207, 4, 63, "Input",
  InitializationCell->True],
Cell[158813, 3705, 178, 4, 39, "Input",
  InitializationCell->True],
Cell[158994, 3711, 178, 4, 39, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[159209, 3720, 41, 0, 58, "Section"],

Cell[CellGroupData[{
Cell[159275, 3724, 62, 1, 57, "Subsection"],
Cell[159340, 3727, 526, 10, 88, "Input",
  InitializationCell->True],
Cell[159869, 3739, 202, 5, 40, "Input",
  InitializationCell->True],
Cell[160074, 3746, 163, 3, 40, "Input",
  InitializationCell->True],
Cell[160240, 3751, 247, 5, 64, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[160524, 3761, 111, 1, 45, "Subsection"],
Cell[160638, 3764, 3007, 49, 496, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[163682, 3818, 126, 4, 45, "Subsection"],
Cell[163811, 3824, 2645, 42, 591, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[166493, 3871, 98, 1, 45, "Subsection"],
Cell[166594, 3874, 2552, 44, 591, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[169183, 3923, 143, 4, 45, "Subsection"],
Cell[169329, 3929, 2709, 45, 615, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[172075, 3979, 98, 1, 45, "Subsection"],
Cell[172176, 3982, 1731, 29, 375, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[173944, 4016, 101, 1, 45, "Subsection"],
Cell[174048, 4019, 2255, 36, 543, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[176340, 4060, 65, 1, 45, "Subsection"],
Cell[176408, 4063, 551, 10, 111, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[176996, 4078, 102, 1, 45, "Subsection"],
Cell[177101, 4081, 2563, 46, 639, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[179701, 4132, 130, 4, 45, "Subsection"],
Cell[179834, 4138, 2714, 47, 615, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[182609, 4192, 48, 0, 46, "Subsubtitle"],

Cell[CellGroupData[{
Cell[182682, 4196, 47, 0, 103, "Section"],
Cell[182732, 4198, 26, 0, 48, "Text"],
Cell[182761, 4200, 912, 16, 207, "Input",
  InitializationCell->True],
Cell[183676, 4218, 47, 0, 48, "Text"],
Cell[183726, 4220, 1742, 30, 471, "Input",
  InitializationCell->True],
Cell[185471, 4252, 248, 5, 63, "Input",
  InitializationCell->True],
Cell[185722, 4259, 68, 0, 48, "Text"],
Cell[185793, 4261, 2562, 47, 615, "Input",
  InitializationCell->True],
Cell[188358, 4310, 99, 3, 48, "Text"],
Cell[188460, 4315, 2694, 50, 639, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[191191, 4370, 49, 0, 57, "Section"],
Cell[191243, 4372, 37, 0, 48, "Text"],
Cell[191283, 4374, 2309, 43, 591, "Input",
  InitializationCell->True],
Cell[193595, 4419, 39, 0, 48, "Text"],
Cell[193637, 4421, 2465, 46, 615, "Input",
  InitializationCell->True],
Cell[196105, 4469, 178, 6, 48, "Text"],
Cell[196286, 4477, 183, 4, 39, "Input",
  InitializationCell->True],
Cell[196472, 4483, 439, 9, 111, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[196948, 4497, 47, 0, 57, "Section"],
Cell[196998, 4499, 53, 0, 46, "Text"],
Cell[197054, 4501, 1800, 34, 636, "Input",
  InitializationCell->True],
Cell[198857, 4537, 69, 0, 46, "Text"],
Cell[198929, 4539, 4482, 82, 1464, "Input",
  InitializationCell->True],
Cell[203414, 4623, 189, 5, 72, "Text"],
Cell[203606, 4630, 369, 7, 130, "Input",
  InitializationCell->True],
Cell[203978, 4639, 121, 6, 46, "Text"],
Cell[204102, 4647, 422, 8, 153, "Input",
  InitializationCell->True],
Cell[204527, 4657, 474, 8, 153, "Input",
  InitializationCell->True],
Cell[205004, 4667, 582, 10, 199, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[205623, 4682, 57, 0, 57, "Section"],
Cell[205683, 4684, 250, 5, 75, "Text"],
Cell[205936, 4691, 155, 3, 39, "Input",
  InitializationCell->True],
Cell[206094, 4696, 229, 4, 87, "Input",
  InitializationCell->True],
Cell[206326, 4702, 1865, 33, 519, "Input",
  InitializationCell->True],
Cell[208194, 4737, 1667, 30, 495, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[209910, 4773, 39, 0, 46, "Subsubtitle"],
Cell[209952, 4775, 109, 2, 39, "Input",
  InitializationCell->True],
Cell[210064, 4779, 214, 4, 63, "Input",
  InitializationCell->True],
Cell[210281, 4785, 166, 3, 39, "Input",
  InitializationCell->True],
Cell[210450, 4790, 502, 9, 135, "Input",
  InitializationCell->True],
Cell[210955, 4801, 538, 9, 111, "Input",
  InitializationCell->True],
Cell[211496, 4812, 10824, 189, 2415, "Input",
  InitializationCell->True],
Cell[222323, 5003, 107, 2, 39, "Input",
  InitializationCell->True],
Cell[222433, 5007, 552, 9, 159, "Input",
  InitializationCell->True],
Cell[222988, 5018, 166, 3, 39, "Input",
  InitializationCell->True],
Cell[223157, 5023, 452, 9, 135, "Input",
  InitializationCell->True],
Cell[223612, 5034, 326, 5, 87, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[223975, 5044, 41, 0, 46, "Subsubtitle"],
Cell[224019, 5046, 111, 2, 40, "Input",
  InitializationCell->True],
Cell[224133, 5050, 787, 13, 208, "Input",
  InitializationCell->True],
Cell[224923, 5065, 170, 3, 64, "Input",
  InitializationCell->True],
Cell[225096, 5070, 10087, 180, 2656, "Input",
  InitializationCell->True],
Cell[235186, 5252, 460, 8, 160, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[235683, 5265, 34, 0, 46, "Subsubtitle"],
Cell[235720, 5267, 101, 2, 39, "Input",
  InitializationCell->True],
Cell[235824, 5271, 711, 12, 183, "Input",
  InitializationCell->True],
Cell[236538, 5285, 408, 8, 111, "Input",
  InitializationCell->True],
Cell[236949, 5295, 194, 4, 63, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[237180, 5304, 31, 0, 46, "Subsubtitle"],
Cell[237214, 5306, 71, 2, 39, "Input",
  InitializationCell->True],
Cell[237288, 5310, 83, 2, 39, "Input",
  InitializationCell->True],
Cell[237374, 5314, 78, 2, 39, "Input",
  InitializationCell->True],
Cell[237455, 5318, 86, 2, 39, "Input",
  InitializationCell->True],
Cell[237544, 5322, 85, 2, 39, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[237678, 5330, 40, 0, 72, "Subtitle"],
Cell[237721, 5332, 44, 0, 47, "Text"],
Cell[237768, 5334, 226, 5, 42, "Input"],
Cell[237997, 5341, 42, 0, 47, "Text"],
Cell[238042, 5343, 252, 5, 39, "Input"],
Cell[238297, 5350, 41, 0, 47, "Text"],
Cell[238341, 5352, 273, 6, 61, "Input"],
Cell[238617, 5360, 159, 5, 47, "Text"],
Cell[238779, 5367, 276, 6, 42, "Input"],
Cell[239058, 5375, 94, 3, 47, "Text"],
Cell[239155, 5380, 853, 20, 139, "Input"],
Cell[240011, 5402, 93, 3, 47, "Text"],
Cell[240107, 5407, 723, 17, 221, "Input"],
Cell[240833, 5426, 59, 0, 47, "Text"],
Cell[240895, 5428, 376, 10, 75, "Input"],
Cell[241274, 5440, 58, 0, 47, "Text"],
Cell[241335, 5442, 692, 19, 115, "Input"],
Cell[242030, 5463, 99, 3, 47, "Text"],
Cell[242132, 5468, 267, 8, 89, "Input"],
Cell[242402, 5478, 222, 7, 47, "Text"],
Cell[242627, 5487, 208, 6, 42, "Input"],
Cell[242838, 5495, 249, 8, 47, "Text"],
Cell[243090, 5505, 335, 8, 42, "Input"],
Cell[243428, 5515, 60, 0, 47, "Text"],
Cell[243491, 5517, 672, 13, 154, "Input"],
Cell[244166, 5532, 51, 0, 47, "Text"],
Cell[244220, 5534, 567, 11, 117, "Input"],
Cell[244790, 5547, 332, 10, 55, "Text"],
Cell[245125, 5559, 344, 8, 97, "Input"],
Cell[245472, 5569, 319, 9, 55, "Text"],
Cell[245794, 5580, 314, 7, 99, "Input"],
Cell[246111, 5589, 255, 8, 47, "Text"],
Cell[246369, 5599, 382, 8, 64, "Input"],
Cell[246754, 5609, 44, 0, 47, "Text"],
Cell[246801, 5611, 303, 7, 62, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[247141, 5623, 37, 0, 72, "Subtitle"],
Cell[247181, 5625, 106, 3, 47, "Text"],

Cell[CellGroupData[{
Cell[247312, 5632, 235, 7, 45, "Subsubtitle"],
Cell[247550, 5641, 350, 12, 75, "Text"],
Cell[247903, 5655, 221, 5, 46, "Input"],
Cell[248127, 5662, 404, 10, 102, "Text"],
Cell[248534, 5674, 348, 7, 64, "Input"],
Cell[248885, 5683, 437, 12, 102, "Text"],
Cell[249325, 5697, 348, 7, 64, "Input"],
Cell[249676, 5706, 141, 3, 48, "Text"],
Cell[249820, 5711, 151, 2, 64, "Input"],
Cell[249974, 5715, 41, 0, 48, "Text"],
Cell[250018, 5717, 199, 3, 64, "Input"],
Cell[250220, 5722, 421, 11, 102, "Text"],
Cell[250644, 5735, 361, 7, 64, "Input"],
Cell[251008, 5744, 213, 6, 48, "Text"],
Cell[251224, 5752, 305, 6, 64, "Input"],
Cell[251532, 5760, 62, 0, 48, "Text"],
Cell[251597, 5762, 936, 25, 64, "Input"],
Cell[252536, 5789, 1131, 27, 88, "Input"],
Cell[253670, 5818, 268, 10, 48, "Text"],
Cell[253941, 5830, 1019, 22, 136, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[254997, 5857, 256, 7, 46, "Subsubtitle"],
Cell[255256, 5866, 319, 9, 75, "Text"],
Cell[255578, 5877, 272, 6, 40, "Input"],
Cell[255853, 5885, 411, 10, 102, "Text"],
Cell[256267, 5897, 306, 6, 64, "Input"],
Cell[256576, 5905, 777, 19, 156, "Text"],
Cell[257356, 5926, 307, 6, 64, "Input"],
Cell[257666, 5934, 463, 12, 102, "Text"],
Cell[258132, 5948, 319, 6, 64, "Input"],
Cell[258454, 5956, 252, 9, 48, "Text"],
Cell[258709, 5967, 146, 2, 64, "Input"],
Cell[258858, 5971, 546, 12, 102, "Text"],
Cell[259407, 5985, 304, 6, 64, "Input"],
Cell[259714, 5993, 101, 3, 48, "Text"],
Cell[259818, 5998, 482, 10, 64, "Input"],
Cell[260303, 6010, 555, 18, 102, "Text"],
Cell[260861, 6030, 339, 7, 64, "Input"],
Cell[261203, 6039, 193, 6, 48, "Text"],
Cell[261399, 6047, 140, 2, 40, "Input"],
Cell[261542, 6051, 224, 6, 75, "Text"],
Cell[261769, 6059, 314, 6, 64, "Input"],
Cell[262086, 6067, 600, 17, 102, "Text"],
Cell[262689, 6086, 1084, 27, 88, "Input"],
Cell[263776, 6115, 33, 0, 48, "Text"],
Cell[263812, 6117, 132, 2, 40, "Input"],
Cell[263947, 6121, 47, 0, 48, "Text"],
Cell[263997, 6123, 1114, 25, 136, "Input"],
Cell[265114, 6150, 43, 0, 48, "Text"],
Cell[265160, 6152, 900, 16, 280, "Input"],
Cell[266063, 6170, 308, 10, 75, "Text"],
Cell[266374, 6182, 880, 20, 136, "Input"],
Cell[267257, 6204, 45, 0, 48, "Text"],
Cell[267305, 6206, 1240, 26, 232, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[268582, 6237, 246, 7, 46, "Subsubtitle"],
Cell[268831, 6246, 393, 13, 75, "Text"],
Cell[269227, 6261, 271, 6, 40, "Input"],
Cell[269501, 6269, 346, 10, 75, "Text"],
Cell[269850, 6281, 305, 6, 64, "Input"],
Cell[270158, 6289, 400, 9, 64, "Input"],
Cell[270561, 6300, 496, 13, 102, "Text"],
Cell[271060, 6315, 324, 6, 64, "Input"],
Cell[271387, 6323, 160, 5, 48, "Text"],
Cell[271550, 6330, 380, 7, 64, "Input"],
Cell[271933, 6339, 249, 6, 75, "Text"],
Cell[272185, 6347, 632, 13, 88, "Input"],
Cell[272820, 6362, 178, 5, 48, "Text"],
Cell[273001, 6369, 618, 12, 88, "Input"],
Cell[273622, 6383, 225, 6, 48, "Text"],
Cell[273850, 6391, 422, 10, 64, "Input"],
Cell[274275, 6403, 75, 0, 48, "Text"],
Cell[274353, 6405, 290, 5, 88, "Input"],
Cell[274646, 6412, 51, 0, 48, "Text"],
Cell[274700, 6414, 524, 11, 88, "Input"],
Cell[275227, 6427, 180, 5, 48, "Text"],
Cell[275410, 6434, 336, 6, 64, "Input"],
Cell[275749, 6442, 73, 0, 48, "Text"],
Cell[275825, 6444, 365, 8, 64, "Input"],
Cell[276193, 6454, 556, 13, 64, "Input"],
Cell[276752, 6469, 152, 5, 48, "Text"],
Cell[276907, 6476, 398, 10, 40, "Input"],
Cell[277308, 6488, 432, 10, 64, "Input"],
Cell[277743, 6500, 192, 5, 48, "Text"],
Cell[277938, 6507, 543, 13, 40, "Input"],
Cell[278484, 6522, 791, 17, 156, "Text"],
Cell[279278, 6541, 194, 7, 48, "Text"],
Cell[279475, 6550, 1451, 29, 280, "Input"],
Cell[280929, 6581, 35, 0, 48, "Text"],
Cell[280967, 6583, 27, 0, 48, "Text"],
Cell[280997, 6585, 309, 5, 88, "Input"],
Cell[281309, 6592, 34, 0, 48, "Text"],
Cell[281346, 6594, 441, 7, 112, "Input"],
Cell[281790, 6603, 52, 0, 48, "Text"],
Cell[281845, 6605, 456, 8, 136, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[282338, 6618, 286, 9, 46, "Subsubtitle"],
Cell[282627, 6629, 312, 10, 75, "Text"],
Cell[282942, 6641, 274, 6, 40, "Input"],
Cell[283219, 6649, 148, 5, 48, "Text"],
Cell[283370, 6656, 309, 6, 64, "Input"],
Cell[283682, 6664, 333, 6, 64, "Input"],
Cell[284018, 6672, 568, 17, 102, "Text"],
Cell[284589, 6691, 308, 6, 64, "Input"],
Cell[284900, 6699, 279, 7, 75, "Text"],
Cell[285182, 6708, 316, 6, 64, "Input"],
Cell[285501, 6716, 202, 5, 48, "Text"],
Cell[285706, 6723, 148, 2, 64, "Input"],
Cell[285857, 6727, 122, 3, 48, "Text"],
Cell[285982, 6732, 140, 2, 39, "Input"],
Cell[286125, 6736, 173, 3, 39, "Input"],
Cell[286301, 6741, 379, 9, 75, "Text"],
Cell[286683, 6752, 283, 6, 39, "Input"],
Cell[286969, 6760, 218, 6, 48, "Text"],
Cell[287190, 6768, 325, 6, 39, "Input"],
Cell[287518, 6776, 187, 4, 48, "Text"],
Cell[287708, 6782, 371, 8, 39, "Input"],
Cell[288082, 6792, 726, 18, 129, "Text"],
Cell[288811, 6812, 334, 6, 63, "Input"],
Cell[289148, 6820, 166, 5, 48, "Text"],
Cell[289317, 6827, 307, 6, 39, "Input"],
Cell[289627, 6835, 65, 0, 48, "Text"],
Cell[289695, 6837, 161, 3, 40, "Input"],
Cell[289859, 6842, 157, 5, 48, "Text"],
Cell[290019, 6849, 343, 7, 64, "Input"],
Cell[290365, 6858, 270, 11, 48, "Text"],
Cell[290638, 6871, 349, 7, 64, "Input"],
Cell[290990, 6880, 62, 0, 48, "Text"],
Cell[291055, 6882, 577, 13, 64, "Input"],
Cell[291635, 6897, 37, 0, 48, "Text"],
Cell[291675, 6899, 511, 11, 64, "Input"],
Cell[292189, 6912, 255, 8, 48, "Text"],
Cell[292447, 6922, 118, 2, 40, "Input"],
Cell[292568, 6926, 138, 2, 40, "Input"],
Cell[292709, 6930, 171, 5, 48, "Text"],
Cell[292883, 6937, 379, 7, 64, "Input"],
Cell[293265, 6946, 165, 7, 48, "Text"],
Cell[293433, 6955, 874, 18, 160, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[294344, 6978, 286, 9, 46, "Subsubtitle"],
Cell[294633, 6989, 445, 10, 99, "Text"],
Cell[295081, 7001, 44, 0, 47, "Text"],
Cell[295128, 7003, 851, 20, 105, "Input"],
Cell[295982, 7025, 178, 6, 47, "Text"],
Cell[296163, 7033, 243, 8, 47, "Text"],
Cell[296409, 7043, 528, 12, 140, "Input"],
Cell[296940, 7057, 45, 0, 47, "Text"],
Cell[296988, 7059, 638, 15, 159, "Input"],
Cell[297629, 7076, 48, 0, 47, "Text"],
Cell[297680, 7078, 844, 22, 105, "Input"],
Cell[298527, 7102, 155, 5, 47, "Text"],
Cell[298685, 7109, 670, 15, 201, "Input"],
Cell[299358, 7126, 141, 5, 47, "Text"],
Cell[299502, 7133, 726, 16, 140, "Input"],
Cell[300231, 7151, 436, 12, 73, "Text"],
Cell[300670, 7165, 722, 17, 205, "Input"],
Cell[301395, 7184, 160, 5, 47, "Text"],
Cell[301558, 7191, 754, 17, 253, "Input"],
Cell[302315, 7210, 102, 4, 47, "Text"],
Cell[302420, 7216, 720, 15, 167, "Input"],
Cell[303143, 7233, 79, 3, 47, "Text"],
Cell[303225, 7238, 752, 16, 192, "Input"],
Cell[303980, 7256, 110, 3, 47, "Text"],
Cell[304093, 7261, 428, 10, 83, "Input"],
Cell[304524, 7273, 47, 0, 47, "Text"],
Cell[304574, 7275, 560, 12, 115, "Input"],
Cell[305137, 7289, 333, 9, 73, "Text"],
Cell[305473, 7300, 731, 16, 136, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[306241, 7321, 93, 1, 43, "Subsubtitle"],
Cell[306337, 7324, 223, 5, 73, "Text"],
Cell[306563, 7331, 134, 2, 94, "Input"],
Cell[306700, 7335, 1046, 28, 213, "Text"],
Cell[307749, 7365, 120, 3, 73, "Text"],
Cell[307872, 7370, 317, 8, 106, "Input"],
Cell[308192, 7380, 379, 10, 99, "Text"],
Cell[308574, 7392, 36, 0, 47, "Text"],
Cell[308613, 7394, 306, 8, 89, "Input"],
Cell[308922, 7404, 225, 6, 73, "Text"],
Cell[309150, 7412, 411, 10, 89, "Input"],
Cell[309564, 7424, 159, 5, 47, "Text"],
Cell[309726, 7431, 360, 7, 85, "Input"],
Cell[310089, 7440, 280, 6, 99, "Text"],
Cell[310372, 7448, 444, 9, 108, "Input"],
Cell[310819, 7459, 128, 5, 47, "Text"],
Cell[310950, 7466, 356, 7, 62, "Input"],
Cell[311309, 7475, 440, 10, 89, "Input"],
Cell[311752, 7487, 205, 6, 73, "Text"],
Cell[311960, 7495, 413, 9, 85, "Input"],
Cell[312376, 7506, 547, 20, 99, "Text"],
Cell[312926, 7528, 197, 6, 73, "Text"],
Cell[313126, 7536, 445, 9, 108, "Input"],
Cell[313574, 7547, 223, 5, 73, "Text"],
Cell[313800, 7554, 440, 9, 108, "Input"],
Cell[314243, 7565, 143, 4, 73, "Text"],
Cell[314389, 7571, 372, 8, 108, "Input"],
Cell[314764, 7581, 193, 5, 73, "Text"],
Cell[314960, 7588, 399, 8, 131, "Input"],
Cell[315362, 7598, 341, 6, 85, "Input"],
Cell[315706, 7606, 420, 8, 108, "Input"],
Cell[316129, 7616, 46, 0, 47, "Text"],
Cell[316178, 7618, 1052, 18, 451, "Input"],
Cell[317233, 7638, 189, 5, 73, "Text"],
Cell[317425, 7645, 261, 7, 73, "Text"],
Cell[317689, 7654, 633, 17, 137, "Input"],
Cell[318325, 7673, 46, 0, 47, "Text"],
Cell[318374, 7675, 1517, 32, 316, "Input"],
Cell[319894, 7709, 45, 0, 47, "Text"],
Cell[319942, 7711, 923, 25, 194, "Input"],
Cell[320868, 7738, 55, 0, 47, "Text"],
Cell[320926, 7740, 1021, 27, 217, "Input"],
Cell[321950, 7769, 230, 9, 47, "Text"],
Cell[322183, 7780, 727, 16, 175, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[322947, 7801, 101, 1, 43, "Subsubtitle"],
Cell[323051, 7804, 175, 4, 75, "Text"],
Cell[323229, 7810, 189, 8, 48, "Text"],
Cell[323421, 7820, 336, 7, 75, "Text"],
Cell[323760, 7829, 356, 8, 75, "Text"],
Cell[324119, 7839, 251, 8, 48, "Text"],
Cell[324373, 7849, 47, 0, 48, "Text"],
Cell[324423, 7851, 31, 0, 48, "Text"],
Cell[324457, 7853, 73, 1, 40, "Input"],
Cell[324533, 7856, 46, 0, 48, "Text"],
Cell[324582, 7858, 198, 6, 61, "Input"],
Cell[324783, 7866, 208, 6, 88, "Input"],
Cell[324994, 7874, 46, 0, 48, "Text"],
Cell[325043, 7876, 331, 9, 87, "Input"],
Cell[325377, 7887, 218, 8, 48, "Text"],
Cell[325598, 7897, 339, 9, 87, "Input"],
Cell[325940, 7908, 155, 3, 48, "Text"],
Cell[326098, 7913, 331, 9, 87, "Input"],
Cell[326432, 7924, 23, 0, 48, "Text"],
Cell[326458, 7926, 201, 6, 60, "Input"],
Cell[326662, 7934, 38, 0, 48, "Text"],
Cell[326703, 7936, 324, 9, 60, "Input"],
Cell[327030, 7947, 60, 0, 48, "Text"],
Cell[327093, 7949, 565, 16, 111, "Input"],
Cell[327661, 7967, 30, 0, 48, "Text"],
Cell[327694, 7969, 201, 6, 61, "Input"],
Cell[327898, 7977, 32, 0, 48, "Text"],
Cell[327933, 7979, 230, 7, 61, "Input"],
Cell[328166, 7988, 37, 0, 48, "Text"],
Cell[328206, 7990, 565, 16, 111, "Input"],
Cell[328774, 8008, 28, 0, 48, "Text"],
Cell[328805, 8010, 198, 6, 61, "Input"],
Cell[329006, 8018, 23, 0, 48, "Text"],
Cell[329032, 8020, 568, 16, 111, "Input"],
Cell[329603, 8038, 568, 16, 111, "Input"],
Cell[330174, 8056, 97, 3, 48, "Text"],
Cell[330274, 8061, 211, 6, 88, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[330522, 8072, 95, 1, 43, "Subsubtitle"],
Cell[330620, 8075, 293, 9, 48, "Text"],
Cell[330916, 8086, 208, 6, 46, "Input"],
Cell[331127, 8094, 97, 3, 48, "Text"],
Cell[331227, 8099, 232, 6, 46, "Input"],
Cell[331462, 8107, 379, 11, 75, "Text"],
Cell[331844, 8120, 278, 6, 46, "Input"],
Cell[332125, 8128, 556, 15, 102, "Text"],
Cell[332684, 8145, 273, 6, 46, "Input"],
Cell[332960, 8153, 280, 6, 46, "Input"],
Cell[333243, 8161, 149, 5, 48, "Text"],
Cell[333395, 8168, 279, 6, 46, "Input"],
Cell[333677, 8176, 782, 25, 102, "Text"],
Cell[334462, 8203, 279, 6, 46, "Input"],
Cell[334744, 8211, 374, 8, 75, "Input"],
Cell[335121, 8221, 266, 8, 75, "Text"],
Cell[335390, 8231, 290, 6, 46, "Input"],
Cell[335683, 8239, 313, 11, 48, "Text"],
Cell[335999, 8252, 331, 7, 75, "Input"],
Cell[336333, 8261, 407, 12, 75, "Text"],
Cell[336743, 8275, 276, 6, 46, "Input"],
Cell[337022, 8283, 514, 16, 75, "Text"],
Cell[337539, 8301, 312, 6, 46, "Input"],
Cell[337854, 8309, 160, 5, 48, "Text"],
Cell[338017, 8316, 318, 6, 46, "Input"],
Cell[338338, 8324, 312, 8, 75, "Text"],
Cell[338653, 8334, 311, 6, 46, "Input"],
Cell[338967, 8342, 424, 8, 75, "Input"],
Cell[339394, 8352, 356, 8, 75, "Text"],
Cell[339753, 8362, 143, 2, 46, "Input"],
Cell[339899, 8366, 226, 4, 75, "Input"],
Cell[340128, 8372, 127, 3, 48, "Text"],
Cell[340258, 8377, 124, 2, 46, "Input"],
Cell[340385, 8381, 232, 6, 75, "Text"],
Cell[340620, 8389, 201, 3, 75, "Input"],
Cell[340824, 8394, 49, 0, 48, "Text"],
Cell[340876, 8396, 194, 3, 64, "Input"],
Cell[341073, 8401, 242, 9, 48, "Text"],
Cell[341318, 8412, 249, 4, 64, "Input"],
Cell[341570, 8418, 148, 5, 48, "Text"],
Cell[341721, 8425, 412, 10, 64, "Input"],
Cell[342136, 8437, 207, 5, 48, "Text"],
Cell[342346, 8444, 238, 4, 97, "Input"],
Cell[342587, 8450, 49, 0, 48, "Text"],
Cell[342639, 8452, 461, 7, 147, "Input"],
Cell[343103, 8461, 192, 5, 48, "Text"],
Cell[343298, 8468, 298, 7, 40, "Input"],
Cell[343599, 8477, 418, 9, 75, "Input"],
Cell[344020, 8488, 791, 17, 156, "Text"],
Cell[344814, 8507, 244, 10, 48, "Text"],
Cell[345061, 8519, 705, 14, 156, "Input"],
Cell[345769, 8535, 1118, 29, 156, "Text"],
Cell[346890, 8566, 1398, 24, 451, "Input"],
Cell[348291, 8592, 229, 6, 75, "Text"],
Cell[348523, 8600, 1086, 19, 283, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[349646, 8624, 102, 1, 43, "Subsubtitle"],
Cell[349751, 8627, 634, 17, 102, "Text"],
Cell[350388, 8646, 164, 5, 48, "Text"],
Cell[350555, 8653, 485, 9, 87, "Input"],
Cell[351043, 8664, 297, 9, 48, "Text"],
Cell[351343, 8675, 270, 6, 39, "Input"],
Cell[351616, 8683, 166, 5, 48, "Text"],
Cell[351785, 8690, 316, 7, 39, "Input"],
Cell[352104, 8699, 269, 8, 48, "Text"],
Cell[352376, 8709, 318, 7, 39, "Input"],
Cell[352697, 8718, 241, 6, 48, "Text"],
Cell[352941, 8726, 371, 8, 63, "Input"],
Cell[353315, 8736, 157, 5, 48, "Text"],
Cell[353475, 8743, 364, 8, 39, "Input"],
Cell[353842, 8753, 160, 5, 48, "Text"],
Cell[354005, 8760, 146, 2, 39, "Input"],
Cell[354154, 8764, 425, 10, 75, "Text"],
Cell[354582, 8776, 497, 11, 63, "Input"],
Cell[355082, 8789, 192, 5, 48, "Text"],
Cell[355277, 8796, 295, 7, 39, "Input"],
Cell[355575, 8805, 791, 17, 129, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[356403, 8827, 100, 1, 43, "Subsubtitle"],
Cell[356506, 8830, 555, 17, 75, "Text"],
Cell[357064, 8849, 40, 0, 48, "Text"],
Cell[357107, 8851, 139, 3, 39, "Input"],
Cell[357249, 8856, 46, 0, 48, "Text"],
Cell[357298, 8858, 230, 4, 93, "Input"],
Cell[357531, 8864, 59, 0, 48, "Text"],
Cell[357593, 8866, 124, 2, 63, "Input"],
Cell[357720, 8870, 59, 0, 48, "Text"],
Cell[357782, 8872, 119, 2, 63, "Input"],
Cell[357904, 8876, 182, 4, 48, "Text"],
Cell[358089, 8882, 446, 11, 63, "Input"],
Cell[358538, 8895, 336, 8, 63, "Input"],
Cell[358877, 8905, 262, 10, 48, "Text"],
Cell[359142, 8917, 645, 14, 114, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[359824, 8936, 268, 7, 50, "Subsubtitle"],
Cell[360095, 8945, 355, 8, 102, "Text"],
Cell[360453, 8955, 527, 10, 136, "Input"],
Cell[360983, 8967, 237, 7, 48, "Text"],
Cell[361223, 8976, 149, 3, 40, "Input"],
Cell[361375, 8981, 182, 5, 40, "Input"],
Cell[361560, 8988, 430, 8, 102, "Text"],
Cell[361993, 8998, 149, 5, 48, "Text"],
Cell[362145, 9005, 277, 5, 64, "Input"],
Cell[362425, 9012, 227, 7, 48, "Text"],
Cell[362655, 9021, 345, 8, 64, "Input"],
Cell[363003, 9031, 384, 14, 75, "Text"],
Cell[363390, 9047, 380, 8, 64, "Input"],
Cell[363773, 9057, 167, 5, 48, "Text"],
Cell[363943, 9064, 260, 5, 64, "Input"],
Cell[364206, 9071, 43, 0, 48, "Text"],
Cell[364252, 9073, 279, 5, 64, "Input"],
Cell[364534, 9080, 66, 0, 48, "Text"],
Cell[364603, 9082, 337, 7, 64, "Input"],
Cell[364943, 9091, 71, 0, 46, "Text"],
Cell[365017, 9093, 293, 4, 84, "Input"],
Cell[365313, 9099, 179, 5, 46, "Text"],
Cell[365495, 9106, 538, 10, 108, "Input"],
Cell[366036, 9118, 546, 10, 130, "Input"],
Cell[366585, 9130, 546, 10, 130, "Input"],
Cell[367134, 9142, 838, 17, 202, "Text"],
Cell[367975, 9161, 134, 3, 72, "Text"],
Cell[368112, 9166, 433, 6, 130, "Input"],
Cell[368548, 9174, 62, 0, 46, "Text"],
Cell[368613, 9176, 70, 1, 39, "Input"],
Cell[368686, 9179, 1058, 20, 315, "Input"],
Cell[369747, 9201, 59, 0, 48, "Text"],
Cell[369809, 9203, 842, 16, 267, "Input"],
Cell[370654, 9221, 770, 15, 286, "Input"],
Cell[371427, 9238, 179, 5, 48, "Text"],
Cell[371609, 9245, 590, 11, 193, "Input"],
Cell[372202, 9258, 179, 4, 75, "Text"],
Cell[372384, 9264, 423, 9, 151, "Input"],
Cell[372810, 9275, 228, 6, 75, "Text"],
Cell[373041, 9283, 740, 17, 151, "Input"],
Cell[373784, 9302, 380, 11, 75, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[374201, 9318, 140, 4, 46, "Subsubtitle"],
Cell[374344, 9324, 141, 3, 46, "Text"],
Cell[374488, 9329, 1306, 31, 246, "Input"],
Cell[375797, 9362, 532, 9, 199, "Input"],
Cell[376332, 9373, 220, 6, 72, "Text"],
Cell[376555, 9381, 573, 13, 130, "Input"],
Cell[377131, 9396, 238, 8, 46, "Text"],
Cell[377372, 9406, 636, 14, 153, "Input"],
Cell[378011, 9422, 581, 13, 108, "Input"],
Cell[378595, 9437, 229, 5, 72, "Text"],
Cell[378827, 9444, 30, 0, 46, "Text"],
Cell[378860, 9446, 5510, 172, 153, "Input",
  Evaluatable->False],
Cell[384373, 9620, 117, 5, 46, "Text"],
Cell[384493, 9627, 594, 13, 162, "Input"],
Cell[385090, 9642, 103, 3, 46, "Text"],
Cell[385196, 9647, 608, 11, 199, "Input"],
Cell[385807, 9660, 74, 0, 46, "Text"],
Cell[385884, 9662, 967, 21, 199, "Input"],
Cell[386854, 9685, 192, 5, 46, "Text"],
Cell[387049, 9692, 197, 3, 64, "Input"],
Cell[387249, 9697, 372, 7, 87, "Input"],
Cell[387624, 9706, 791, 17, 177, "Text"],
Cell[388418, 9725, 469, 13, 99, "Text"],
Cell[388890, 9740, 1276, 27, 337, "Input"],
Cell[390169, 9769, 223, 6, 72, "Text"],
Cell[390395, 9777, 3840, 66, 1008, "Input"],
Cell[394238, 9845, 66, 1, 39, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[394341, 9851, 137, 4, 46, "Subsubtitle"],
Cell[394481, 9857, 399, 11, 72, "Text"],
Cell[394883, 9870, 364, 7, 61, "Input"],
Cell[395250, 9879, 225, 5, 72, "Text"],
Cell[395478, 9886, 5510, 172, 153, "Input",
  Evaluatable->False],
Cell[400991, 10060, 150, 5, 46, "Text"],
Cell[401144, 10067, 456, 9, 84, "Input"],
Cell[401603, 10078, 821, 18, 153, "Input"],
Cell[402427, 10098, 237, 6, 72, "Text"],
Cell[402667, 10106, 643, 15, 84, "Input"],
Cell[403313, 10123, 182, 5, 46, "Text"],
Cell[403498, 10130, 484, 10, 84, "Input"],
Cell[403985, 10142, 147, 5, 46, "Text"],
Cell[404135, 10149, 1049, 23, 153, "Input"],
Cell[405187, 10174, 50, 0, 46, "Text"],
Cell[405240, 10176, 1072, 23, 153, "Input"],
Cell[406315, 10201, 93, 3, 46, "Text"],
Cell[406411, 10206, 657, 15, 84, "Input"],
Cell[407071, 10223, 197, 5, 72, "Text"],
Cell[407271, 10230, 818, 19, 177, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[408126, 10254, 142, 4, 46, "Subsubtitle"],
Cell[408271, 10260, 260, 7, 73, "Text"],
Cell[408534, 10269, 221, 6, 69, "Text"],
Cell[408758, 10277, 207, 6, 73, "Text"],
Cell[408968, 10285, 428, 9, 108, "Input"],
Cell[409399, 10296, 176, 6, 73, "Text"],
Cell[409578, 10304, 484, 11, 85, "Input"],
Cell[410065, 10317, 96, 4, 47, "Text"],
Cell[410164, 10323, 502, 11, 108, "Input"],
Cell[410669, 10336, 179, 4, 73, "Text"],
Cell[410851, 10342, 724, 15, 108, "Input"],
Cell[411578, 10359, 728, 15, 108, "Input"],
Cell[412309, 10376, 141, 5, 47, "Text"],
Cell[412453, 10383, 534, 11, 108, "Input"],
Cell[412990, 10396, 89, 3, 47, "Text"],
Cell[413082, 10401, 355, 5, 154, "Input"],
Cell[413440, 10408, 93, 3, 47, "Text"],
Cell[413536, 10413, 263, 4, 147, "Input"],
Cell[413802, 10419, 129, 5, 47, "Text"],
Cell[413934, 10426, 495, 12, 125, "Input"],
Cell[414432, 10440, 64, 0, 47, "Text"],
Cell[414499, 10442, 225, 4, 147, "Input"],
Cell[414727, 10448, 474, 15, 99, "Text"],
Cell[415204, 10465, 408, 9, 85, "Input"],
Cell[415615, 10476, 833, 30, 151, "Text"],
Cell[416451, 10508, 128, 3, 73, "Text"],
Cell[416582, 10513, 653, 14, 108, "Input"],
Cell[417238, 10529, 111, 3, 47, "Text"],
Cell[417352, 10534, 653, 14, 108, "Input"],
Cell[418008, 10550, 307, 11, 73, "Text"],
Cell[418318, 10563, 567, 13, 108, "Input"],
Cell[418888, 10578, 329, 11, 99, "Text"],
Cell[419220, 10591, 251, 4, 108, "Input"],
Cell[419474, 10597, 200, 6, 73, "Text"],
Cell[419677, 10605, 230, 4, 85, "Input"],
Cell[419910, 10611, 842, 24, 177, "Text"],
Cell[420755, 10637, 544, 11, 108, "Input"],
Cell[421302, 10650, 130, 5, 47, "Text"],
Cell[421435, 10657, 544, 11, 108, "Input"],
Cell[421982, 10670, 631, 17, 149, "Text"],
Cell[422616, 10689, 581, 12, 108, "Input"],
Cell[423200, 10703, 110, 3, 73, "Text"],
Cell[423313, 10708, 246, 4, 108, "Input"],
Cell[423562, 10714, 510, 14, 151, "Text"],
Cell[424075, 10730, 628, 11, 262, "Input"],
Cell[424706, 10743, 47, 0, 47, "Text"],
Cell[424756, 10745, 373, 6, 154, "Input"],
Cell[425132, 10753, 145, 4, 73, "Text"],
Cell[425280, 10759, 394, 6, 177, "Input"],
Cell[425677, 10767, 477, 11, 151, "Text"],
Cell[426157, 10780, 293, 11, 73, "Text"],
Cell[426453, 10793, 1135, 20, 386, "Input"],
Cell[427591, 10815, 240, 5, 99, "Text"],
Cell[427834, 10822, 1302, 22, 520, "Input"],

Cell[CellGroupData[{
Cell[429161, 10848, 574, 9, 223, "Input"],
Cell[429738, 10859, 98703, 2669, 372, 26214, 1770, "GraphicsData", \
"PostScript", "Graphics"],
Cell[528444, 13530, 167, 4, 41, "Output"]
}, Open  ]],
Cell[528626, 13537, 73, 0, 47, "Text"],
Cell[528702, 13539, 1025, 18, 407, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[529764, 13562, 100, 1, 46, "Subsubtitle"],
Cell[529867, 13565, 510, 11, 102, "Text"],

Cell[CellGroupData[{
Cell[530402, 13580, 67, 0, 103, "Section"],
Cell[530472, 13582, 213, 5, 72, "Text"],
Cell[530688, 13589, 215, 5, 61, "Input"],
Cell[530906, 13596, 199, 6, 46, "Text"],
Cell[531108, 13604, 146, 2, 61, "Input"],
Cell[531257, 13608, 360, 11, 72, "Text"],
Cell[531620, 13621, 499, 11, 84, "Input"],
Cell[532122, 13634, 233, 6, 72, "Text"],
Cell[532358, 13642, 264, 5, 61, "Input"],
Cell[532625, 13649, 155, 5, 46, "Text"],
Cell[532783, 13656, 261, 5, 61, "Input"],
Cell[533047, 13663, 347, 7, 61, "Input"],
Cell[533397, 13672, 143, 5, 46, "Text"],
Cell[533543, 13679, 261, 5, 61, "Input"],
Cell[533807, 13686, 344, 7, 61, "Input"],
Cell[534154, 13695, 151, 5, 46, "Text"],
Cell[534308, 13702, 151, 2, 61, "Input"],
Cell[534462, 13706, 352, 13, 46, "Text"],
Cell[534817, 13721, 417, 8, 84, "Input"],
Cell[535237, 13731, 557, 10, 108, "Input"],
Cell[535797, 13743, 642, 13, 130, "Input"],
Cell[536442, 13758, 169, 5, 46, "Text"],
Cell[536614, 13765, 506, 9, 84, "Input"],
Cell[537123, 13776, 315, 9, 72, "Text"],
Cell[537441, 13787, 281, 4, 108, "Input"],
Cell[537725, 13793, 461, 12, 99, "Text"],
Cell[538189, 13807, 501, 9, 130, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[538727, 13821, 66, 0, 58, "Section"],
Cell[538796, 13823, 167, 5, 46, "Text"],
Cell[538966, 13830, 359, 8, 84, "Input"],
Cell[539328, 13840, 149, 5, 46, "Text"],
Cell[539480, 13847, 368, 7, 84, "Input"],
Cell[539851, 13856, 278, 9, 72, "Text"],
Cell[540132, 13867, 362, 7, 84, "Input"],
Cell[540497, 13876, 289, 8, 72, "Text"],
Cell[540789, 13886, 372, 7, 84, "Input"],
Cell[541164, 13895, 495, 8, 108, "Input"],
Cell[541662, 13905, 392, 7, 108, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[542091, 13917, 52, 0, 58, "Section"],
Cell[542146, 13919, 346, 7, 99, "Text"],
Cell[542495, 13928, 244, 6, 61, "Input"],
Cell[542742, 13936, 278, 9, 46, "Text"],
Cell[543023, 13947, 135, 2, 61, "Input"],
Cell[543161, 13951, 1739, 56, 46, "Text"],
Cell[544903, 14009, 137, 2, 61, "Input"],
Cell[545043, 14013, 165, 5, 46, "Text"],
Cell[545211, 14020, 309, 6, 61, "Input"],
Cell[545523, 14028, 91, 3, 46, "Text"],
Cell[545617, 14033, 103, 2, 39, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[545757, 14040, 47, 0, 58, "Section"],
Cell[545807, 14042, 172, 7, 48, "Text"],
Cell[545982, 14051, 1354, 29, 207, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[547373, 14085, 45, 0, 58, "Section"],
Cell[547421, 14087, 372, 10, 75, "Text"],
Cell[547796, 14099, 390, 7, 63, "Input"],
Cell[548189, 14108, 300, 9, 75, "Text"],
Cell[548492, 14119, 291, 6, 39, "Input"],
Cell[548786, 14127, 282, 8, 48, "Text"],
Cell[549071, 14137, 279, 6, 63, "Input"],
Cell[549353, 14145, 213, 4, 63, "Input"],
Cell[549569, 14151, 274, 6, 75, "Text"],
Cell[549846, 14159, 525, 9, 87, "Input"],
Cell[550374, 14170, 214, 6, 48, "Text"],
Cell[550591, 14178, 252, 4, 63, "Input"],
Cell[550846, 14184, 388, 10, 75, "Text"],
Cell[551237, 14196, 315, 5, 63, "Input"],
Cell[551555, 14203, 293, 6, 75, "Text"],
Cell[551851, 14211, 137, 2, 39, "Input"],
Cell[551991, 14215, 136, 2, 39, "Input"],
Cell[552130, 14219, 129, 3, 48, "Text"],
Cell[552262, 14224, 215, 4, 63, "Input"],
Cell[552480, 14230, 488, 8, 159, "Input"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

